@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -91,7 +91,7 @@ void RequestExample::categorySaveRequestHandler(QLandmarkAbstractRequest::State
 {
     if (state == QLandmarkAbstractRequest::FinishedState) {
         if (catSaveRequest->error() == QLandmarkManager::NoError) {
-            qDebug() << "Category save succesfully completed";
+            qDebug() << "Category save successfully completed";
         }
         else {
             qDebug() << "Category save was unsuccessful";
@@ -134,7 +134,7 @@ void RequestExample::landmarkSaveRequestHandler(QLandmarkAbstractRequest::State
 {
     if (state == QLandmarkAbstractRequest::FinishedState) {
         if (lmSaveRequest->error() == QLandmarkManager::NoError) {
-            qDebug() << "Landmark save succesfully completed";
+            qDebug() << "Landmark save successfully completed";
         }
         else {
             qDebug() << "Landmark save was unsuccessful";
@@ -168,7 +168,7 @@ void RequestExample::categoryFetchRequestHandler(QLandmarkAbstractRequest::State
     if (state == QLandmarkAbstractRequest::FinishedState) {
         if (catFetchRequest->error() == QLandmarkManager::NoError) {
             QList<QLandmarkCategory> categories = catFetchRequest->categories();
-            qDebug() << "Category fetch succesfully completed";
+            qDebug() << "Category fetch successfully completed";
             for(int i=0; i < categories.count(); ++i) {
                 qDebug() << categories[i].name();
             }
@@ -213,7 +213,7 @@ void RequestExample::landmarkFetchRequestHandler(QLandmarkAbstractRequest::State
     if (state == QLandmarkAbstractRequest::FinishedState) {
         previousLastIndex = 0;
         if (lmFetchRequest->error() == QLandmarkManager::NoError) {
-            qDebug() << "Landmark fetch succesfully completed";
+            qDebug() << "Landmark fetch successfully completed";
             QList<QLandmark> landmarks = lmFetchRequest->landmarks();
             for(int i=0; i < landmarks.count(); ++i) {
                 qDebug() << landmarks[i].name();
@@ -250,7 +250,7 @@ void RequestExample::categoryRemoveRequestHandler(QLandmarkAbstractRequest::Stat
 {
     if (state == QLandmarkAbstractRequest::FinishedState) {
         if (catRemoveRequest->error() == QLandmarkManager::NoError) {
-            qDebug() << "Category remove succesfully completed";
+            qDebug() << "Category remove successfully completed";
         }
         else {
             qDebug() << "Category remove was unsuccessful";
@@ -280,7 +280,7 @@ void RequestExample::landmarkRemoveRequestHandler(QLandmarkAbstractRequest::Stat
 {
     if (state == QLandmarkAbstractRequest::FinishedState) {
         if (lmRemoveRequest->error() == QLandmarkManager::NoError) {
-            qDebug() << "Landmark removal succesfully completed";
+            qDebug() << "Landmark removal successfully completed";
         }
         else {
             qDebug() << "Landmark removal was unsuccessful";
@@ -318,7 +318,7 @@ void addLandmarkAndCategory(QLandmarkManager *lmManager)
     //! [Add landmark synchronously]
 
     {
-    QLandmarkManager *landmarkManager;
+    QLandmarkManager *landmarkManager = new QLandmarkManager;
     //! [Add landmark synchronously simple]
     QLandmark monks;
     monks.setName("Monk's cafe");
@@ -345,7 +345,7 @@ void categoryFetch(QLandmarkManager *lmManager)
     //! [Retrieve categories synchronously]
 
     {
-    QLandmarkManager *landmarkManager;
+    QLandmarkManager *landmarkManager = new QLandmarkManager;
     //! [Retrieve categories synchronously simple]
     QList<QLandmarkCategory> categories = landmarkManager->categories();
     //! [Retrieve categories synchronously simple]
@@ -386,7 +386,7 @@ void landmarkFetch(QLandmarkManager *lmManager)
 
     {
 
-        QLandmarkManager *landmarkManager;
+        QLandmarkManager *landmarkManager = new QLandmarkManager;
         QLandmarkCategory category;
         //! [Retrieve landmarks by category synchronously]
         QLandmarkCategoryFilter filter;
@@ -461,7 +461,7 @@ void deleteLandmarkAndCategory(QLandmarkManager *lmManager)
     //! [Remove landmark synchronously]
 
     {
-    QLandmarkManager *landmarkManager;
+    QLandmarkManager *landmarkManager = new QLandmarkManager;
     //! [Remove landmark synchronously simple]
     landmarkManager->removeLandmark(landmark);
     //! [Remove landmark synchronously simple]
@@ -469,7 +469,7 @@ void deleteLandmarkAndCategory(QLandmarkManager *lmManager)
 }
 
 void importExportLandmark() {
-    QLandmarkManager *landmarkManager;
+    QLandmarkManager *landmarkManager = new QLandmarkManager;
     //! [ImportExport landmark simple]
     landmarkManager->importLandmarks("places.gpx");
 
@@ -532,7 +532,7 @@ void RequestExample::landmarkImportRequestHandler(QLandmarkAbstractRequest::Stat
 {
     if (state == QLandmarkAbstractRequest::FinishedState) {
         if (lmImportRequest->error() == QLandmarkManager::NoError) {
-            qDebug() << "Landmark import succesfully completed";
+            qDebug() << "Landmark import successfully completed";
         }
         else {
             qDebug() << "Landmark import was unsuccessful";
@@ -568,7 +568,7 @@ void RequestExample::landmarkExportRequestHandler(QLandmarkAbstractRequest::Stat
 {
     if (state == QLandmarkAbstractRequest::FinishedState) {
         if (lmExportRequest->error() == QLandmarkManager::NoError) {
-            qDebug() << "Landmark export succesfully completed";
+            qDebug() << "Landmark export successfully completed";
         }
         else {
             qDebug() << "Landmark export was unsuccessful";
