@@ -4,7 +4,7 @@
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the Qt Mobility Components.
+** This file is part of the examples of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:BSD$
 ** You may use this file under the terms of the BSD license as follows:
@@ -79,7 +79,7 @@ public:
 private slots:
     void includePeriodChanged(int);
     void excludePeriodEnabled(int);
-    void addressSelected(const QString&);
+    void addressSelected(int);
     void searchMessages();
     void stateChanged(QMessageService::State a);
     void messagesFound(const QMessageIdList &ids);
