@@ -4,7 +4,7 @@
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the Qt Mobility Components.
+** This file is part of the examples of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:BSD$
 ** You may use this file under the terms of the BSD license as follows:
@@ -47,6 +47,11 @@ namespace arrows{
     static const QString ARROW_UP="^", ARROW_DOWN="v", ARROW_LEFT="<",ARROW_RIGHT=">";
 }
 
+namespace orientation{
+    static const QString LANDSCAPE="landscape", PORTRAIT="portrait";
+}
+
+
 class AccelerometerFilter : public QAccelerometerFilter
 {
 public:
@@ -79,12 +84,16 @@ int main(int argc, char **argv)
         qWarning("No Accelerometer available!");
         return EXIT_FAILURE;
     }
+
+    const char* alwaysOn = "alwaysOn";
+    sensor.setProperty(alwaysOn, true);
+
     AccelerometerFilter filter;
     sensor.addFilter(&filter);
 
     qrangelist datarates = sensor.availableDataRates();
     int i = datarates.size();
-    sensor.setDataRate(datarates.at(i-1).second);
+    if (i>0) sensor.setDataRate(datarates.at(i-1).second);
     sensor.start();
 
     return app.exec();
