@@ -24,6 +24,19 @@
 #include <cntphonenumparser.h>
 #endif
 
+//max amount of contacts deleted in one go 
+const TInt KDeleteBatchSize = 400;
+
+/// Unnamed namespace for local definitions
+namespace {
+
+TBool ComparePtr( const TPtrC* aLeft, const TPtrC& aRight )
+    {
+    return ( aLeft->Compare( aRight )== 0 );
+    }
+
+} /// namespace
+
 /**
 @param aDatabase A handle to the database.
 @param aProperties A contact properties object.
@@ -231,10 +244,13 @@ void CPplCommAddrTable::CreateInDbL(CContactItem& aItem)
 					}
 				}
 			// get email addresses
-			else if (isEmail && newEmails.Find(currField.TextStorage()->Text() ) == KErrNotFound)
+			else if (isEmail)
 				{
-				DoNonPhoneWriteOpL(currField.TextStorage()->Text(), EInsert, KItemId, EEmailAddress);
-				newEmails.AppendL(currField.TextStorage()->Text() );
+				if (newEmails.Find( currField.TextStorage()->Text(), ComparePtr ) == KErrNotFound)
+					{
+					DoNonPhoneWriteOpL(currField.TextStorage()->Text(), EInsert, KItemId, EEmailAddress);
+					newEmails.AppendL(currField.TextStorage()->Text() );
+					}
 				}
 			// get SIP addresses
 			else if (newSips.Find(currField.TextStorage()->Text() ) == KErrNotFound)
@@ -311,10 +327,13 @@ void CPplCommAddrTable::UpdateL(const CContactItem& aItem)
                     }
 				}
 			// get email addresses
-			else if (isEmail && newEmails.Find(currField.TextStorage()->Text() ) == KErrNotFound)
-				{
-				newEmails.AppendL(currField.TextStorage()->Text() );
-				}
+		   else if (isEmail)
+			  {
+			  if (newEmails.Find(currField.TextStorage()->Text(), ComparePtr ) == KErrNotFound)
+				  {
+				  newEmails.AppendL(currField.TextStorage()->Text() );
+				  }
+			  }
 			// get SIP addresses
 			else if (newSips.Find(currField.TextStorage()->Text() ) == KErrNotFound)
 				{
@@ -346,7 +365,6 @@ void CPplCommAddrTable::UpdateL(const CContactItem& aItem)
 	RemoveNonUpdatedAddrsL(newPhones, newEmails, newSips, freeCommAddrIds, KItemId, extraInfoType);
 
 	// do the actual updating on an address-by-address basis
-
 	DoUpdateCommAddrsL(newPhones, newEmails, newSips, freeCommAddrIds, KItemId,extraInfoType);
 
 	CleanupStack::PopAndDestroy(4, &newPhones); // and freeCommAddrIds, newSips, newEmails
@@ -406,7 +424,7 @@ void CPplCommAddrTable::RemoveNonUpdatedAddrsL(RArray<TMatch>& aNewPhones, RArra
 			// we already have them in the db and they haven't changed...
 			if (KType == EEmailAddress)
 				{
-				matchIndex = aNewEmails.Find(valString);
+				matchIndex = aNewEmails.Find( valString, ComparePtr );
 				if (matchIndex != KErrNotFound)
 					{
 					aNewEmails.Remove(matchIndex);
@@ -682,6 +700,57 @@ void CPplCommAddrTable::DeleteL(const CContactItem& aItem, TBool& aLowDiskErrorO
 		}
 	}
 
+/**
+Deletes all the communication addresses for specified contact items. Should be used when
+deleting contact items from the database altogether.
+
+@param aIdArray The contact items whose communcation addresses are to be deleted.
+*/
+void CPplCommAddrTable::DeleteMultipleContactsL(const CContactIdArray* aIdArray)
+    {
+    _LIT(KDeleteQuery, "DELETE FROM comm_addr WHERE contact_id IN (");
+    TInt count = aIdArray->Count();
+    bool allContactsProcessed = false;
+    TInt round = 0;
+    while (!allContactsProcessed) 
+        {
+        RBuf deleteQuery;
+        deleteQuery.CreateL(KDeleteQuery().Length());
+        CleanupClosePushL(deleteQuery);
+        deleteQuery.Copy(KDeleteQuery);
+        TInt startValue = round*KDeleteBatchSize;
+        TInt endValue = (round+1)*KDeleteBatchSize < count ? (round+1)*KDeleteBatchSize : count;
+        for (TInt j = startValue; j < endValue; j++)
+            {
+            //add all contact ids to the delete query
+            TContactItemId id = aIdArray->operator[](j);
+            TBuf<16> number;
+            number.Num(id);
+            deleteQuery.ReAllocL(deleteQuery.Length() + number.Length() + 1); //1 is for comma or
+                                                                              //closing bracket
+            deleteQuery.Append(number);
+            if (j < endValue - 1)
+                {
+                //last id doesn't need a comma afterwards
+                deleteQuery.Append(',');
+                }
+            else
+                {
+                deleteQuery.Append(')');
+                }
+            }
+        
+        TInt err = iDatabase.Exec(deleteQuery);
+        User::LeaveIfError(err);
+        CleanupStack::PopAndDestroy(&deleteQuery);
+        
+        round++;
+        if (endValue == count)
+            {
+            allContactsProcessed = true;
+            }
+        }
+    }
 
 /**
 Creates the comm_addr table and its indexes in the database.
@@ -856,8 +925,8 @@ CContactIdArray* CPplCommAddrTable::BestMatchingPhoneNumberL(const TDesC& aNumbe
                 stored /= 10;
                 }
 
-            if ( (phoneDigits.iUpperDigits == 0) || (storedUpperDigits == 0) ||
-                 (number == stored) )
+            if ((phoneDigits.iUpperDigits == 0) || (storedUpperDigits == 0) ||
+                 (number == stored))
                 {
                 phoneMatchArray->AddL(stmnt.ColumnInt(KContactIdIdx));
                 }
@@ -996,7 +1065,8 @@ CPplCommAddrTable::TMatch CPplCommAddrTable::CreatePaddedPhoneDigitsL(const TDes
 		// digits total.
 		TInt pad = KMaxPhoneMatchLength - KLowerSevenDigits - phoneNumber.iNumUpperDigits;
 		phoneNumber.iUpperDigits = TMatch::PadOutPhoneMatchNumber(phoneNumber.iUpperDigits,pad);
-		}
+        phoneNumber.iNumUpperDigits = aNumUpperDigits;
+        }
 
 	return phoneNumber;
 	}
