@@ -26,12 +26,7 @@
 #include "cntsqlprovider.h"
 #include "dbsqlconstants.h"
 #include "cntpersistenceutility.h"
-#include "c12keypredictivesearchtable.h"
-#include "cqwertypredictivesearchtable.h"
-#include "cpredictivesearchsettingstable.h"
-#include "cpredictivesearchsynchronizer.h"
-#include "predictivesearchlog.h"
-#include "cntsqlsearch.h"
+#include "cntsqldbstructure.h"
 
 //#include "cntmetadataoperation.h"
 
@@ -39,12 +34,6 @@
 #include <sqldb.h>
 #include <cntdb.h>
 
-// TODO: The code related to predictive search table is placed inside this
-// macro. Uncomment the below line to get the table into use.
-#define USE_PRED_SEARCH_TABLE
-
-// If this macro is defined, then pred.search qwerty tables are used
-#define USE_QWERTY_PRED_SEARCH_TABLE
 
 
 /**
@@ -73,18 +62,7 @@ CPplContactItemManager::~CPplContactItemManager()
 	delete iSelectStatement;	
 	delete iContactTable;
 	delete iCommAddrTable;
-#if defined(USE_PRED_SEARCH_TABLE)
-	PRINT(_L("delete pred search table objects"));
-	delete iPredictiveSearchSynchronizer;
-	delete iPredSearch12keyTable;
-#if defined(USE_QWERTY_PRED_SEARCH_TABLE)
-	delete iPredSearchQwertyTable;
-	delete iPredSearchSettingsTable;
-#endif
-	PRINT(_L("delete pred search table objects - done"));
-#endif
-    delete iPresenceTable; 
-	delete iGroupTable;
+    delete iGroupTable;
 	delete iPreferencePersistor;
 	//iColSession.Close();
 	}
@@ -145,15 +123,6 @@ TContactItemId CPplContactItemManager::CreateL(CContactItem& aItem, TUint aSessi
 	iContactTable->CreateInDbL(aItem);	
 	iGroupTable->CreateInDbL(aItem);	
 	iCommAddrTable->CreateInDbL(aItem);
-#if defined(USE_PRED_SEARCH_TABLE)
-	PRINT(_L("add new contact to pred search tables"));
-	iPredSearch12keyTable->CreateInDbL(aItem);
-#if defined(USE_QWERTY_PRED_SEARCH_TABLE)
-	iPredSearchQwertyTable->CreateInDbL(aItem);
-	iPredSearchSettingsTable->CreateInDbL(aItem);
-#endif
-	PRINT(_L("add new contact to pred search tables - done"));
-#endif
 
    	TContactItemId groupId = iIccContactStore.CreateInDbL(aItem, aSessionId);
    	if(groupId != KNullContactId)
@@ -280,7 +249,7 @@ CContactItem* CPplContactItemManager::ReadLC(TContactItemId aItemId, const CCont
 				}
 			}
 			
-		CleanupStack::PopAndDestroy(&fastAccessFields);		
+		CleanupStack::PopAndDestroy(&fastAccessFields);
 		}
 	else
 		{
@@ -342,15 +311,6 @@ void CPplContactItemManager::UpdateL(CContactItem& aItem, TUint aSessionId, TBoo
 	iContactTable->UpdateL(aItem);	
 	iGroupTable->UpdateL(aItem);	
 	iCommAddrTable->UpdateL(aItem);
-#if defined(USE_PRED_SEARCH_TABLE)
-	PRINT(_L("update contact in pred search tables"));
-	iPredSearch12keyTable->UpdateL(aItem);
-#if defined(USE_QWERTY_PRED_SEARCH_TABLE)
-	iPredSearchQwertyTable->UpdateL(aItem);
-	iPredSearchSettingsTable->UpdateL(aItem);
-#endif
-	PRINT(_L("update contact in pred search tables - done"));
-#endif
 
 	if(controlTransaction)
 		{
@@ -435,30 +395,6 @@ CContactItem* CPplContactItemManager::DeleteLC(TContactItemId  aItemId, TUint aS
 		DeleteInLowDiskConditionL(iCommAddrTable, savedContactItem);
 		}
 
-#if defined(USE_PRED_SEARCH_TABLE)
-	PRINT(_L("delete contact from pred search tables"));
-	lowDisk = EFalse;
-    iPredSearch12keyTable->DeleteL(*savedContactItem, lowDisk);
-    if (lowDisk) 
-		{
-		DeleteInLowDiskConditionL(iPredSearch12keyTable, savedContactItem);
-		}
-	lowDisk = EFalse;
-#if defined(USE_QWERTY_PRED_SEARCH_TABLE)
-	iPredSearchQwertyTable->DeleteL(*savedContactItem, lowDisk);
-    if (lowDisk) 
-		{
-		DeleteInLowDiskConditionL(iPredSearchQwertyTable, savedContactItem);
-		}
-	iPredSearchSettingsTable->DeleteL(*savedContactItem, lowDisk);
-    if (lowDisk) 
-		{
-		DeleteInLowDiskConditionL(iPredSearchSettingsTable, savedContactItem);
-		}
-#endif
-	PRINT(_L("delete contact from pred search tables - done"));
-#endif
-  
     //Fake checking read access to ICCEntry store to keep BC.
     iIccContactStore.ReadL(*savedContactItem, EPlGroupMembershipInfo, aSessionId, EFalse);    
     
@@ -483,7 +419,36 @@ CContactItem* CPplContactItemManager::DeleteLC(TContactItemId  aItemId, TUint aS
 	return savedContactItem;
 	
 	}
-	
+
+/**
+Deletes the given contacts from the database.Forward the call to CPplTableBase
+based classes representing the tables in the contact database. In low disk condition
+a KErrDiskFull will be thrown.
+
+@param aIdArray The contact IDs of the contact items to be deleted.
+@param aSessionId The ID of the session that issued the request.  Used to
+prevent Phonebook Synchroniser deadlock.
+
+@leave KErrDiskFull if a full disk error appears
+*/  
+void CPplContactItemManager::DeleteMultipleContactsL(const CContactIdArray* aIdArray, TUint aSessionId, TCntSendEventAction /*aEventType*/)
+    {
+    TBool controlTransaction = !(iTransactionManager.IsTransactionActive());
+    if(controlTransaction)
+        {
+        StartTransactionL(aSessionId);
+        }
+    
+    static_cast<CPplContactTable*>(iContactTable)->DeleteMultipleContactsL(aIdArray);
+    static_cast<CPplGroupsTable*>(iGroupTable)->DeleteMultipleContactsL(aIdArray);
+    static_cast<CPplCommAddrTable*>(iCommAddrTable)->DeleteMultipleContactsL(aIdArray);
+    
+    if(controlTransaction)
+        {
+        CommitTransactionL();
+        }
+    }
+
 /**
 Perform a deletion in low disk condition
 
@@ -556,7 +521,7 @@ void CPplContactItemManager::ConstructL()
 	iSelectStatement->SetParamL(KContactFirstNamePrn, KSpace);
 	iSelectStatement->SetParamL(KContactLastNamePrn, KSpace);
 	iSelectStatement->SetParamL(KContactCompanyNamePrn, KSpace);
-	
+		
 	HBufC* condition = HBufC::NewLC(KWhereStringEqualsStringFormatText().Size() + KContactId().Size());
 	TPtr ptrCondition = condition->Des();
 	ptrCondition.Format(KWhereStringEqualsStringFormatText, &KContactId, &KVar);
@@ -571,26 +536,6 @@ void CPplContactItemManager::ConstructL()
 	iCommAddrTable = CPplCommAddrTable::NewL(iDatabase, iContactProperties);
 	iGroupTable = CPplGroupsTable::NewL(iDatabase);
 	iPreferencePersistor = CPplPreferencesPersistor::NewL(iDatabase);
-
-#if defined(USE_PRED_SEARCH_TABLE)
-	PRINT(_L("create C12keyPredictiveSearchTable object"));
-	iPredSearch12keyTable = C12keyPredictiveSearchTable::NewL(iDatabase);
-#if defined(USE_QWERTY_PRED_SEARCH_TABLE)
-	PRINT(_L("create CQwertyPredictiveSearchTable object"));
-	iPredSearchQwertyTable = CQwertyPredictiveSearchTable::NewL(iDatabase);
-	PRINT(_L("create CPredictiveSearchSettingsTable object"));
-	iPredSearchSettingsTable = CPredictiveSearchSettingsTable::NewL(iDatabase);
-
-	iPredictiveSearchSynchronizer =
-		CPredictiveSearchSynchronizer::NewL(iDatabase,
-											*iPredSearch12keyTable,
-											*iPredSearchQwertyTable,
-											*iPredSearchSettingsTable);
-#endif // #if defined(USE_QWERTY_PRED_SEARCH_TABLE)
-#endif // #if defined(USE_PRED_SEARCH_TABLE)
-
-	iPresenceTable = CPplPresenceTable::NewL(iDatabase); 
-	
 	// Connect to metadata server
 	//User::LeaveIfError(iColSession.Connect());
 
@@ -670,16 +615,6 @@ void CPplContactItemManager::CreateTablesL()
 	iGroupTable->CreateTableL();	
 	iCommAddrTable->CreateTableL();
 	iPreferencePersistor->CreateTableL();
-#if defined(USE_PRED_SEARCH_TABLE)
-	PRINT(_L("create pred search tables to DB"));	
-	iPredSearch12keyTable->CreateTableL();
-#if defined(USE_QWERTY_PRED_SEARCH_TABLE)
-	iPredSearchQwertyTable->CreateTableL();
-	iPredSearchSettingsTable->CreateTableL();
-#endif
-	PRINT(_L("create pred search tables to DB - done"));	
-#endif
-	iPresenceTable->CreateTableL(); 
 	
 	if (controlTransaction)
 		{
@@ -835,24 +770,6 @@ CBufSeg* CPplContactItemManager::DetailsListL(const TDesC& aSearchQuery) const
     return array;
     }
 
-
-CBufSeg* CPplContactItemManager::DetailsListPredictiveL(const TDesC& aSearchPattern ) const
-    {
-    
-	
-    QString qString;
-    QString queryString;
-    CntSqlSearch sqlSearch( *iPredSearch12keyTable->KeyMap(), 
-	                        *iPredSearchQwertyTable->KeyMap() );
-
-    QT_TRYCATCH_LEAVING({
-        qString = QString((QChar*)aSearchPattern.Ptr(),aSearchPattern.Length());
-        queryString = sqlSearch.CreatePredictiveSearch( qString );
-        });
-    TPtrC query (reinterpret_cast<const TText*>(queryString.constData()),queryString.length());   
-    return DetailsListL( query );
-    }
-
 /**
 Utility method used to rthe prefered card template id
 */
@@ -869,19 +786,14 @@ void CPplContactItemManager::SetCardTemplatePrefIdL(TInt aCardTemplatePrefId)
 	iPreferencePersistor->SetPreferredCardTemplateIdL(aCardTemplatePrefId);
 	}
 
-void CPplContactItemManager::SynchronizePredSearchTableL()
-	{
-#if defined(USE_PRED_SEARCH_TABLE)
-	iPredictiveSearchSynchronizer->SynchronizeTablesL();
-#endif
-	}
-
-void CPplContactItemManager::RecreatePredSearchTablesL()
-	{
-#if defined(USE_PRED_SEARCH_TABLE)
-	iPredictiveSearchSynchronizer->DeletePredSearchTablesL();
-	iPredictiveSearchSynchronizer->CreatePredSearchTablesL();
-#endif
-	}
+void CPplContactItemManager::MakeDatabaseCompatibleL()
+    {
+    //check compatibility
+    CCntSqlDbStructure* tblStructure = CCntSqlDbStructure::NewL( iDatabase, *this );   
+    CleanupStack::PushL(tblStructure);
+    tblStructure->MakeDatabaseCompatibleL();
+    CleanupStack::PopAndDestroy(); //tblStructure
+    }
 
 
+    
