@@ -432,10 +432,6 @@ TInt CViewSubSessionBase::ContactAtLengthL(const RMessage2& aMessage)
 	delete iContact;
 	iContact=NULL;
 	iContact = CViewContact::NewL(contact);
-
-	//Always keep server side local view in memory saving mode, so we
-	//change the view contact object stored in iView into lightweight object
-	const_cast<CViewContact&>(contact).ChangeToLightweightObject();
 	
 	const TInt externalizedSize=iContact->ExternalizedSize();
 	TPckgBuf<TInt> pckg(externalizedSize);
@@ -874,7 +870,7 @@ void CViewSubSession::GetSortOrderL(const RMessage2& aMessage) const
 CNamedViewSubSession* CNamedViewSubSession::NewL(CViewManager& aViewManager,const RMessage2& aMessage)
 	{
 	CNamedViewSubSession* self=new(ELeave) CNamedViewSubSession(aViewManager);
-	CleanupStack::PushL(self);
+	CleanupClosePushL(*self); // CObject: Close will call the destructor.
 	self->ConstructL(aMessage);
 	CleanupStack::Pop(); // self.
 	return self;
@@ -1007,12 +1003,12 @@ CContactLocalView& CViewManager::OpenViewL(const RContactViewSortOrder& aSortOrd
 
 	// Register this view as an observer of database events with the
 	// associated CCntDbManager.
-	iManager.RegisterDatabaseEventObserverL(*viewHandle.iLocalView);
+	iManager.RegisterDatabaseEventObserverL(viewHandle.iLocalView->ObserverV2());
 
 	TInt error = iLocalViews.Append(viewHandle);
 	if (error != KErrNone)
 		{
-		iManager.UnRegisterDatabaseEventObserver(*viewHandle.iLocalView);
+		iManager.UnRegisterDatabaseEventObserver(viewHandle.iLocalView->ObserverV2());
 		viewHandle.iLocalView->Close(aObserver);
 		User::Leave(error);
 		}
@@ -1058,12 +1054,12 @@ CContactNamedLocalView& CViewManager::OpenNamedViewL(const TDesC& aName,const RC
 
 	// Register this view as an observer of database events with the
 	// associated CCntDbManager.
-	iManager.RegisterDatabaseEventObserverL(*newNamedView);
+	iManager.RegisterDatabaseEventObserverL(newNamedView->ObserverV2());
 
 	TInt error = iNamedLocalViews.Append(newNamedView);
 	if (error != KErrNone)
 		{
-		iManager.UnRegisterDatabaseEventObserver(*newNamedView);
+		iManager.UnRegisterDatabaseEventObserver(newNamedView->ObserverV2());
 		newNamedView->Close(aObserver);
 		User::Leave(error);
 		}
