@@ -80,7 +80,10 @@ enum TContactViewPreferences
 	EICCEntriesOnly					=0x00000040, 
 	/** Only contact cards and ICC entries (of type KUidContactCard, KUidContactOwnCard 
 	or KUidContactICCEntry) are included in the view. */
-	EICCEntriesAndContacts			=0x00000080  
+	EICCEntriesAndContacts			=0x00000080,
+	/** Only contact cards (of type KUidContactCard) are included 
+	in the view. Own card not included. */
+    EContactCardsOnly				=0x00000100
 	};
 
 
@@ -613,6 +616,28 @@ The view preferences and sort order are specified on construction.
 @released
 */
 	{
+#ifdef __SYMBIAN_CNTMODEL_USE_SQLITE__
+private:
+    NONSHARABLE_CLASS(CContactLocalViewExtension) : public CBase, public MContactDbObserverV2
+    /** An extension class that holds member data added to this class.
+
+    It was created for binary compatibility purposes. 
+    @internalComponent
+    @released */
+        {
+        public:
+            static CContactLocalViewExtension* NewL(CContactLocalView& aLocalView);
+            ~CContactLocalViewExtension(){};
+
+        private:
+            CContactLocalViewExtension(CContactLocalView& aLocalView) : iLocalView(aLocalView){};
+            void HandleDatabaseEventV2L(TContactDbObserverEventV2 aEvent);
+            
+        private:
+            CContactLocalView& iLocalView;  // Not own
+        };
+#endif
+    
 public:
 	IMPORT_C static CContactLocalView* NewL(MContactViewObserver& aObserver,const CContactDatabase& aDb,const RContactViewSortOrder& aSortOrder,TContactViewPreferences aContactTypes);
 	IMPORT_C static CContactLocalView* NewL(MContactViewObserver& aObserver,const CContactDatabase& aDb,const RContactViewSortOrder& aSortOrder,TContactViewPreferences aContactTypes,
@@ -621,6 +646,7 @@ public:
 		MLplPersistenceLayerFactory* aFactory,const TDesC8& aSortPluginName);
 
 	IMPORT_C const RContactViewSortOrder& SortOrder() const;
+    IMPORT_C MContactDbObserverV2& ObserverV2() const;
 public: // From CContactViewBase.
 	TContactItemId AtL(TInt aIndex) const;
 	TInt CountL() const;
@@ -645,7 +671,9 @@ protected:
 protected:
 	void SetState(TState aState);
 private: // From MContactDbObserver.
-	virtual void HandleDatabaseEventL(TContactDbObserverEvent aEvent);
+    virtual void HandleDatabaseEventL(TContactDbObserverEvent aEvent);
+private:
+    void HandleDatabaseEventV2L(TContactDbObserverEventV2 aEvent);
 	
 private:
 	void SortComplete(TInt aSortErr);	
@@ -676,7 +704,11 @@ private:
 	CContactTextDef*	iTextDef;
 	TContactViewPreferences iViewPreferences;
 	TBool iSpare0;
+#ifdef __SYMBIAN_CNTMODEL_USE_SQLITE__
+	CContactLocalViewExtension* iLocalExtension;
+#else
 	TInt iSpare;
+#endif
 	};
 
 class RContactRemoteView : public RSubSessionBase
