@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -151,7 +151,7 @@ void TestCntTransformContactData::executeCntTransformBithday()
     QVERIFY(err == 0);
 }
 
-#ifdef SYMBIAN_BACKEND_USE_SQLITE
+#ifdef SYMBIAN_BACKEND_USE_CNTMODEL_V2
 
 void TestCntTransformContactData::executeCntTransformOnlineAccount()
 {
@@ -175,7 +175,7 @@ void TestCntTransformContactData::executeCntTransformPresence()
     QVERIFY(err == 0);
 }
 
-#endif // SYMBIAN_BACKEND_USE_SQLITE
+#endif // SYMBIAN_BACKEND_USE_CNTMODEL_V2
 
 void TestCntTransformContactData::executeCntTransformOrganisation()
 {
@@ -193,7 +193,7 @@ void TestCntTransformContactData::executeCntTransformOrganisation()
 
 void TestCntTransformContactData::executeCntTransformAvatar()
 {
-    TRAPD(err, validateCntTransformAvatarL(_L("dummyavatar"), QString("dummyavatar"));
+    TRAPD(err, validateCntTransformAvatarL(_L("c:\\dummyavatar.jpg"), QString("c:\\dummyavatar.jpg"));
         validateCntTransformAvatarL(_L(""), QString(""));
         );
     QVERIFY(err == 0);
@@ -201,8 +201,8 @@ void TestCntTransformContactData::executeCntTransformAvatar()
 
 void TestCntTransformContactData::executeCntTransformRingtone()
 {
-    TRAPD(err, validateCntTransformRingtoneL(_L("dummyaudioringtone"), QString("dummyaudioringtone"),
-                                             _L("dummyvideoringtone"), QString("dummyvideoringtone"));
+    TRAPD(err, validateCntTransformRingtoneL(_L("c:\\dummyaudioringtone"), QString("c:\\dummyaudioringtone"),
+                                             _L("c:\\dummyvideoringtone"), QString("c:\\dummyvideoringtone"));
         validateCntTransformRingtoneL(_L(""), QString(""), _L(""), QString(""));
         );
     QVERIFY(err == 0);
@@ -1070,7 +1070,7 @@ void TestCntTransformContactData::validateCntTransformBirthdayL(TTime field, QDa
     delete transformBirthday;
 }
 
-#ifdef SYMBIAN_BACKEND_USE_SQLITE
+#ifdef SYMBIAN_BACKEND_USE_CNTMODEL_V2
 
 void TestCntTransformContactData::validateCntTransformOnlineAccountL(
     TPtrC16 sipField, QString sipDetail,
@@ -1311,7 +1311,7 @@ void TestCntTransformContactData::validateCntTransformPresenceL(TPtrC16 presence
      
     delete transformPresence;
     }
-#endif // SYMBIAN_BACKEND_USE_SQLITE
+#endif // SYMBIAN_BACKEND_USE_CNTMODEL_V2
 
 void TestCntTransformContactData::validateCntTransformOrganisationL(TPtrC16 companyField, QString companyDetail,
                                 TPtrC16 departmentField, QStringList departmentDetail,
@@ -1474,7 +1474,7 @@ void TestCntTransformContactData::validateCntTransformAvatarL(TPtrC16 field, QSt
     QContactDetail* contactDetail = transformAvatar->transformItemField(*newField, contact);
     QVERIFY(contactDetail != NULL);
     const QContactAvatar* avatarInfo1(static_cast<const QContactAvatar*>(contactDetail));
-    QCOMPARE(avatarInfo1->imageUrl().toString(), detail);
+    QCOMPARE(avatarInfo1->imageUrl().toString(), QUrl::fromUserInput(detail).toString());
     delete contactDetail;
     contactDetail = 0;
     delete newField;
@@ -1527,7 +1527,7 @@ void TestCntTransformContactData::validateCntTransformRingtoneL(TPtrC16 audioRin
     QContactDetail* contactDetail = transformRingtone->transformItemField(*newField, contact);
     QVERIFY(contactDetail != NULL);
     const QContactRingtone* ringtoneInfo1(static_cast<const QContactRingtone*>(contactDetail));
-    QCOMPARE(ringtoneInfo1->audioRingtoneUrl().toString(), audioRingtoneDetail);
+    QCOMPARE(ringtoneInfo1->audioRingtoneUrl().toString(), QUrl::fromUserInput(audioRingtoneDetail).toString());
     delete contactDetail;
     contactDetail = 0;
     delete newField;
@@ -1538,7 +1538,7 @@ void TestCntTransformContactData::validateCntTransformRingtoneL(TPtrC16 audioRin
     contactDetail = transformRingtone->transformItemField(*newField, contact);
     QVERIFY(contactDetail != NULL);
     const QContactRingtone* ringtoneInfo2(static_cast<const QContactRingtone*>(contactDetail));
-    QCOMPARE(ringtoneInfo2->videoRingtoneUrl().toString(), videoRingtoneDetail);
+    QCOMPARE(ringtoneInfo2->videoRingtoneUrl().toString(), QUrl::fromUserInput(videoRingtoneDetail).toString());
     delete contactDetail;
     contactDetail = 0;
     delete newField;
