@@ -7,11 +7,11 @@
 ** This file is part of the QtDeclarative module of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -1169,7 +1169,6 @@ QString QDeclarativeContactDetail::fieldName(ContactDetailType detailType, int f
    \list
    \o Ringtone.AudioRingtoneUrl
    \o Ringtone.VideoRingtoneUrl
-   \o Ringtone.VibrationRingtoneUrl
    \endlist
 
   This element is part of the \bold{QtMobility.contacts 1.1} module.
@@ -1185,7 +1184,9 @@ QString QDeclarativeContactDetail::fieldName(ContactDetailType detailType, int f
 
   This property holds the value of the URL for a video ringtone.
   */
-/*!
+
+// Not in use (note the missing ! below)
+/*
   \qmlproperty url Ringtone::vibrationRingtoneUrl
 
   This property holds the value of the URL for a vibration ringtone.
@@ -1202,6 +1203,7 @@ QString QDeclarativeContactDetail::fieldName(ContactDetailType detailType, int f
    \o SyncTarget.SyncTarget
    \endlist
 
+  \sa QContactSyncTarget
   This element is part of the \bold{QtMobility.contacts 1.1} module.
  */
 /*!
@@ -1220,7 +1222,7 @@ QString QDeclarativeContactDetail::fieldName(ContactDetailType detailType, int f
    \list
    \o Tag.Tag
    \endlist
-
+  \sa QContactTag
   This element is part of the \bold{QtMobility.contacts 1.1} module.
  */
 /*!
