@@ -7,11 +7,11 @@
 ** This file is part of the QtDeclarative module of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -240,7 +240,12 @@ QVariant QDeclarativeContactMetaObject::details(const QString& name)
 {
     if (name.isEmpty()) {
         //return all
-        return QVariant::fromValue(QDeclarativeListProperty<QDeclarativeContactDetail>(object(), m_details));
+        return QVariant::fromValue(QDeclarativeListProperty<QDeclarativeContactDetail>(object(),
+                                                                                       0,
+                                                                                       detail_append,
+                                                                                       detail_count,
+                                                                                       detail_at,
+                                                                                       detail_clear));
     } else {
         int propId = indexOfProperty(name.toLatin1());
         if (propId <= 0) {
@@ -278,7 +283,8 @@ QContact QDeclarativeContactMetaObject::contact()
 {
     foreach (const QDeclarativeContactDetail* cd, m_details) {
        QContactDetail detail = cd->detail();
-       m_contact.saveDetail(&detail);
+       if (!detail.isEmpty())
+          m_contact.saveDetail(&detail);
     }
 
     return m_contact;
@@ -295,11 +301,12 @@ QContactId QDeclarativeContactMetaObject::contactId() const
 }
 void QDeclarativeContactMetaObject::detail_append(QDeclarativeListProperty<QDeclarativeContactDetail> *p, QDeclarativeContactDetail *detail)
 {
-    ContactDetailNameMap* data = (ContactDetailNameMap*)(p->data);
-    if (data) {
-        QDeclarativeContact* dc = qobject_cast<QDeclarativeContact*>(p->object);
-        if (dc && detail->detail().definitionName() == data->definitionName) {
-            detail->connect(detail, SIGNAL(fieldsChanged()), dc, SIGNAL(detailsChanged()));
+    QDeclarativeContact* dc = qobject_cast<QDeclarativeContact*>(p->object);
+    if (dc) {
+        ContactDetailNameMap* data = (ContactDetailNameMap*)(p->data);
+        if (!data || detail->detail().definitionName() == data->definitionName) {
+            detail->connect(detail, SIGNAL(fieldsChanged()), SIGNAL(valueChanged()), Qt::UniqueConnection);
+            detail->connect(detail, SIGNAL(valueChanged()), dc, SIGNAL(detailsChanged()), Qt::UniqueConnection);
             dc->d->m_details.append(detail);
         }
     }
@@ -307,13 +314,17 @@ void QDeclarativeContactMetaObject::detail_append(QDeclarativeListProperty<QDecl
 
 int  QDeclarativeContactMetaObject::detail_count(QDeclarativeListProperty<QDeclarativeContactDetail> *p)
 {
-    ContactDetailNameMap* data = (ContactDetailNameMap*)(p->data);
     int count = 0;
     QDeclarativeContact* dc = qobject_cast<QDeclarativeContact*>(p->object);
-    if (dc && data) {
-        foreach(const QDeclarativeContactDetail* detail, dc->d->m_details) {
-            if (detail->detail().definitionName() == data->definitionName)
-                count++;
+    if (dc) {
+        ContactDetailNameMap* data = (ContactDetailNameMap*)(p->data);
+        if (data) {
+            foreach(const QDeclarativeContactDetail* detail, dc->d->m_details) {
+                if (detail->detail().definitionName() == data->definitionName)
+                    count++;
+            }
+        } else {
+            count = dc->d->m_details.size();
         }
     }
     return count;
@@ -321,20 +332,24 @@ int  QDeclarativeContactMetaObject::detail_count(QDeclarativeListProperty<QDecla
 
 QDeclarativeContactDetail * QDeclarativeContactMetaObject::detail_at(QDeclarativeListProperty<QDeclarativeContactDetail> *p, int idx)
 {
-    ContactDetailNameMap* data = (ContactDetailNameMap*)(p->data);
     QDeclarativeContactDetail* detail = 0;
     QDeclarativeContact* dc = qobject_cast<QDeclarativeContact*>(p->object);
-    if (dc && data) {
-        int i = 0;
-        foreach(QDeclarativeContactDetail* cd,dc->d->m_details) {
-            if (cd->detail().definitionName() == data->definitionName) {
-                if (i == idx) {
-                    detail = cd;
-                    break;
-                } else {
-                    i++;
+    if (dc) {
+        ContactDetailNameMap* data = (ContactDetailNameMap*)(p->data);
+        if (data) {
+            int i = 0;
+            foreach(QDeclarativeContactDetail* cd,dc->d->m_details) {
+                if (cd->detail().definitionName() == data->definitionName) {
+                    if (i == idx) {
+                        detail = cd;
+                        break;
+                    } else {
+                        i++;
+                    }
                 }
             }
+        } else if (idx < dc->d->m_details.size()) {
+            detail = dc->d->m_details.at(idx);
         }
     }
     return detail;
@@ -342,13 +357,17 @@ QDeclarativeContactDetail * QDeclarativeContactMetaObject::detail_at(QDeclarativ
 
 void  QDeclarativeContactMetaObject::detail_clear(QDeclarativeListProperty<QDeclarativeContactDetail> *p)
 {
-    ContactDetailNameMap* data = (ContactDetailNameMap*)(p->data);
     QDeclarativeContact* dc = qobject_cast<QDeclarativeContact*>(p->object);
-    if (dc && data) {
-        foreach(QDeclarativeContactDetail* cd, dc->d->m_details) {
-            if (cd->detail().definitionName() == data->definitionName) {
-                dc->d->m_details.removeAll(cd);
+    if (dc) {
+        ContactDetailNameMap* data = (ContactDetailNameMap*)(p->data);
+        if (data) {
+            foreach(QDeclarativeContactDetail* cd, dc->d->m_details) {
+                if (cd->detail().definitionName() == data->definitionName) {
+                    dc->d->m_details.removeAll(cd);
+                }
             }
+        } else {
+            dc->d->m_details.clear();
         }
     }
 }
