@@ -7,11 +7,11 @@
 ** This file is part of the QtDeclarative module of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,20 +25,21 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 #include <qcontactdetails.h>
+#include <QtDeclarative/qdeclarativeinfo.h>
 
 #include "qdeclarativecontactmodel_p.h"
 #include "qcontactmanager.h"
@@ -90,6 +91,7 @@ public:
         :m_manager(0),
         m_fetchHint(0),
         m_filter(0),
+        m_fetchRequest(0),
         m_autoUpdate(true),
         m_updatePending(false),
         m_componentCompleted(false)
@@ -108,6 +110,8 @@ public:
     QList<QDeclarativeContactSortOrder*> m_sortOrders;
     QDeclarativeContactFilter* m_filter;
 
+    QContactFetchRequest* m_fetchRequest;
+    QList<QContactLocalId> m_updatedContactIds;
     QVersitReader m_reader;
     QVersitWriter m_writer;
     QStringList m_importProfiles;
@@ -126,14 +130,14 @@ QDeclarativeContactModel::QDeclarativeContactModel(QObject *parent) :
     roleNames.insert(ContactRole, "contact");
     setRoleNames(roleNames);
 
-    connect(this, SIGNAL(managerChanged()), SLOT(fetchAgain()));
-    connect(this, SIGNAL(filterChanged()), SLOT(fetchAgain()));
-    connect(this, SIGNAL(fetchHintChanged()), SLOT(fetchAgain()));
-    connect(this, SIGNAL(sortOrdersChanged()), SLOT(fetchAgain()));
+    connect(this, SIGNAL(managerChanged()), SLOT(update()));
+    connect(this, SIGNAL(filterChanged()), SLOT(update()));
+    connect(this, SIGNAL(fetchHintChanged()), SLOT(update()));
+    connect(this, SIGNAL(sortOrdersChanged()), SLOT(update()));
     
-    d->m_manager = new QContactManager();
     //import vcard
     connect(&d->m_reader, SIGNAL(stateChanged(QVersitReader::State)), this, SLOT(startImport(QVersitReader::State)));
+    connect(&d->m_writer, SIGNAL(stateChanged(QVersitWriter::State)), this, SLOT(contactsExported(QVersitWriter::State)));
 }
 
 /*!
@@ -155,8 +159,8 @@ void QDeclarativeContactModel::setManager(const QString& managerName)
 
     d->m_manager = new QContactManager(managerName);
 
-    connect(d->m_manager, SIGNAL(dataChanged()), this, SLOT(fetchAgain()));
-    connect(d->m_manager, SIGNAL(contactsAdded(QList<QContactLocalId>)), this, SLOT(fetchAgain()));
+    connect(d->m_manager, SIGNAL(dataChanged()), this, SLOT(update()));
+    connect(d->m_manager, SIGNAL(contactsAdded(QList<QContactLocalId>)), this, SLOT(update()));
     connect(d->m_manager, SIGNAL(contactsRemoved(QList<QContactLocalId>)), this, SLOT(contactsRemoved(QList<QContactLocalId>)));
     connect(d->m_manager, SIGNAL(contactsChanged(QList<QContactLocalId>)), this, SLOT(contactsChanged(QList<QContactLocalId>)));
     emit managerChanged();
@@ -164,14 +168,11 @@ void QDeclarativeContactModel::setManager(const QString& managerName)
 void QDeclarativeContactModel::componentComplete()
 {
     d->m_componentCompleted = true;
-    if (!d->m_manager) {
-        d->m_manager = new QContactManager();
-        //connectManager();
-    }
-    if (d->m_autoUpdate) {
-        //TODO
-        //scheduleUpdate();
-    }
+    if (!d->m_manager)
+        setManager(QString());
+
+    if (d->m_autoUpdate)
+        update();
 }
 /*!
   \qmlproperty bool ContactModel::autoUpdate
@@ -193,7 +194,20 @@ bool QDeclarativeContactModel::autoUpdate() const
 
 void QDeclarativeContactModel::update()
 {
-    //TODO
+    if (!d->m_componentCompleted || d->m_updatePending)
+        return;
+    d->m_updatePending = true; // Disallow possible duplicate request triggering
+    QMetaObject::invokeMethod(this, "fetchAgain", Qt::QueuedConnection);
+}
+
+void QDeclarativeContactModel::cancelUpdate()
+{
+    if (d->m_fetchRequest) {
+        d->m_fetchRequest->cancel();
+        d->m_fetchRequest->deleteLater();
+        d->m_fetchRequest = 0;
+        d->m_updatePending = false;
+    }
 }
 
 /*!
@@ -205,6 +219,8 @@ void QDeclarativeContactModel::update()
   */
 QString QDeclarativeContactModel::error() const
 {
+    if (!d->m_manager)
+        return QLatin1String("Invalid contact manager");
     switch (d->m_manager->error()) {
     case QContactManager::DoesNotExistError:
         return QLatin1String("DoesNotExist");
@@ -267,10 +283,20 @@ static QString urlToLocalFileName(const QUrl& url)
   \qmlmethod ContactModel::importContacts(url url, list<string> profiles)
 
   Import contacts from a vcard by the given \a url and optional \a profiles.
+  Supported profiles are:
+  \list
+  \o "Sync"  Imports contacts in sync mode, currently, this is the same as passing in an empty list, and is generally what you want.
+  \o "Backup" imports contacts in backup mode, use this mode if the vCard was generated by exporting in backup mode.
+
+  \endlist
+
+  \sa QVersitContactHandlerFactory
+  \sa QVersitContactHandlerFactory::ProfileSync
+  \sa QVersitContactHandlerFactory::ProfileBackup
+
   */
 void QDeclarativeContactModel::importContacts(const QUrl& url, const QStringList& profiles)
 {
-   //qWarning() << "importing contacts from:" << url;
    d->m_importProfiles = profiles;
 
    //TODO: need to allow download vcard from network
@@ -287,10 +313,20 @@ void QDeclarativeContactModel::importContacts(const QUrl& url, const QStringList
 
   Export contacts into a vcard file to the given \a url by optional \a profiles.
   At the moment only the local file url is supported in export method.
+  Supported profiles are:
+  \list
+  \o "Sync"  exports contacts in sync mode, currently, this is the same as passing in an empty list, and is generally what you want.
+  \o "Backup" exports contacts in backup mode, this will add non-standard properties to the generated vCard
+              to try to save every detail of the contacts. Only use this if the vCard is going to be imported using the backup profile.
+
+  \endlist
+
+  \sa QVersitContactHandlerFactory
+  \sa QVersitContactHandlerFactory::ProfileSync
+  \sa QVersitContactHandlerFactory::ProfileBackup
   */
 void QDeclarativeContactModel::exportContacts(const QUrl& url, const QStringList& profiles)
 {
-   //qWarning() << "exporting contacts into:" << url;
 
    QString profile = profiles.isEmpty()? QString() : profiles.at(0);
     //only one profile string supported now
@@ -304,7 +340,7 @@ void QDeclarativeContactModel::exportContacts(const QUrl& url, const QStringList
    exporter.exportContacts(contacts, QVersitDocument::VCard30Type);
    QList<QVersitDocument> documents = exporter.documents();
    QFile* file = new QFile(urlToLocalFileName(url));
-   bool ok = file->open(QIODevice::ReadWrite);
+   bool ok = file->open(QIODevice::WriteOnly);
    if (ok) {
       d->m_writer.setDevice(file);
       d->m_writer.startWriting(documents);
@@ -343,7 +379,7 @@ void QDeclarativeContactModel::setFilter(QDeclarativeContactFilter* filter)
 {
     d->m_filter = filter;
     if (d->m_filter) {
-        connect(d->m_filter, SIGNAL(valueChanged()), SLOT(fetchAgain()));
+        connect(d->m_filter, SIGNAL(filterChanged()), SLOT(update()));
         emit filterChanged();
     }
 }
@@ -370,7 +406,7 @@ void QDeclarativeContactModel::setFetchHint(QDeclarativeContactFetchHint* fetchH
 }
 
 /*!
-  \qmlproperty QDeclarativeListProperty ContactModel::contacts
+  \qmlproperty list<Contact> ContactModel::contacts
 
   This property holds a list of contacts.
 
@@ -378,11 +414,43 @@ void QDeclarativeContactModel::setFetchHint(QDeclarativeContactFetchHint* fetchH
   */
 QDeclarativeListProperty<QDeclarativeContact> QDeclarativeContactModel::contacts()
 {
-    return QDeclarativeListProperty<QDeclarativeContact>(this, d->m_contacts);
+    return QDeclarativeListProperty<QDeclarativeContact>(this,
+                                                         0,
+                                                         contacts_append,
+                                                         contacts_count,
+                                                         contacts_at,
+                                                         contacts_clear);
 }
 
+
+
+void QDeclarativeContactModel::contacts_append(QDeclarativeListProperty<QDeclarativeContact>* prop, QDeclarativeContact* contact)
+{
+    Q_UNUSED(prop);
+    Q_UNUSED(contact);
+    qmlInfo(0) << tr("ContactModel: appending contacts is not currently supported");
+}
+
+int QDeclarativeContactModel::contacts_count(QDeclarativeListProperty<QDeclarativeContact>* prop)
+{
+    return static_cast<QDeclarativeContactModel*>(prop->object)->d->m_contacts.count();
+}
+
+QDeclarativeContact* QDeclarativeContactModel::contacts_at(QDeclarativeListProperty<QDeclarativeContact>* prop, int index)
+{
+    return static_cast<QDeclarativeContactModel*>(prop->object)->d->m_contacts.at(index);
+}
+
+void QDeclarativeContactModel::contacts_clear(QDeclarativeListProperty<QDeclarativeContact>* prop)
+{
+    QDeclarativeContactModel* model = static_cast<QDeclarativeContactModel*>(prop->object);
+    model->clearContacts();
+    emit model->contactsChanged();
+}
+
+
 /*!
-  \qmlproperty QDeclarativeListProperty ContactModel::sortOrders
+  \qmlproperty list<SortOrder> ContactModel::sortOrders
 
   This property holds a list of sort orders used by the organizer model.
 
@@ -390,7 +458,12 @@ QDeclarativeListProperty<QDeclarativeContact> QDeclarativeContactModel::contacts
   */
 QDeclarativeListProperty<QDeclarativeContactSortOrder> QDeclarativeContactModel::sortOrders()
 {
-    return QDeclarativeListProperty<QDeclarativeContactSortOrder>(this, d->m_sortOrders);
+    return QDeclarativeListProperty<QDeclarativeContactSortOrder>(this,
+                                                                  0,
+                                                                  sortOrder_append,
+                                                                  sortOrder_count,
+                                                                  sortOrder_at,
+                                                                  sortOrder_clear);
 }
 
 void QDeclarativeContactModel::startImport(QVersitReader::State state)
@@ -404,9 +477,13 @@ void QDeclarativeContactModel::startImport(QVersitReader::State state)
         d->m_reader.setDevice(0);
 
         if (d->m_manager) {
-            if (d->m_manager->saveContacts(&contacts))
-                qWarning() << "contacts imported.";
-                fetchAgain();
+            for (int i = 0; i < contacts.size(); i++) {
+                contacts[i] = d->m_manager->compatibleContact(contacts[i]);
+            }
+            if (d->m_manager->saveContacts(&contacts)) {
+                qmlInfo(this) << tr("contacts imported.");
+                update();
+            }
         }
     }
 }
@@ -414,68 +491,90 @@ void QDeclarativeContactModel::startImport(QVersitReader::State state)
 /*!
   \qmlmethod ContactModel::fetchContacts(list<int> contactIds)
   Fetch a list of contacts from the contacts store by given \a contactIds.
+
+  \sa Contact::contactId
   */
 void QDeclarativeContactModel::fetchContacts(const QList<QContactLocalId>& contactIds)
 {
-    QList<QContactSortOrder> sortOrders;
-    foreach (QDeclarativeContactSortOrder* so, d->m_sortOrders) {
-        sortOrders.append(so->sortOrder());
-    }
-    QContactFetchRequest* req = new QContactFetchRequest(this);
-    req->setManager(d->m_manager);
-    req->setSorting(sortOrders);
-
-    QContactLocalIdFilter filter;
-    filter.setIds(contactIds);
-    req->setFilter(filter);
-
-    req->setFetchHint(d->m_fetchHint ? d->m_fetchHint->fetchHint() : QContactFetchHint());
-
-    connect(req,SIGNAL(stateChanged(QContactAbstractRequest::State)), this, SLOT(requestUpdated()));
-
-    req->start();
+    d->m_updatedContactIds = contactIds;
+    d->m_updatePending = true;
+    QMetaObject::invokeMethod(this, "fetchAgain", Qt::QueuedConnection);
+}
+void QDeclarativeContactModel::clearContacts()
+{
+    qDeleteAll(d->m_contacts);
+    d->m_contacts.clear();
+    d->m_contactMap.clear();
 }
 
 void QDeclarativeContactModel::fetchAgain()
 {
-    d->m_contacts.clear();
-    d->m_contactMap.clear();
+    cancelUpdate();
+    if (d->m_updatedContactIds.isEmpty()) //fetch all contacts
+        clearContacts();
 
     QList<QContactSortOrder> sortOrders;
     foreach (QDeclarativeContactSortOrder* so, d->m_sortOrders) {
         sortOrders.append(so->sortOrder());
     }
-    QContactFetchRequest* req = new QContactFetchRequest(this);
-    req->setManager(d->m_manager);
-    req->setSorting(sortOrders);
+    d->m_fetchRequest = new QContactFetchRequest(this);
+    d->m_fetchRequest->setManager(d->m_manager);
+    d->m_fetchRequest->setSorting(sortOrders);
 
-    req->setFilter(d->m_filter? d->m_filter->filter() : QContactFilter());
-    req->setFetchHint(d->m_fetchHint ? d->m_fetchHint->fetchHint() : QContactFetchHint());
+    if (!d->m_updatedContactIds.isEmpty()) {
+        QContactLocalIdFilter f;
+        f.setIds(d->m_updatedContactIds);
+        d->m_fetchRequest->setFilter(f);
+        d->m_updatedContactIds.clear();
+    } else if (d->m_filter){
+        d->m_fetchRequest->setFilter(d->m_filter->filter());
+    } else {
+        d->m_fetchRequest->setFilter(QContactFilter());
+    }
 
-    connect(req,SIGNAL(stateChanged(QContactAbstractRequest::State)), this, SLOT(requestUpdated()));
+    d->m_fetchRequest->setFetchHint(d->m_fetchHint ? d->m_fetchHint->fetchHint() : QContactFetchHint());
 
-    req->start();
+    connect(d->m_fetchRequest,SIGNAL(stateChanged(QContactAbstractRequest::State)), this, SLOT(requestUpdated()));
+
+    d->m_fetchRequest->start();
 }
 
 void QDeclarativeContactModel::requestUpdated()
 {
+    //Don't use d->m_fetchRequest, this pointer might be invalid if cancelUpdate() was called, use QObject::sender() instead.
     QContactFetchRequest* req = qobject_cast<QContactFetchRequest*>(QObject::sender());
     if (req && req->isFinished()) {
         QList<QContact> contacts = req->contacts();
+        if (d->m_contacts.isEmpty()) {
+            QList<QDeclarativeContact*> dcs;
+            foreach (QContact c, contacts) {
+                QDeclarativeContact* dc = new QDeclarativeContact(c, d->m_manager->detailDefinitions(c.type()), this);
+                dcs.append(dc);
+                d->m_contactMap.insert(c.localId(), dc);
+            }
 
-        QList<QDeclarativeContact*> dcs;
-        foreach(QContact c, contacts) {
-            QDeclarativeContact* dc = new QDeclarativeContact(c, d->m_manager->detailDefinitions(c.type()), this);
-            dcs.append(dc);
-            d->m_contactMap.insert(c.localId(), dc);
+            reset();
+            beginInsertRows(QModelIndex(), 0, req->contacts().count());
+            d->m_contacts = dcs;
+            endInsertRows();
+        } else {
+            //Partial updating, insert the fetched contacts into the the exist contact list.
+            QList<QDeclarativeContact*> dcs;
+            foreach (QContact c, contacts) {
+                if (d->m_contactMap.contains(c.localId())) {
+                    d->m_contactMap.value(c.localId())->setContact(c);
+                } else {
+                    QDeclarativeContact* dc = new QDeclarativeContact(c, d->m_manager->detailDefinitions(c.type()), this);
+                    dcs.append(dc);
+                    d->m_contactMap.insert(c.localId(), dc);
+                }
+            }
         }
-
-        reset();
-        beginInsertRows(QModelIndex(), 0, req->contacts().count());
-        d->m_contacts = dcs;
-        endInsertRows();
         emit contactsChanged();
+        emit errorChanged();
         req->deleteLater();
+        d->m_fetchRequest = 0;
+        d->m_updatePending = false;
     }
 }
 
@@ -488,7 +587,7 @@ void QDeclarativeContactModel::requestUpdated()
 void QDeclarativeContactModel::saveContact(QDeclarativeContact* dc)
 {
     if (dc) {
-        QContact c = dc->contact();
+        QContact c = d->m_manager->compatibleContact(dc->contact());
         QContactSaveRequest* req = new QContactSaveRequest(this);
         req->setManager(d->m_manager);
         req->setContact(c);
@@ -520,12 +619,14 @@ void QDeclarativeContactModel::contactsSaved()
             }
         }
         req->deleteLater();
+        emit errorChanged();
     }
 }
 
 /*!
   \qmlmethod ContactModel::removeContact(int contactId)
   Remove the contact from the contacts store by given \a contactId.
+  \sa Contact::contactId
   */
 void QDeclarativeContactModel::removeContact(QContactLocalId id)
 {
@@ -535,6 +636,7 @@ void QDeclarativeContactModel::removeContact(QContactLocalId id)
 /*!
   \qmlmethod ContactModel::removeContacts(list<int> contactIds)
   Remove the list of contacts from the contacts store by given \a contactIds.
+  \sa Contact::contactId
   */
 
 void QDeclarativeContactModel::removeContacts(const QList<QContactLocalId>& ids)
@@ -543,7 +645,7 @@ void QDeclarativeContactModel::removeContacts(const QList<QContactLocalId>& ids)
     req->setManager(d->m_manager);
     req->setContactIds(ids);
 
-    connect(req,SIGNAL(stateChanged(QContactAbstractRequest::State)), this, SLOT(contactRemoved()));
+    connect(req,SIGNAL(stateChanged(QContactAbstractRequest::State)), this, SLOT(contactsRemoved()));
 
     req->start();
 }
@@ -569,46 +671,57 @@ void QDeclarativeContactModel::contactsRemoved(const QList<QContactLocalId>& ids
             }
         }
     }
+    emit errorChanged();
     if (emitSignal)
         emit contactsChanged();
 }
 
 void QDeclarativeContactModel::contactsChanged(const QList<QContactLocalId>& ids)
 {
-    QList<QContactLocalId> updatedIds;
-    foreach (const QContactLocalId& id, ids) {
-        if (d->m_contactMap.contains(id)) {
-            updatedIds << id;
+    if (d->m_autoUpdate) {
+        QList<QContactLocalId> updatedIds;
+        foreach (const QContactLocalId& id, ids) {
+            if (d->m_contactMap.contains(id)) {
+                updatedIds << id;
+            }
         }
-    }
 
-    if (updatedIds.count() > 0)
-        fetchContacts(updatedIds);
+        if (updatedIds.count() > 0)
+            fetchContacts(updatedIds);
+    }
 }
 
 void QDeclarativeContactModel::contactsRemoved()
 {
-    QContactRemoveRequest* req = qobject_cast<QContactRemoveRequest*>(QObject::sender());
+    if (d->m_autoUpdate) {
+        QContactRemoveRequest* req = qobject_cast<QContactRemoveRequest*>(QObject::sender());
 
 
-    if (req->isFinished()) {
-        QList<QContactLocalId> ids = req->contactIds();
-        QList<int> errorIds = req->errorMap().keys();
-        QList<QContactLocalId> removedIds;
-        for( int i = 0; i < ids.count(); i++) {
-            if (!errorIds.contains(i))
-                removedIds << ids.at(i);
+        if (req->isFinished()) {
+            QList<QContactLocalId> ids = req->contactIds();
+            QList<int> errorIds = req->errorMap().keys();
+            QList<QContactLocalId> removedIds;
+            for (int i = 0; i < ids.count(); i++) {
+                if (!errorIds.contains(i))
+                    removedIds << ids.at(i);
+            }
+            if (!removedIds.isEmpty())
+                contactsRemoved(removedIds);
+            req->deleteLater();
         }
-        if (!removedIds.isEmpty())
-            contactsRemoved(removedIds);
-        req->deleteLater();
     }
 }
 
 
 QVariant QDeclarativeContactModel::data(const QModelIndex &index, int role) const
 {
+    //Check if QList itme's index is valid before access it, index should be between 0 and count - 1
+    if (index.row() < 0 || index.row() >= d->m_contacts.count()) {
+        return QVariant();
+    }
+
     QDeclarativeContact* dc = d->m_contacts.value(index.row());
+    Q_ASSERT(dc);
     QContact c = dc->contact();
 
     switch(role) {
@@ -627,3 +740,50 @@ QVariant QDeclarativeContactModel::data(const QModelIndex &index, int role) cons
     return QVariant();
 }
 
+
+void QDeclarativeContactModel::sortOrder_append(QDeclarativeListProperty<QDeclarativeContactSortOrder> *p, QDeclarativeContactSortOrder *sortOrder)
+{
+    QDeclarativeContactModel* model = qobject_cast<QDeclarativeContactModel*>(p->object);
+    if (model && sortOrder) {
+        QObject::connect(sortOrder, SIGNAL(sortOrderChanged()), model, SIGNAL(sortOrdersChanged()));
+        model->d->m_sortOrders.append(sortOrder);
+        emit model->sortOrdersChanged();
+    }
+}
+
+int  QDeclarativeContactModel::sortOrder_count(QDeclarativeListProperty<QDeclarativeContactSortOrder> *p)
+{
+    QDeclarativeContactModel* model = qobject_cast<QDeclarativeContactModel*>(p->object);
+    if (model)
+        return model->d->m_sortOrders.size();
+    return 0;
+}
+QDeclarativeContactSortOrder * QDeclarativeContactModel::sortOrder_at(QDeclarativeListProperty<QDeclarativeContactSortOrder> *p, int idx)
+{
+    QDeclarativeContactModel* model = qobject_cast<QDeclarativeContactModel*>(p->object);
+
+    QDeclarativeContactSortOrder* sortOrder = 0;
+    if (model) {
+        int i = 0;
+        foreach (QDeclarativeContactSortOrder* s, model->d->m_sortOrders) {
+            if (i == idx) {
+                sortOrder = s;
+                break;
+            } else {
+                i++;
+            }
+        }
+    }
+    return sortOrder;
+}
+void  QDeclarativeContactModel::sortOrder_clear(QDeclarativeListProperty<QDeclarativeContactSortOrder> *p)
+{
+    QDeclarativeContactModel* model = qobject_cast<QDeclarativeContactModel*>(p->object);
+
+    if (model) {
+        model->d->m_sortOrders.clear();
+        emit model->sortOrdersChanged();
+    }
+}
+
+
