@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -592,6 +592,7 @@ void QDeclarativeDocumentGalleryModel::classBegin()
     \qmlproperty QStringList DocumentGalleryModel::properties
 
     This property holds the item properties a query should return values for.
+    All supported properties are listed \l QDocumentGallery.
 */
 
 /*!
@@ -599,6 +600,10 @@ void QDeclarativeDocumentGalleryModel::classBegin()
 
     This property holds the properties the results of a query should be sorted
     on.
+
+    Prefixing a property name with the '+' character indicates it should be sorted
+    in ascending order, and a '-' character prefix indicates a descending order. If
+    there is no prefix ascending order is assumed.
 */
 
 /*!
@@ -698,30 +703,6 @@ void QDeclarativeDocumentGalleryModel::setRootType(QDeclarativeDocumentGallery::
     Clears the results of a query.
 */
 
-/*!
-    \qmlsignal DocumentGalleryModel::onSucceeded()
-
-    Signals that a query has finished successfully.
-*/
-
-/*!
-    \qmlsignal DocumentGalleryModel::onCanceled()
-
-    Signals that a query was canceled.
-*/
-
-/*!
-    \qmlsignal DocumentGalleryModel::onFailed(error)
-
-    Signals that a query failed with the given \a error.
-*/
-
-/*!
-    \qmlsignal DocumentGalleryModel::onFinished(result)
-
-    Signals that a query finished with the given \a result.
-*/
-
 /*!
     \qmlproperty int DocumentGalleryModel::count
 
