@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -49,14 +43,14 @@
 
 #include <QtCore/qcoreevent.h>
 #include <QtCore/qurl.h>
+#include <QtDeclarative/qdeclarativeinfo.h>
 
 #include <qmediaplayercontrol.h>
 #include <qmediaservice.h>
 #include <qmediaserviceprovider.h>
 #include <qmetadatareadercontrol.h>
-#include "qmetadatacontrolmetaobject_p.h"
-
 
+#include "qdeclarativemediametadata_p.h"
 
 QT_BEGIN_NAMESPACE
 
@@ -104,6 +98,25 @@ public:
     void stop() {}
 };
 
+
+class QDeclarativeMediaBaseMetaDataControl : public QMetaDataReaderControl
+{
+public:
+    QDeclarativeMediaBaseMetaDataControl(QObject *parent)
+        : QMetaDataReaderControl(parent)
+    {
+    }
+
+    bool isMetaDataAvailable() const { return false; }
+
+    QVariant metaData(QtMultimediaKit::MetaData) const { return QVariant(); }
+    QList<QtMultimediaKit::MetaData> availableMetaData() const {
+        return QList<QtMultimediaKit::MetaData>(); }
+
+    QVariant extendedMetaData(const QString &) const { return QVariant(); }
+    QStringList availableExtendedMetaData() const { return QStringList(); }
+};
+
 class QDeclarativeMediaBaseAnimation : public QObject
 {
 public:
@@ -121,7 +134,7 @@ protected:
         if (event->timerId() == m_timer.timerId()) {
             event->accept();
 
-            if (m_media->m_state == QMediaPlayer::PlayingState)
+            if (m_media->m_playing && !m_media->m_paused)
                 emit m_media->positionChanged();
             if (m_media->m_status == QMediaPlayer::BufferingMedia || QMediaPlayer::StalledMedia)
                 emit m_media->bufferProgressChanged();
@@ -135,49 +148,69 @@ private:
     QBasicTimer m_timer;
 };
 
-void QDeclarativeMediaBase::_q_stateChanged(QMediaPlayer::State state)
+void QDeclarativeMediaBase::_q_statusChanged()
 {
-    if (m_state == state)
-        return;
+    if (m_playerControl->mediaStatus() == QMediaPlayer::EndOfMedia && m_runningCount != 0) {
+        m_runningCount -= 1;
+        m_playerControl->play();
+    }
+
+    const QMediaPlayer::MediaStatus oldStatus = m_status;
+    const bool wasPlaying = m_playing;
+    const bool wasPaused = m_paused;
+
+    const QMediaPlayer::State state = m_playerControl->state();
+
+    m_status = m_playerControl->mediaStatus();
+
+    if (m_complete)
+        m_playing = state != QMediaPlayer::StoppedState;
+
+    if (state == QMediaPlayer::PausedState)
+        m_paused = true;
+    else if (state == QMediaPlayer::PlayingState)
+        m_paused = false;
+
+    if (m_status != oldStatus)
+        emit statusChanged();
 
     switch (state) {
-    case QMediaPlayer::StoppedState: {
+    case QMediaPlayer::StoppedState:
+        if (wasPlaying) {
             emit stopped();
 
-            if (m_playing) {
-                m_playing = false;
+            if (!m_playing)
                 emit playingChanged();
-            }
         }
         break;
-    case QMediaPlayer::PausedState: {
+    case QMediaPlayer::PausedState:
+        if (!wasPlaying) {
+            emit started();
+            if (m_playing)
+                emit playingChanged();
+        }
+        if ((!wasPaused || !wasPlaying) && m_paused)
             emit paused();
+        if (!wasPaused && m_paused)
+            emit pausedChanged();
 
-            if (!m_paused) {
-                m_paused = true;
-                emit pausedChanged();
-            }
-
-            if (m_state == QMediaPlayer::StoppedState)
-                emit started();
-        }
         break;
-    case QMediaPlayer::PlayingState: {
-            if (m_state == QMediaPlayer::PausedState)
-                emit resumed();
-            else
-                emit started();
 
-           if (m_paused) {
-               m_paused = false;
-               emit pausedChanged();
-           }
-        }
+    case QMediaPlayer::PlayingState:
+        if (wasPaused && wasPlaying)
+            emit resumed();
+        else
+            emit started();
+
+        if (wasPaused && !m_paused)
+            emit pausedChanged();
+        if (!wasPlaying && m_playing)
+            emit playingChanged();
         break;
     }
 
     // Check
-    if (state == QMediaPlayer::PlayingState
+    if ((m_playing && !m_paused)
             || m_status == QMediaPlayer::BufferingMedia
             || m_status == QMediaPlayer::StalledMedia) {
         m_animation->start();
@@ -185,50 +218,6 @@ void QDeclarativeMediaBase::_q_stateChanged(QMediaPlayer::State state)
     else {
         m_animation->stop();
     }
-
-    m_state = state;
-}
-
-void QDeclarativeMediaBase::_q_mediaStatusChanged(QMediaPlayer::MediaStatus status)
-{
-    if (status != m_status) {
-        m_status = status;
-
-        switch (status) {
-        case QMediaPlayer::LoadedMedia:
-            emit loaded();
-            break;
-        case QMediaPlayer::BufferingMedia:
-            emit buffering();
-            break;
-        case QMediaPlayer::BufferedMedia:
-            emit buffered();
-            break;
-        case QMediaPlayer::StalledMedia:
-            emit stalled();
-            break;
-        case QMediaPlayer::EndOfMedia:
-            emit endOfMedia();
-            break;
-        default:
-            break;
-        }
-
-        emit statusChanged();
-
-        if (m_state == QMediaPlayer::PlayingState
-                || m_status == QMediaPlayer::BufferingMedia
-                || m_status == QMediaPlayer::StalledMedia) {
-            m_animation->start();
-        } else {
-            m_animation->stop();
-        }
-    }
-}
-
-void QDeclarativeMediaBase::_q_metaDataChanged()
-{
-    m_metaObject->metaDataChanged();
 }
 
 QDeclarativeMediaBase::QDeclarativeMediaBase()
@@ -237,17 +226,19 @@ QDeclarativeMediaBase::QDeclarativeMediaBase()
     , m_autoLoad(true)
     , m_loaded(false)
     , m_muted(false)
+    , m_complete(false)
+    , m_loopCount(1)
+    , m_runningCount(0)
     , m_position(0)
     , m_vol(1.0)
     , m_playbackRate(1.0)
     , m_mediaService(0)
     , m_playerControl(0)
+    , m_qmlObject(0)
     , m_mediaObject(0)
     , m_mediaProvider(0)
     , m_metaDataControl(0)
-    , m_metaObject(0)
     , m_animation(0)
-    , m_state(QMediaPlayer::StoppedState)
     , m_status(QMediaPlayer::NoMedia)
     , m_error(QMediaPlayer::ServiceMissingError)
 {
@@ -259,8 +250,8 @@ QDeclarativeMediaBase::~QDeclarativeMediaBase()
 
 void QDeclarativeMediaBase::shutdown()
 {
-    delete m_metaObject;
     delete m_mediaObject;
+    m_metaData.reset();
 
     if (m_mediaProvider)
         m_mediaProvider->releaseService(m_mediaService);
@@ -271,6 +262,8 @@ void QDeclarativeMediaBase::shutdown()
 
 void QDeclarativeMediaBase::setObject(QObject *object)
 {
+    m_qmlObject = object;
+
     if ((m_mediaProvider = QMediaServiceProvider::defaultServiceProvider()) != 0) {
         if ((m_mediaService = m_mediaProvider->requestService(Q_MEDIASERVICE_MEDIAPLAYER)) != 0) {
             m_playerControl = qobject_cast<QMediaPlayerControl *>(
@@ -283,9 +276,9 @@ void QDeclarativeMediaBase::setObject(QObject *object)
 
     if (m_playerControl) {
         QObject::connect(m_playerControl, SIGNAL(stateChanged(QMediaPlayer::State)),
-                object, SLOT(_q_stateChanged(QMediaPlayer::State)));
+                object, SLOT(_q_statusChanged()));
         QObject::connect(m_playerControl, SIGNAL(mediaStatusChanged(QMediaPlayer::MediaStatus)),
-                object, SLOT(_q_mediaStatusChanged(QMediaPlayer::MediaStatus)));
+                object, SLOT(_q_statusChanged()));
         QObject::connect(m_playerControl, SIGNAL(mediaChanged(QMediaContent)),
                 object, SIGNAL(sourceChanged()));
         QObject::connect(m_playerControl, SIGNAL(durationChanged(qint64)),
@@ -311,14 +304,17 @@ void QDeclarativeMediaBase::setObject(QObject *object)
         m_playerControl = new QDeclarativeMediaBasePlayerControl(object);
     }
 
-    if (m_metaDataControl) {
-        m_metaObject = new QMetaDataControlMetaObject(m_metaDataControl, object);
+    if (!m_metaDataControl)
+        m_metaDataControl = new QDeclarativeMediaBaseMetaDataControl(object);
 
-        QObject::connect(m_metaDataControl, SIGNAL(metaDataChanged()),
-                object, SLOT(_q_metaDataChanged()));
-    }
+    m_metaData.reset(new QDeclarativeMediaMetaData(m_metaDataControl));
 
-    // Init
+    QObject::connect(m_metaDataControl, SIGNAL(metaDataChanged()),
+            m_metaData.data(), SIGNAL(metaDataChanged()));
+}
+
+void QDeclarativeMediaBase::componentComplete()
+{
     m_playerControl->setVolume(m_vol * 100);
     m_playerControl->setMuted(m_muted);
     m_playerControl->setPlaybackRate(m_playbackRate);
@@ -326,16 +322,24 @@ void QDeclarativeMediaBase::setObject(QObject *object)
     if (!m_source.isEmpty() && (m_autoLoad || m_playing)) // Override autoLoad if playing set
         m_playerControl->setMedia(m_source, 0);
 
-    if (m_paused)
-        m_playerControl->pause();
-    else if (m_playing)
-        m_playerControl->play();
+    m_complete = true;
 
-    if ((m_playing || m_paused) && m_position > 0)
-        m_playerControl->setPosition(m_position);
+    if (m_playing) {
+        if (m_position > 0)
+            m_playerControl->setPosition(m_position);
+
+        if (m_source.isEmpty()) {
+            m_playing = false;
+
+            emit playingChanged();
+        } else if (m_paused) {
+            m_playerControl->pause();
+        } else {
+            m_playerControl->play();
+        }
+    }
 }
 
-
 // Properties
 
 QUrl QDeclarativeMediaBase::source() const
@@ -350,7 +354,7 @@ void QDeclarativeMediaBase::setSource(const QUrl &url)
 
     m_source = url;
     m_loaded = false;
-    if (m_playerControl != 0 && m_autoLoad) {
+    if (m_complete && (m_autoLoad || url.isEmpty())) {
         if (m_error != QMediaPlayer::ServiceMissingError && m_error != QMediaPlayer::NoError) {
             m_error = QMediaPlayer::NoError;
             m_errorString = QString();
@@ -379,6 +383,25 @@ void QDeclarativeMediaBase::setAutoLoad(bool autoLoad)
     emit autoLoadChanged();
 }
 
+int QDeclarativeMediaBase::loopCount() const
+{
+    return m_loopCount;
+}
+
+void QDeclarativeMediaBase::setLoopCount(int loopCount)
+{
+    if (loopCount == 0)
+        loopCount = 1;
+    else if (loopCount < -1)
+        loopCount = -1;
+
+    if (m_loopCount == loopCount) {
+        return;
+    }
+    m_loopCount = loopCount;
+    emit loopCountChanged();
+}
+
 bool QDeclarativeMediaBase::isPlaying() const
 {
     return m_playing;
@@ -389,25 +412,27 @@ void QDeclarativeMediaBase::setPlaying(bool playing)
     if (playing == m_playing)
         return;
 
-    m_playing = playing;
-    if (m_playerControl != 0) {
-        if (m_playing) {
+    if (m_complete) {
+        if (playing) {
             if (!m_autoLoad && !m_loaded) {
                 m_playerControl->setMedia(m_source, 0);
                 m_playerControl->setPosition(m_position);
                 m_loaded = true;
             }
 
+            m_runningCount = m_loopCount - 1;
+
             if (!m_paused)
                 m_playerControl->play();
             else
                 m_playerControl->pause();
-        }
-        else if (m_state != QMediaPlayer::StoppedState)
+        } else {
             m_playerControl->stop();
+        }
+    } else {
+        m_playing = playing;
+        emit playingChanged();
     }
-
-    emit playingChanged();
 }
 
 bool QDeclarativeMediaBase::isPaused() const
@@ -420,42 +445,40 @@ void QDeclarativeMediaBase::setPaused(bool paused)
     if (m_paused == paused)
         return;
 
-    m_paused = paused;
-    if (m_playerControl != 0) {
+    if (m_complete && m_playing) {
         if (!m_autoLoad && !m_loaded) {
             m_playerControl->setMedia(m_source, 0);
             m_playerControl->setPosition(m_position);
             m_loaded = true;
         }
 
-        if (m_paused && m_state == QMediaPlayer::PlayingState) {
-            m_playerControl->pause();
-        }
-        else if (!m_paused && m_playing) {
+        if (!paused)
             m_playerControl->play();
-        }
+        else
+            m_playerControl->pause();
+    } else {
+        m_paused = paused;
+        emit pausedChanged();
     }
-
-    emit pausedChanged();
 }
 
 int QDeclarativeMediaBase::duration() const
 {
-    return m_playerControl == 0 ? 0 : m_playerControl->duration();
+    return !m_complete ? 0 : m_playerControl->duration();
 }
 
 int QDeclarativeMediaBase::position() const
 {
-    return m_playerControl == 0 ? m_position : m_playerControl->position();
+    return !m_complete ? m_position : m_playerControl->position();
 }
 
 void QDeclarativeMediaBase::setPosition(int position)
 {
-    if (m_position == position)
+    if (this->position() == position)
         return;
 
     m_position = position;
-    if (m_playerControl != 0)
+    if (m_complete)
         m_playerControl->setPosition(m_position);
     else
         emit positionChanged();
@@ -463,17 +486,22 @@ void QDeclarativeMediaBase::setPosition(int position)
 
 qreal QDeclarativeMediaBase::volume() const
 {
-    return m_playerControl == 0 ? m_vol : qreal(m_playerControl->volume()) / 100;
+    return !m_complete ? m_vol : qreal(m_playerControl->volume()) / 100;
 }
 
 void QDeclarativeMediaBase::setVolume(qreal volume)
 {
+    if (volume < 0 || volume > 1) {
+        qmlInfo(m_qmlObject) << m_qmlObject->tr("volume should be between 0.0 and 1.0");
+        return;
+    }
+
     if (m_vol == volume)
         return;
 
     m_vol = volume;
 
-    if (m_playerControl != 0)
+    if (m_complete)
         m_playerControl->setVolume(qRound(volume * 100));
     else
         emit volumeChanged();
@@ -481,7 +509,7 @@ void QDeclarativeMediaBase::setVolume(qreal volume)
 
 bool QDeclarativeMediaBase::isMuted() const
 {
-    return m_playerControl == 0 ? m_muted : m_playerControl->isMuted();
+    return !m_complete ? m_muted : m_playerControl->isMuted();
 }
 
 void QDeclarativeMediaBase::setMuted(bool muted)
@@ -491,7 +519,7 @@ void QDeclarativeMediaBase::setMuted(bool muted)
 
     m_muted = muted;
 
-    if (m_playerControl != 0)
+    if (m_complete)
         m_playerControl->setMuted(muted);
     else
         emit mutedChanged();
@@ -499,12 +527,12 @@ void QDeclarativeMediaBase::setMuted(bool muted)
 
 qreal QDeclarativeMediaBase::bufferProgress() const
 {
-    return m_playerControl == 0 ? 0 : qreal(m_playerControl->bufferStatus()) / 100;
+    return !m_complete ? 0 : qreal(m_playerControl->bufferStatus()) / 100;
 }
 
 bool QDeclarativeMediaBase::isSeekable() const
 {
-    return m_playerControl == 0 ? false : m_playerControl->isSeekable();
+    return !m_complete ? false : m_playerControl->isSeekable();
 }
 
 qreal QDeclarativeMediaBase::playbackRate() const
@@ -519,7 +547,7 @@ void QDeclarativeMediaBase::setPlaybackRate(qreal rate)
 
     m_playbackRate = rate;
 
-    if (m_playerControl != 0)
+    if (m_complete)
         m_playerControl->setPlaybackRate(m_playbackRate);
     else
         emit playbackRateChanged();
@@ -530,5 +558,10 @@ QString QDeclarativeMediaBase::errorString() const
     return m_errorString;
 }
 
+QDeclarativeMediaMetaData *QDeclarativeMediaBase::metaData() const
+{
+    return m_metaData.data();
+}
+
 QT_END_NAMESPACE
 
