@@ -7,11 +7,11 @@
 ** This file is part of the QtDeclarative module of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -43,7 +43,7 @@
 #define QDECLARATIVEORGANIZERITEMDETAIL_H
 
 #include <QtDeclarative>
-
+#include <QtDeclarative/qdeclarativeinfo.h>
 #include <QVariant>
 #include "qorganizeritemdetail.h"
 #include "qorganizeritemdetails.h"
@@ -142,8 +142,10 @@ public:
         return ok;
     }
 
+    static QString detailName(ItemDetailType type) ;
     static QString definitionName(ItemDetailType type) ;
-    static ItemDetailType detailType(const QString& definitionName) ;
+    static ItemDetailType detailTypeByDefinitionName(const QString& definitionName) ;
+    static ItemDetailType detailTypeByDetailName(const QString& definitionName) ;
     static QString fieldName(ItemDetailType detailType, int fieldType);
 
 signals:
@@ -175,6 +177,7 @@ public:
     QDeclarativeOrganizerEventTime(QObject* parent = 0)
         :QDeclarativeOrganizerItemDetail(parent)
     {
+        setDetail(QOrganizerEventTime());
         connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
     }
 
@@ -186,19 +189,19 @@ public:
     void setStartDateTime(const QDateTime& datetime)
     {
          if (datetime != startDateTime() && !readOnly()) {
-            m_detail.setValue(QOrganizerEventTime::FieldStartDateTime, datetime);
+            m_detail.setValue(QOrganizerEventTime::FieldStartDateTime, datetime.toUTC());
             emit valueChanged();
          }
     }
-    QDateTime startDateTime() const {return m_detail.value<QDateTime>(QOrganizerEventTime::FieldStartDateTime);}
+    QDateTime startDateTime() const {return m_detail.value<QDateTime>(QOrganizerEventTime::FieldStartDateTime).toLocalTime();}
     void setEndDateTime(const QDateTime& datetime)
     {
         if (datetime != endDateTime() && !readOnly()) {
-            m_detail.setValue(QOrganizerEventTime::FieldEndDateTime, datetime);
+            m_detail.setValue(QOrganizerEventTime::FieldEndDateTime, datetime.toUTC());
             emit valueChanged();
         }
     }
-    QDateTime endDateTime() const {return m_detail.value<QDateTime>(QOrganizerEventTime::FieldEndDateTime);}
+    QDateTime endDateTime() const {return m_detail.value<QDateTime>(QOrganizerEventTime::FieldEndDateTime).toLocalTime();}
     void setAllDay(bool allDay)
     {
         if (allDay != isAllDay() && !readOnly()) {
@@ -230,6 +233,7 @@ public:
     QDeclarativeOrganizerItemComment(QObject* parent = 0)
         :QDeclarativeOrganizerItemDetail(parent)
     {
+        setDetail(QOrganizerItemComment());
         connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
     }
     virtual ItemDetailType type() const
@@ -267,6 +271,7 @@ public:
     QDeclarativeOrganizerItemDescription(QObject* parent = 0)
         :QDeclarativeOrganizerItemDetail(parent)
     {
+        setDetail(QOrganizerItemDescription());
         connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
     }
     virtual ItemDetailType type() const
@@ -303,6 +308,7 @@ public:
     QDeclarativeOrganizerItemDisplayLabel(QObject* parent = 0)
         :QDeclarativeOrganizerItemDetail(parent)
     {
+        setDetail(QOrganizerItemDisplayLabel());
         connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
     }
     virtual ItemDetailType type() const
@@ -339,6 +345,7 @@ public:
     QDeclarativeOrganizerItemGuid(QObject* parent = 0)
         :QDeclarativeOrganizerItemDetail(parent)
     {
+        setDetail(QOrganizerItemGuid());
         connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
     }
     virtual ItemDetailType type() const
@@ -364,7 +371,7 @@ QML_DECLARE_TYPE(QDeclarativeOrganizerItemGuid)
 class QDeclarativeOrganizerItemParent : public QDeclarativeOrganizerItemDetail
 {
     Q_OBJECT
-    Q_PROPERTY(uint parentId READ parentId WRITE setParentId NOTIFY valueChanged)
+    Q_PROPERTY(QString parentId READ parentId WRITE setParentId NOTIFY valueChanged)
     Q_PROPERTY(QDate originalDate READ originalDate WRITE setOriginalDate NOTIFY valueChanged)
 
     Q_ENUMS(FieldType)
@@ -379,6 +386,7 @@ public:
     QDeclarativeOrganizerItemParent(QObject* parent = 0)
         :QDeclarativeOrganizerItemDetail(parent)
     {
+        setDetail(QOrganizerItemParent());
         connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
     }
 
@@ -387,16 +395,16 @@ public:
         return QDeclarativeOrganizerItemDetail::Parent;
     }
 
-    void setParentId(uint newParentId)
+    void setParentId(const QString& newParentId)
     {
         if (newParentId != parentId() && !readOnly()) {
-            m_detail.setValue(QOrganizerItemParent::FieldParentId, newParentId);
+            m_detail.setValue(QOrganizerItemParent::FieldParentId, QVariant::fromValue(QOrganizerItemId::fromString(newParentId)));
             emit valueChanged();
         }
     }
-    uint parentId() const
+    QString parentId() const
     {
-        return m_detail.variantValue(QOrganizerItemParent::FieldParentId).toInt();
+        return m_detail.variantValue(QOrganizerItemParent::FieldParentId).value<QOrganizerItemId>().toString();
     }
 
 
@@ -435,6 +443,7 @@ public:
     QDeclarativeOrganizerItemLocation(QObject* parent = 0)
         :QDeclarativeOrganizerItemDetail(parent)
     {
+        setDetail(QOrganizerItemLocation());
         connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
     }
     virtual ItemDetailType type() const
@@ -502,6 +511,7 @@ public:
     QDeclarativeOrganizerItemPriority(QObject* parent = 0)
         :QDeclarativeOrganizerItemDetail(parent)
     {
+        setDetail(QOrganizerItemPriority());
         connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
     }
     virtual ItemDetailType type() const
@@ -545,6 +555,7 @@ public:
     QDeclarativeOrganizerItemRecurrence(QObject* parent = 0)
         :QDeclarativeOrganizerItemDetail(parent)
     {
+        setDetail(QOrganizerItemRecurrence());
         connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
         connect(this, SIGNAL(recurrenceRulesChanged()), SLOT(_saveRecurrenceRules()));
         connect(this, SIGNAL(exceptionRulesChanged()), SLOT(_saveExceptionRules()));
@@ -627,10 +638,10 @@ QML_DECLARE_TYPE(QDeclarativeOrganizerItemRecurrence)
 class QDeclarativeOrganizerItemReminder : public QDeclarativeOrganizerItemDetail
 {
     Q_OBJECT
-    Q_PROPERTY(ReminderType reminderType READ reminderType NOTIFY valueChanged)
-    Q_PROPERTY(int secondsBeforeStart READ secondsBeforeStart WRITE setSecondsBeforeStart NOTIFY valueChanged)
-    Q_PROPERTY(int repetitionCount READ repetitionCount WRITE setRepetitionCount NOTIFY valueChanged)
-    Q_PROPERTY(int repetitionDelay READ repetitionDelay WRITE setRepetitionDelay NOTIFY valueChanged)
+    Q_PROPERTY(ReminderType reminderType READ reminderType NOTIFY reminderChanged)
+    Q_PROPERTY(int secondsBeforeStart READ secondsBeforeStart WRITE setSecondsBeforeStart NOTIFY reminderChanged)
+    Q_PROPERTY(int repetitionCount READ repetitionCount WRITE setRepetitionCount NOTIFY reminderChanged)
+    Q_PROPERTY(int repetitionDelay READ repetitionDelay WRITE setRepetitionDelay NOTIFY reminderChanged)
     Q_ENUMS(ReminderType)
     Q_ENUMS(FieldType)
 public:
@@ -654,7 +665,8 @@ public:
     QDeclarativeOrganizerItemReminder(QObject* parent = 0)
         :QDeclarativeOrganizerItemDetail(parent)
     {
-        connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
+        setDetail(QOrganizerItemReminder());
+        connect(this, SIGNAL(reminderChanged()), SIGNAL(detailChanged()));
     }
 
     virtual ItemDetailType type() const
@@ -679,7 +691,7 @@ public:
     {
         if (seconds != secondsBeforeStart() && !readOnly()) {
             m_detail.setValue(QOrganizerItemReminder::FieldSecondsBeforeStart, seconds);
-            emit valueChanged();
+            emit reminderChanged();
         }
     }
     int secondsBeforeStart() const {return m_detail.value<int>(QOrganizerItemReminder::FieldSecondsBeforeStart);}
@@ -688,21 +700,21 @@ public:
     {
         if (delaySeconds != repetitionDelay() && !readOnly()) {
             m_detail.setValue(QOrganizerItemReminder::FieldRepetitionDelay, delaySeconds);
-            emit valueChanged();
+            emit reminderChanged();
         }
     }
     void setRepetitionCount(int count)
     {
         if (count != repetitionCount() && !readOnly()) {
             m_detail.setValue(QOrganizerItemReminder::FieldRepetitionCount, count);
-            emit valueChanged();
+            emit reminderChanged();
         }
     }
     int repetitionDelay() const {return m_detail.value<int>(QOrganizerItemReminder::FieldRepetitionDelay);}
     int repetitionCount() const {return m_detail.value<int>(QOrganizerItemReminder::FieldRepetitionCount);}
 
 signals:
-    void valueChanged();
+    void reminderChanged();
 };
 QML_DECLARE_TYPE(QDeclarativeOrganizerItemReminder)
 
@@ -723,6 +735,7 @@ public:
     QDeclarativeOrganizerItemAudibleReminder(QObject* parent = 0)
         :QDeclarativeOrganizerItemReminder(parent)
     {
+        setDetail(QOrganizerItemAudibleReminder());
         connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
     }
     virtual ItemDetailType type() const
@@ -761,6 +774,7 @@ public:
     QDeclarativeOrganizerItemVisualReminder(QObject* parent = 0)
         :QDeclarativeOrganizerItemReminder(parent)
     {
+        setDetail(QOrganizerItemVisualReminder());
         connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
     }
 
@@ -813,6 +827,7 @@ public:
     QDeclarativeOrganizerItemEmailReminder(QObject* parent = 0)
         :QDeclarativeOrganizerItemReminder(parent)
     {
+        setDetail(QOrganizerItemEmailReminder());
         connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
     }
     virtual ItemDetailType type() const
@@ -878,6 +893,7 @@ public:
     QDeclarativeOrganizerItemTimestamp(QObject* parent = 0)
         :QDeclarativeOrganizerItemDetail(parent)
     {
+        setDetail(QOrganizerItemTimestamp());
         connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
     }
     virtual ItemDetailType type() const
@@ -887,19 +903,19 @@ public:
     void setLastModified(const QDateTime& timestamp)
     {
         if (timestamp != lastModified() && !readOnly()) {
-            m_detail.setValue(QOrganizerItemTimestamp::FieldModificationTimestamp, timestamp);
+            m_detail.setValue(QOrganizerItemTimestamp::FieldModificationTimestamp, timestamp.toUTC());
             emit valueChanged();
         }
     }
-    QDateTime lastModified() const {return m_detail.value<QDateTime>(QOrganizerItemTimestamp::FieldModificationTimestamp);}
+    QDateTime lastModified() const {return m_detail.value<QDateTime>(QOrganizerItemTimestamp::FieldModificationTimestamp).toLocalTime();}
     void setCreated(const QDateTime& timestamp)
     {
         if (timestamp != created() && !readOnly()) {
-            m_detail.setValue(QOrganizerItemTimestamp::FieldCreationTimestamp, timestamp);
+            m_detail.setValue(QOrganizerItemTimestamp::FieldCreationTimestamp, timestamp.toUTC());
             emit valueChanged();
         }
     }
-    QDateTime created() const {return m_detail.value<QDateTime>(QOrganizerItemTimestamp::FieldCreationTimestamp);}
+    QDateTime created() const {return m_detail.value<QDateTime>(QOrganizerItemTimestamp::FieldCreationTimestamp).toLocalTime();}
 
 signals:
     void valueChanged();
@@ -933,6 +949,7 @@ public:
     QDeclarativeOrganizerItemType(QObject* parent = 0)
         :QDeclarativeOrganizerItemDetail(parent)
     {
+        setDetail(QOrganizerItemType());
         connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
     }
     virtual ItemDetailType type() const
@@ -962,7 +979,7 @@ public:
                 m_detail.setValue(QOrganizerItemType::FieldType, QOrganizerItemType::TypeJournal);
                 break;
             default:
-                qWarning() << "I don't known how to set the customized item type name here!";
+                qmlInfo(this) << tr("I don't known how to set the customized item type name here!");
                 break;
             }
             emit valueChanged();
@@ -983,7 +1000,7 @@ public:
             return Note;
         else if (typeString == QOrganizerItemType::TypeJournal)
             return Journal;
-        qWarning() << "Unknown organizer item type: " << typeString;
+        qmlInfo(this) << tr("Unknown organizer item type: ") << typeString;
         return Customized;
     }
 
@@ -1008,6 +1025,7 @@ public:
     QDeclarativeOrganizerJournalTime(QObject* parent = 0)
         :QDeclarativeOrganizerItemDetail(parent)
     {
+        setDetail(QOrganizerJournalTime());
         connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
     }
     virtual ItemDetailType type() const
@@ -1017,11 +1035,11 @@ public:
     void setEntryDateTime(const QDateTime& datetime)
     {
         if (datetime != entryDateTime() && !readOnly()) {
-            m_detail.setValue(QOrganizerJournalTime::FieldEntryDateTime, datetime);
+            m_detail.setValue(QOrganizerJournalTime::FieldEntryDateTime, datetime.toUTC());
             emit valueChanged();
         }
     }
-    QDateTime entryDateTime() const {return m_detail.value<QDateTime>(QOrganizerJournalTime::FieldEntryDateTime);}
+    QDateTime entryDateTime() const {return m_detail.value<QDateTime>(QOrganizerJournalTime::FieldEntryDateTime).toLocalTime();}
 signals:
     void valueChanged();
 };
@@ -1055,6 +1073,8 @@ public:
     QDeclarativeOrganizerTodoProgress(QObject* parent = 0)
         :QDeclarativeOrganizerItemDetail(parent)
     {
+        setDetail(QOrganizerTodoProgress());
+        connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
     }
     virtual ItemDetailType type() const
     {
@@ -1064,11 +1084,11 @@ public:
     void setFinishedDateTime(const QDateTime& datetime)
     {
         if (datetime != finishedDateTime() && !readOnly()) {
-            m_detail.setValue(QOrganizerTodoProgress::FieldFinishedDateTime, datetime);
+            m_detail.setValue(QOrganizerTodoProgress::FieldFinishedDateTime, datetime.toUTC());
             emit valueChanged();
         }
     }
-    QDateTime finishedDateTime() const {return m_detail.value<QDateTime>(QOrganizerTodoProgress::FieldFinishedDateTime);}
+    QDateTime finishedDateTime() const {return m_detail.value<QDateTime>(QOrganizerTodoProgress::FieldFinishedDateTime).toLocalTime();}
 
     void setPercentageComplete(int percentage)
     {
@@ -1077,7 +1097,7 @@ public:
                 m_detail.setValue(QOrganizerTodoProgress::FieldPercentageComplete, percentage);
                 emit valueChanged();
             } else {
-                qWarning() << "Trying to set an invalid percentage value:" << percentage;
+                qmlInfo(this) << tr("Trying to set an invalid percentage value:") << percentage;
             }
         }
     }
@@ -1119,6 +1139,7 @@ public:
     QDeclarativeOrganizerTodoTime(QObject* parent = 0)
         :QDeclarativeOrganizerItemDetail(parent)
     {
+        setDetail(QOrganizerTodoTime());
         connect(this, SIGNAL(valueChanged()), SIGNAL(detailChanged()));
     }
     virtual ItemDetailType type() const
@@ -1128,19 +1149,19 @@ public:
     void setStartDateTime(const QDateTime& datetime)
     {
         if (datetime != startDateTime() && !readOnly()) {
-            m_detail.setValue(QOrganizerTodoTime::FieldStartDateTime, datetime);
+            m_detail.setValue(QOrganizerTodoTime::FieldStartDateTime, datetime.toUTC());
             emit valueChanged();
         }
     }
-    QDateTime startDateTime() const {return m_detail.value<QDateTime>(QOrganizerTodoTime::FieldStartDateTime);}
+    QDateTime startDateTime() const {return m_detail.value<QDateTime>(QOrganizerTodoTime::FieldStartDateTime).toLocalTime();}
     void setDueDateTime(const QDateTime& dateTime)
     {
         if (dateTime != dueDateTime() && !readOnly()) {
-            m_detail.setValue(QOrganizerTodoTime::FieldDueDateTime, dateTime);
+            m_detail.setValue(QOrganizerTodoTime::FieldDueDateTime, dateTime.toUTC());
             emit valueChanged();
         }
     }
-    QDateTime dueDateTime() const {return m_detail.value<QDateTime>(QOrganizerTodoTime::FieldDueDateTime);}
+    QDateTime dueDateTime() const {return m_detail.value<QDateTime>(QOrganizerTodoTime::FieldDueDateTime).toLocalTime();}
 
     void setAllDay(bool allDay)
     {
