@@ -4,15 +4,14 @@
  ** All rights reserved.
  ** Contact: Nokia Corporation (qt-info@nokia.com)
  **
- **  
  ** This file is part of the Qt Mobility Components.
  **
  ** $QT_BEGIN_LICENSE:LGPL$
- ** Commercial Usage
- ** Licensees holding valid Qt Commercial licenses may use this file in 
- ** accordance with the Qt Commercial License Agreement provided with
- ** the Software or, alternatively, in accordance with the terms
- ** contained in a written agreement between you and Nokia.
+ ** No Commercial Usage
+ ** This file contains pre-release code and may not be distributed.
+ ** You may use this file in accordance with the terms and conditions
+ ** contained in the Technology Preview License Agreement accompanying
+ ** this package.
  **
  ** GNU Lesser General Public License Usage
  ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -26,16 +25,16 @@
  ** rights.  These rights are described in the Nokia Qt LGPL Exception
  ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
  **
- ** GNU General Public License Usage
- ** Alternatively, this file may be used under the terms of the GNU
- ** General Public License version 3.0 as published by the Free Software
- ** Foundation and appearing in the file LICENSE.GPL included in the
- ** packaging of this file.  Please review the following information to
- ** ensure the GNU General Public License version 3.0 requirements will be
- ** met: http://www.gnu.org/copyleft/gpl.html.
+ ** If you have questions regarding the use of this file, please contact
+ ** Nokia at qt-info@nokia.com.
+ **
+ **
+ **
+ **
+ **
+ **
+ **
  **
- ** If you are unsure which license is appropriate for your use, please
- ** contact the sales department at qt-sales@nokia.com.
  ** $QT_END_LICENSE$
  **
  ****************************************************************************/
@@ -44,10 +43,12 @@
 #include "qlandmarkmanagerengine_symbian_p.h"
 #include <qlandmarkidfetchrequest.h>
 #include <qlandmarkfetchrequest.h>
-#include <qdebug.h>
+#include <qDebug.h>
+#include <qdatetime.h>
 
 // constant data
 const TUint KOneSecond = 1000;
+//const char* const DATE_FORMAT = "yyyyMMddhhmmsszzz";
 
 TWaitThrdData::TWaitThrdData()
 {
@@ -58,7 +59,8 @@ TWaitThrdData::TWaitThrdData()
 
 CLandmarkRequestAO::CLandmarkRequestAO(CPosLmOperation *aOperation,
     MLandmarkRequestObserver *aObserver) :
-    CActive(EPriorityStandard), iObserver(aObserver), iOperation(aOperation)
+    CActive(EPriorityStandard), iObserver(aObserver), iOperation(aOperation),
+        iIsDestructing(EFalse), iIsWFFRequestComplete(EFalse)
 {
     CActiveScheduler::Add(this);
 }
@@ -79,6 +81,7 @@ void CLandmarkRequestAO::RunL()
         if (iStatus == KPosLmOperationNotComplete || iStatus == KErrLocked || iStatus
             == KErrAccessDenied) {
             iOperation->NextStep(iStatus, iProgress);
+            //qDebug() << "CLandmarkRequestAO::RunL => SetActive 1";
             SetActive();
         }
         else if (iStatus == KErrNone && IsMultiOperationRequest()) {
@@ -88,10 +91,12 @@ void CLandmarkRequestAO::RunL()
                 iStatus = KRequestPending;
                 if (iOperation) {
                     iOperation->NextStep(iStatus, iProgress);
+                    //qDebug() << "CLandmarkRequestAO::RunL => SetActive 2";
                     SetActive();
                 }
                 else {
                     //qDebug() << "starting multi-operation";
+                    //qDebug() << "CLandmarkRequestAO::RunL => SetActive 3";
                     SetActive();
                     // Only for the Landmark save and Category save. These dont have async operations.
                     // Self completing ative object.
@@ -100,7 +105,7 @@ void CLandmarkRequestAO::RunL()
                 }
             }
             else {
-
+                //qDebug() << "CLandmarkRequestAO::RunL() - WakeupThreads - 1";
                 iIsComplete = ETrue;
                 // All processing is done now. Notify observer.
                 iParent->iErrorId = err;
@@ -110,9 +115,10 @@ void CLandmarkRequestAO::RunL()
 
             }
         }
-        // if request is complete or any error occured 
+        // if request is complete or any error occurred 
         // then complete the request with appropriate error code
         else {
+            //qDebug() << "CLandmarkRequestAO::RunL() - WakeupThreads - 2";
             iIsComplete = ETrue;
             // All processing is done now. Notify observer.
             iParent->iErrorId = iStatus.Int();
@@ -135,9 +141,13 @@ void CLandmarkRequestAO::RunL()
             iStatus = KRequestPending;
             if (iOperation) {
                 iOperation->NextStep(iStatus, iProgress);
+                //qDebug() << "CLandmarkRequestAO::RunL => SetActive 4";
+
                 SetActive();
             }
             else {
+                //qDebug() << "CLandmarkRequestAO::RunL => SetActive 5";
+
                 SetActive();
                 // Only for the Landmark save and Category save. These dont have async operations.
                 // Self completing ative object.
@@ -145,9 +155,11 @@ void CLandmarkRequestAO::RunL()
                 User::RequestComplete(Ptr, KErrNone);
             }
         }
-        // if request is complete or any error occured 
+        // if request is complete or any error occurred 
         // then complete the request with appropriate error code
         else {
+            //qDebug() << "CLandmarkRequestAO::RunL() - WakeupThreads - 3";
+
             iIsComplete = ETrue;
             iParent->iErrorId = iStatus.Int();
             // All processing is done now. Notify observer.
@@ -164,10 +176,12 @@ void CLandmarkRequestAO::RunL()
  */
 TBool CLandmarkRequestAO::WaitForRequestL(TInt aTime, TRequestStatus &aRequest)
 {
+    //qDebug() << "WaitForRequestL start";
     while (!iIsComplete) {
 
         // if request is cancel from outside.
         if (iCancelRequest) {
+            //qDebug() << "CLandmarkRequestAO::WaitForRequestL - WakeupThreads - 1";
             iParent->iErrorId = KErrCancel;
             // All processing is cancelled now. Notify observer.
             iObserver->HandleCompletionL(iParent);
@@ -177,16 +191,28 @@ TBool CLandmarkRequestAO::WaitForRequestL(TInt aTime, TRequestStatus &aRequest)
         }
         // Wait for the first request.
         if (aTime > 0) {
+
+            //qDebug() << "current time = " << QDateTime::currentDateTime().toString(DATE_FORMAT);
             User::WaitForRequest(iStatus, aRequest);
+            //qDebug() << "aRequest = " << aRequest.Int();
+            //qDebug() << "iStatus = " << iStatus.Int();
+
+            if (iStatus == KErrNone) {
+                iIsWFFRequestComplete = ETrue;
+            }
+
             if (aRequest != KRequestPending) {
                 // Timer has expired. return false.
                 return EFalse;
             }
         }
         else {
+            //qDebug() << "wait for iStatus";
             User::WaitForRequest(iStatus);
         }
 
+        //qDebug() << "continue execution";
+
         if (iOperation) {
             // if operation is not complete or database is locked 
             // then request again to complete it.
@@ -199,9 +225,10 @@ TBool CLandmarkRequestAO::WaitForRequestL(TInt aTime, TRequestStatus &aRequest)
                 TRequestStatus *Ptr = &iStatus;
                 User::RequestComplete(Ptr, 0);
             }
-            // if request is complete or any error occured 
+            // if request is complete or any error occurred 
             // then complete the request with appropriate error code
             else {
+                //qDebug() << "CLandmarkRequestAO::WaitForRequestL - WakeupThreads - 2";
                 iIsComplete = ETrue;
                 iParent->iErrorId = iStatus.Int();
                 // All processing is done now. Notify observer.
@@ -230,9 +257,11 @@ TBool CLandmarkRequestAO::WaitForRequestL(TInt aTime, TRequestStatus &aRequest)
                     User::RequestComplete(Ptr, KErrNone);
                 }
             }
-            // if request is complete or any error occured 
+            // if request is complete or any error occurred 
             // then complete the request with appropriate error code
             else {
+                //qDebug() << "CLandmarkRequestAO::WaitForRequestL - WakeupThreads - 3";
+
                 iIsComplete = ETrue;
                 iParent->iErrorId = iStatus.Int();
                 // All processing is done now. Notify observer.
@@ -242,31 +271,40 @@ TBool CLandmarkRequestAO::WaitForRequestL(TInt aTime, TRequestStatus &aRequest)
             }
         }
     }
+    //qDebug() << "WaitForRequestL end";
     return ETrue;
 }
 
 void CLandmarkRequestAO::DoCancel()
 {
-    //qDebug() << "DoCancel : request is canceled";
+    //qDebug() << "DoCancel start";
     if (iOperation) {
+        //qDebug() << "a operational request is canceled";
+
         // Only way to cancel the operation is to delete the CPosLmOperation object.
         // Will also take care of cancelling any request which may be pending.
         delete iOperation;
         iOperation = NULL;
     }
     else {
-        // TODO: Modify this hack if required
         if (IsActive())
             memset(&iStatus, 0, sizeof(TRequestStatus));
     }
-    // All processing is cancelled now. Notify observer.
-    iParent->iErrorId = KErrCancel;
-    TRAPD(err,iObserver->HandleCompletionL(iParent);)
-    if (err != KErrNone) {
-        //qDebug() << "DoCancel failed with = " << err;
+
+    if (iIsRequestRunning) {
+        // All processing is cancelled now. Notify observer.
+        iParent->iErrorId = KErrCancel;
+        TRAPD(err,iObserver->HandleCompletionL(iParent);)
+        if (err != KErrNone) {
+            //qDebug() << "DoCancel failed with = " << err;
+        }
+
+        //qDebug() << "CLandmarkRequestAO::DoCancel - WakeupThreads";
+        WakeupThreads(KErrCancel);
+        iIsRequestRunning = EFalse;
     }
-    WakeupThreads(KErrCancel);
-    iIsRequestRunning = EFalse;
+
+    //qDebug() << "DoCancel end";
 }
 
 CLandmarkRequestAO * CLandmarkRequestAO::NewL(MLandmarkRequestObserver *aObserver,
@@ -278,9 +316,10 @@ CLandmarkRequestAO * CLandmarkRequestAO::NewL(MLandmarkRequestObserver *aObserve
 
 CLandmarkRequestAO::~CLandmarkRequestAO()
 {
-    Cancel();
-    // Deletion of ioperation not required, as CPosLandmarkSearch* objects own it
-    // iOperation will get deleted whenever CPosLandmarkSearch* object get deleted.
+    //qDebug() << "~CLandmarkRequestAO start";
+    iIsDestructing = ETrue;
+    CancelRequest();
+    //qDebug() << "~CLandmarkRequestAO end";
 }
 
 TBool CLandmarkRequestAO::StartRequest(CPosLandmarkSearch *aLandmarkSearch)
@@ -290,11 +329,16 @@ TBool CLandmarkRequestAO::StartRequest(CPosLandmarkSearch *aLandmarkSearch)
     if (aLandmarkSearch)
         iParent->iLandmarkSearch = aLandmarkSearch;
 
+    if (iIsRequestRunning || iCancelRequest || iIsComplete || IsActive())
+        return EFalse;
+
     iCancelRequest = iIsComplete = EFalse;
+    iIsRequestRunning = ETrue;
 
     // Case where owned CPosLmOperation.
     if (iOperation) {
         iOperation->NextStep(iStatus, iProgress);
+        //qDebug() << "CLandmarkRequestAO::StartRequest => SetActive 1";
         SetActive();
     }
     // Case where manually do operation on single item out of a list.
@@ -311,10 +355,13 @@ TBool CLandmarkRequestAO::StartRequest(CPosLandmarkSearch *aLandmarkSearch)
 
             iStatus = KRequestPending;
             if (iOperation) {
+                //qDebug() << "CLandmarkRequestAO::StartRequest => SetActive 2";
                 iOperation->NextStep(iStatus, iProgress);
                 SetActive();
             }
             else {
+                //qDebug() << "CLandmarkRequestAO::StartRequest => SetActive 3";
+
                 SetActive();
                 // Only for the Landmark save and Category save. These dont have async operations.
                 // Self completing ative object.
@@ -322,9 +369,10 @@ TBool CLandmarkRequestAO::StartRequest(CPosLandmarkSearch *aLandmarkSearch)
                 User::RequestComplete(Ptr, KErrNone);
             }
         }
-        // if request is complete or any error occured 
+        // if request is complete or any error occurred 
         // then complete the request with appropriate error code
         else {
+            //qDebug() << "CLandmarkRequestAO::StartRequest -> WakeupThreads";
             iIsComplete = ETrue;
             iParent->iErrorId = iStatus.Int();
             // All processing is done now. Notify observer.
@@ -332,17 +380,14 @@ TBool CLandmarkRequestAO::StartRequest(CPosLandmarkSearch *aLandmarkSearch)
             WakeupThreads(iStatus.Int());
             iIsRequestRunning = EFalse;
         }
-
     }
 
-    iIsRequestRunning = ETrue;
-
     return ETrue;
 }
 
 TBool CLandmarkRequestAO::CancelRequest()
 {
-    //qDebug() << "Cancel : request is canceled";
+    //qDebug() << "CancelRequest start";
 
     iCancelRequest = ETrue;
 
@@ -352,6 +397,8 @@ TBool CLandmarkRequestAO::CancelRequest()
         DoCancel();
     }
 
+    //qDebug() << "CancelRequest end";
+
     if (iParent->iErrorId == KErrCancel)
         return ETrue;
     else
@@ -360,18 +407,24 @@ TBool CLandmarkRequestAO::CancelRequest()
 
 TBool CLandmarkRequestAO::WaitForFinished(TInt aTime)
 {
+    //qDebug() << "WaitForFinished start, aTime = " << aTime;
     if (iIsComplete || iCancelRequest) {
         return ETrue;
     }
 
     RTimer timer;
+    TInt wffTime = aTime * KOneSecond;
     TRequestStatus timestatus = KErrNone;
     if (aTime > 0) {
         if (timer.CreateLocal() != KErrNone) {
             return EFalse; // ???
         }
-        timer.After(timestatus, aTime * KOneSecond);
+
+        //qDebug() << "starting timer, current time = " << QDateTime::currentDateTime().toString(
+            //DATE_FORMAT);
+        timer.After(timestatus, wffTime);
     }
+
     TBool IsOperationComplete = EFalse;
 
     // Check the Thread ID in the list against current.
@@ -393,26 +446,29 @@ TBool CLandmarkRequestAO::WaitForFinished(TInt aTime)
         Data.iThrdRequest = KRequestPending;
         iParent->iWaitThrds.AddFirst(Data);
 
-        //qDebug() << "Wait for request started";
         if (aTime > 0) {
+            //qDebug() << "aTime >0, Wait for request started";
             User::WaitForRequest(Data.iThrdRequest, timestatus);
             if (timestatus == KRequestPending) {
                 IsOperationComplete = ETrue;
             }
         }
         else {
+            //qDebug() << "Wait for request started";
             IsOperationComplete = ETrue;
             User::WaitForRequest(Data.iThrdRequest);
         }
         //qDebug() << "Out of Wait for request in" << currThrdId;
     }
     if (timestatus == KRequestPending) {
+        //qDebug() << "Cancelling the timer";
         timer.Cancel();
     }
     timer.Close();
 
     iIsRequestRunning = EFalse;
 
+    //qDebug() << "WaitForFinished end";
     return IsOperationComplete;
 }
 
@@ -450,33 +506,57 @@ CPosLmOperation * CLandmarkRequestAO::GetOperation()
 
 void CLandmarkRequestAO::WakeupThreads(TInt aCompletion)
 {
-    //qDebug() << "WakeupThreads - start aCompletion = " << aCompletion;
+    //qDebug() << "In wakeup threads start";
+
+    if (IsActive() && iIsWFFRequestComplete) {
+        //qDebug() << "Request is still active";
+        iIsRequestRunning = EFalse;
+        Cancel();
+
+        //qDebug() << "iStatus = " << iStatus.Int();
+
+        if (iStatus != KErrNone) {
+
+            iParent->iErrorId = KErrNone;
+            TRAPD(err,iObserver->HandleCompletionL(iParent);)
+            if (err != KErrNone) {
+                //qDebug() << "DoCancel failed with = " << err;
+            }
+
+            //qDebug() << "CLandmarkRequestAO::WakeupThreads - request is active";
+            WakeupThreads(KErrNone);
+            return;
+        }
+    }
+
     TWaitThrdData* Ptr = NULL;
     TSglQueIter<TWaitThrdData> Iter(iParent->iWaitThrds);
 
-    if (iIsRequestRunning)
+    //qDebug() << "starting the lock";
+
+    if (!iIsDestructing) {
+
         iParent->iLock.Wait();
 
-    Iter.SetToFirst();
-    while ((Ptr = Iter++) != NULL) {
+        Iter.SetToFirst();
+        while ((Ptr = Iter++) != NULL) {
 
-        RThread waiter;
-        if (waiter.Open(Ptr->iThrdId) == KErrNone) {
-            TRequestStatus* reqptr = &Ptr->iThrdRequest;
-            //qDebug() << "Waking up thread" << Ptr->iThrdId;
-            waiter.RequestComplete(reqptr, aCompletion);
-            waiter.Close();
+            //qDebug() << "cleanup request";
+            RThread waiter;
+            if (waiter.Open(Ptr->iThrdId) == KErrNone) {
+                TRequestStatus* reqptr = &Ptr->iThrdRequest;
+                //qDebug() << "Waking up thread" << Ptr->iThrdId;
+                waiter.RequestComplete(reqptr, aCompletion);
+                waiter.Close();
+            }
 
+            iParent->iWaitThrds.Remove(*Ptr);
         }
 
-        iParent->iWaitThrds.Remove(*Ptr);
+        //qDebug() << "Releasking the lock";
+        iParent->iLock.Signal();
     }
-    iParent->iLock.Signal();
-
-    if (!iIsRequestRunning)
-        iParent->iLock.Close();
-
-    qDebug() << "WakeupThreads - end = ";
+    //qDebug() << "In wakeup threads end ";
 }
 
 TBool CLandmarkRequestAO::IsMultiOperationRequest()
@@ -498,6 +578,8 @@ TBool CLandmarkRequestAO::IsMultiOperationRequest()
 
 TInt CLandmarkRequestAO::RunError(TInt aError)
 {
+    //qDebug() << "CLandmarkRequestAO::RunError -> WakeupThreads";
+
     iIsComplete = ETrue;
     iParent->iErrorId = aError;
     // All processing is done now. Notify observer.
@@ -538,8 +620,8 @@ void CLandmarkRequestData::ConstructL()
 
 CLandmarkRequestData::~CLandmarkRequestData()
 {
+    //qDebug() << "CLandmarkRequestData::~CLandmarkRequestData - start";
     iLock.Wait();
-
     TSglQueIter<TWaitThrdData> Iter(iWaitThrds);
     Iter.SetToFirst();
     TWaitThrdData* Ptr;
@@ -559,9 +641,9 @@ CLandmarkRequestData::~CLandmarkRequestData()
     }
 
     Reset();
-
     iLock.Signal();
     iLock.Close();
+    //qDebug() << "CLandmarkRequestData::~CLandmarkRequestData - end";
 }
 
 /**
