@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -45,6 +45,7 @@
 
 #include "dsserviceplugin.h"
 
+
 #ifdef QMEDIA_DIRECTSHOW_CAMERA
 #include "dscameraservice.h"
 #endif
@@ -57,6 +58,10 @@
 
 
 #ifdef QMEDIA_DIRECTSHOW_CAMERA
+
+extern const CLSID CLSID_VideoInputDeviceCategory;
+
+
 #ifndef _STRSAFE_H_INCLUDED_
 #include <tchar.h>
 #endif
@@ -66,8 +71,11 @@
 #pragma comment(lib, "strmiids.lib")
 #pragma comment(lib, "ole32.lib")
 #include <windows.h>
+#include <ocidl.h>
 #endif
 
+QT_USE_NAMESPACE
+
 QStringList DSServicePlugin::keys() const
 {
     return QStringList()
@@ -91,7 +99,7 @@ QMediaService* DSServicePlugin::create(QString const& key)
         return new DirectShowPlayerService;
 #endif
 
-    //qDebug() << "unsupported key:" << key;
+    qDebug() << "unsupported key:" << key;
     return 0;
 }
 
@@ -100,6 +108,15 @@ void DSServicePlugin::release(QMediaService *service)
     delete service;
 }
 
+QMediaServiceProviderHint::Features DSServicePlugin::supportedFeatures(
+        const QByteArray &service) const
+{
+    if (service == Q_MEDIASERVICE_MEDIAPLAYER)
+        return QMediaServiceProviderHint::StreamPlayback | QMediaServiceProviderHint::VideoSurface;
+    else
+        return QMediaServiceProviderHint::Features();
+}
+
 QList<QByteArray> DSServicePlugin::devices(const QByteArray &service) const
 {
 #ifdef QMEDIA_DIRECTSHOW_CAMERA
@@ -130,11 +147,12 @@ QString DSServicePlugin::deviceDescription(const QByteArray &service, const QByt
 }
 
 #ifdef QMEDIA_DIRECTSHOW_CAMERA
+
 void DSServicePlugin::updateDevices() const
 {
     m_cameraDevices.clear();
     m_cameraDescriptions.clear();
-
+    BOOL bFound = TRUE;
     CoInitialize(NULL);
     ICreateDevEnum* pDevEnum = NULL;
     IEnumMoniker* pEnum = NULL;
@@ -146,36 +164,46 @@ void DSServicePlugin::updateDevices() const
         // Create the enumerator for the video capture category
 	hr = pDevEnum->CreateClassEnumerator(
 	     CLSID_VideoInputDeviceCategory, &pEnum, 0);
-	pEnum->Reset();
-	// go through and find all video capture devices
-	IMoniker* pMoniker = NULL;
-	while(pEnum->Next(1, &pMoniker, NULL) == S_OK) {
-	    IPropertyBag *pPropBag;
-	    hr = pMoniker->BindToStorage(0,0,IID_IPropertyBag,
-	         (void**)(&pPropBag));
-            if(FAILED(hr)) {
-	        pMoniker->Release();
-		continue; // skip this one
-	    }
-	    // Find the description
-	    WCHAR str[120];
-	    VARIANT varName;
-	    varName.vt = VT_BSTR;
-            hr = pPropBag->Read(L"FriendlyName", &varName, 0);
-	    if(SUCCEEDED(hr)) {
-	        StringCchCopyW(str,sizeof(str)/sizeof(str[0]),varName.bstrVal);
-		QString temp(QString::fromUtf16((unsigned short*)str));
-		m_cameraDevices.append(QString("ds:%1").arg(temp).toLocal8Bit().constData());
-	        hr = pPropBag->Read(L"Description", &varName, 0);
-	        StringCchCopyW(str,sizeof(str)/sizeof(str[0]),varName.bstrVal);
-		QString temp2(QString::fromUtf16((unsigned short*)str));
-		m_cameraDescriptions.append(temp2);
-	    }
-	    pPropBag->Release();
-	    pMoniker->Release();
-	}
+        if (S_OK == hr) {
+            pEnum->Reset();
+            // go through and find all video capture devices
+            IMoniker* pMoniker = NULL;
+            while(pEnum->Next(1, &pMoniker, NULL) == S_OK) {
+                IPropertyBag *pPropBag;
+                hr = pMoniker->BindToStorage(0,0,IID_IPropertyBag,
+                     (void**)(&pPropBag));
+                if(FAILED(hr)) {
+                    pMoniker->Release();
+                    continue; // skip this one
+                }
+                bFound = TRUE;
+                // Find the description
+                WCHAR str[120];
+                VARIANT varName;
+                varName.vt = VT_BSTR;
+                hr = pPropBag->Read(L"FriendlyName", &varName, 0);
+                if(SUCCEEDED(hr)) {
+                    wcsncpy(str, varName.bstrVal, sizeof(str)/sizeof(str[0]));
+                    QString temp(QString::fromUtf16((unsigned short*)str));
+                    m_cameraDevices.append(QString("ds:%1").arg(temp).toLocal8Bit().constData());
+                    hr = pPropBag->Read(L"Description", &varName, 0);
+                    wcsncpy(str, varName.bstrVal, sizeof(str)/sizeof(str[0]));
+                    QString temp2(QString::fromUtf16((unsigned short*)str));
+                    m_cameraDescriptions.append(temp2);
+                } else {
+                    qWarning() << "No friendly name";
+                }
+                pPropBag->Release();
+                pMoniker->Release();
+            }
+            pEnum->Release();
+        }
+        pDevEnum->Release();
     }
     CoUninitialize();
+    if (!bFound) {
+        qWarning() << "No camera devices found";
+    }
 }
 #endif
 
