@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -46,7 +46,9 @@
 #include "directshowmetadatacontrol.h"
 #include "directshowplayercontrol.h"
 #include "directshowvideorenderercontrol.h"
+#ifndef Q_WS_SIMULATOR
 #include "vmr9videowindowcontrol.h"
+#endif
 
 #include "../../src/multimedia/qmediacontent.h"
 
@@ -57,6 +59,10 @@
 
 Q_GLOBAL_STATIC(DirectShowEventLoop, qt_directShowEventLoop)
 
+
+// QMediaPlayer uses millisecond time units, direct show uses 100 nanosecond units.
+static const int qt_directShowTimeScale = 10000;
+
 class DirectShowPlayerServiceThread : public QThread
 {
 public:
@@ -77,7 +83,9 @@ DirectShowPlayerService::DirectShowPlayerService(QObject *parent)
     , m_playerControl(0)
     , m_metaDataControl(0)
     , m_videoRendererControl(0)
+#ifndef Q_WS_SIMULATOR
     , m_videoWindowControl(0)
+#endif
     , m_audioEndpointControl(0)
     , m_taskThread(0)
     , m_loop(qt_directShowEventLoop())
@@ -99,6 +107,7 @@ DirectShowPlayerService::DirectShowPlayerService(QObject *parent)
     , m_seekable(false)
     , m_atEnd(false)
 {
+    CoInitialize(NULL);
     m_playerControl = new DirectShowPlayerControl(this);
     m_metaDataControl = new DirectShowMetaDataControl(this);
     m_audioEndpointControl = new DirectShowAudioEndpointControl(this);
@@ -135,9 +144,12 @@ DirectShowPlayerService::~DirectShowPlayerService()
     delete m_audioEndpointControl;
     delete m_metaDataControl;
     delete m_videoRendererControl;
+#ifndef Q_WS_SIMULATOR
     delete m_videoWindowControl;
+#endif
 
     ::CloseHandle(m_taskHandle);
+    CoUninitialize();
 }
 
 QMediaControl *DirectShowPlayerService::requestControl(const char *name)
@@ -149,7 +161,11 @@ QMediaControl *DirectShowPlayerService::requestControl(const char *name)
     } else if (qstrcmp(name, QMetaDataReaderControl_iid) == 0) {
         return m_metaDataControl;
     } else if (qstrcmp(name, QVideoRendererControl_iid) == 0) {
+#ifndef Q_WS_SIMULATOR
         if (!m_videoRendererControl && !m_videoWindowControl) {
+#else
+        if (!m_videoRendererControl) {
+#endif
             m_videoRendererControl = new DirectShowVideoRendererControl(m_loop);
 
             connect(m_videoRendererControl, SIGNAL(filterChanged()),
@@ -157,6 +173,7 @@ QMediaControl *DirectShowPlayerService::requestControl(const char *name)
 
             return m_videoRendererControl;
         }
+#ifndef Q_WS_SIMULATOR
     } else if (qstrcmp(name, QVideoWindowControl_iid) == 0) {
         if (!m_videoRendererControl && !m_videoWindowControl) {
             m_videoWindowControl = new Vmr9VideoWindowControl;
@@ -165,6 +182,7 @@ QMediaControl *DirectShowPlayerService::requestControl(const char *name)
 
             return m_videoWindowControl;
         }
+#endif
     }
     return 0;
 }
@@ -180,12 +198,14 @@ void DirectShowPlayerService::releaseControl(QMediaControl *control)
         delete m_videoRendererControl;
 
         m_videoRendererControl = 0;
+#ifndef Q_WS_SIMULATOR
     } else if (control == m_videoWindowControl) {
         setVideoOutput(0);
 
         delete m_videoWindowControl;
 
         m_videoWindowControl = 0;
+#endif
     }
 }
 
@@ -264,7 +284,6 @@ void DirectShowPlayerService::doSetUrlSource(QMutexLocker *locker)
                 clsid_WMAsfReader, iid_IFileSourceFilter)) {
             locker->unlock();
             hr = fileSource->Load(reinterpret_cast<const OLECHAR *>(url.toString().utf16()), 0);
-            locker->relock();
 
             if (SUCCEEDED(hr)) {
                 source = com_cast<IBaseFilter>(fileSource, IID_IBaseFilter);
@@ -274,16 +293,18 @@ void DirectShowPlayerService::doSetUrlSource(QMutexLocker *locker)
                     source = 0;
                 }
             }
-
             fileSource->Release();
+            locker->relock();
         }
     } else if (url.scheme() == QLatin1String("qrc")) {
         DirectShowRcSource *rcSource = new DirectShowRcSource(m_loop);
 
+        locker->unlock();
         if (rcSource->open(url) && SUCCEEDED(hr = m_graph->AddFilter(rcSource, L"Source")))
             source = rcSource;
         else
             rcSource->Release();
+        locker->relock();
     }
 
     if (!SUCCEEDED(hr)) {
@@ -497,7 +518,7 @@ void DirectShowPlayerService::doFinalizeLoad(QMutexLocker *locker)
         if (IMediaSeeking *seeking = com_cast<IMediaSeeking>(m_graph, IID_IMediaSeeking)) {
             LONGLONG duration = 0;
             seeking->GetDuration(&duration);
-            m_duration = duration / 10;
+            m_duration = duration / qt_directShowTimeScale;
 
             DWORD capabilities = 0;
             seeking->GetCapabilities(&capabilities);
@@ -659,6 +680,8 @@ void DirectShowPlayerService::play()
 
         ::SetEvent(m_taskHandle);
     }
+
+    updateStatus();
 }
 
 void DirectShowPlayerService::doPlay(QMutexLocker *locker)
@@ -701,6 +724,8 @@ void DirectShowPlayerService::pause()
 
         ::SetEvent(m_taskHandle);
     }
+
+    updateStatus();
 }
 
 void DirectShowPlayerService::doPause(QMutexLocker *locker)
@@ -719,7 +744,7 @@ void DirectShowPlayerService::doPause(QMutexLocker *locker)
                 seeking->GetCurrentPosition(&position);
                 seeking->Release();
 
-                m_position = position / 10;
+                m_position = position / qt_directShowTimeScale;
             } else {
                 m_position = 0;
             }
@@ -751,6 +776,7 @@ void DirectShowPlayerService::stop()
         m_loop->wait(&m_mutex);
     }
 
+    updateStatus();
 }
 
 void DirectShowPlayerService::doStop(QMutexLocker *locker)
@@ -761,16 +787,8 @@ void DirectShowPlayerService::doStop(QMutexLocker *locker)
             control->Release();
         }
 
-        if (IMediaSeeking *seeking = com_cast<IMediaSeeking>(m_graph, IID_IMediaSeeking)) {
-            LONGLONG position = 0;
-
-            seeking->GetCurrentPosition(&position);
-            seeking->Release();
-
-            m_position = position / 10;
-        } else {
-            m_position = 0;
-        }
+        m_position = 0;
+        m_pendingTasks |= Seek;
 
         m_executedTasks &= ~(Play | Pause);
         
@@ -801,12 +819,12 @@ void DirectShowPlayerService::doSetRate(QMutexLocker *locker)
         // possibility of a deadlock when flushing the VideoSurfaceFilter.
         LONGLONG currentPosition = 0;
         seeking->GetCurrentPosition(&currentPosition);
-        m_position = currentPosition / 10;
+        m_position = currentPosition / qt_directShowTimeScale;
 
         LONGLONG minimum = 0;
         LONGLONG maximum = 0;
         m_playbackRange = SUCCEEDED(seeking->GetAvailable(&minimum, &maximum))
-                ? QMediaTimeRange(minimum / 10, maximum / 10)
+                ? QMediaTimeRange(minimum / qt_directShowTimeScale, maximum / qt_directShowTimeScale)
                 : QMediaTimeRange();
 
         locker->unlock();
@@ -832,7 +850,7 @@ qint64 DirectShowPlayerService::position() const
     QMutexLocker locker(const_cast<QMutex *>(&m_mutex));
 
     if (m_graphStatus == Loaded) {
-        if (m_executingTask == Seek || m_executingTask == SetRate) {
+        if (m_executingTask == Seek || m_executingTask == SetRate || (m_pendingTasks & Seek)) {
             return m_position;
         } else if (IMediaSeeking *seeking = com_cast<IMediaSeeking>(m_graph, IID_IMediaSeeking)) {
             LONGLONG position = 0;
@@ -840,7 +858,7 @@ qint64 DirectShowPlayerService::position() const
             seeking->GetCurrentPosition(&position);
             seeking->Release();
 
-            const_cast<qint64 &>(m_position) = position / 10;
+            const_cast<qint64 &>(m_position) = position / qt_directShowTimeScale;
 
             return m_position;
         }
@@ -853,7 +871,7 @@ QMediaTimeRange DirectShowPlayerService::availablePlaybackRanges() const
     QMutexLocker locker(const_cast<QMutex *>(&m_mutex));
 
     if (m_graphStatus == Loaded) {
-        if (m_executingTask == Seek || m_executingTask == SetRate) {
+        if (m_executingTask == Seek || m_executingTask == SetRate || (m_pendingTasks & Seek)) {
             return m_playbackRange;
         } else if (IMediaSeeking *seeking = com_cast<IMediaSeeking>(m_graph, IID_IMediaSeeking)) {
             LONGLONG minimum = 0;
@@ -884,18 +902,19 @@ void DirectShowPlayerService::seek(qint64 position)
 void DirectShowPlayerService::doSeek(QMutexLocker *locker)
 {
     if (IMediaSeeking *seeking = com_cast<IMediaSeeking>(m_graph, IID_IMediaSeeking)) {
-        LONGLONG seekPosition = LONGLONG(m_position) * 10;
+        LONGLONG seekPosition = LONGLONG(m_position) * qt_directShowTimeScale;
 
         // Cache current values as we can't query IMediaSeeking during a seek due to the
         // possibility of a deadlock when flushing the VideoSurfaceFilter.
         LONGLONG currentPosition = 0;
         seeking->GetCurrentPosition(&currentPosition);
-        m_position = currentPosition / 10;
+        m_position = currentPosition / qt_directShowTimeScale;
 
         LONGLONG minimum = 0;
         LONGLONG maximum = 0;
         m_playbackRange = SUCCEEDED(seeking->GetAvailable(&minimum, &maximum))
-                ? QMediaTimeRange(minimum / 10, maximum / 10)
+                ? QMediaTimeRange(
+                        minimum / qt_directShowTimeScale, maximum / qt_directShowTimeScale)
                 : QMediaTimeRange();
 
         locker->unlock();
@@ -904,7 +923,7 @@ void DirectShowPlayerService::doSeek(QMutexLocker *locker)
         locker->relock();
 
         seeking->GetCurrentPosition(&currentPosition);
-        m_position = currentPosition / 10;
+        m_position = currentPosition / qt_directShowTimeScale;
 
         seeking->Release();
     } else {
@@ -1134,6 +1153,8 @@ void DirectShowPlayerService::customEvent(QEvent *event)
     } else if (event->type() == QEvent::Type(PositionChange)) {
         QMutexLocker locker(&m_mutex);
 
+        if (m_playerControl->mediaStatus() == QMediaPlayer::EndOfMedia)
+            m_playerControl->updateStatus(QMediaPlayer::LoadedMedia);
         m_playerControl->updatePosition(m_position);
     } else {
         QMediaService::customEvent(event);
@@ -1172,7 +1193,7 @@ void DirectShowPlayerService::graphEvent(QMutexLocker *locker)
                     seeking->GetCurrentPosition(&position);
                     seeking->Release();
 
-                    m_position = position / 10;
+                    m_position = position / qt_directShowTimeScale;
                 }
 
                 QCoreApplication::postEvent(this, new QEvent(QEvent::Type(EndOfMedia)));
@@ -1181,7 +1202,7 @@ void DirectShowPlayerService::graphEvent(QMutexLocker *locker)
                 if (IMediaSeeking *seeking = com_cast<IMediaSeeking>(m_graph, IID_IMediaSeeking)) {
                     LONGLONG duration = 0;
                     seeking->GetDuration(&duration);
-                    m_duration = duration / 10;
+                    m_duration = duration / qt_directShowTimeScale;
 
                     DWORD capabilities = 0;
                     seeking->GetCapabilities(&capabilities);
