@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -121,40 +121,48 @@ void QGstreamerCaptureSession::setCaptureMode(CaptureMode mode)
 
 GstElement *QGstreamerCaptureSession::buildEncodeBin()
 {
-    bool ok = true;
-
     GstElement *encodeBin = gst_bin_new("encode-bin");
 
     GstElement *muxer = gst_element_factory_make( m_mediaContainerControl->formatElementName().constData(), "muxer");
     if (!muxer) {
+        qWarning() << "Could not create a media muxer element:" << m_mediaContainerControl->formatElementName();
         gst_object_unref(encodeBin);
-        encodeBin = 0;
         return 0;
     }
 
     GstElement *fileSink = gst_element_factory_make("filesink", "filesink");
-
     g_object_set(G_OBJECT(fileSink), "location", m_sink.toString().toLocal8Bit().constData(), NULL);
-
     gst_bin_add_many(GST_BIN(encodeBin), muxer, fileSink,  NULL);
-    ok &= gst_element_link(muxer, fileSink);
+
+    if (!gst_element_link(muxer, fileSink)) {
+        gst_object_unref(encodeBin);
+        return 0;
+    }
 
     if (m_captureMode & Audio) {
         GstElement *audioConvert = gst_element_factory_make("audioconvert", "audioconvert");
         GstElement *audioQueue = gst_element_factory_make("queue", "audio-encode-queue");
         m_audioVolume = gst_element_factory_make("volume", "volume");
+        gst_bin_add_many(GST_BIN(encodeBin), audioConvert, audioQueue, m_audioVolume, NULL);
+
         GstElement *audioEncoder = m_audioEncodeControl->createEncoder();
+        if (!audioEncoder) {
+            gst_object_unref(encodeBin);
+            qWarning() << "Could not create an audio encoder element:" << m_audioEncodeControl->audioSettings().codec();
+            return 0;
+        }
 
-        ok &= audioEncoder != 0;
+        gst_bin_add(GST_BIN(encodeBin), audioEncoder);
 
-        gst_bin_add_many(GST_BIN(encodeBin), audioConvert, audioQueue, m_audioVolume, audioEncoder,  NULL);
+        if (!gst_element_link_many(audioConvert, audioQueue, m_audioVolume, audioEncoder, muxer, NULL)) {
+            gst_object_unref(encodeBin);
+            return 0;
+        }
 
-        ok &= gst_element_link_many(audioConvert, audioQueue, m_audioVolume, audioEncoder, muxer, NULL);
         g_object_set(G_OBJECT(m_audioVolume), "volume", (m_muted ? 0.0 : 1.0), NULL);
 
         // add ghostpads
         GstPad *pad = gst_element_get_static_pad(audioConvert, "sink");
-        Q_ASSERT(pad);
         gst_element_add_pad(GST_ELEMENT(encodeBin), gst_ghost_pad_new("audiosink", pad));
         gst_object_unref(GST_OBJECT(pad));
     }
@@ -163,26 +171,28 @@ GstElement *QGstreamerCaptureSession::buildEncodeBin()
         GstElement *videoQueue = gst_element_factory_make("queue", "video-encode-queue");
         GstElement *colorspace = gst_element_factory_make("ffmpegcolorspace", "ffmpegcolorspace-encoder");
         GstElement *videoscale = gst_element_factory_make("videoscale","videoscale-encoder");
+        gst_bin_add_many(GST_BIN(encodeBin), videoQueue, colorspace, videoscale, NULL);
 
         GstElement *videoEncoder = m_videoEncodeControl->createEncoder();
+        if (!videoEncoder) {
+            gst_object_unref(encodeBin);
+            qWarning() << "Could not create a video encoder element:" << m_videoEncodeControl->videoSettings().codec();
+            return 0;
+        }
 
-        ok &= videoEncoder != 0;
+        gst_bin_add(GST_BIN(encodeBin), videoEncoder);
 
-        gst_bin_add_many(GST_BIN(encodeBin), videoQueue, colorspace, videoscale, videoEncoder, NULL);
-        ok &= gst_element_link_many(videoQueue, colorspace, videoscale, videoEncoder, muxer, NULL);
+        if (!gst_element_link_many(videoQueue, colorspace, videoscale, videoEncoder, muxer, NULL)) {
+            gst_object_unref(encodeBin);
+            return 0;
+        }
 
         // add ghostpads
         GstPad *pad = gst_element_get_static_pad(videoQueue, "sink");
-        Q_ASSERT(pad);
         gst_element_add_pad(GST_ELEMENT(encodeBin), gst_ghost_pad_new("videosink", pad));
         gst_object_unref(GST_OBJECT(pad));
     }
 
-    if (!ok) {
-        gst_object_unref(encodeBin);
-        encodeBin = 0;
-    }
-
     return encodeBin;
 }
 
@@ -800,6 +810,9 @@ void QGstreamerCaptureSession::setState(QGstreamerCaptureSession::State newState
                 //with live sources it's necessary to send EOS even to pipeline
                 //before going to STOPPED state
                 gst_element_send_event(m_pipeline, gst_event_new_eos());
+                // Unless gstreamer is in GST_STATE_PLAYING our EOS message will not be received.
+                gst_element_set_state(m_pipeline, GST_STATE_PLAYING);
+
                 return;
             } else {
                 m_waitingForEos = false;
@@ -914,9 +927,11 @@ bool QGstreamerCaptureSession::processSyncMessage(const QGstreamerMessage &messa
 {
     GstMessage* gm = message.rawMessage();
 
-    if (gm && GST_MESSAGE_TYPE(gm) == GST_MESSAGE_ELEMENT &&
-            gst_structure_has_name(gm->structure, "prepare-xwindow-id"))
-        {
+    if (gm && GST_MESSAGE_TYPE(gm) == GST_MESSAGE_ELEMENT) {
+        if (GST_MESSAGE_SRC(gm) == GST_OBJECT_CAST(m_videoPreview))
+            m_viewfinderInterface->handleSyncMessage(gm);
+
+        if (gst_structure_has_name(gm->structure, "prepare-xwindow-id")) {
             if (m_audioPreviewFactory)
                 m_audioPreviewFactory->prepareWinId();
 
@@ -925,6 +940,7 @@ bool QGstreamerCaptureSession::processSyncMessage(const QGstreamerMessage &messa
 
             return true;
         }
+    }
 
     return false;
 }
@@ -1017,6 +1033,10 @@ void QGstreamerCaptureSession::busMessage(const QGstreamerMessage &message)
             }
             //qDebug() << "New session state:" << ENUM_NAME(QGstreamerCaptureSession,"State",m_state);
         }
+
+        if (m_videoPreview && m_viewfinderInterface &&
+                GST_MESSAGE_SRC(gm) == GST_OBJECT_CAST(m_videoPreview))
+            m_viewfinderInterface->handleBusMessage(gm);
     }
 }
 
