@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -43,6 +43,7 @@
 #define QGSTREAMERPLAYERCONTROL_H
 
 #include <QtCore/qobject.h>
+#include <QtCore/qstack.h>
 
 #include <qmediaplayercontrol.h>
 #include <qmediaplayer.h>
@@ -59,10 +60,12 @@ QT_USE_NAMESPACE
 
 class QGstreamerPlayerSession;
 class QGstreamerPlayerService;
+class PlayerResourcePolicy;
 
 class QGstreamerPlayerControl : public QMediaPlayerControl
 {
     Q_OBJECT
+    Q_PROPERTY(bool mediaDownloadEnabled READ isMediaDownloadEnabled WRITE setMediaDownloadEnabled)
 
 public:
     QGstreamerPlayerControl(QGstreamerPlayerSession *session, QObject *parent = 0);
@@ -93,6 +96,9 @@ public:
     const QIODevice *mediaStream() const;
     void setMedia(const QMediaContent&, QIODevice *);
 
+    bool isMediaDownloadEnabled() const;
+    void setMediaDownloadEnabled(bool enabled);
+
 public Q_SLOTS:
     void setPosition(qint64 pos);
 
@@ -107,20 +113,35 @@ private Q_SLOTS:
     void writeFifo();
     void fifoReadyWrite(int socket);
 
-    void updateState(QMediaPlayer::State);
+    void updateSessionState(QMediaPlayer::State state);
+    void updateMediaStatus();
     void processEOS();
     void setBufferProgress(int progress);
+    void applyPendingSeek(bool isSeekable);
+
+    void handleInvalidMedia();
+
+    void handleResourcesGranted();
+    void handleResourcesLost();
 
 private:
     bool openFifo();
     void closeFifo();
     void playOrPause(QMediaPlayer::State state);
 
+    void pushState();
+    void popAndNotifyState();
+
+    bool m_ownStream;
     QGstreamerPlayerSession *m_session;
     QMediaPlayer::State m_state;
     QMediaPlayer::MediaStatus m_mediaStatus;
+    QStack<QMediaPlayer::State> m_stateStack;
+    QStack<QMediaPlayer::MediaStatus> m_mediaStatusStack;
+
     int m_bufferProgress;
     bool m_seekToStartPending;
+    qint64 m_pendingSeekPosition;
     QMediaContent m_currentResource;
     QIODevice *m_stream;
     QSocketNotifier *m_fifoNotifier;
@@ -129,6 +150,8 @@ private:
     int m_bufferSize;
     int m_bufferOffset;
     char m_buffer[PIPE_BUF];
+
+    PlayerResourcePolicy *m_resources;
 };
 
 #endif
