@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -56,8 +50,6 @@
 
 Q_DECLARE_METATYPE(XvImage*);
 
-static QAbstractVideoBuffer::HandleType XvHandleType = QAbstractVideoBuffer::HandleType(4);
-
 struct XvFormatRgb
 {
     QVideoFrame::PixelFormat pixelFormat;
@@ -316,7 +308,7 @@ int QX11VideoSurface::redistribute(
 QList<QVideoFrame::PixelFormat> QX11VideoSurface::supportedPixelFormats(
         QAbstractVideoBuffer::HandleType handleType) const
 {
-    return handleType == QAbstractVideoBuffer::NoHandle || handleType ==  XvHandleType
+    return handleType == QAbstractVideoBuffer::NoHandle || handleType ==  QAbstractVideoBuffer::XvShmImageHandle
             ? m_supportedPixelFormats
             : QList<QVideoFrame::PixelFormat>();
 }
@@ -396,17 +388,17 @@ bool QX11VideoSurface::present(const QVideoFrame &frame)
         } else {
             bool presented = false;
 
-            if (frame.handleType() != XvHandleType &&
+            if (frame.handleType() != QAbstractVideoBuffer::XvShmImageHandle &&
                 m_image->data_size > frame.mappedBytes()) {
                 qWarning("Insufficient frame buffer size");
                 setError(IncorrectFormatError);
-            } else if (frame.handleType() != XvHandleType &&
+            } else if (frame.handleType() != QAbstractVideoBuffer::XvShmImageHandle &&
                        m_image->num_planes > 0 &&
                        m_image->pitches[0] != frame.bytesPerLine()) {
                 qWarning("Incompatible frame pitches");
                 setError(IncorrectFormatError);
             } else {
-                if (frame.handleType() != XvHandleType) {
+                if (frame.handleType() != QAbstractVideoBuffer::XvShmImageHandle) {
                     m_image->data = reinterpret_cast<char *>(frameCopy.bits());
 
                     //qDebug() << "copy frame";
@@ -468,7 +460,7 @@ bool QX11VideoSurface::findPort()
 #ifdef Q_WS_MAEMO_5
             //the overlay xvideo adapter fails to switch winId,
             //prefer the "SGX Textured Video" adapter instead
-        for (unsigned int i = count-1; i >=0 && !portFound; --i) {
+        for (int i = count-1; i >= 0 && !portFound; --i) {
 #else
         for (unsigned int i = 0; i < count && !portFound; ++i) {
 #endif
