@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -57,6 +51,8 @@
 #include <QtCore/qcoreevent.h>
 #include <QtCore/qcoreapplication.h>
 
+#include <QtCore/qreadwritelock.h>
+
 #include <qabstractvideobuffer.h>
 #include <qabstractvideosurface.h>
 #include <qvideosurfaceformat.h>
@@ -116,6 +112,7 @@ private:
 @private
     QWidget *m_window;
     QT7MovieViewRenderer *m_renderer;
+    QReadWriteLock m_rendererLock;
 }
 
 - (HiddenQTMovieView *) initWithRenderer:(QT7MovieViewRenderer *)renderer;
@@ -133,6 +130,7 @@ private:
         [self setControllerVisible:NO];
         [self setDelegate:self];
 
+        QWriteLocker lock(&self->m_rendererLock);
         self->m_renderer = renderer;
 
         self->m_window = new QWidget;
@@ -153,6 +151,7 @@ private:
 
 - (void) setRenderer:(QT7MovieViewRenderer *)renderer
 {
+    QWriteLocker lock(&m_rendererLock);
     m_renderer = renderer;
 }
 
@@ -171,6 +170,8 @@ private:
     // This method is called from QTMovieView just
     // before the image will be drawn.
     Q_UNUSED(view);
+    QReadLocker lock(&m_rendererLock);
+
     if (m_renderer) {
         CGRect bounds = [img extent];
         int w = bounds.size.width;
@@ -204,8 +205,7 @@ private:
             [bitmap release];
         }
 
-        if (m_renderer)
-            m_renderer->renderFrame(frame);
+        m_renderer->renderFrame(frame);
     }
 
     return img;
