@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,20 +25,22 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
+#include "DebugMacros.h"
+
 #include "s60audioencodercontrol.h"
 #include "s60audiocapturesession.h"
 
@@ -48,7 +50,9 @@
 
 S60AudioEncoderControl::S60AudioEncoderControl(QObject *session, QObject *parent)
     :QAudioEncoderControl(parent), m_quality(QtMultimediaKit::NormalQuality)
-{   
+{
+    DP0("S60AudioEncoderControl::S60AudioEncoderControl +++");
+
     m_session = qobject_cast<S60AudioCaptureSession*>(session);
     QAudioFormat fmt = m_session->format();
     // medium, 22050Hz mono S16
@@ -62,29 +66,42 @@ S60AudioEncoderControl::S60AudioEncoderControl(QObject *session, QObject *parent
     m_settings.setChannelCount(fmt.channels());
     m_settings.setCodec(fmt.codec());
     m_settings.setSampleRate(fmt.sampleRate());
+
+    DP0("S60AudioEncoderControl::S60AudioEncoderControl ---");
 }
 
 S60AudioEncoderControl::~S60AudioEncoderControl()
 {
+    DP0("S60AudioEncoderControl::~S60AudioEncoderControl +++");
+
+    DP0("S60AudioEncoderControl::~S60AudioEncoderControl ---");
 }
 
 QStringList S60AudioEncoderControl::supportedAudioCodecs() const
 {
+    DP0("S60AudioEncoderControl::supportedAudioCodecs");
+
     return m_session->supportedAudioCodecs();
 }
 
 QString S60AudioEncoderControl::codecDescription(const QString &codecName) const
 {
-	return m_session->codecDescription(codecName);    
+    DP0("S60AudioEncoderControl::codecDescription");
+
+    return m_session->codecDescription(codecName);
 }
 
 QtMultimediaKit::EncodingQuality S60AudioEncoderControl::quality() const
 {
+    DP0("S60AudioEncoderControl::quality");
+
     return m_quality;
 }
 
 void S60AudioEncoderControl::setQuality(QtMultimediaKit::EncodingQuality value, QAudioFormat &fmt)
 {
+    DP0("S60AudioEncoderControl::setQuality +++");
+
     switch (value) {
     case QtMultimediaKit::VeryLowQuality:
     case QtMultimediaKit::LowQuality:
@@ -112,10 +129,14 @@ void S60AudioEncoderControl::setQuality(QtMultimediaKit::EncodingQuality value,
     default:
         break;
     }
+
+    DP0("S60AudioEncoderControl::setQuality ---");
 }
 
 QStringList S60AudioEncoderControl::supportedEncodingOptions(const QString &codec) const
 {
+    DP0("S60AudioEncoderControl::supportedEncodingOptions");
+
     Q_UNUSED(codec)
     QStringList list;
     if (codec == "PCM") 
@@ -125,6 +146,8 @@ QStringList S60AudioEncoderControl::supportedEncodingOptions(const QString &code
 
 QVariant S60AudioEncoderControl::encodingOption(const QString &codec, const QString &name) const
 {
+    DP0("S60AudioEncoderControl::encodingOption");
+
     if (codec == "PCM") {
         QAudioFormat fmt = m_session->format();
         
@@ -144,7 +167,9 @@ QVariant S60AudioEncoderControl::encodingOption(const QString &codec, const QStr
 void S60AudioEncoderControl::setEncodingOption(
         const QString &codec, const QString &name, const QVariant &value)
 {
-    if (codec == "PCM") {        
+    DP0("S60AudioEncoderControl::setEncodingOption +++");
+
+    if (codec == "PCM") {
         QAudioFormat fmt = m_session->format();
 
         if(qstrcmp(name.toLocal8Bit().constData(), "quality") == 0) {
@@ -156,10 +181,14 @@ void S60AudioEncoderControl::setEncodingOption(
         }
         m_session->setFormat(fmt);
     }
+
+    DP0("S60AudioEncoderControl::setEncodingOption ---");
 }
 
 QList<int> S60AudioEncoderControl::supportedSampleRates(const QAudioEncoderSettings &settings, bool *continuous) const
 {
+    DP0("S60AudioEncoderControl::supportedSampleRates");
+
     if (continuous)
         *continuous = false;
     
@@ -168,11 +197,15 @@ QList<int> S60AudioEncoderControl::supportedSampleRates(const QAudioEncoderSetti
 
 QAudioEncoderSettings S60AudioEncoderControl::audioSettings() const
 {
+    DP0("S60AudioEncoderControl::audioSettings");
+
     return m_settings;
 }
 
 void S60AudioEncoderControl::setAudioSettings(const QAudioEncoderSettings &settings)
 {
+    DP0("S60AudioEncoderControl::setAudioSettings +++");
+
     QAudioFormat fmt = m_session->format();
     if (settings.encodingMode() == QtMultimediaKit::ConstantQualityEncoding) {
         fmt.setCodec(settings.codec());
@@ -195,5 +228,8 @@ void S60AudioEncoderControl::setAudioSettings(const QAudioEncoderSettings &setti
         fmt.setChannels(settings.channelCount());
     }
     m_session->setFormat(fmt);
+    m_session->setEncoderSettings(settings);
     m_settings = settings;
+
+    DP0("S60AudioEncoderControl::setAudioSettings ---");
 }
