@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,73 +25,120 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
+#include "DebugMacros.h"
+
 #include "s60mediametadataprovider.h"
 #include "s60mediaplayercontrol.h"
 #include "s60mediaplayersession.h"
 #include <QtCore/qdebug.h>
 
+/*!
+ * Typecasts the \a control object to S60MediaPlayerControl object.
+*/
 S60MediaMetaDataProvider::S60MediaMetaDataProvider(QObject *control, QObject *parent)
     : QMetaDataReaderControl(parent)
     , m_control(NULL)
 {
+    DP0("S60MediaMetaDataProvider::S60MediaMetaDataProvider +++");
+
     m_control = qobject_cast<S60MediaPlayerControl*>(control);
+
+    DP0("S60MediaMetaDataProvider::S60MediaMetaDataProvider ---");
 }
 
+/*!
+ * Destructor
+*/
+
 S60MediaMetaDataProvider::~S60MediaMetaDataProvider()
 {
+    DP0("S60MediaMetaDataProvider::~S60MediaMetaDataProvider +++");
+    DP0("S60MediaMetaDataProvider::~S60MediaMetaDataProvider ---");
 }
 
+/*!
+ * Returns TRUE if MetaData is Available or else FALSE.
+*/
+
 bool S60MediaMetaDataProvider::isMetaDataAvailable() const
 {
+    DP0("S60MediaMetaDataProvider::isMetaDataAvailable");
+
     if (m_control->session())
        return m_control->session()->isMetadataAvailable();
     return false;
 }
 
+/*!
+ * Always returns FLASE.
+*/
 bool S60MediaMetaDataProvider::isWritable() const
 {
+    DP0("S60MediaMetaDataProvider::isWritable");
+
     return false;
 }
 
+/*!
+ * Returns when \a key meta data is found in metaData.
+*/
+
 QVariant S60MediaMetaDataProvider::metaData(QtMultimediaKit::MetaData key) const
 {
+    DP0("S60MediaMetaDataProvider::metaData");
 
     if (m_control->session())
         return m_control->session()->metaData(key);
     return QVariant();
 }
 
+/*!
+ * Returns available metaData.
+*/
+
 QList<QtMultimediaKit::MetaData> S60MediaMetaDataProvider::availableMetaData() const
 {
+    DP0("S60MediaMetaDataProvider::availableMetaData");
+
     if (m_control->session())
         return m_control->session()->availableMetaData();
     return QList<QtMultimediaKit::MetaData>();
 }
 
+/*!
+ * Returns when \a key string is found in extended metaData.
+*/
+
 QVariant S60MediaMetaDataProvider::extendedMetaData(const QString &key) const
 {
+    DP0("S60MediaMetaDataProvider::extendedMetaData");
 
     if (m_control->session())
         return m_control->session()->metaData(key);
     return QVariant();
 }
 
+/*!
+ * Returns available Extended MetaData.
+*/
+
 QStringList S60MediaMetaDataProvider::availableExtendedMetaData() const
 {
+    DP0("S60MediaMetaDataProvider::availableExtendedMetaData");
 
     if (m_control->session())
         return m_control->session()->availableExtendedMetaData();
