@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,20 +25,22 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
+#include "DebugMacros.h"
+
 #include "s60mediaplayercontrol.h"
 #include "s60mediaplayersession.h"
 #include "s60mediaplayeraudioendpointselector.h"
@@ -46,29 +48,55 @@
 #include <QtGui/QIcon>
 #include <QtCore/QDebug>
 
+/*!
+    Constructs a new audio endpoint selector with the given \a parent.
+*/
+
 S60MediaPlayerAudioEndpointSelector::S60MediaPlayerAudioEndpointSelector(QObject *control, QObject *parent)
    :QAudioEndpointSelector(parent)
     , m_control(0)
 {
+    DP0("S60MediaPlayerAudioEndpointSelector::S60MediaPlayerAudioEndpointSelector +++");
+
     m_control = qobject_cast<S60MediaPlayerControl*>(control);
     m_audioEndpointNames.append("Default");
     m_audioEndpointNames.append("All");
     m_audioEndpointNames.append("None");
     m_audioEndpointNames.append("Earphone");
     m_audioEndpointNames.append("Speaker");
+
+    DP0("S60MediaPlayerAudioEndpointSelector::S60MediaPlayerAudioEndpointSelector ---");
 }
 
+/*!
+    Destroys an audio endpoint selector.
+*/
+
 S60MediaPlayerAudioEndpointSelector::~S60MediaPlayerAudioEndpointSelector()
 {
+    DP0("S60MediaPlayerAudioEndpointSelector::~S60MediaPlayerAudioEndpointSelector +++");
+    DP0("S60MediaPlayerAudioEndpointSelector::~S60MediaPlayerAudioEndpointSelector ---");
 }
 
+/*!
+    \return a list of available audio endpoints.
+*/
+
 QList<QString> S60MediaPlayerAudioEndpointSelector::availableEndpoints() const
 {
+    DP0("S60MediaPlayerAudioEndpointSelector::availableEndpoints");
+
     return m_audioEndpointNames;
 }
 
+/*!
+    \return the description of the endpoint name.
+*/
+
 QString S60MediaPlayerAudioEndpointSelector::endpointDescription(const QString& name) const
 {
+    DP0("S60MediaPlayerAudioEndpointSelector::endpointDescription");
+
     if (name == QString("Default")) //ENoPreference
         return QString("Used to indicate that the playing audio can be routed to"
             "any speaker. This is the default value for audio.");
@@ -88,24 +116,56 @@ QString S60MediaPlayerAudioEndpointSelector::endpointDescription(const QString&
     return QString();
 }
 
+/*!
+    \return the name of the currently selected audio endpoint.
+*/
+
 QString S60MediaPlayerAudioEndpointSelector::activeEndpoint() const
 {
-    if (m_control->session())
+    DP0("S60MediaPlayerAudioEndpointSelector::activeEndpoint");
+
+    if (m_control->session()) {
+        DP1("S60MediaPlayerAudioEndpointSelector::activeEndpoint - ",
+                m_control->session()->activeEndpoint());
         return m_control->session()->activeEndpoint();
-    else
+    }
+    else {
+        DP1("S60MediaPlayerAudioEndpointSelector::activeEndpoint - ",
+                m_control->mediaControlSettings().audioEndpoint());
         return m_control->mediaControlSettings().audioEndpoint();
+    }
 }
 
+/*!
+    \return the name of the default audio endpoint.
+*/
+
 QString S60MediaPlayerAudioEndpointSelector::defaultEndpoint() const
 {
-    if (m_control->session())
+    DP0("S60MediaPlayerAudioEndpointSelector::defaultEndpoint");
+
+    if (m_control->session()) {
+        DP1("S60MediaPlayerAudioEndpointSelector::defaultEndpoint - ",
+                m_control->session()->defaultEndpoint());
         return m_control->session()->defaultEndpoint();
-    else
+    }
+    else {
+        DP1("S60MediaPlayerAudioEndpointSelector::defaultEndpoint - ",
+                m_control->mediaControlSettings().audioEndpoint());
         return m_control->mediaControlSettings().audioEndpoint();
+    }
 }
 
+/*!
+    Set the audio endpoint to \a name.
+*/
+
 void S60MediaPlayerAudioEndpointSelector::setActiveEndpoint(const QString& name)
 {
+    DP0("S60MediaPlayerAudioEndpointSelector::setActiveEndpoin +++");
+
+    DP1("S60MediaPlayerAudioEndpointSelector::setActiveEndpoint - ", name);
+
     QString oldEndpoint = m_control->mediaControlSettings().audioEndpoint();
 
     if (name != oldEndpoint && (name == QString("Default") || name == QString("All") ||
@@ -117,4 +177,6 @@ void S60MediaPlayerAudioEndpointSelector::setActiveEndpoint(const QString& name)
         }
         m_control->setAudioEndpoint(name);
     }
+
+    DP0("S60MediaPlayerAudioEndpointSelector::setActiveEndpoin ---");
 }
