@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -50,6 +50,10 @@
 #include <QRect>
 #include "s60mediaplayerservice.h"
 
+
+_LIT( KSeekable, "Seekable" );
+_LIT( KFalse, "0");
+
 QT_BEGIN_NAMESPACE
 class QMediaTimeRange;
 QT_END_NAMESPACE
@@ -93,12 +97,16 @@ public:
     void setMediaStatus(QMediaPlayer::MediaStatus);
     void setState(QMediaPlayer::State state);
     void setAudioEndpoint(const QString& audioEndpoint);
-    
-protected:    
+    virtual void setPlaybackRate(qreal rate) = 0;
+    virtual bool getIsSeekable() const { return ETrue; }
+    TBool isStreaming();
+
+protected:
     virtual void doLoadL(const TDesC &path) = 0;
     virtual void doLoadUrlL(const TDesC &path) = 0;
     virtual void doPlay() = 0;
     virtual void doStop() = 0;
+    virtual void doClose() = 0;
     virtual void doPauseL() = 0;
     virtual void doSetVolumeL(int volume) = 0;
     virtual void doSetPositionL(qint64 microSeconds) = 0;
@@ -116,7 +124,9 @@ public Q_SLOTS:
     virtual void setActiveEndpoint(const QString& name) = 0;
 
 protected:
+    int error() const;
     void setError(int error,  const QString &errorString = QString(), bool forceReset = false);
+    void setAndEmitError(int error);
     void loaded();
     void buffering();
     void buffered();
@@ -150,7 +160,14 @@ signals:
     void error(int error, const QString &errorString);
     void activeEndpointChanged(const QString &name);
     void mediaChanged();
-    
+    void playbackRateChanged(qreal rate);
+    void volumeChanged(int volume);
+    void mutedChanged(bool muted);
+
+protected:
+    QUrl m_UrlPath;
+    bool m_stream;
+
 private:
     qreal m_playbackRate;
     QMap<QString, QVariant> m_metaDataMap;
@@ -162,7 +179,8 @@ private:
     QTimer *m_stalledTimer;
     int m_error;    
     bool m_play_requested;
-    bool m_stream;
+    bool m_seekable;
+    qint64 m_duration;
 };
 
 #endif
