@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,21 +25,23 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
-#include "S60mediarecognizer.h"
+#include "DebugMacros.h"
+
+#include "s60mediarecognizer.h"
 #include <e32def.h>
 #include <e32cmn.h>
 #include <QtCore/qurl.h>
@@ -52,19 +54,41 @@ static const TInt KMimeTypePrefixLength = 6; // "audio/" or "video/"
 _LIT(KMimeTypePrefixAudio, "audio/");
 _LIT(KMimeTypePrefixVideo, "video/");
 
+/*!
+    Construct a media Recognizer with the given \a parent.
+*/
+
 S60MediaRecognizer::S60MediaRecognizer(QObject *parent) : QObject(parent)
 {
+    DP0("S60MediaRecognizer::S60MediaRecognizer +++");
+    DP0("S60MediaRecognizer::S60MediaRecognizer ---");
 }
 
+/*!
+    Destroys a media Recognizer.
+*/
+
 S60MediaRecognizer::~S60MediaRecognizer()
 {
+    DP0("S60MediaRecognizer::~S60MediaRecognizer +++");
+
     m_file.Close();
     m_fileServer.Close();
     m_recognizer.Close();
+
+    DP0("S60MediaRecognizer::~S60MediaRecognizer ---");
 }
 
+/*!
+ * \return media type of \a url.
+ * \a url may be a streaming link or a local file.
+ * If \a url is local file then identifies the media type and returns it.
+*/
+
 S60MediaRecognizer::MediaType S60MediaRecognizer::mediaType(const QUrl &url)
 {
+    DP0("S60MediaRecognizer::mediaType");
+
     bool isStream = (url.scheme() == "file")?false:true;
 
     if (isStream)
@@ -73,8 +97,16 @@ S60MediaRecognizer::MediaType S60MediaRecognizer::mediaType(const QUrl &url)
         return identifyMediaType(url.toLocalFile());
 }
 
+/*!
+ * \return Media type of \a file name by recognizing its mimetype whether its audio or video.
+*/
+
 S60MediaRecognizer::MediaType S60MediaRecognizer::identifyMediaType(const QString& fileName)
 {
+    DP0("S60MediaRecognizer::identifyMediaType +++");
+
+    DP1("S60MediaRecognizer::identifyMediaType - ", fileName);
+
     S60MediaRecognizer::MediaType result = Video; // default to videoplayer
     bool recognizerOpened = false;
 
@@ -113,11 +145,20 @@ S60MediaRecognizer::MediaType S60MediaRecognizer::identifyMediaType(const QStrin
             }
         }
     }
+
+    DP0("S60MediaRecognizer::identifyMediaType ---");
+
     return result;
 }
 
+/*!
+ * \return Symbian modifiable pointer descriptor from a QString \a string.
+ */
+
 TPtrC S60MediaRecognizer::QString2TPtrC( const QString& string )
 {
+    DP1("S60MediaRecognizer::QString2TPtrC - ", string);
+
     // Returned TPtrC is valid as long as the given parameter is valid and unmodified
     return TPtrC16(static_cast<const TUint16*>(string.utf16()), string.length());
 }
