@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -44,60 +44,106 @@
 
 #include "s60mediaplayersession.h"
 #include "s60mediaplayeraudioendpointselector.h"
-#ifdef MMF_VIDEO_SURFACES_SUPPORTED
+#include "s60medianetworkaccesscontrol.h"
+#include "s60videodisplay.h"
+
+#ifdef VIDEOOUTPUT_GRAPHICS_SURFACES
 #include <videoplayer2.h>
 #else
 #include <videoplayer.h>
-#endif // MMF_VIDEO_SURFACES_SUPPORTED
+#endif // VIDEOOUTPUT_GRAPHICS_SURFACES
+
+#include <QtCore/QCoreApplication>
 #include <QtGui/qwidget.h>
 #include <qvideowidget.h>
 
 #ifdef HAS_AUDIOROUTING_IN_VIDEOPLAYER
 #include <AudioOutput.h>
 #include <MAudioOutputObserver.h>
-#endif
-class QTimer;
+#endif // HAS_AUDIOROUTING_IN_VIDEOPLAYER
 
-class S60VideoPlayerSession : public S60MediaPlayerSession,
-                              public MVideoPlayerUtilityObserver,
-                              public MVideoLoadingObserver
+class QTimer;
+class S60MediaNetworkAccessControl;
+class S60VideoDisplay;
+
+// Helper classes to pass Symbian events from WServ to the S60VideoPlayerSession
+// so it can control video player on certain events if required
+
+class ApplicationFocusObserver
+{
+public:
+    virtual void applicationGainedFocus() = 0;
+    virtual void applicationLostFocus() = 0;
+};
+
+class S60VideoPlayerEventHandler : public QObject
+{
+public:
+    static S60VideoPlayerEventHandler *instance();
+    static bool filterEvent(void *message, long *result);
+    void addApplicationFocusObserver(ApplicationFocusObserver* observer);
+    void removeApplicationFocusObserver(ApplicationFocusObserver* observer);
+private:
+    S60VideoPlayerEventHandler();
+    ~S60VideoPlayerEventHandler();
+private:
+    static S60VideoPlayerEventHandler *m_instance;
+    static QList<ApplicationFocusObserver *> m_applicationFocusObservers;
+    static QCoreApplication::EventFilter m_eventFilter;
+};
+
+class S60VideoPlayerSession : public S60MediaPlayerSession
+                            , public MVideoPlayerUtilityObserver
+                            , public MVideoLoadingObserver
 #ifdef HAS_AUDIOROUTING_IN_VIDEOPLAYER
-                              , public MAudioOutputObserver
-#endif //HAS_AUDIOROUTING_IN_VIDEOPLAYER
+                            , public MAudioOutputObserver
+#endif // HAS_AUDIOROUTING_IN_VIDEOPLAYER
+                            , public ApplicationFocusObserver
 {
     Q_OBJECT
 public:
-    S60VideoPlayerSession(QMediaService *service);
+    S60VideoPlayerSession(QMediaService *service, S60MediaNetworkAccessControl *object);
     ~S60VideoPlayerSession();
 
-    //From S60MediaPlayerSession
+    // From S60MediaPlayerSession
     bool isVideoAvailable();
     bool isAudioAvailable();
     void setVideoRenderer(QObject *renderer);
 
-    //From MVideoLoadingObserver
+    // From MVideoLoadingObserver
     void MvloLoadingStarted();
     void MvloLoadingComplete();
-
+    void setPlaybackRate(qreal rate);
 #ifdef HAS_AUDIOROUTING_IN_VIDEOPLAYER
     // From MAudioOutputObserver
     void DefaultAudioOutputChanged(CAudioOutput& aAudioOutput,
-        CAudioOutput::TAudioOutputPreference aNewDefault);
-#endif //HAS_AUDIOROUTING_IN_VIDEOPLAYER
-public:
+                                   CAudioOutput::TAudioOutputPreference aNewDefault);
+#endif
+
     // From S60MediaPlayerAudioEndpointSelector
     QString activeEndpoint() const;
     QString defaultEndpoint() const;
+
+    // ApplicationFocusObserver
+    void applicationGainedFocus();
+    void applicationLostFocus();
+
+signals:
+    void nativeSizeChanged(QSize);
+
 public Q_SLOTS:
     void setActiveEndpoint(const QString& name);
-    void resizeVideoWindow();
+
+signals:
+    void accessPointChanged(int);
 
 protected:
-    //From S60MediaPlayerSession
+    // From S60MediaPlayerSession
     void doLoadL(const TDesC &path);
     void doLoadUrlL(const TDesC &path);
     void doPlay();
     void doStop();
+    void doClose();
     void doPauseL();
     void doSetVolumeL(int volume);
     qint64 doGetPositionL() const;
@@ -106,21 +152,28 @@ protected:
     int doGetBufferStatusL() const;
     qint64 doGetDurationL() const;
     void doSetAudioEndpoint(const QString& audioEndpoint);
+    bool getIsSeekable() const;
 
-private slots: 
-    void resetVideoDisplay();
+private slots:
+    void windowHandleChanged();
+    void displayRectChanged();
+    void aspectRatioChanged();
+    void rotationChanged();
+#ifndef VIDEOOUTPUT_GRAPHICS_SURFACES
     void suspendDirectScreenAccess();
     void resumeDirectScreenAccess();
+#endif
     
 private: 
-    bool resetNativeHandles();
-    QPair<qreal, qreal> scaleFactor();
+    void applyPendingChanges(bool force = false);
+#ifndef VIDEOOUTPUT_GRAPHICS_SURFACES
     void startDirectScreenAccess();
     bool stopDirectScreenAccess();
+#endif
 #ifdef HAS_AUDIOROUTING_IN_VIDEOPLAYER
     QString qStringFromTAudioOutputPreference(CAudioOutput::TAudioOutputPreference output) const;
 #endif
-    
+
     // From MVideoPlayerUtilityObserver
     void MvpuoOpenComplete(TInt aError);
     void MvpuoPrepareComplete(TInt aError);
@@ -129,31 +182,34 @@ private:
     void MvpuoEvent(const TMMFEvent &aEvent);
 
 private:
-    // Qwn
-#ifdef MMF_VIDEO_SURFACES_SUPPORTED
+    int m_accessPointId;
+    S60MediaNetworkAccessControl* m_networkAccessControl;
+    RWsSession *const m_wsSession;
+    CWsScreenDevice *const m_screenDevice;
+    QMediaService *const m_service;
+#ifdef VIDEOOUTPUT_GRAPHICS_SURFACES
     CVideoPlayerUtility2 *m_player;
 #else
     CVideoPlayerUtility *m_player;
-#endif // MMF_VIDEO_SURFACES_SUPPORTED
-    TRect m_rect;
-    //QVideoOutputControl::Output m_output;
-    QObject *m_videoOutput;
-    WId m_windowId;
     bool m_dsaActive;
     bool m_dsaStopped;
-    
-    //Reference
-    RWsSession &m_wsSession;
-    CWsScreenDevice &m_screenDevice;
-    RWindowBase *m_window;
+#endif // VIDEOOUTPUT_GRAPHICS_SURFACES
+    QObject *m_videoOutputControl;
+    S60VideoDisplay *m_videoOutputDisplay;
     RWindow *m_displayWindow;
-    QMediaService &m_service;
-    Qt::AspectRatioMode m_aspectRatioMode;
-    QSize m_originalSize;
+    QSize m_nativeSize;
 #ifdef HAS_AUDIOROUTING_IN_VIDEOPLAYER
     CAudioOutput *m_audioOutput;
 #endif
     QString m_audioEndpoint;
+    enum Parameter {
+        WindowHandle = 0x1,
+        DisplayRect  = 0x2,
+        ScaleFactors = 0x4,
+        Rotation     = 0x8
+    };
+    QFlags<Parameter> m_pendingChanges;
+    bool m_backendInitiatedPause;
 };
 
 #endif
