@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -251,10 +251,11 @@ QOrganizerItemMaemo5Engine::QOrganizerItemMaemo5Engine()
     QString dbPath = QDir::homePath().append(CALENDAR).append(CALENDARDB);
     QFileSystemWatcher *databaseMonitor = new QFileSystemWatcher(this);
     databaseMonitor->addPath(dbPath);
-    connect(databaseMonitor, SIGNAL(fileChanged(const QString &)), this, SLOT(dataChanged()));
+    connect(databaseMonitor, SIGNAL(fileChanged(QString)), this, SLOT(databaseChanged()));
+    connect(&m_waitTimer, SIGNAL(timeout()), this, SIGNAL(dataChanged()));
 
     d->m_itemTransformer.setManagerUri(managerUri());
-    d->m_asynchProcess = new OrganizerAsynchProcess(this);
+    d->m_asynchManager = new OrganizerAsynchManager(this);
 
     d->m_dbCache = new OrganizerDbCache();
     connect(databaseMonitor, SIGNAL(fileChanged(const QString &)), d->m_dbCache, SLOT(invalidate()));
@@ -262,26 +263,27 @@ QOrganizerItemMaemo5Engine::QOrganizerItemMaemo5Engine()
 
     bool dbOk = d->m_dbAccess->open(QDir::homePath().append(CALENDAR).append(CALENDARDB));
     if (!dbOk) {
-        qDebug() << "Database didn't open!";
-        // TODO: Then what? Constructor has no error status. Throw an exception?
+        qWarning() << "QOrganizerItemMaemo5Engine: error: unable to open database; instance will be invalid.";
     }
 }
 
-void QOrganizerItemMaemo5Engine::dataChanged()
+void QOrganizerItemMaemo5Engine::databaseChanged()
 {
     // Timer prevents from sending multiple signals
     // when database is changed during short period of time
-    if (!m_waitTimer.isActive()) {
-        m_waitTimer.setSingleShot(true);
-        m_waitTimer.setInterval(50);
-        m_waitTimer.start();
-        emit dataChanged();
+    if (m_waitTimer.isActive()) {
+        // we need to reset the timer.
+        m_waitTimer.stop();
     }
+
+    m_waitTimer.setSingleShot(true);
+    m_waitTimer.setInterval(50);
+    m_waitTimer.start();
 }
 
 QOrganizerItemMaemo5Engine::~QOrganizerItemMaemo5Engine()
 {
-    delete d->m_asynchProcess;
+    delete d->m_asynchManager;
 }
 
 QString QOrganizerItemMaemo5Engine::managerName() const
@@ -1083,23 +1085,23 @@ bool QOrganizerItemMaemo5Engine::internalRemoveCollection(const QOrganizerCollec
 
 bool QOrganizerItemMaemo5Engine::startRequest(QOrganizerAbstractRequest* req)
 {
-    d->m_asynchProcess->addRequest(req);
+    d->m_asynchManager->startRequest(req);
     return true;
 }
 
 bool QOrganizerItemMaemo5Engine::cancelRequest(QOrganizerAbstractRequest* req)
 {
-    return d->m_asynchProcess->cancelRequest(req);
+    return d->m_asynchManager->cancelRequest(req);
 }
 
 bool QOrganizerItemMaemo5Engine::waitForRequestFinished(QOrganizerAbstractRequest* req, int msecs)
 {
-    return d->m_asynchProcess->waitForRequestFinished(req, msecs);
+    return d->m_asynchManager->waitForRequestFinished(req, msecs);
 }
 
 void QOrganizerItemMaemo5Engine::requestDestroyed(QOrganizerAbstractRequest* req)
 {
-    return d->m_asynchProcess->requestDestroyed(req);
+    return d->m_asynchManager->requestDestroyed(req);
 }
 
 bool QOrganizerItemMaemo5Engine::hasFeature(QOrganizerManager::ManagerFeature feature, const QString &itemType) const
@@ -1807,7 +1809,7 @@ QOrganizerItem QOrganizerItemMaemo5Engine::parentOf(CCalendar *cal, QOrganizerIt
                             QList<QOrganizerItem> parentCandidateOccurrences =
                                     internalItemOccurrences(*parentCandidateEvent, periodStart, periodEnd, 0, error);
                             if (*error != QOrganizerManager::NoError)
-                                return QOrganizerItem(); // error occured
+                                return QOrganizerItem(); // error occurred
 
                             // Because the period was set, it's enough to just check if we got any
                             if (!parentCandidateOccurrences.isEmpty()) {
