@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,21 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 //system includes
 #include <calcommon.h>
-#include <calinstance.h>
 #include <calsession.h>
 #include <calchangecallback.h>
 #include <calentryview.h>
@@ -48,7 +47,6 @@
 #include <calrrule.h>
 #ifdef SYMBIAN_CALENDAR_V2
 #include <QColor>
-#include <calinstanceiterator.h>
 #include <calcalendariterator.h>
 #include <calcalendarinfo.h>
 // This file (calenmulticaluids.hrh) no longer exists in S^4, so use a local 
@@ -367,17 +365,13 @@ QList<QOrganizerItem> QOrganizerItemSymbianEngine::itemOccurrences(
     QOrganizerManager::Error* error) const
 {
     QList<QOrganizerItem> itemOccurrences;
-    TRAPD(err, itemOccurrencesL(itemOccurrences, parentItem, periodStart, periodEnd, maxCount, fetchHint));
-    if (err != KErrNone) {
-        transformError(err, error);
-        return QList<QOrganizerItem>();
-    }
+    TRAPD(err, itemOccurrences = itemOccurrencesL(parentItem.id(), periodStart, periodEnd, maxCount, fetchHint));
+    transformError(err, error);
     return itemOccurrences;
 }
 
-void QOrganizerItemSymbianEngine::itemOccurrencesL(
-    QList<QOrganizerItem> &itemOccurrences,
-    const QOrganizerItem &parentItem,
+QList<QOrganizerItem> QOrganizerItemSymbianEngine::itemOccurrencesL(
+    const QOrganizerItemId &parentItemId,
     const QDateTime &periodStart,
     const QDateTime &periodEnd,
     int maxCount,
@@ -385,19 +379,28 @@ void QOrganizerItemSymbianEngine::itemOccurrencesL(
 {
     Q_UNUSED(fetchHint)
 
-    // Check parameters
-    if (periodStart.isValid() && periodEnd.isValid() && periodEnd < periodStart) {
-        User::Leave(KErrArgument);
+    //Verify maximum number of items requested
+    if (0 == maxCount)
+    {
+        //Return an empty occurrence list if maxCount is 0
+        return QList<QOrganizerItem>();
     }
 
+    // Verify that parent item exists
+    QOrganizerManager::Error error;
+    QOrganizerItem parentItem = this->item(parentItemId, QOrganizerItemFetchHint(), &error);
+    if (error != QOrganizerManager::NoError)
+        return QList<QOrganizerItem>(); // return an empty occurrence list if parent item is not found
+
+    // Verify time range
+    if (periodStart.isValid() && periodEnd.isValid() && periodEnd < periodStart)
+        User::Leave(KErrArgument);
+
     // Set cal view filter based on the item type
     CalCommon::TCalViewFilter filter(0);
-    QString itemType;
     if (parentItem.type() == QOrganizerItemType::TypeEvent) {
-        itemType = QOrganizerItemType::TypeEventOccurrence.latin1();
         filter = CalCommon::EIncludeAppts | CalCommon::EIncludeEvents;
     } else if (parentItem.type() == QOrganizerItemType::TypeTodo) {
-        itemType = QOrganizerItemType::TypeTodoOccurrence.latin1();
         filter = (CalCommon::EIncludeCompletedTodos | CalCommon::EIncludeIncompletedTodos);
     } else {
         User::Leave(KErrInvalidItemType);
@@ -415,16 +418,19 @@ void QOrganizerItemSymbianEngine::itemOccurrencesL(
     if (periodEnd.isValid())
         endTime.SetTimeLocalL(toTTime(periodEnd, Qt::LocalTime));
 
-    // Loop through all the instance views and fetch the item instances
-    foreach(QOrganizerCollectionId collectionId, m_collections.keys()) {
-        RPointerArray<CCalInstance> instanceList;
-        CleanupResetAndDestroyPushL(instanceList);
-        instanceViewL(collectionId)->FindInstanceL(instanceList, filter,
-            CalCommon::TCalTimeRange(startTime, endTime));
-        // Transform CCalInstances to QOrganizerItems
-        toItemOccurrencesL(instanceList, parentItem, maxCount, collectionId, itemOccurrences);
-        CleanupStack::PopAndDestroy(&instanceList);
-    }
+    // Find instances
+    RPointerArray<CCalInstance> instanceList;
+    CleanupResetAndDestroyPushL(instanceList);
+    m_collections[parentItem.collectionId()].calInstanceView()->FindInstanceL(
+        instanceList, filter, CalCommon::TCalTimeRange(startTime, endTime));
+    
+    // Transform CCalInstances to QOrganizerItems
+    QList<QOrganizerItem> itemOccurrences;
+    toItemOccurrencesL(instanceList, parentItem, maxCount, parentItem.collectionId(), itemOccurrences);
+    
+    CleanupStack::PopAndDestroy(&instanceList);
+    
+    return itemOccurrences;
 }
 
 QList<QOrganizerItem> QOrganizerItemSymbianEngine::items(
@@ -436,16 +442,12 @@ QList<QOrganizerItem> QOrganizerItemSymbianEngine::items(
     QOrganizerManager::Error* error) const
 {
     QList<QOrganizerItem> items;
-    TRAPD(err, itemsL(items, periodStart, periodEnd, filter, sortOrders, fetchHint));
-    if (err != KErrNone) {
-        transformError(err, error);
-        return QList<QOrganizerItem>();
-    }
+    TRAPD(err, items = itemOccurrencesL(periodStart, periodEnd, filter, sortOrders, fetchHint));
+    transformError(err, error);
     return items;
 }
 
-QList<QOrganizerItem> QOrganizerItemSymbianEngine::itemsL(
-    QList<QOrganizerItem> &items,
+QList<QOrganizerItem> QOrganizerItemSymbianEngine::itemOccurrencesL(
     const QDateTime& periodStart,
     const QDateTime& periodEnd,
     const QOrganizerItemFilter &filter,
@@ -454,6 +456,10 @@ QList<QOrganizerItem> QOrganizerItemSymbianEngine::itemsL(
 {
     // TODO: It might be possible to optimize by using fetch hint
     Q_UNUSED(fetchHint);
+    
+    // Verify time range
+    if (periodStart.isValid() && periodEnd.isValid() && periodEnd < periodStart)
+        User::Leave(KErrArgument);  
 
     // If start time is not defined, use minimum start date
     TCalTime startTime;
@@ -468,21 +474,24 @@ QList<QOrganizerItem> QOrganizerItemSymbianEngine::itemsL(
         endTime.SetTimeLocalL(toTTime(periodEnd, Qt::LocalTime));
 
     // Loop through all the instance views and fetch the item instances
-    foreach(QOrganizerCollectionId collectionId, m_collections.keys()) {
+    QList<QOrganizerItem> items;
+    QList<OrganizerSymbianCollection> collections = filteredSymbianCollectionsL(filter);
+    foreach (OrganizerSymbianCollection collection, collections) {
+        
+        // Get instances
         RPointerArray<CCalInstance> instanceList;
         CleanupResetAndDestroyPushL(instanceList);
-        instanceViewL(collectionId)->FindInstanceL(
-            instanceList, CalCommon::EIncludeAll,
-            CalCommon::TCalTimeRange(startTime, endTime));
+        collection.calInstanceView()->FindInstanceL(
+            instanceList, CalCommon::EIncludeAll, CalCommon::TCalTimeRange(startTime, endTime));
+        
         // Transform CCalInstances to QOrganizerItems
-        toItemOccurrencesL(instanceList, QOrganizerItem(), -1, collectionId, items);
+        toItemOccurrencesL(instanceList, QOrganizerItem(), -1, collection.id(), items);
+        
         CleanupStack::PopAndDestroy(&instanceList);
     }
 
     // Use the general implementation to filter and sort items
-    items = slowFilter(items, filter, sortOrders);
-
-    return items;
+    return slowFilterItems(items, filter, sortOrders);
 }
 
 void QOrganizerItemSymbianEngine::toItemOccurrencesL(
@@ -494,6 +503,8 @@ void QOrganizerItemSymbianEngine::toItemOccurrencesL(
 {
     quint64 localCollectionIdValue = m_collections[collectionId].calCollectionId();
 
+    // Counter for the found match items
+    int count = 0;
     // Transform all the instances to QOrganizerItems
     for(int i(0); i < calInstanceList.Count(); i++) {
         QOrganizerItem itemOccurrence;
@@ -504,8 +515,10 @@ void QOrganizerItemSymbianEngine::toItemOccurrencesL(
         if (!parentItem.isEmpty() && parentItem.guid() != itemOccurrence.guid())
             continue;
 
+        // Found one match item
+        count++;
         // Check if maxCount limit is reached
-        if(maxCount > 0 && i >= maxCount)
+        if (maxCount > 0 && count > maxCount)
             break;
 
         // Set local id if this is either an exceptional item or a non-recurring item
@@ -521,20 +534,22 @@ void QOrganizerItemSymbianEngine::toItemOccurrencesL(
 
         // Set instance origin, the detail is set here because transform classes are not aware of
         // the required APIs
-        TCalLocalUid parentLocalUid(0);
-        if (isException) {
-            HBufC8* globalUid = OrganizerItemGuidTransform::guidLC(itemOccurrence);
-            CCalEntry *parentEntry = findParentEntryLC(collectionId, itemOccurrence, *globalUid);
-            parentLocalUid = parentEntry->LocalUidL();
-            CleanupStack::PopAndDestroy(parentEntry);
-            CleanupStack::PopAndDestroy(globalUid);
-        } else {
-            parentLocalUid = calInstance->Entry().LocalUidL();
+        if (isException || isRecurring) {
+            TCalLocalUid parentLocalUid(0);
+            if (isException) {
+                HBufC8* globalUid = OrganizerItemGuidTransform::guidLC(itemOccurrence);
+                CCalEntry *parentEntry = findParentEntryLC(collectionId, itemOccurrence, *globalUid);
+                parentLocalUid = parentEntry->LocalUidL();
+                CleanupStack::PopAndDestroy(parentEntry);
+                CleanupStack::PopAndDestroy(globalUid);
+            } else {
+                parentLocalUid = calInstance->Entry().LocalUidL();
+            }
+            QOrganizerItemParent origin(itemOccurrence.detail<QOrganizerItemParent>());
+            origin.setParentId(toItemId(localCollectionIdValue, parentLocalUid));
+            origin.setOriginalDate(toQDateTimeL(calInstance->StartTimeL()).date());
+            itemOccurrence.saveDetail(&origin);
         }
-        QOrganizerItemParent origin(itemOccurrence.detail<QOrganizerItemParent>());
-        origin.setParentId(toItemId(localCollectionIdValue, parentLocalUid));
-        origin.setOriginalDate(toQDateTimeL(calInstance->StartTimeL()).date());
-        itemOccurrence.saveDetail(&origin);
 
         // Set collection id
         itemOccurrence.setCollectionId(collectionId);
@@ -551,80 +566,92 @@ QList<QOrganizerItemId> QOrganizerItemSymbianEngine::itemIds(
         QOrganizerManager::Error* error) const
 {
     QList<QOrganizerItemId> ids;
-    TRAPD(err, itemIdsL(ids, periodStart, periodEnd, filter, sortOrders))
+    TRAPD(err, ids = itemIdsL(periodStart, periodEnd, filter, sortOrders))
     transformError(err, error);
-    if (*error != QOrganizerManager::NoError) {
-        return QList<QOrganizerItemId>();
-    } else {
-        return ids;
-    }
+    return ids;
 }
 
-void QOrganizerItemSymbianEngine::itemIdsL(
-    QList<QOrganizerItemId>& itemIds, 
+QList<QOrganizerItemId> QOrganizerItemSymbianEngine::itemIdsL(
     const QDateTime& periodStart,
     const QDateTime& periodEnd,
     const QOrganizerItemFilter& filter, 
     const QList<QOrganizerItemSortOrder>& sortOrders) const
 {
-    // Get item ids
-    QList<QOrganizerItemId> modifiedItemIds = getIdsModifiedSinceDateL(periodStart, periodEnd, filter);
-
-    // No filtering and sorting needed?
-    if (filter.type() == QOrganizerItemFilter::DefaultFilter &&
-        sortOrders.count() == 0) {
-        itemIds.append(modifiedItemIds);
-        return;
-    }
-        
-    // Get items for slow filter
-    QOrganizerItemFetchHint fetchHint;
-    QList<QOrganizerItem> items;
-    foreach(const QOrganizerItemId &id, modifiedItemIds)
-        items << itemL(id, fetchHint);
-        
-    // Use the general implementation to filter and sort items
-    QList<QOrganizerItem> filteredAndSorted = slowFilter(items, filter, sortOrders);
-    
-    foreach (const QOrganizerItem& item, filteredAndSorted) {
-        itemIds << item.id();
-    }
+    QList<OrganizerSymbianCollection> collections = filteredSymbianCollectionsL(filter);   
+    QList<QOrganizerItemId> itemIds = itemIdsL(collections, periodStart, periodEnd);
+    return slowFilterIdsL(itemIds, filter, sortOrders);
 }
 
-QList<QOrganizerItemId> QOrganizerItemSymbianEngine::getIdsModifiedSinceDateL(
+QList<QOrganizerItemId> QOrganizerItemSymbianEngine::itemIdsL(
+    const QList<OrganizerSymbianCollection> &collections,
     const QDateTime& periodStart,
-    const QDateTime& periodEnd,
-    const QOrganizerItemFilter& filter) const
+    const QDateTime& periodEnd) const
 {
-    Q_UNUSED(periodStart)
-    Q_UNUSED(periodEnd)
-    Q_UNUSED(filter)
-    // TODO filter by periodStart, periodEnd
-    // TODO: implement collection filter
+    // Verify time range
+    if (periodStart.isValid() && periodEnd.isValid() && periodEnd < periodStart)
+        User::Leave(KErrArgument);
+    
+    QSet<QOrganizerItemId> itemIds;
+    foreach (OrganizerSymbianCollection collection, collections) {
 
-    // Set minumum time for id fetch
-    TCalTime calTime;
-    calTime.SetTimeUtcL(TCalTime::MinTime());
-    
-    // Loop through collections
-    QList<QOrganizerItemId> itemIds;
-    foreach (const OrganizerSymbianCollection &collection, m_collections) {
-        
-        // Get ids from entry view
-        RArray<TCalLocalUid> ids;
-        CleanupClosePushL(ids);
-        collection.calEntryView()->GetIdsModifiedSinceDateL(calTime, ids);
-        
-        // Convert to QOrganizerItemId
-        int count = ids.Count();
-        for (int i=0; i<count; i++)
-            itemIds << toItemId(collection.calCollectionId(), ids[i]);
-        
-        CleanupStack::PopAndDestroy(&ids);
+        if (!periodStart.isValid() && !periodEnd.isValid()) {
+
+            // Time range is not defined. So we can just return all entries. 
+            // NOTE: this a lot faster than using instance view
+
+            // Get all entries
+            TCalTime minTime;
+            minTime.SetTimeUtcL(TCalTime::MinTime());
+            RArray<TCalLocalUid> ids;
+            CleanupClosePushL(ids);
+            collection.calEntryView()->GetIdsModifiedSinceDateL(minTime, ids);
+
+            // Convert to item id's
+            int count = ids.Count();
+            for (int i=0; i<count; i++)
+                itemIds << toItemId(collection.calCollectionId(), ids[i]);
+
+            CleanupStack::PopAndDestroy(&ids);
+
+        } else {
+
+            // Time range is defined so we need to use instance view to find
+            // all entries in the range. For example an item which starts before
+            // periodStart might have an occurrence in the range. We cannot catch 
+            // that through CCalEntryView.
+            // NOTE: If the client does not define periodEnd we might get
+            // a huge amount of instances!
+
+            // If start time is not defined, use minimum start date
+            TCalTime startTime;
+            startTime.SetTimeUtcL(TCalTime::MinTime());
+            if (periodStart.isValid())
+                startTime.SetTimeLocalL(toTTime(periodStart, Qt::LocalTime));
+
+            // If end date is not defined, use maximum end date
+            TCalTime endTime;
+            endTime.SetTimeUtcL(TCalTime::MaxTime());
+            if (periodEnd.isValid())
+                endTime.SetTimeLocalL(toTTime(periodEnd, Qt::LocalTime));
+
+            // Find instances
+            RPointerArray<CCalInstance> instances;
+            CleanupResetAndDestroyPushL(instances);
+            collection.calInstanceView()->FindInstanceL(
+                instances, CalCommon::EIncludeAll, CalCommon::TCalTimeRange(startTime, endTime));
+
+            // Get parent entry ids from instances
+            for (int i=0; i<instances.Count(); i++) {
+                QOrganizerItemId id = toItemId(collection.calCollectionId(), instances[i]->Entry().LocalUidL());
+                if (!itemIds.contains(id))
+                    itemIds << id;
+            }
+
+            CleanupStack::PopAndDestroy(&instances);
+        }
     }
-    return itemIds;
+    return itemIds.toList();
 }
-    
 QList<QOrganizerItem> QOrganizerItemSymbianEngine::itemsForExport(
     const QDateTime& periodStart,
     const QDateTime& periodEnd,
@@ -633,40 +660,22 @@ QList<QOrganizerItem> QOrganizerItemSymbianEngine::itemsForExport(
     const QOrganizerItemFetchHint& fetchHint, 
     QOrganizerManager::Error* error) const
 {
+    Q_UNUSED(fetchHint);
     QList<QOrganizerItem> itemsList;
-    TRAPD(err, itemsForExportL(itemsList, periodStart, periodEnd, filter, sortOrders, fetchHint));
+    TRAPD(err, itemsList = itemsForExportL(periodStart, periodEnd, filter, sortOrders));
     transformError(err, error);
-    if (*error != QOrganizerManager::NoError) {
-        return QList<QOrganizerItem>();
-    } else {
-        return itemsList;
-    }
+    return itemsList;
 }
 
-void QOrganizerItemSymbianEngine::itemsForExportL(QList<QOrganizerItem>& itemsList, 
+QList<QOrganizerItem> QOrganizerItemSymbianEngine::itemsForExportL( 
     const QDateTime& periodStart,
     const QDateTime& periodEnd,
     const QOrganizerItemFilter& filter, 
-    const QList<QOrganizerItemSortOrder>& sortOrders, 
-    const QOrganizerItemFetchHint& fetchHint) const
+    const QList<QOrganizerItemSortOrder>& sortOrders) const
 {
-    // Get item ids
-    QList<QOrganizerItemId> itemIds = getIdsModifiedSinceDateL(periodStart, periodEnd, filter);
-
-    // Get items
-    QList<QOrganizerItem> items;
-    foreach (QOrganizerItemId id, itemIds)
-        items << itemL(id, fetchHint);
-    
-    // No filtering and sorting needed?
-    if (filter.type() == QOrganizerItemFilter::DefaultFilter &&
-        sortOrders.count() == 0) {
-        itemsList.append(items);
-        return;
-    }
-    
-    // Use the general implementation to filter and sort items
-    itemsList.append(slowFilter(items, filter, sortOrders));
+    QList<OrganizerSymbianCollection> collections = filteredSymbianCollectionsL(filter);   
+    QList<QOrganizerItemId> itemIds = itemIdsL(collections, periodStart, periodEnd);
+    return slowFilterIdsToItemsL(itemIds, filter, sortOrders);
 }
 
 QOrganizerItem QOrganizerItemSymbianEngine::item(
@@ -1150,27 +1159,127 @@ void QOrganizerItemSymbianEngine::removeItemL(
     CleanupStack::PopAndDestroy(calEntry);
 }
 
-QList<QOrganizerItem> QOrganizerItemSymbianEngine::slowFilter(
-    const QList<QOrganizerItem> &items, const QOrganizerItemFilter& filter, 
+QList<QOrganizerItem> QOrganizerItemSymbianEngine::slowFilterIdsToItemsL(
+    const QList<QOrganizerItemId> &itemIds,
+    const QOrganizerItemFilter& filter, 
     const QList<QOrganizerItemSortOrder>& sortOrders) const
 {
+    // Nothing to filter?
+    if (filter.type() == QOrganizerItemFilter::InvalidFilter)
+        return QList<QOrganizerItem>();
+    
+    // Get item. Filter and sort it.
     QList<QOrganizerItem> filteredAndSorted;
-
-    if (filter.type() == QOrganizerItemFilter::DefaultFilter) {
-        // Only sort items.
-        foreach(const QOrganizerItem& item, items) {
-            QOrganizerManagerEngine::addSorted(&filteredAndSorted, item, sortOrders);
-        }
-    } else if (filter.type() != QOrganizerItemFilter::InvalidFilter) {
-        foreach(const QOrganizerItem& item, items) {
-            if (QOrganizerManagerEngine::testFilter(filter, item))
-                QOrganizerManagerEngine::addSorted(&filteredAndSorted, item, sortOrders);
-        }
-    }
+    foreach (const QOrganizerItemId &id, itemIds)
+        addFilteredAndSorted(&filteredAndSorted, itemL(id, QOrganizerItemFetchHint()), filter, sortOrders);
 
     return filteredAndSorted;
 }
 
+QList<QOrganizerItemId> QOrganizerItemSymbianEngine::slowFilterIdsL(
+    const QList<QOrganizerItemId> &itemIds,
+    const QOrganizerItemFilter& filter, 
+    const QList<QOrganizerItemSortOrder>& sortOrders) const
+{
+    // Nothing to filter?
+    if (filter.type() == QOrganizerItemFilter::InvalidFilter)
+        return QList<QOrganizerItemId>();
+    
+    // No filtering and sorting needed?
+    if (filter.type() == QOrganizerItemFilter::DefaultFilter && sortOrders.count() == 0)
+        return itemIds;    
+    
+    // Get item. Filter and sort it.
+    QList<QOrganizerItem> filteredAndSorted;
+    foreach (const QOrganizerItemId &id, itemIds)
+        addFilteredAndSorted(&filteredAndSorted, itemL(id, QOrganizerItemFetchHint()), filter, sortOrders);
+
+    // Convert items to item id's
+    QList<QOrganizerItemId> ids;
+    foreach (const QOrganizerItem& item, filteredAndSorted)
+        ids << item.id();
+        
+    return ids;
+}
+
+QList<QOrganizerItem> QOrganizerItemSymbianEngine::slowFilterItems(
+    const QList<QOrganizerItem> &items,
+    const QOrganizerItemFilter& filter, 
+    const QList<QOrganizerItemSortOrder>& sortOrders) const
+{
+    // Nothing to filter?
+    if (filter.type() == QOrganizerItemFilter::InvalidFilter)
+        return QList<QOrganizerItem>();
+    
+    // No filtering and sorting needed?
+    if (filter.type() == QOrganizerItemFilter::DefaultFilter && sortOrders.count() == 0)
+        return items; 
+    
+    // Filter and sort
+    QList<QOrganizerItem> filteredAndSorted;
+    foreach(const QOrganizerItem& item, items)
+        addFilteredAndSorted(&filteredAndSorted, item, filter, sortOrders);
+    return filteredAndSorted;
+}
+
+void QOrganizerItemSymbianEngine::addFilteredAndSorted(
+    QList<QOrganizerItem> *items,
+    const QOrganizerItem &item,
+    const QOrganizerItemFilter& filter,
+    const QList<QOrganizerItemSortOrder>& sortOrders) const
+{
+    if (filter.type() == QOrganizerItemFilter::DefaultFilter) {
+        QOrganizerManagerEngine::addSorted(items, item, sortOrders); // only sorting needed
+    } else {
+        if (QOrganizerManagerEngine::testFilter(filter, item))
+            QOrganizerManagerEngine::addSorted(items, item, sortOrders);
+    }
+}
+
+QList<OrganizerSymbianCollection> QOrganizerItemSymbianEngine::filteredSymbianCollectionsL(
+    const QOrganizerItemFilter &filter) const
+{
+    // No filter for collections?
+    if (filter.type() == QOrganizerItemFilter::DefaultFilter)
+        return m_collections.values();
+    
+    // Nothing to filter?
+    if (filter.type() == QOrganizerItemFilter::InvalidFilter)
+        return QList<OrganizerSymbianCollection>();
+    
+    // Get filters
+    QList<QOrganizerItemFilter> filters;
+    if (filter.type() == QOrganizerItemFilter::UnionFilter) 
+        filters = static_cast<QOrganizerItemUnionFilter>(filter).filters();
+    if (filter.type() == QOrganizerItemFilter::CollectionFilter)
+        filters.append(filter);
+    
+    // TODO: QOrganizerItemFilter::IntersectionFilter
+    // Implementing this is not really worth the effort. It's an unlikely use case.
+    // Simpler just to return all collections and let slowfilter handle this.
+    
+    // Get collection ids from collection filters
+    QList<QOrganizerCollectionId> cIds;
+    foreach (const QOrganizerItemFilter &f, filters) {
+        if (f.type() == QOrganizerItemFilter::CollectionFilter)
+            cIds << static_cast<QOrganizerItemCollectionFilter>(f).collectionIds().toList();
+    }
+    
+    // No filter found?
+    if (cIds.count() == 0)
+        return m_collections.values();
+    
+    // Find matching collections
+    QList<OrganizerSymbianCollection> collections;
+    foreach (const QOrganizerCollectionId &id, cIds) {
+        if (m_collections.contains(id))
+            collections << m_collections[id];
+        else
+            User::Leave(KErrArgument); // TODO: Not really sure if we should leave in this case...
+    }    
+    return collections;
+}
+
 QOrganizerCollection QOrganizerItemSymbianEngine::defaultCollection(
     QOrganizerManager::Error* error) const
 {
