@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -234,6 +234,9 @@ void tst_ItemOccurrence::fetchOccurrenceByFilterSort_data()
     }    
 }
 
+/*!
+ * TODO: to be refactored into several smaller test cases.
+ */
 void tst_ItemOccurrence::fetchOccurrenceByFilterSort()
 {
     QFETCH(QString, managerName);
@@ -246,7 +249,6 @@ void tst_ItemOccurrence::fetchOccurrenceByFilterSort()
     // Set the item type
     QOrganizerItem item;
     item.setType(itemType);
-    QDateTime endTime(QDate(QDate::currentDate().year() , 9, 30));
     QOrganizerEventTime timeRange;
     timeRange.setStartDateTime(startTime);
     QVERIFY(item.saveDetail(&timeRange));
@@ -294,25 +296,21 @@ void tst_ItemOccurrence::fetchOccurrenceByFilterSort()
     QCOMPARE(instanceList.size(), 2);
     
     QOrganizerItem firstItem = instanceList.at(0);
-    // The type must be either "event" or "event occurrence"
-    QVERIFY(firstItem.type() == QLatin1String(QOrganizerItemType::TypeEventOccurrence)
-        || firstItem.type() == QLatin1String(QOrganizerItemType::TypeEvent));
+    QCOMPARE(firstItem.type(), QLatin1String(QOrganizerItemType::TypeEventOccurrence));
     QCOMPARE(firstItem.detail<QOrganizerEventTime>().startDateTime(), QDateTime(QDate(QDate::currentDate().year(), 9, 15)));
     QCOMPARE(firstItem.displayLabel(), instanceList[1].displayLabel());
 
     //Search without filtering and sorting. Full instanceList is returned
-    instanceList.clear();
     sortList.clear();    
-    instanceList = m_om->items(f,sortList,fetchHint);
+    instanceList = m_om->items(f, sortList, fetchHint);
     QCOMPARE(instanceList.size(), 3);
     
     //Search full instance list in descending order without filtering
     sortList.append(sortOrder);
-    instanceList = m_om->items(f,sortList,fetchHint);
+    instanceList = m_om->items(f, sortList, fetchHint);
     QCOMPARE(instanceList.size(), 3);
     QOrganizerItem thirdItem = instanceList.at(2);
-    QVERIFY(thirdItem.type() == QLatin1String(QOrganizerItemType::TypeEventOccurrence)
-        || thirdItem.type() == QLatin1String(QOrganizerItemType::TypeEvent));
+    QCOMPARE(thirdItem.type(), QLatin1String(QOrganizerItemType::TypeEventOccurrence));
     QCOMPARE(thirdItem.detail<QOrganizerEventTime>().startDateTime(), startTime);
 
     // Save another item with same attributes as first item
@@ -322,9 +320,9 @@ void tst_ItemOccurrence::fetchOccurrenceByFilterSort()
     secondItem.setDisplayLabel(modifiedLabel); 
     QVERIFY(secondItem.saveDetail(&recurrence));
     QVERIFY(m_om->saveItem(&secondItem));
-    
-    instanceList = m_om->items(df,sortList,fetchHint);
-    QCOMPARE(instanceList.size(), 4);
+
+    instanceList = m_om->items(df, sortList, fetchHint);
+    QCOMPARE(instanceList.size(), 5);
 }
 
 void tst_ItemOccurrence::addOccurrenceWithException_data()
@@ -794,20 +792,20 @@ void tst_ItemOccurrence::daylightSavingTime()
     // Verify that event occurs the same time every month
     QList<QOrganizerItem> events = m_om->itemOccurrences(event, event.startDateTime(), QDateTime(rule.limitDate()));
     QVERIFY(events.count() == 12);
-    foreach(QOrganizerEventOccurrence occurence, events) {
+    foreach(QOrganizerEventOccurrence occurrence, events) {
 
         //qDebug() << "event occurrence:";
-        //qDebug() << "\tstart time utc   :" << occurence.startDateTime().toUTC();
-        //qDebug() << "\tstart time local :" << occurence.startDateTime().toLocalTime();
-        //qDebug() << "\tend time utc     :" << occurence.endDateTime().toUTC();
-        //qDebug() << "\tend time local   :" << occurence.endDateTime().toLocalTime();
+        //qDebug() << "\tstart time utc   :" << occurrence.startDateTime().toUTC();
+        //qDebug() << "\tstart time local :" << occurrence.startDateTime().toLocalTime();
+        //qDebug() << "\tend time utc     :" << occurrence.endDateTime().toUTC();
+        //qDebug() << "\tend time local   :" << occurrence.endDateTime().toLocalTime();
 
-        QVERIFY(occurence.startDateTime().toUTC().time() == startDateTime.toUTC().time());
-        QVERIFY(occurence.endDateTime().toUTC().time() == endDateTime.toUTC().time());
-        QVERIFY(occurence.startDateTime().toLocalTime().time() == startDateTime.toLocalTime().time());
-        QVERIFY(occurence.endDateTime().toLocalTime().time() == endDateTime.toLocalTime().time());
-        QVERIFY(occurence.startDateTime().toLocalTime().date().day() == startDateTime.toLocalTime().date().day());
-        QVERIFY(occurence.endDateTime().toLocalTime().date().day() == endDateTime.toLocalTime().date().day());
+        QVERIFY(occurrence.startDateTime().toUTC().time() == startDateTime.toUTC().time());
+        QVERIFY(occurrence.endDateTime().toUTC().time() == endDateTime.toUTC().time());
+        QVERIFY(occurrence.startDateTime().toLocalTime().time() == startDateTime.toLocalTime().time());
+        QVERIFY(occurrence.endDateTime().toLocalTime().time() == endDateTime.toLocalTime().time());
+        QVERIFY(occurrence.startDateTime().toLocalTime().date().day() == startDateTime.toLocalTime().date().day());
+        QVERIFY(occurrence.endDateTime().toLocalTime().date().day() == endDateTime.toLocalTime().date().day());
     }
 
 }
@@ -831,11 +829,11 @@ void tst_ItemOccurrence::leapYear()
     // Verify
     QList<QOrganizerItem> events = m_om->itemOccurrences(event, event.startDateTime(), QDateTime(rule.limitDate()));
     QVERIFY(events.count() == 9);
-    foreach(QOrganizerEventOccurrence occurence, events) {
-        if (occurence.startDateTime().date().year() % 4 == 0)
-            QVERIFY(occurence.startDateTime().date().day() == 29); // leap year
+    foreach(QOrganizerEventOccurrence occurrence, events) {
+        if (occurrence.startDateTime().date().year() % 4 == 0)
+            QVERIFY(occurrence.startDateTime().date().day() == 29); // leap year
         else
-            QVERIFY(occurence.startDateTime().date().day() == 28); // normal year
+            QVERIFY(occurrence.startDateTime().date().day() == 28); // normal year
     }
 }
 
