@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -123,8 +123,7 @@ private: // util functions
     QOrganizerItemFilter detailRangeFilter(QString defNam, QString fieldNam, int flags, QVariant min, QVariant max);
 private:
     QList<QOrganizerManager *> m_managers;
-    QList<QOrganizerItemIdList> m_itemIds;
-
+    QMap<int, QOrganizerItemIdList> m_itemIds; // <"manager index", "item ids">
 };
 
 tst_itemSortFilter::tst_itemSortFilter()
@@ -252,7 +251,13 @@ void tst_itemSortFilter::filterItems()
     QFETCH(int, mgrIndex);
     QFETCH(QString, matchingItemsStr);
 
-    QList<QOrganizerItem>actualItems = m_managers.at(mgrIndex)->items(filter);
+    // Verify item occurrences
+    QList<QOrganizerItem> actualItems = m_managers.at(mgrIndex)->items(filter);
+    // Cannot use id comparison, since no ids are available for occurrences
+    QCOMPARE(actualItems.count(), matchingItemsStr.count());
+
+    // Verify items for export
+    actualItems = m_managers.at(mgrIndex)->itemsForExport(QDateTime(), QDateTime(), filter);
     QList<QOrganizerItemId> actualIds;
     QString actualItemsStr;
 
@@ -260,11 +265,7 @@ void tst_itemSortFilter::filterItems()
         actualIds << item.id();
     }
     actualItemsStr = convertIds(mgrIndex, actualIds);
-
-    QVERIFY(actualItemsStr.length() == matchingItemsStr.length());
-    for(int i=0;i < matchingItemsStr.length();i++) {
-        QVERIFY(actualItemsStr.contains(matchingItemsStr.at(i)));
-    }
+    QCOMPARE(actualItemsStr, matchingItemsStr);
 }
 
 void tst_itemSortFilter::sortItems_data()
@@ -319,7 +320,13 @@ void tst_itemSortFilter::sortItems()
     QFETCH(int, mgrIndex);
     QFETCH(QString, matchingItemsStr);
 
+    // Verify item occurrences
     QList<QOrganizerItem> actualItems = m_managers.at(mgrIndex)->items(QOrganizerItemFilter(), sortOrderList);
+    // Cannot use id comparison, since no ids are available for occurrences
+    QCOMPARE(actualItems.count(), matchingItemsStr.count());
+
+    // Verify items for export
+    actualItems = m_managers.at(mgrIndex)->itemsForExport(QDateTime(), QDateTime(), QOrganizerItemFilter(), sortOrderList);
     QList<QOrganizerItemId> actualIds;
     QString actualItemsStr;
 
@@ -408,7 +415,7 @@ void tst_itemSortFilter::addTodo_data(int mgrIndex)
             << QTstDetailField(QOrganizerTodoProgress::DefinitionName, QOrganizerTodoProgress::FieldFinishedDateTime, QDateTime::currentDateTime().addDays(2)));
     }
 
-     m_itemIds << itemIdList;
+    m_itemIds.insert(mgrIndex, itemIdList);
 }
 
 /*!
@@ -446,13 +453,14 @@ bool tst_itemSortFilter::parseDetails(QTstDetailFieldList detailsList, QList<QOr
 
 QString tst_itemSortFilter::convertIds(int mgrIndex, QOrganizerItemIdList ids)
 {
-   QString ret;
-   /* Expected is of the form "abcd".. it's possible that there are some extra contacts */
-   for (int i = 0; i < ids.size(); i++) {
-       if (m_itemIds.at(mgrIndex).indexOf(ids.at(i)) >= 0)
-           ret += ('a' + m_itemIds.at(mgrIndex).indexOf(ids.at(i)));
-   }
-   return ret;
+    QOrganizerItemIdList managerIds = m_itemIds.value(mgrIndex);
+    QString ret;
+    /* Expected is of the form "abcd".. it's possible that there are some extra contacts */
+    for (int i = 0; i < ids.size(); i++) {
+        if (managerIds.indexOf(ids.at(i)) >= 0)
+            ret += ('a' + managerIds.indexOf(ids.at(i)));
+    }
+    return ret;
 }
 
 QOrganizerItemFilter tst_itemSortFilter::invalidFilter()
