@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,21 +25,23 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #include "n900filebasedsensor.h"
+#include <time.h>
+#include <QTimer>
 
 n900filebasedsensor::n900filebasedsensor(QSensor *sensor)
     : QSensorBackend(sensor)
@@ -59,8 +61,8 @@ void n900filebasedsensor::start()
     int dataRate = sensor()->dataRate();
     if (dataRate == 0) {
         if (sensor()->availableDataRates().count())
-            // Use the first available rate when -1 is chosen
-            dataRate = sensor()->availableDataRates().first().first;
+            // Use the faster part of the first available rate by default
+            dataRate = sensor()->availableDataRates().first().second;
         else
             dataRate = 1;
     }
@@ -69,6 +71,10 @@ void n900filebasedsensor::start()
 
     if (interval)
         m_timerid = startTimer(interval);
+
+    // Don't poll now because Symbian/MeeGo can't do anything till we hit the event loop
+    // Emulate this behaviour for consistency
+    QTimer::singleShot(0, this, SLOT(pollnow()));
 }
 
 void n900filebasedsensor::stop()
@@ -84,3 +90,20 @@ void n900filebasedsensor::timerEvent(QTimerEvent * /*event*/)
     poll();
 }
 
+quint64 n900filebasedsensor::getTimestamp()
+{
+    struct timespec tv;
+    int ok;
+
+    ok = clock_gettime(CLOCK_MONOTONIC, &tv);
+    Q_ASSERT(ok == 0);
+
+    quint64 result = (tv.tv_sec * 1000000ULL) + (tv.tv_nsec * 0.001); // scale to microseconds
+    return result;
+}
+
+void n900filebasedsensor::pollnow()
+{
+    poll();
+}
+
