@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -56,7 +56,7 @@ CAmbientLightSensorSym* CAmbientLightSensorSym::NewL(QSensor *sensor)
     CleanupStack::PushL(self);
     self->ConstructL();
     CleanupStack::Pop();
-    return self;    
+    return self;
     }
 
 /**
@@ -74,24 +74,22 @@ CAmbientLightSensorSym::~CAmbientLightSensorSym()
  */
 CAmbientLightSensorSym::CAmbientLightSensorSym(QSensor *sensor):CSensorBackendSym(sensor)
     {
-    setReading<QAmbientLightReading>(&iReading);    
+    setReading<QAmbientLightReading>(&iReading);
     iBackendData.iSensorType = KSensrvChannelTypeIdAmbientLightData;
     }
 
 /*
- * RecvData is used to retrieve the sensor reading from sensor server
+ * DataReceived is used to retrieve the sensor reading from sensor server
  * It is implemented here to handle ambient light sensor specific
  * reading data and provides conversion and utility code
- */  
-void CAmbientLightSensorSym::RecvData(CSensrvChannel &aChannel)
+ */
+void CAmbientLightSensorSym::DataReceived(CSensrvChannel &aChannel, TInt aCount, TInt /*aDataLost*/)
+    {
+    ProcessData(aChannel, aCount, iData);
+    }
+
+void CAmbientLightSensorSym::ProcessReading()
     {
-    TPckg<TSensrvAmbientLightData> lightpkg( iData );
-    TInt ret = aChannel.GetData( lightpkg );
-    if(KErrNone != ret)
-        {
-        // If there is no reading available, return without setting
-        return;
-        }
     // Get a lock on the reading data
     iBackendData.iReadingLock.Wait();
     switch (iData.iAmbientLight)
@@ -99,7 +97,7 @@ void CAmbientLightSensorSym::RecvData(CSensrvChannel &aChannel)
         case TSensrvAmbientLightData::KAmbientLightVeryDark:
         case TSensrvAmbientLightData::KAmbientLightDark:
             {
-            iReading.setLightLevel(QAmbientLightReading::Dark);               
+            iReading.setLightLevel(QAmbientLightReading::Dark);
             }
             break;
 
@@ -136,6 +134,8 @@ void CAmbientLightSensorSym::RecvData(CSensrvChannel &aChannel)
     iReading.setTimestamp(iData.iTimeStamp.Int64());
     // Release the lock
     iBackendData.iReadingLock.Signal();
+    // Notify that a reading is available
+    newReadingAvailable();
     }
 
 /**
