@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,23 +25,22 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 // Internal Headers
 #include "magnetometersensorsym.h"
-
 #include <sensrvgeneralproperties.h>
 
 /**
@@ -59,7 +58,7 @@ CMagnetometerSensorSym* CMagnetometerSensorSym::NewL(QSensor *sensor)
     CleanupStack::PushL(self);
     self->ConstructL();
     CleanupStack::Pop();
-    return self;    
+    return self;
     }
 
 /**
@@ -83,7 +82,7 @@ CMagnetometerSensorSym::CMagnetometerSensorSym(QSensor *sensor):CSensorBackendSy
         {
         setReading<QMagnetometerReading>(&iReading);
         }
-    iBackendData.iSensorType = KSensrvChannelTypeIdMagnetometerXYZAxisData;    
+    iBackendData.iSensorType = KSensrvChannelTypeIdMagnetometerXYZAxisData;
     //Enable Property listening, required to get Calibration level
     SetListening(ETrue, ETrue);
     }
@@ -118,8 +117,8 @@ void CMagnetometerSensorSym::start()
         }
     // Call backend start
     CSensorBackendSym::start();
-    
-    
+
+
     TSensrvProperty dataFormatProperty;
     TRAP(err, iBackendData.iSensorChannel->GetPropertyL(KSensrvPropIdChannelDataFormat, ESensrvSingleProperty, dataFormatProperty));
     if(err == KErrNone)
@@ -129,7 +128,7 @@ void CMagnetometerSensorSym::start()
         if(dataFormat == ESensrvChannelDataFormatScaled)
             {
             TSensrvProperty scaleRangeProperty;
-            TRAP(err, iBackendData.iSensorChannel->GetPropertyL(KSensrvPropIdScaledRange, KSensrvItemIndexNone, scaleRangeProperty)); 
+            TRAP(err, iBackendData.iSensorChannel->GetPropertyL(KSensrvPropIdScaledRange, KSensrvItemIndexNone, scaleRangeProperty));
             if(err == KErrNone)
                 {
                 if(scaleRangeProperty.GetArrayIndex() == ESensrvSingleProperty)
@@ -149,12 +148,12 @@ void CMagnetometerSensorSym::start()
                     {
                     TInt index;
                     if(scaleRangeProperty.PropertyType() == ESensrvIntProperty)
-                        {              
+                        {
                         scaleRangeProperty.GetValue(index);
                         }
                     else if(scaleRangeProperty.PropertyType() == ESensrvRealProperty)
                         {
-                        TReal realIndex;              
+                        TReal realIndex;
                         scaleRangeProperty.GetValue(realIndex);
                         index = realIndex;
                         }
@@ -179,20 +178,17 @@ void CMagnetometerSensorSym::start()
     }
 
 /*
- * RecvData is used to retrieve the sensor reading from sensor server
+ * DataReceived is used to retrieve the sensor reading from sensor server
  * It is implemented here to handle magnetometer sensor specific
  * reading data and provides conversion and utility code
- */ 
-void CMagnetometerSensorSym::RecvData(CSensrvChannel &aChannel)
+ */
+void CMagnetometerSensorSym::DataReceived(CSensrvChannel &aChannel, TInt aCount, TInt /*aDataLost*/)
+    {
+    ProcessData(aChannel, aCount, iData);
+    }
+
+void CMagnetometerSensorSym::ProcessReading()
     {
-    TPckg<TSensrvMagnetometerAxisData> magnetometerpkg( iData );
-    TInt ret = aChannel.GetData( magnetometerpkg );
-    if(KErrNone != ret)
-        {
-        // If there is no reading available, return without setting
-        return;
-        }
-    
     TReal x, y, z;
     // If Geo values are requested set it
     if(iReturnGeoValues)
@@ -207,20 +203,20 @@ void CMagnetometerSensorSym::RecvData(CSensrvChannel &aChannel)
         x = iData.iAxisXRaw;
         y = iData.iAxisYRaw;
         z = iData.iAxisZRaw;
-        }   
+        }
     // Scale adjustments
     if(iScaleRange)
-	{
-	qoutputrangelist rangeList = sensor()->outputRanges();
+        {
+        qoutputrangelist rangeList = sensor()->outputRanges();
         int outputRange = sensor()->outputRange();
         if (outputRange == -1)
             outputRange = 0;
-	TReal maxValue = rangeList[outputRange].maximum;
-	x = (x/iScaleRange) * maxValue;
-	y = (y/iScaleRange) * maxValue;
-	z = (z/iScaleRange) * maxValue;
-	}
-	// Get a lock on the reading data
+        TReal maxValue = rangeList[outputRange].maximum;
+        x = (x/iScaleRange) * maxValue;
+        y = (y/iScaleRange) * maxValue;
+        z = (z/iScaleRange) * maxValue;
+        }
+    // Get a lock on the reading data
     iBackendData.iReadingLock.Wait();
     iReading.setX(x);
     iReading.setY(y);
@@ -231,6 +227,8 @@ void CMagnetometerSensorSym::RecvData(CSensrvChannel &aChannel)
     iReading.setCalibrationLevel(iCalibrationLevel);
     // Release the lock
     iBackendData.iReadingLock.Signal();
+    // Notify that a reading is available
+    newReadingAvailable();
     }
 
 /**
@@ -268,6 +266,6 @@ qreal CMagnetometerSensorSym::GetCalibrationLevel()
 void CMagnetometerSensorSym::ConstructL()
     {
     InitializeL();
-    
+
     }
 
