@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -63,57 +63,58 @@ public:
      * @return CMagnetometerSensorSym if successful, leaves on failure
      */
     static CMagnetometerSensorSym* NewL(QSensor *sensor);
-    
+
     /**
      * Destructor
      * Closes the backend resources
      */
     ~CMagnetometerSensorSym();
-    
+
     /*
      * Used to retrieve the current calibration level
      * iCalibrationLevel is automatically updated whenever there is a change
      * in calibration level
      */
     qreal GetCalibrationLevel();
-    
+
     /**
      * start is overridden to allow retrieving initial calibration property before
      * and to set the required value type flags
      */
     void start();
-    
+
 private:
     /**
      * Default constructor
      */
     CMagnetometerSensorSym(QSensor *sensor);
-    
+
     /*
-     * RecvData is used to retrieve the sensor reading from sensor server
+     * DataReceived is used to retrieve the sensor reading from sensor server
      * It is implemented here to handle magnetometer sensor specific
      * reading data and provides conversion and utility code
-     */ 
-    void RecvData(CSensrvChannel &aChannel);
-    
+     */
+    void DataReceived(CSensrvChannel &aChannel, TInt aCount, TInt aDataLost);
+    void ProcessReading();
+
     /**
      * HandlePropertyChange is called from backend, to indicate a change in property
      */
     void HandlePropertyChange(CSensrvChannel &aChannel, const TSensrvProperty &aChangedProperty);
-    
+
     /**
      * Second phase constructor
      * Initialize the backend resources
      */
-    void ConstructL();    
-    
+    void ConstructL();
+
 public:
     /**
      * Holds the id of the magnetometer
      */
     static char const * const id;
-    
-private:     
+
+private:
     QMagnetometerReading iReading;
     TSensrvMagnetometerAxisData iData;
     qreal iCalibrationLevel;
