@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,21 +25,22 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #include "tapsensorsym.h"
+
 /**
  * set the id of the Tap sensor
  */
@@ -55,7 +56,7 @@ CTapSensorSym* CTapSensorSym::NewL(QSensor *sensor)
     CleanupStack::PushL(self);
     self->ConstructL();
     CleanupStack::Pop();
-    return self;    
+    return self;
     }
 
 /**
@@ -72,94 +73,95 @@ CTapSensorSym::~CTapSensorSym()
  */
 CTapSensorSym::CTapSensorSym(QSensor *sensor):CSensorBackendSym(sensor)
     {
-    setReading<QTapReading>(&iReading);    
+    setReading<QTapReading>(&iReading);
     iBackendData.iSensorType = KSensrvChannelTypeIdAccelerometerDoubleTappingData;
     }
 /*
- * RecvData is used to retrieve the sensor reading from sensor server
+ * DataReceived is used to retrieve the sensor reading from sensor server
  * It is implemented here to handle tap sensor specific
  * reading data and provides conversion and utility code
- */ 
-void CTapSensorSym::RecvData(CSensrvChannel &aChannel)
+ */
+void CTapSensorSym::DataReceived(CSensrvChannel &aChannel, TInt aCount, TInt /*aDataLost*/)
     {
-    TPckg<TSensrvTappingData> tappkg( iData );
-    TInt ret = aChannel.GetData( tappkg );
-    if(KErrNone != ret)
-        {
-		// If there is no reading available, return without setting
-        return;
-        }
-	// Get a lock on the reading data
+    ProcessData(aChannel, aCount, iData);
+    }
+
+void CTapSensorSym::ProcessReading()
+    {
+    // Get a lock on the reading data
     iBackendData.iReadingLock.Wait();
-	//Mapping device tap sensor enum values to Qt tap sensor enum values
+    //Mapping device tap sensor enum values to Qt tap sensor enum values
     switch (iData.iDirection)
         {
-			// Indicates a tap on positive X axis
+            // Indicates a tap on positive X axis
         case KSensrvAccelerometerDirectionXplus:
             {
             iReading.setTapDirection(QTapReading::X_Pos);
             }
             break;
-			// Indicates a tap on negative X axis
+            // Indicates a tap on negative X axis
         case KSensrvAccelerometerDirectionXminus:
             {
             iReading.setTapDirection(QTapReading::X_Neg);
             }
             break;
-			// Indicates a tap on positive Y axis
+            // Indicates a tap on positive Y axis
         case KSensrvAccelerometerDirectionYplus:
             {
             iReading.setTapDirection(QTapReading::Y_Pos);
             }
             break;
-			// Indicates a tap on negative Y axis
+            // Indicates a tap on negative Y axis
         case KSensrvAccelerometerDirectionYminus:
             {
             iReading.setTapDirection(QTapReading::Y_Neg);
             }
-            break;    
-			// Indicates a tap on positive Z axis
+            break;
+            // Indicates a tap on positive Z axis
         case KSensrvAccelerometerDirectionZplus:
             {
             iReading.setTapDirection(QTapReading::Z_Pos);
             }
             break;
-			// Indicates a tap on negative Z axis
+            // Indicates a tap on negative Z axis
         case KSensrvAccelerometerDirectionZminus:
             {
             iReading.setTapDirection(QTapReading::Z_Neg);
             }
-            break;    
+            break;
         default:
             {
-				// Indicates a tap on X axis
+                // Indicates a tap on X axis
             if(iData.iDirection==(KSensrvAccelerometerDirectionXplus|KSensrvAccelerometerDirectionXminus))
                 {
-                iReading.setTapDirection(QTapReading::X);
+                iReading.setTapDirection(QTapReading::X_Both);
                 }
-				// Indicates a tap on Y axis
+                // Indicates a tap on Y axis
             else if(iData.iDirection==(KSensrvAccelerometerDirectionYplus|KSensrvAccelerometerDirectionYminus))
                 {
-                iReading.setTapDirection(QTapReading::Y);
+                iReading.setTapDirection(QTapReading::Y_Both);
                 }
-				// Indicates a tap on Z axis
+                // Indicates a tap on Z axis
             else if(iData.iDirection==(KSensrvAccelerometerDirectionZplus|KSensrvAccelerometerDirectionZminus))
                 {
-                iReading.setTapDirection(QTapReading::Z);
+                iReading.setTapDirection(QTapReading::Z_Both);
                 }
-				 // Undefined value
+                // Undefined value
             else
                 {
                 iReading.setTapDirection(QTapReading::Undefined);
                 }
-            }            
+            }
         }
-	//Set the type of tap to be double tap
+    //Set the type of tap to be double tap
     iReading.setDoubleTap(true);
-    iReading.setTimestamp(iData.iTimeStamp.Int64());  
-	    // Release the lock
+    iReading.setTimestamp(iData.iTimeStamp.Int64());
+    // Release the lock
     iBackendData.iReadingLock.Signal();
+    // Notify that a reading is available
+    newReadingAvailable();
     }
+
 /**
  * Second phase constructor
  * Initialize the backend resources
