@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -53,6 +53,28 @@
 
 QTM_BEGIN_NAMESPACE
 
+#if QT_VERSION >= 0x040800
+#define Q_GLOBAL_STATIC_QAPP_DESTRUCTION(TYPE, NAME)                    \
+    static QGlobalStatic<TYPE> this_##NAME                              \
+                 = { Q_BASIC_ATOMIC_INITIALIZER(0), false };            \
+    static void NAME##_cleanup()                                        \
+    {                                                                   \
+        delete this_##NAME.pointer;                                     \
+        this_##NAME.pointer = 0;                                        \
+        this_##NAME.destroyed = true;                                   \
+    }                                                                   \
+    static TYPE *NAME()                                                 \
+    {                                                                   \
+        if (!this_##NAME.pointer && !this_##NAME.destroyed) {           \
+            TYPE *x = new TYPE;                                         \
+            if (!this_##NAME.pointer.testAndSetOrdered(0, x))           \
+                delete x;                                               \
+            else                                                        \
+                qAddPostRoutine(NAME##_cleanup);                        \
+        }                                                               \
+        return this_##NAME.pointer;                                     \
+    }
+#else
 #define Q_GLOBAL_STATIC_QAPP_DESTRUCTION(TYPE, NAME)                    \
     Q_GLOBAL_STATIC_INIT(TYPE, NAME);                                   \
     static void NAME##_cleanup()                                        \
@@ -72,6 +94,7 @@ QTM_BEGIN_NAMESPACE
         }                                                               \
         return this_##NAME.pointer;                                     \
     }
+#endif
 
 Q_GLOBAL_STATIC_QAPP_DESTRUCTION(QNetworkConfigurationManagerPrivate, connManager);
 
@@ -83,6 +106,7 @@ Q_GLOBAL_STATIC_QAPP_DESTRUCTION(QNetworkConfigurationManagerPrivate, connManage
 
     \inmodule QtNetwork
     \ingroup bearer
+    \since 1.0
 
     QNetworkConfigurationManager provides access to the network configurations known to the system and
     enables applications to detect the system capabilities (with regards to network sessions) at runtime.
@@ -110,7 +134,7 @@ Q_GLOBAL_STATIC_QAPP_DESTRUCTION(QNetworkConfigurationManagerPrivate, connManage
     \sa QNetworkConfiguration
 */
 
-/*! 
+/*!
     \fn void QNetworkConfigurationManager::configurationAdded(const QNetworkConfiguration& config)
 
     This signal is emitted whenever a new network configuration is added to the system. The new
@@ -201,7 +225,7 @@ QNetworkConfigurationManager::QNetworkConfigurationManager( QObject* parent )
             this, SIGNAL(configurationRemoved(QNetworkConfiguration)));
     connect(priv, SIGNAL(configurationUpdateComplete()),
             this, SIGNAL(updateCompleted()));
-    connect(priv, SIGNAL(onlineStateChanged(bool)), 
+    connect(priv, SIGNAL(onlineStateChanged(bool)),
             this, SIGNAL(onlineStateChanged(bool)));
     connect(priv, SIGNAL(configurationChanged(QNetworkConfiguration)),
             this, SIGNAL(configurationChanged(QNetworkConfiguration)));
@@ -261,7 +285,7 @@ QList<QNetworkConfiguration> QNetworkConfigurationManager::allConfigurations(QNe
 
     //find all InternetAccessPoints
     foreach (const QString &ii, conPriv->accessPointConfigurations.keys()) {
-        QExplicitlySharedDataPointer<QNetworkConfigurationPrivate> p = 
+        QExplicitlySharedDataPointer<QNetworkConfigurationPrivate> p =
             conPriv->accessPointConfigurations.value(ii);
         if ( (p->state & filter) == filter ) {
             QNetworkConfiguration pt;
@@ -272,7 +296,7 @@ QList<QNetworkConfiguration> QNetworkConfigurationManager::allConfigurations(QNe
 
     //find all service networks
     foreach (const QString &ii, conPriv->snapConfigurations.keys()) {
-        QExplicitlySharedDataPointer<QNetworkConfigurationPrivate> p = 
+        QExplicitlySharedDataPointer<QNetworkConfigurationPrivate> p =
             conPriv->snapConfigurations.value(ii);
         if ( (p->state & filter) == filter ) {
             QNetworkConfiguration pt;
