@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -59,22 +59,23 @@ QTM_BEGIN_NAMESPACE
 
 /*!
   \class QContactMemoryEngine
-  
+
   \inmodule QtContacts
-  
+
   \brief The QContactMemoryEngine class provides an in-memory implementation
   of a contacts backend.
+   \since 1.0
 
   \internal
- 
+
   It may be used as a reference implementation, or when persistent storage is not required.
- 
+
   During construction, it will load the in-memory data associated with the memory store
   identified by the "id" parameter from the given parameters if it exists, or a new,
   anonymous store if it does not.
- 
+
   Data stored in this engine is only available in the current process.
- 
+
   This engine supports sharing, so an internal reference count is increased
   whenever a manager uses this backend, and is decreased when the manager
   no longer requires this engine.
@@ -176,7 +177,7 @@ QContactLocalId QContactMemoryEngine::selfContactId(QContactManager::Error* erro
 /*! \reimp */
 QContact QContactMemoryEngine::contact(const QContactLocalId& contactId, const QContactFetchHint& fetchHint, QContactManager::Error* error) const
 {
-    Q_UNUSED(fetchHint); // no optimisations are possible in the memory backend; ignore the fetch hint.
+    Q_UNUSED(fetchHint); // no optimizations are possible in the memory backend; ignore the fetch hint.
     int index = d->m_contactIds.indexOf(contactId);
     if (index != -1) {
         // found the contact successfully.
@@ -209,7 +210,7 @@ QList<QContactLocalId> QContactMemoryEngine::contactIds(const QContactFilter& fi
 /*! \reimp */
 QList<QContact> QContactMemoryEngine::contacts(const QContactFilter& filter, const QList<QContactSortOrder>& sortOrders, const QContactFetchHint& fetchHint, QContactManager::Error* error) const
 {
-    Q_UNUSED(fetchHint); // no optimisations are possible in the memory backend; ignore the fetch hint.
+    Q_UNUSED(fetchHint); // no optimizations are possible in the memory backend; ignore the fetch hint.
     Q_UNUSED(error);
 
     QList<QContact> sorted;
@@ -230,7 +231,7 @@ QList<QContact> QContactMemoryEngine::contacts(const QContactFilter& filter, con
 }
 
 /*! Saves the given contact \a theContact, storing any error to \a error and
-    filling the \a changeSet with ids of changed contacts as required 
+    filling the \a changeSet with ids of changed contacts as required
     Returns true if the operation was successful otherwise false.
 */
 bool QContactMemoryEngine::saveContact(QContact* theContact, QContactChangeSet& changeSet, QContactManager::Error* error)
@@ -381,7 +382,7 @@ bool QContactMemoryEngine::removeContacts(const QList<QContactLocalId>& contactI
         *error = QContactManager::BadArgumentError;
         return false;
     }
-    
+
     QContactChangeSet changeSet;
     QContactLocalId current;
     QContactManager::Error operationError = QContactManager::NoError;
@@ -435,7 +436,7 @@ QList<QContactRelationship> QContactMemoryEngine::relationships(const QString& r
 }
 
 /*! Saves the given relationship \a relationship, storing any error to \a error and
-    filling the \a changeSet with ids of changed contacts and relationships as required 
+    filling the \a changeSet with ids of changed contacts and relationships as required
     Returns true if the operation was successful otherwise false.
 */
 bool QContactMemoryEngine::saveRelationship(QContactRelationship* relationship, QContactChangeSet& changeSet, QContactManager::Error* error)
@@ -527,7 +528,7 @@ bool QContactMemoryEngine::saveRelationships(QList<QContactRelationship>* relati
 }
 
 /*! Removes the given relationship \a relationship, storing any error to \a error and
-    filling the \a changeSet with ids of changed contacts and relationships as required 
+    filling the \a changeSet with ids of changed contacts and relationships as required
     Returns true if the operation was successful otherwise false.
 */
 bool QContactMemoryEngine::removeRelationship(const QContactRelationship& relationship, QContactChangeSet& changeSet, QContactManager::Error* error)
@@ -594,7 +595,7 @@ QMap<QString, QContactDetailDefinition> QContactMemoryEngine::detailDefinitions(
 }
 
 /*! Saves the given detail definition \a def, storing any error to \a error and
-    filling the \a changeSet with ids of changed contacts as required 
+    filling the \a changeSet with ids of changed contacts as required
     Returns true if the operation was successful otherwise false.
 */
 bool QContactMemoryEngine::saveDetailDefinition(const QContactDetailDefinition& def, const QString& contactType, QContactChangeSet& changeSet, QContactManager::Error* error)
