@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,58 +25,65 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #include <QSet>
 #include <QDebug>
+#include <QDataStream>
 
 #include "qcontact.h"
 #include "qcontact_p.h"
 #include "qcontactdetail_p.h"
 #include "qcontactmanager_p.h"
+#include "qcontactactionmanager_p.h"
+#include "qcontactaction.h"
 
 QTM_BEGIN_NAMESPACE
 
 /*!
   \class QContact
- 
+
   \brief The QContact class represents an addressbook contact.
 
+  \inmodule QtContacts
+  \since 1.0
+
   \ingroup contacts-main
 
   Individual contacts, groups, and other types of contacts are represented with
   a QContact object.  In addition to the type, a QContact consists of information
-  that belongs to the contact and some information about the relationships that the
-  contact has.
+  that belongs to the contact, some information about the relationships that the
+  contact has, and the preferred ways to interact with the contact.
 
   A QContact object has a collection of details (like a name, phone numbers and
   email addresses).  Each detail (which can have multiple fields) is stored
   in an appropriate subclass of QContactDetail, and the QContact allows
   retrieving these details in various ways.
 
+  Depending on the details of the QContact, certain actions are available for a
+  contact.  An instance of a QContact can return a list of actions that can be
+  performed on it, and a list of details supported by a specific action can be
+  retrieved (for example - a list of phone numbers supported by a specific "Call" action).
+  It is also possible to store one detail for each type of action that is the "preferred"
+  detail to use.
+
   A QContact may have zero or more relationships with other contacts.  For example,
   a group contact would have a \c "HasMember" relationship with the QContacts that
   are its members.  Spouses, managers and assistants can also be represented this
   way.
- 
+
   A QContact instance represents the in-memory version of an addressbook contact,
   and has no tie to a specific QContactManager.  It is possible for the contents
   of a QContact to change independently of the contents that are stored persistently
@@ -94,7 +101,7 @@ QTM_BEGIN_NAMESPACE
   you will need to ask a specific QContactManager for the new display label for the
   contact, since system settings (like the order of first or last names) can vary
   between managers.
- 
+
   \sa QContactManager, QContactDetail
  */
 
@@ -212,6 +219,24 @@ QContactId QContact::id() const
     return d->m_id;
 }
 
+/*!
+ * Sets the id of this contact to \a id.
+ *
+ * Note that this only affects this object, not any corresponding structures stored
+ * by a QContactManager.
+ *
+ * If you change the id of a contact and save the contact
+ * in a manager, the previously existing contact will still
+ * exist.  You can do this to create copies (possibly modified)
+ * of an existing contact, or to save a contact in a different manager.
+ *
+ * \sa QContactManager::saveContact()
+ */
+void QContact::setId(const QContactId& id)
+{
+    d->m_id = id;
+}
+
 /*!
     Returns the QContactLocalId that identifies this contact within its manager
 
@@ -292,21 +317,52 @@ QString QContact::displayLabel() const
 }
 
 /*!
- * Sets the id of this contact to \a id.
+ * Returns the list of tags for this contact.  Tags are used for non-exclusive categorization.
  *
- * Note that this only affects this object, not any corresponding structures stored
- * by a QContactManager.
- *
- * If you change the id of a contact and save the contact
- * in a manager, the previously existing contact will still
- * exist.  You can do this to create copies (possibly modified)
- * of an existing contact, or to save a contact in a different manager.
- *
- * \sa QContactManager::saveContact()
+ * \sa QContactTag
  */
-void QContact::setId(const QContactId& id)
+QStringList QContact::tags() const
 {
-    d->m_id = id;
+    QStringList tags;
+    foreach (const QContactTag& tagDetail, details<QContactTag>()) {
+        tags.append(tagDetail.tag());
+    }
+    return tags;
+}
+
+/*!
+ * Removes all tags associated with the contact.
+ *
+ * \sa QContactTag
+ */
+void QContact::clearTags()
+{
+    d->removeOnly(QContactTag::DefinitionName);
+}
+
+/*!
+ * Adds the \a tag to this contact.
+ *
+ * \sa QContactTag
+ */
+void QContact::addTag(const QString& tag)
+{
+    QContactTag tagDetail;
+    tagDetail.setTag(tag);
+    saveDetail(&tagDetail);
+}
+
+/*!
+ * Sets the list of tags associated with the contact to \a tags.
+ *
+ * \sa QContactTag
+ */
+void QContact::setTags(const QStringList& tags)
+{
+    d->removeOnly(QContactTag::DefinitionName);
+    foreach (const QString& tag, tags) {
+        addTag(tag);
+    }
 }
 
 /*!
@@ -581,6 +637,8 @@ bool QContact::saveDetail(QContactDetail* detail)
  * will be removed if it exists.  Only the key is used for comparison - that is, the
  * information in the detail may be different.
  *
+ * Any action preferences for the matching detail is also removed.
+ *
  * Be aware that if a contact is retrieved (or reloaded) from the backend, the
  * keys of any details it contains may have been changed by the backend, or other
  * threads may have modified the contact details in the backend.  Therefore,
@@ -618,6 +676,15 @@ bool QContact::removeDetail(QContactDetail* detail)
     if (!d->m_details.contains(*detail))
         return false;
 
+    // remove any preferences we may have stored for the detail.
+    QStringList keys = d->m_preferences.keys();
+    for (int i = 0; i < keys.size(); i++) {
+        QString prefKey = keys.at(i);
+        if (d->m_preferences.value(prefKey) == detail->d->m_id) {
+            d->m_preferences.remove(prefKey);
+        }
+    }
+
     // then remove the detail.
     d->m_details.removeAt(removeIndex);
     return true;
@@ -643,6 +710,7 @@ uint qHash(const QContact &key)
     return hash;
 }
 
+#ifndef QT_NO_DEBUG_STREAM
 QDebug operator<<(QDebug dbg, const QContact& contact)
 {
     dbg.nospace() << "QContact(" << contact.id() << ")";
@@ -651,6 +719,39 @@ QDebug operator<<(QDebug dbg, const QContact& contact)
     }
     return dbg.maybeSpace();
 }
+#endif
+
+#ifndef QT_NO_DATASTREAM
+/*!
+ * Writes \a contact to the stream \a out.
+ */
+QDataStream& operator<<(QDataStream& out, const QContact& contact)
+{
+    quint8 formatVersion = 1; // Version of QDataStream format for QContact
+    return out << formatVersion << contact.id() << contact.details() << contact.d->m_preferences;
+}
+
+/*!
+ * Reads a contact from stream \a in into \a contact.
+ */
+QDataStream& operator>>(QDataStream& in, QContact& contact)
+{
+    contact = QContact();
+    quint8 formatVersion;
+    in >> formatVersion;
+    if (formatVersion == 1) {
+        QContactId id;
+        QList<QContactDetail> details;
+        QMap<QString, int> preferences;
+        in >> id >> contact.d->m_details >> contact.d->m_preferences;
+        contact.setId(id);
+    } else {
+        in.setStatus(QDataStream::ReadCorruptData);
+    }
+    return in;
+}
+
+#endif
 
 /*!
     Returns a list of relationships of the given \a relationshipType in which this contact is a participant.
@@ -733,4 +834,148 @@ QList<QContactId> QContact::relatedContacts(const QString& relationshipType, QCo
     return retn;
 }
 
+/*!
+ * Return a list of descriptors for the actions available to be performed on this contact.
+ *
+ * The actions considered can be restricted by the optional parameters
+ * The actions can be restricted to those provided by a specific service with the \a serviceName parameter.
+ * If \a serviceName is empty, actions provided by any service will be returned if the
+ * contact meets the required criteria (contains details of the correct type, etc).
+ *
+ * Each action that matches the above criteria will be tested to see if this contact is supported
+ * by the action, and a list of the action descriptors that are supported will be returned.
+ */
+QList<QContactActionDescriptor> QContact::availableActions(const QString& serviceName) const
+{
+    QList<QContactActionDescriptor> ret;
+    QList<QContactActionDescriptor> allds = QContactActionManager::instance()->availableActions(*this);
+    foreach (const QContactActionDescriptor& d, allds) {
+        if (serviceName.isEmpty() || d.serviceName() == serviceName) {
+            ret.append(d);
+        }
+    }
+
+    return ret;
+}
+
+/*!
+ * Set a particular detail (\a preferredDetail) as the preferred detail for any actions with the given \a actionName.
+ *
+ * The \a preferredDetail object must exist in this object, and the \a actionName cannot be empty.
+ *
+ * Returns true if the preference could be recorded, and false otherwise.
+ *
+ * \sa preferredDetail()
+ */
+bool QContact::setPreferredDetail(const QString& actionName, const QContactDetail& preferredDetail)
+{
+    // if the given action name is empty, bad argument.
+    if (actionName.isEmpty())
+        return false;
+
+    // check to see whether the the given preferredDetail is saved in this contact
+    if (!d->m_details.contains(preferredDetail))
+        return false;
+
+    // otherwise, save the preference.
+    d->m_preferences.insert(actionName, preferredDetail.d->m_id);
+    return true;
+}
+
+/*!
+ * Returns true if the given \a detail is a preferred detail for the given \a actionName,
+ * or for any action if the \a actionName is empty.
+ *
+ * \sa preferredDetail()
+ */
+bool QContact::isPreferredDetail(const QString& actionName, const QContactDetail& detail) const
+{
+    if (!d->m_details.contains(detail))
+        return false;
+
+    if (actionName.isEmpty())
+         return d->m_preferences.values().contains(detail.d->m_id);
+
+    QMap<QString, int>::const_iterator it = d->m_preferences.find(actionName);
+    if (it != d->m_preferences.end() && it.value() == detail.d->m_id)
+        return true;
+
+    return false;
+}
+
+/*!
+ * Returns the preferred detail for a given \a actionName.
+ *
+ * If the \a actionName is empty, or there is no preference recorded for
+ * the supplied \a actionName, returns an empty QContactDetail.
+ *
+ * \sa preferredDetails()
+ */
+QContactDetail QContact::preferredDetail(const QString& actionName) const
+{
+    // if the given action name is empty, bad argument.
+    if (actionName.isEmpty())
+        return QContactDetail();
+
+    if (!d->m_preferences.contains(actionName))
+        return QContactDetail();
+
+    QContactDetail retn;
+    int detId = d->m_preferences.value(actionName);
+    for (int i = 0; i < d->m_details.size(); i++) {
+        QContactDetail det = d->m_details.at(i);
+        if (det.d->m_id == detId) {
+            // found it.
+            retn = det;
+            break;
+        }
+    }
+
+    return retn;
+}
+
+/*!
+ * Returns the recorded detail preferences for action names.
+ *
+ * Each entry in the map has the action name as the key, and the corresponding
+ * preferred detail as the value.
+ */
+QMap<QString, QContactDetail> QContact::preferredDetails() const
+{
+    QMap<QString, QContactDetail> ret;
+    QMap<QString, int>::const_iterator it = d->m_preferences.constBegin();
+    while (it != d->m_preferences.constEnd()) {
+        ret.insert(it.key(), d->m_details.at(it.value()));
+        ++it;
+    }
+
+    return ret;
+}
+
+
+/* Helper functions for QContactData */
+void QContactData::removeOnly(const QString& definitionName)
+{
+    QList<QContactDetail>::iterator dit = m_details.begin();
+    while (dit != m_details.end()) {
+        // XXX this doesn't check type or display label
+        if (dit->definitionName() == definitionName)
+            dit = m_details.erase(dit);
+        else
+            ++dit;
+    }
+}
+
+void QContactData::removeOnly(const QSet<QString> &definitionNames)
+{
+    QList<QContactDetail>::iterator dit = m_details.begin();
+    while (dit != m_details.end()) {
+        // XXX this doesn't check type or display label
+        if (definitionNames.contains(dit->definitionName()))
+            dit = m_details.erase(dit);
+        else
+            ++dit;
+    }
+}
+
 QTM_END_NAMESPACE
