@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -48,6 +48,10 @@
 #include <QMutex>
 #include <QMutexLocker>
 
+#ifndef QT_NO_DEBUG_STREAM
+#include <QDebug>
+#endif
+
 QTM_BEGIN_NAMESPACE
 /*!
   \class QContactAbstractRequest
@@ -56,6 +60,7 @@ QTM_BEGIN_NAMESPACE
   asynchronous requests to be made of a manager if it supports them.
 
   \inmodule QtContacts
+  \since 1.0
 
   \ingroup contacts-main
 
@@ -334,6 +339,23 @@ bool QContactAbstractRequest::waitForFinished(int msecs)
     return false; // unable to wait for operation; not in progress or no engine.
 }
 
+#ifndef QT_NO_DEBUG_STREAM
+/*!
+  Outputs \a request to the debug stream \a dbg
+ */
+QDebug operator<<(QDebug dbg, const QContactAbstractRequest& request)
+{
+    dbg.nospace() << "QContactAbstractRequest(";
+    if (request.d_ptr)
+        request.d_ptr->debugStreamOut(dbg);
+    else
+        dbg.nospace() << "(null)";
+    dbg.nospace() << ")";
+
+    return dbg.maybeSpace();
+}
+#endif
+
 #include "moc_qcontactabstractrequest.cpp"
 
 QTM_END_NAMESPACE
