@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -78,13 +78,14 @@ Q_DESTRUCTOR_FUNCTION(qClearAllocatedStringHash)
 
 /*!
   \class QContactDetail
- 
+
   \brief The QContactDetail class represents a single, complete detail about a contact.
   \inmodule QtContacts
   \ingroup contacts-main
- 
+  \since 1.0
+
   All of the information for a contact is stored in one or more QContactDetail objects.
- 
+
   A detail is a group of logically related bits of data - for example, a street address is a single
   detail that has multiple fields (number, region, country etc).  Every QContactDetail has the name of an
   associated QContactDetailDefinition that describes the fields, their data type, and any
@@ -120,7 +121,7 @@ Q_DESTRUCTOR_FUNCTION(qClearAllocatedStringHash)
   standardized access to values.  For example, \l QContactPhoneNumber provides
   a convenient API for manipulating a QContactDetail as a phone number, according
   to the schema.
- 
+
   In general, QContactDetail and the built in subclasses (like \l QContactPhoneNumber) provide
   constants for the names of fields (like \l QContactPhoneNumber::FieldNumber), and for predefined
   common values like \l QContactDetail::ContextHome.  Typically the constants for field names start
@@ -132,36 +133,36 @@ Q_DESTRUCTOR_FUNCTION(qClearAllocatedStringHash)
   operation, and declare your own field constants with \l Q_DECLARE_LATIN1_CONSTANT.
   See the predefined detail subclasses (like \l QContactPhoneNumber,
   \l QContactAddress) for more information.
- 
+
   QContactDetail objects act like type checked values.  In general, you can assign them
   to and fro and have reasonable behaviour, like the following example.
- 
+
   \code
- 
+
   QContactPhoneNumber number;
   number.setNumber("555-1212");
   // number.value(QContactPhoneNumber::FieldNumber) == "555-1212";
   // number.definitionName() == QContactPhoneNumber::DefinitionName
- 
+
   QContactDetail detail = number;
   // detail.value(QContactPhoneNumber::FieldNumber) == "555-1212";
   // detail.definitionName() == QContactPhoneNumber::DefinitionName
- 
+
   QContactPhoneNumber otherNumber = detail;
   // otherNumber.number() == "555-1212";
   // otherNumber.definitionName() == QContactPhoneNumber::DefinitionName
- 
+
   QContactAddress address = detail;
   // address is now a default constructed QContactAddress
   // address.value(QContactPhoneNumber::FieldNumber) is empty
   // address.definitionName() == QContactAddress::DefinitionName
- 
+
   QContactAddress otherAddress = number;
   // otherAddress is now a default constructed QContactAddress
   // otherAddress.value(QContactPhoneNumber::FieldNumber) is empty
   // otherAddress.definitionName() == QContactAddress::DefinitionName
   \endcode
- 
+
   \sa QContact, QContactDetailDefinition, QContactDetailFilter, QContactDetailRangeFilter, Q_DECLARE_CUSTOM_CONTACT_DETAIL
  */
 
@@ -435,7 +436,11 @@ QDataStream& operator>>(QDataStream& in, QContactDetail& detail)
 #endif
 
 /*!
-    Returns true if no values are contained in this detail.  Note that context is stored as a value; hence, if a context is set, this function will return false.
+    Returns true if no values are contained in this detail.  Note that context
+    is stored as a value; hence, if a context is set, this function will return false.
+
+    An empty value (for example, the string "") is still a value contained in this
+    detail, so this function will return false.
  */
 bool QContactDetail::isEmpty() const
 {
