@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -61,8 +55,11 @@ QTM_BEGIN_NAMESPACE
 /*!
   \class QContactManager
   \brief The QContactManager class provides an interface which allows clients with access to contact information stored in a particular backend.
+  \inmodule QtContacts
+   \since 1.0
+
   \ingroup contacts-main
- 
+
   This class provides an abstraction of a datastore or aggregation of datastores which contains contact information.
   It provides methods to retrieve and manipulate contact information, contact relationship information, and
   supported schema definitions.  It also provides metadata and error information reporting.
@@ -133,6 +130,9 @@ QStringList QContactManager::availableManagers()
 {
     QStringList ret;
     ret << QLatin1String("memory") << QLatin1String("invalid");
+#ifdef QT_SIMULATOR
+    ret << QLatin1String("simulator");
+#endif
     QContactManagerData::loadFactories();
     ret.append(QContactManagerData::m_engines.keys());
 
@@ -210,7 +210,7 @@ bool QContactManager::parseUri(const QString& uri, QString* pManagerId, QMap<QSt
    \a implementationVersion.  This function is generally useful only if you intend to construct a
    manager with the \l fromUri() function, or wish to set the manager URI field in a QContactId
    manually (for synchronization or other purposes).  Most clients will not need to use this function. */
-QString QContactManager::buildUri(const QString& managerName, const QMap<QString, QString>& params, int implementationVersion) 
+QString QContactManager::buildUri(const QString& managerName, const QMap<QString, QString>& params, int implementationVersion)
 {
     QString ret(QLatin1String("qtcontacts:%1:%2"));
     // we have to escape each param
@@ -262,7 +262,8 @@ QContactManager* QContactManager::fromUri(const QString& managerUri, QObject* pa
   The default implementation for the platform will be created.
  */
 QContactManager::QContactManager(QObject* parent)
-    : QObject(parent)
+    : QObject(parent),
+    d(new QContactManagerData)
 {
     createEngine(QString(), QMap<QString, QString>());
 }
@@ -279,19 +280,14 @@ QContactManager::QContactManager(const QString& managerName, const QMap<QString,
     : QObject(parent),
     d(new QContactManagerData)
 {
-    createEngine(managerName, parameters); 
-} 
+    createEngine(managerName, parameters);
+}
 
-void QContactManager::createEngine(const QString& managerName, const QMap<QString, QString>& parameters) 
-{ 
+void QContactManager::createEngine(const QString& managerName, const QMap<QString, QString>& parameters)
+{
     d->createEngine(managerName, parameters);
-    connect(d->m_engine, SIGNAL(dataChanged()), this, SIGNAL(dataChanged()));
-    connect(d->m_engine, SIGNAL(contactsAdded(QList<QContactLocalId>)), this, SIGNAL(contactsAdded(QList<QContactLocalId>)));
-    connect(d->m_engine, SIGNAL(contactsChanged(QList<QContactLocalId>)), this, SIGNAL(contactsChanged(QList<QContactLocalId>)));
-    connect(d->m_engine, SIGNAL(contactsRemoved(QList<QContactLocalId>)), this, SIGNAL(contactsRemoved(QList<QContactLocalId>)));
-    connect(d->m_engine, SIGNAL(relationshipsAdded(QList<QContactLocalId>)), this, SIGNAL(relationshipsAdded(QList<QContactLocalId>)));
-    connect(d->m_engine, SIGNAL(relationshipsRemoved(QList<QContactLocalId>)), this, SIGNAL(relationshipsRemoved(QList<QContactLocalId>)));
-    connect(d->m_engine, SIGNAL(selfContactIdChanged(QContactLocalId,QContactLocalId)), this, SIGNAL(selfContactIdChanged(QContactLocalId,QContactLocalId)));
+
+    QContactManagerData::m_aliveEngines.insert(this);
 }
 
 /*!
@@ -303,21 +299,88 @@ void QContactManager::createEngine(const QString& managerName, const QMap<QStrin
   If an empty \a managerName is specified, the default implementation for the platform will be instantiated.
   If the specified implementation version is not available, the manager with the name \a managerName with the default implementation version is instantiated.
  */
-QContactManager::QContactManager(const QString& managerName, int implementationVersion, const QMap<QString, QString>& parameters, QObject* parent) 
-    : QObject(parent), 
-    d(new QContactManagerData) 
-{ 
-    QMap<QString, QString> params = parameters; 
+QContactManager::QContactManager(const QString& managerName, int implementationVersion, const QMap<QString, QString>& parameters, QObject* parent)
+    : QObject(parent),
+    d(new QContactManagerData)
+{
+    QMap<QString, QString> params = parameters;
     params[QString(QLatin1String(QTCONTACTS_IMPLEMENTATION_VERSION_NAME))] = QString::number(implementationVersion);
-    createEngine(managerName, params); 
-} 
- 
+    createEngine(managerName, params);
+}
+
 /*! Frees the memory used by the QContactManager */
 QContactManager::~QContactManager()
 {
+    QContactManagerData::m_aliveEngines.remove(this);
     delete d;
 }
 
+
+/*!
+   \variable QContactManager::ParameterSignalSources
+   The string constant for the parameter key which holds the value for signal sources.
+   If a manager supports suppressing change signals depending on the value given for
+   this construction parameter, clients can request that signals be suppressed if the
+   changes which might cause a signal to be emitted do not match particular criteria.
+
+   If the parameter (or value given for the parameter) is not supported by the manager,
+   the manager may still be constructed, however the parameter will not be reported
+   to the client if the client calls managerParameters() subsequent to manager construction.
+
+   The default (assumed) value for this parameter, if this parameter is not given,
+   is that the client wants to be notified of all changes to the data, regardless of
+   the source of the change.
+ */
+Q_DEFINE_LATIN1_CONSTANT(QContactManager::ParameterSignalSources, "SignalSources");
+
+/*!
+   \variable QContactManager::ParameterSignalDefinitions
+   The string constant for the parameter key which holds the names of detail definitions.
+   If a manager supports suppressing change signals depending on the value given for
+   this construction parameter, clients can request that signals be suppressed if the
+   changes which might otherwise cause a signal to be emitted, involve details whose
+   definition name is not contained in the given list.
+
+   That is, if a detail in a contact is changed, but that detail's definition name is
+   not listed in the value for this parameter, the manager will not emit a change signal
+   for that change.
+
+   If this parameter is not specified at construction time, changes to any detail of a contact
+   will cause a change signal to be emitted.
+
+   The value of this parameter should be a comma (,) separated list of definition names.  Any
+   commas which might be part of a definition name must be escaped with a single backslash
+   (\) character prior to concatenation.  Any backslash character which might be part of a
+   definition name must also be escaped with a backslash.
+
+   If the parameter (or value given for the parameter) is not supported by the manager,
+   the manager may still be constructed, however the parameter will not be reported
+   to the client if the client calls managerParameters() subsequent to manager construction.
+ */
+Q_DEFINE_LATIN1_CONSTANT(QContactManager::ParameterSignalDefinitions, "SignalDefinitions");
+
+/*!
+   \variable QContactManager::ParameterValueOnlyOtherManagers
+   This value tells the manager to only emit signals for changes which
+   are made in other manager instances.  That is, the client wishes to receive
+   change signals when another client (or background service) changes
+   the data as it is stored in the backend, but does not wish to be
+   notified of changes (or side effects) which it has caused itself.
+ */
+Q_DEFINE_LATIN1_CONSTANT(QContactManager::ParameterValueOnlyOtherManagers, "OnlyOtherManagers");
+
+/*!
+   \variable QContactManager::ParameterValueOnlyOtherProcesses
+   This value tells the manager to only emit signals for changes which
+   are made in other processes.  That is, the client wishes to receive
+   change signals when a client (or background service) in another process changes
+   the data as it is stored in the backend, but does not wish to be
+   notified of changes (or side effects) which were caused in the current client's
+   process, even if those changes were made in a different manager instance to this
+   one.
+ */
+Q_DEFINE_LATIN1_CONSTANT(QContactManager::ParameterValueOnlyOtherProcesses, "OnlyOtherProcesses");
+
 /*!
   \enum QContactManager::Error
 
@@ -337,21 +400,43 @@ QContactManager::~QContactManager()
   \value LimitReachedError The most recent operation failed because the limit for that type of object has been reached
   \value NotSupportedError The most recent operation failed because the requested operation is not supported in the specified store
   \value BadArgumentError The most recent operation failed because one or more of the parameters to the operation were invalid
+  \value TimeoutError The most recent operation failed because it took longer than expected.  It may be possible to try again.
   \value UnspecifiedError The most recent operation failed for an undocumented reason
  */
 
-/*! Return the error code of the most recent operation */
+/*!
+  Return the error code of the most recent operation.
+  For batch operations, if the error code is not equal to
+  \c QContactManager::NoError, detailed per-input errors
+  may be retrieved by calling \l errorMap().
+  \sa errorMap()
+ */
 QContactManager::Error QContactManager::error() const
 {
     return d->m_error;
 }
 
+/*!
+  Returns per-input error codes for the most recent operation.
+  This function only returns meaningful information if the most
+  recent operation was a batch operation.
+  Each key in the map is the index of the element in the input list
+  for which the error (whose error code is stored in the value for
+  that key in the map) occurred during the batch operation.
+  \sa error(), contacts(), saveContacts(), removeContacts(), saveRelationships(), removeRelationships()
+ */
+QMap<int, QContactManager::Error> QContactManager::errorMap() const
+{
+    return d->m_errorMap;
+}
+
 /*!
   Return the list of contact ids, sorted according to the given list of \a sortOrders
  */
 QList<QContactLocalId> QContactManager::contactIds(const QList<QContactSortOrder>& sortOrders) const
 {
     d->m_error = QContactManager::NoError;
+    d->m_errorMap.clear();
     return d->m_engine->contactIds(QContactFilter(), sortOrders, &d->m_error);
 }
 
@@ -362,6 +447,7 @@ QList<QContactLocalId> QContactManager::contactIds(const QList<QContactSortOrder
 QList<QContactLocalId> QContactManager::contactIds(const QContactFilter& filter, const QList<QContactSortOrder>& sortOrders) const
 {
     d->m_error = QContactManager::NoError;
+    d->m_errorMap.clear();
     return d->m_engine->contactIds(filter, sortOrders, &d->m_error);
 }
 
@@ -369,17 +455,17 @@ QList<QContactLocalId> QContactManager::contactIds(const QContactFilter& filter,
   Returns the list of contacts stored in the manager sorted according to the given list of \a sortOrders.
 
   The \a fetchHint parameter describes the optimization hints that a manager may take.
-  If the \a fetchHint is the default constructed hint, all existing details and relationships
-  in the matching contacts will be returned.  A client should not make changes to a contact which has
-  been retrieved using a fetch hint other than the default fetch hint.  Doing so will result in information
-  loss when saving the contact back to the manager (as the "new" restricted contact will
-  replace the previously saved contact in the backend).
+  If the \a fetchHint is the default constructed hint, all existing details, relationships and
+  action preferences in the matching contact will be returned.  If a client makes changes to an
+  contact which has been retrieved with a fetch hint, they should save it back using a partial save,
+  masked by the same set of detail names in order to avoid information loss.
 
   \sa QContactFetchHint
  */
 QList<QContact> QContactManager::contacts(const QList<QContactSortOrder>& sortOrders, const QContactFetchHint& fetchHint) const
 {
     d->m_error = QContactManager::NoError;
+    d->m_errorMap.clear();
     return d->m_engine->contacts(QContactFilter(), sortOrders, fetchHint, &d->m_error);
 }
 
@@ -390,17 +476,17 @@ QList<QContact> QContactManager::contacts(const QList<QContactSortOrder>& sortOr
   contacts and testing them against the supplied filter - see the \l isFilterSupported() function.
 
   The \a fetchHint parameter describes the optimization hints that a manager may take.
-  If the \a fetchHint is the default constructed hint, all existing details and relationships
-  in the matching contacts will be returned.  A client should not make changes to a contact which has
-  been retrieved using a fetch hint other than the default fetch hint.  Doing so will result in information
-  loss when saving the contact back to the manager (as the "new" restricted contact will
-  replace the previously saved contact in the backend).
+  If the \a fetchHint is the default constructed hint, all existing details, relationships and
+  action preferences in the matching contact will be returned.  If a client makes changes to an
+  contact which has been retrieved with a fetch hint, they should save it back using a partial save,
+  masked by the same set of detail names in order to avoid information loss.
 
   \sa QContactFetchHint
  */
 QList<QContact> QContactManager::contacts(const QContactFilter& filter, const QList<QContactSortOrder>& sortOrders, const QContactFetchHint& fetchHint) const
 {
     d->m_error = QContactManager::NoError;
+    d->m_errorMap.clear();
     return d->m_engine->contacts(filter, sortOrders, fetchHint, &d->m_error);
 }
 
@@ -411,20 +497,52 @@ QList<QContact> QContactManager::contacts(const QContactFilter& filter, const QL
   and the error returned by \l error() will be \c QContactManager::DoesNotExistError.
 
   The \a fetchHint parameter describes the optimization hints that a manager may take.
-  If the \a fetchHint is the default constructed hint, all existing details and relationships
-  in the matching contact will be returned.  A client should not make changes to a contact which has
-  been retrieved using a fetch hint other than the default fetch hint.  Doing so will result in information
-  loss when saving the contact back to the manager (as the "new" restricted contact will
-  replace the previously saved contact in the backend).
+  If the \a fetchHint is the default constructed hint, all existing details, relationships and
+  action preferences in the matching contact will be returned.  If a client makes changes to an
+  contact which has been retrieved with a fetch hint, they should save it back using a partial save,
+  masked by the same set of detail names in order to avoid information loss.
+
 
   \sa QContactFetchHint
  */
 QContact QContactManager::contact(const QContactLocalId& contactId, const QContactFetchHint& fetchHint) const
 {
     d->m_error = QContactManager::NoError;
+    d->m_errorMap.clear();
     return d->m_engine->contact(contactId, fetchHint, &d->m_error);
 }
 
+/*!
+  Returns a list of contacts given a list of local ids (\a localIds).
+
+  Returns the list of contacts with the ids given by \a localIds.  There is a one-to-one
+  correspondence between the returned contacts and the supplied \a localIds.
+
+  If there is an invalid id in \a localIds, then an empty QContact will take its place in the
+  returned list.  The deprecated \a errorMap parameter can be supplied to store per-input errors in.
+  In all cases, calling \l errorMap() will return the per-input errors for the latest batch function.
+
+  The \a fetchHint parameter describes the optimization hints that a manager may take.
+  If the \a fetchHint is the default constructed hint, all existing details, relationships and
+  action preferences in the matching contact will be returned.  If a client makes changes to an
+  contact which has been retrieved with a fetch hint, they should save it back using a partial save,
+  masked by the same set of detail names in order to avoid information loss.
+
+  \sa QContactFetchHint
+ */
+QList<QContact> QContactManager::contacts(const QList<QContactLocalId>& localIds, const QContactFetchHint &fetchHint, QMap<int, QContactManager::Error> *errorMap) const
+{
+    d->m_error = QContactManager::NoError;
+    d->m_errorMap.clear();
+
+    QList<QContact> retn = d->m_engine->contacts(localIds, fetchHint, &d->m_errorMap, &d->m_error);
+
+    if (errorMap)
+        *errorMap = d->m_errorMap;
+
+    return retn;
+}
+
 /*!
   Adds the given \a contact to the database if \a contact has a
   default-constructed id, or an id with the manager URI set to the URI of
@@ -463,6 +581,7 @@ QContact QContactManager::contact(const QContactLocalId& contactId, const QConta
  */
 bool QContactManager::saveContact(QContact* contact)
 {
+    d->m_errorMap.clear();
     if (contact) {
         d->m_error = QContactManager::NoError;
         return d->m_engine->saveContact(contact, &d->m_error);
@@ -481,6 +600,7 @@ bool QContactManager::saveContact(QContact* contact)
 bool QContactManager::removeContact(const QContactLocalId& contactId)
 {
     d->m_error = QContactManager::NoError;
+    d->m_errorMap.clear();
     return d->m_engine->removeContact(contactId, &d->m_error);
 }
 
@@ -488,29 +608,68 @@ bool QContactManager::removeContact(const QContactLocalId& contactId)
   Adds the list of contacts given by \a contacts list to the database.
   Returns true if the contacts were saved successfully, otherwise false.
 
-  The manager might populate \a errorMap (the map of indices of the \a contacts list to
-  the error which occurred when saving the contact at that index) for
-  every index for which the contact could not be saved, if it is able.
+  The deprecated \a errorMap parameter can be supplied to store per-input errors in.
+  In all cases, calling \l errorMap() will return the per-input errors for the latest batch function.
   The \l QContactManager::error() function will only return \c QContactManager::NoError
   if all contacts were saved successfully.
 
   For each newly saved contact that was successful, the id of the contact
-  in the \a contacts list will be updated with the new value.  If a failure occurs
-  when saving a new contact, the id will be cleared.
+  in the \a contacts list will be updated with the new value.
 
   \sa QContactManager::saveContact()
  */
 bool QContactManager::saveContacts(QList<QContact>* contacts, QMap<int, QContactManager::Error>* errorMap)
 {
-    if (errorMap)
-        errorMap->clear();
-    if (!contacts) {
+    bool retn = false;
+    d->m_errorMap.clear();
+
+    if (contacts) {
+        d->m_error = QContactManager::NoError;
+        retn = d->m_engine->saveContacts(contacts, &d->m_errorMap, &d->m_error);
+    } else {
         d->m_error =QContactManager::BadArgumentError;
-        return false;
     }
 
-    d->m_error = QContactManager::NoError;
-    return d->m_engine->saveContacts(contacts, errorMap, &d->m_error);
+    if (errorMap)
+        *errorMap = d->m_errorMap;
+
+    return retn;
+}
+
+/*!
+  Adds the list of contacts given by \a contacts list to the database.
+  Returns true if the contacts were saved successfully, otherwise false.
+
+  This function accepts a \a definitionMask, which specifies which details of
+  the contacts should be updated.  Details with definition names not included in
+  the definitionMask will not be updated or added.
+
+  The deprecated \a errorMap parameter can be supplied to store per-input errors in.
+  In all cases, calling \l errorMap() will return the per-input errors for the latest batch function.
+  The \l QContactManager::error() function will only return \c QContactManager::NoError
+  if all contacts were saved successfully.
+
+  For each newly saved contact that was successful, the id of the contact
+  in the \a contacts list will be updated with the new value.
+
+  \sa QContactManager::saveContact()
+ */
+bool QContactManager::saveContacts(QList<QContact>* contacts, const QStringList& definitionMask, QMap<int, QContactManager::Error>* errorMap)
+{
+    bool retn = false;
+    d->m_errorMap.clear();
+
+    if (contacts) {
+        d->m_error = QContactManager::NoError;
+        retn = d->m_engine->saveContacts(contacts, definitionMask, &d->m_errorMap, &d->m_error);
+    } else {
+        d->m_error =QContactManager::BadArgumentError;
+    }
+
+    if (errorMap)
+        *errorMap = d->m_errorMap;
+
+    return retn;
 }
 
 /*!
@@ -521,9 +680,8 @@ bool QContactManager::saveContacts(QList<QContact>* contacts, QMap<int, QContact
   Any contact that was removed successfully will have the relationships
   in which it was involved removed also.
 
-  The manager might populate \a errorMap (the map of indices of the \a contactIds list to
-  the error which occurred when saving the contact at that index) for every
-  index for which the contact could not be removed, if it is able.
+  The deprecated \a errorMap parameter can be supplied to store per-input errors in.
+  In all cases, calling \l errorMap() will return the per-input errors for the latest batch function.
   The \l QContactManager::error() function will
   only return \c QContactManager::NoError if all contacts were removed
   successfully.
@@ -540,15 +698,20 @@ bool QContactManager::saveContacts(QList<QContact>* contacts, QMap<int, QContact
  */
 bool QContactManager::removeContacts(const QList<QContactLocalId>& contactIds, QMap<int, QContactManager::Error>* errorMap)
 {
-    if (errorMap)
-        errorMap->clear();
-    if (contactIds.isEmpty()) {
+    bool retn = false;
+    d->m_errorMap.clear();
+
+    if (!contactIds.isEmpty()) {
+        d->m_error = QContactManager::NoError;
+        retn = d->m_engine->removeContacts(contactIds, &d->m_errorMap, &d->m_error);
+    } else {
         d->m_error = QContactManager::BadArgumentError;
-        return false;
     }
 
-    d->m_error = QContactManager::NoError;
-    return d->m_engine->removeContacts(contactIds, errorMap, &d->m_error);
+    if (errorMap)
+        *errorMap = d->m_errorMap;
+
+    return retn;
 }
 
 /*!
@@ -560,6 +723,7 @@ bool QContactManager::removeContacts(const QList<QContactLocalId>& contactIds, Q
 QContact QContactManager::compatibleContact(const QContact& original)
 {
     d->m_error = QContactManager::NoError;
+    d->m_errorMap.clear();
     return d->m_engine->compatibleContact(original, &d->m_error);
 }
 
@@ -575,6 +739,7 @@ QContact QContactManager::compatibleContact(const QContact& original)
 QString QContactManager::synthesizedContactDisplayLabel(const QContact& contact) const
 {
     d->m_error = QContactManager::NoError;
+    d->m_errorMap.clear();
     return d->m_engine->synthesizedDisplayLabel(contact, &d->m_error);
 }
 
@@ -598,6 +763,7 @@ QString QContactManager::synthesizedContactDisplayLabel(const QContact& contact)
  */
 void QContactManager::synthesizeContactDisplayLabel(QContact *contact) const
 {
+    d->m_errorMap.clear();
     if (contact) {
         d->m_error = QContactManager::NoError;
         QContactManagerEngine::setContactDisplayLabel(contact, d->m_engine->synthesizedDisplayLabel(*contact, &d->m_error));
@@ -620,6 +786,7 @@ void QContactManager::synthesizeContactDisplayLabel(QContact *contact) const
 bool QContactManager::setSelfContactId(const QContactLocalId& contactId)
 {
     d->m_error = QContactManager::NoError;
+    d->m_errorMap.clear();
     return d->m_engine->setSelfContactId(contactId, &d->m_error);
 }
 
@@ -633,10 +800,10 @@ bool QContactManager::setSelfContactId(const QContactLocalId& contactId)
 QContactLocalId QContactManager::selfContactId() const
 {
     d->m_error = QContactManager::NoError;
+    d->m_errorMap.clear();
     return d->m_engine->selfContactId(&d->m_error);
 }
 
-
 /*!
   Returns a list of relationships in which the contact identified by the given \a participantId participates in the given \a role.
   If \a participantId is the default-constructed id, \a role is ignored and all relationships are returned.
@@ -644,6 +811,7 @@ QContactLocalId QContactManager::selfContactId() const
 QList<QContactRelationship> QContactManager::relationships(const QContactId& participantId, QContactRelationship::Role role) const
 {
     d->m_error = QContactManager::NoError;
+    d->m_errorMap.clear();
     return d->m_engine->relationships(QString(), participantId, role, &d->m_error);
 }
 
@@ -655,6 +823,7 @@ QList<QContactRelationship> QContactManager::relationships(const QContactId& par
 QList<QContactRelationship> QContactManager::relationships(const QString& relationshipType, const QContactId& participantId, QContactRelationship::Role role) const
 {
     d->m_error = QContactManager::NoError;
+    d->m_errorMap.clear();
     return d->m_engine->relationships(relationshipType, participantId, role, &d->m_error);
 }
 
@@ -673,6 +842,7 @@ QList<QContactRelationship> QContactManager::relationships(const QString& relati
  */
 bool QContactManager::saveRelationship(QContactRelationship* relationship)
 {
+    d->m_errorMap.clear();
     if (relationship) {
         d->m_error = QContactManager::NoError;
         return d->m_engine->saveRelationship(relationship, &d->m_error);
@@ -684,21 +854,25 @@ bool QContactManager::saveRelationship(QContactRelationship* relationship)
 
 /*!
   Saves the given \a relationships in the database and returns true if the operation was successful.
-  For any relationship which was unable to be saved, an entry into the \a errorMap will be created,
-  with the key being the index into the input relationships list, and the value being the error which
-  occurred for that index.
+  The deprecated \a errorMap parameter can be supplied to store per-input errors in.
+  In all cases, calling \l errorMap() will return the per-input errors for the latest batch function.
  */
 bool QContactManager::saveRelationships(QList<QContactRelationship>* relationships, QMap<int, QContactManager::Error>* errorMap)
 {
-    if (errorMap)
-        errorMap->clear();
-    if (!relationships) {
+    bool retn = false;
+    d->m_errorMap.clear();
+
+    if (relationships) {
+        d->m_error = QContactManager::NoError;
+        retn = d->m_engine->saveRelationships(relationships, &d->m_errorMap, &d->m_error);
+    } else {
         d->m_error =QContactManager::BadArgumentError;
-        return false;
     }
 
-    d->m_error = QContactManager::NoError;
-    return d->m_engine->saveRelationships(relationships, errorMap, &d->m_error);
+    if (errorMap)
+        *errorMap = d->m_errorMap;
+
+    return retn;
 }
 
 /*!
@@ -710,21 +884,26 @@ bool QContactManager::saveRelationships(QList<QContactRelationship>* relationshi
 bool QContactManager::removeRelationship(const QContactRelationship& relationship)
 {
     d->m_error = QContactManager::NoError;
+    d->m_errorMap.clear();
     return d->m_engine->removeRelationship(relationship, &d->m_error);
 }
 
+
 /*!
   Removes the given \a relationships from the database and returns true if the operation was successful.
-  For any relationship which was unable to be removed, an entry into the \a errorMap will be created,
-  with the key being the index into the input relationships list, and the value being the error which
-  occurred for that index.
+  The deprecated \a errorMap parameter can be supplied to store per-input errors in.
+  In all cases, calling \l errorMap() will return the per-input errors for the latest batch function.
  */
 bool QContactManager::removeRelationships(const QList<QContactRelationship>& relationships, QMap<int, QContactManager::Error>* errorMap)
 {
-    if (errorMap)
-        errorMap->clear();
     d->m_error = QContactManager::NoError;
-    return d->m_engine->removeRelationships(relationships, errorMap, &d->m_error);
+    d->m_errorMap.clear();
+    bool retn = d->m_engine->removeRelationships(relationships, &d->m_errorMap, &d->m_error);
+
+    if (errorMap)
+        *errorMap = d->m_errorMap;
+
+    return retn;
 }
 
 /*!
@@ -733,6 +912,7 @@ bool QContactManager::removeRelationships(const QList<QContactRelationship>& rel
  */
 QMap<QString, QContactDetailDefinition> QContactManager::detailDefinitions(const QString& contactType) const
 {
+    d->m_errorMap.clear();
     if (!supportedContactTypes().contains(contactType)) {
         d->m_error =QContactManager::InvalidContactTypeError;
         return QMap<QString, QContactDetailDefinition>();
@@ -745,6 +925,7 @@ QMap<QString, QContactDetailDefinition> QContactManager::detailDefinitions(const
 /*! Returns the definition identified by the given \a definitionName that is valid for the contacts whose type is the given \a contactType in this store, or a default-constructed QContactDetailDefinition if no such definition exists */
 QContactDetailDefinition QContactManager::detailDefinition(const QString& definitionName, const QString& contactType) const
 {
+    d->m_errorMap.clear();
     if (!supportedContactTypes().contains(contactType)) {
         d->m_error =QContactManager::InvalidContactTypeError;
         return QContactDetailDefinition();
@@ -757,6 +938,7 @@ QContactDetailDefinition QContactManager::detailDefinition(const QString& defini
 /*! Persists the given definition \a def in the database, which is valid for contacts whose type is the given \a contactType.  Returns true if the definition was saved successfully, otherwise returns false */
 bool QContactManager::saveDetailDefinition(const QContactDetailDefinition& def, const QString& contactType)
 {
+    d->m_errorMap.clear();
     if (!supportedContactTypes().contains(contactType)) {
         d->m_error =QContactManager::InvalidContactTypeError;
         return false;
@@ -769,6 +951,7 @@ bool QContactManager::saveDetailDefinition(const QContactDetailDefinition& def,
 /*! Removes the detail definition identified by \a definitionName from the database, which is valid for contacts whose type is the given \a contactType.  Returns true if the definition was removed successfully, otherwise returns false */
 bool QContactManager::removeDetailDefinition(const QString& definitionName, const QString& contactType)
 {
+    d->m_errorMap.clear();
     if (!supportedContactTypes().contains(contactType)) {
         d->m_error =QContactManager::InvalidContactTypeError;
         return false;
@@ -782,7 +965,7 @@ bool QContactManager::removeDetailDefinition(const QString& definitionName, cons
   \enum QContactManager::ManagerFeature
   This enum describes the possible features that a particular manager may support
   \value Groups The manager supports saving contacts of the \c QContactType::TypeGroup type
-  \omitvalue ActionPreferences The manager supports saving preferred details per action per contact
+  \value ActionPreferences The manager supports saving preferred details per action per contact
   \value DetailOrdering When a contact is retrieved, the manager will return the details in the same order in which they were saved
   \value Relationships The manager supports at least some types of relationships between contacts
   \value ArbitraryRelationshipTypes The manager supports relationships of arbitrary types between contacts
@@ -865,7 +1048,7 @@ QString QContactManager::managerName() const
 QMap<QString, QString> QContactManager::managerParameters() const
 {
     QMap<QString, QString> params = d->m_engine->managerParameters();
-    
+
     params.remove(QString::fromAscii(QTCONTACTS_VERSION_NAME));
     params.remove(QString::fromAscii(QTCONTACTS_IMPLEMENTATION_VERSION_NAME));
     return params;
@@ -879,6 +1062,43 @@ QString QContactManager::managerUri() const
     return d->m_engine->managerUri();
 }
 
+
+/*!
+    \internal
+
+    When someone connects to this manager, connect the corresponding signal from the engine, if we
+    haven't before. If we have, just increment a count.
+
+    This allows lazy evaluation on the engine side (e.g. setting up dbus watchers) and prevents
+    unnecessary work.
+*/
+void QContactManager::connectNotify(const char *signal)
+{
+    /* For most signals we just connect from the engine to ourselves, since we just proxy, but we should connect only once */
+    QByteArray ba(signal);
+    if (!d->m_connectedSignals.contains(ba)) {
+        connect(d->m_engine, signal, this, signal);
+    }
+    d->m_connectedSignals[ba]++;
+}
+
+/*!
+    \internal
+
+    When someone disconnects, disconnect from the engine too if there are no more users of that signal.
+*/
+void QContactManager::disconnectNotify(const char *signal)
+{
+    QByteArray ba(signal);
+    if (d->m_connectedSignals[ba] <= 1) {
+        disconnect(d->m_engine, signal, this, signal);
+        d->m_connectedSignals.remove(ba);
+    } else {
+        d->m_connectedSignals[ba]--;
+    }
+}
+
+
 #include "moc_qcontactmanager.cpp"
 
 QTM_END_NAMESPACE
