@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -62,6 +62,7 @@
 #include "qcontactmanager.h"
 #include "qcontactmanagerengine.h"
 #include "qcontactactionmanager_p.h"
+#include "qcontactobserver.h"
 
 QTM_USE_NAMESPACE
 QTM_BEGIN_NAMESPACE
@@ -83,7 +84,9 @@ public:
         delete m_engine;
     }
 
+
     void createEngine(const QString& managerName, const QMap<QString, QString>& parameters);
+    static QContactManagerData* get(const QContactManager* manager);
     static QContactManagerEngineV2* engine(const QContactManager* manager);
 
     QContactManagerEngineV2* m_engine;
@@ -92,12 +95,25 @@ public:
 
     /* Manager plugins */
     static QHash<QString, QContactManagerEngineFactory*> m_engines;
+    static QSet<QContactManager*> m_aliveEngines;
+    static QContactManagerData* managerData(QContactManager* manager) {return manager->d;}
     static QList<QContactActionManagerPlugin*> m_actionManagers;
     static bool m_discoveredStatic;
     static QStringList m_pluginPaths;
     static void loadFactories();
     static void loadStaticFactories();
 
+    // Observer stuff
+    static void registerObserver(QContactManager *m, QContactObserver* observer);
+    static void unregisterObserver(QContactManager *m, QContactObserver* observer);
+    void _q_contactsUpdated(const QList<QContactLocalId>& ids);
+    void _q_contactsDeleted(const QList<QContactLocalId>& ids);
+
+    QMultiHash<QContactLocalId, QContactObserver*> m_observerForContact;
+
+    // Lazy connection stuff - reference counted set
+    QHash<QByteArray, int> m_connectedSignals;
+
 private:
     Q_DISABLE_COPY(QContactManagerData)
 };
