@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -42,14 +42,19 @@
 #include "qcontactsortorder.h"
 #include "qcontactsortorder_p.h"
 
+#ifndef QT_NO_DEBUG_STREAM
+#include <QDebug>
+#endif
+
 QTM_BEGIN_NAMESPACE
 
 /*!
   \class QContactSortOrder
   \brief The QContactSortOrder class defines how a list of contacts should be ordered according to some criteria
-  
+
   \inmodule QtContacts
-  
+   \since 1.0
+
  */
 
 /*!
@@ -173,6 +178,23 @@ QDataStream& operator>>(QDataStream& in, QContactSortOrder& sortOrder)
 }
 #endif
 
+#ifndef QT_NO_DEBUG_STREAM
+/*!
+  Outputs \a sortOrder to the debug stream \a dbg
+ */
+QDebug operator<<(QDebug dbg, const QContactSortOrder& sortOrder)
+{
+    dbg.nospace() << "QContactSortOrder("
+                  << "detailDefinitionName=" << sortOrder.detailDefinitionName() << ","
+                  << "detailFieldName=" << sortOrder.detailFieldName() << ","
+                  << "blankPolicy=" << static_cast<quint32>(sortOrder.blankPolicy()) << ","
+                  << "direction=" << static_cast<quint32>(sortOrder.direction()) << ","
+                  << "caseSensitivity=" << static_cast<quint32>(sortOrder.caseSensitivity())
+                  << ")";
+    return dbg.maybeSpace();
+}
+#endif
+
 /*!
  * Sets the definition name of the details which will be inspected to perform sorting to \a definitionName,
  * and the name of those details' fields which contains the value which contacts will be sorted by to \a fieldName
