@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -48,14 +42,17 @@
 
 #if defined(Q_OS_SYMBIAN) && defined(QT_LOCATION_S60_MONITORING)
 #include "qgeoareamonitor_s60_p.h"
-#elif defined(Q_WS_MAEMO_5)
-#include "qgeoareamonitor_maemo_p.h"
 #endif
+#include "qgeoareamonitor_polling_p.h"
 
 /*!
     \class QGeoAreaMonitor
     \brief The QGeoAreaMonitor class enables the detection of proximity
     changes for a specified set of coordinates.
+
+    \inmodule QtLocation
+    \since 1.0
+
     \ingroup location
 
     A QGeoAreaMonitor emits signals when the current position is in
@@ -175,19 +172,24 @@ qreal QGeoAreaMonitor::radius() const
     monitors areas using resources on the underlying system.
 
     Returns 0 if the system has no support for position monitoring.
+
+    Note: Symbian applications will need to have the Location capability
+    otherwise this will return 0.
 */
 QGeoAreaMonitor *QGeoAreaMonitor::createDefaultMonitor(QObject *parent)
 {
-#if defined(Q_OS_SYMBIAN) && defined(QT_LOCATION_S60_MONITORING)
-    QGeoAreaMonitor *ret = NULL;
-    TRAPD(error, ret = QGeoAreaMonitorS60::NewL(parent));
-    return ret;
-#elif defined(Q_WS_MAEMO_5)
-    QGeoAreaMonitorMaemo *ret = new QGeoAreaMonitorMaemo(parent);
-    return ret;
-#else
-    Q_UNUSED(parent);
-#endif
+    // Native Symbian area monitor is temporarily disabled,
+    // see http://bugreports.qt.nokia.com/browse/QTMOBILITY-1059
+//#if defined(Q_OS_SYMBIAN) && defined(QT_LOCATION_S60_MONITORING)
+//    QGeoAreaMonitor *ret = NULL;
+//    TRAPD(error, ret = QGeoAreaMonitorS60::NewL(parent));
+//    return ret;
+//#else
+    QGeoAreaMonitorPolling *ret = NULL;
+    ret = new QGeoAreaMonitorPolling(parent);
+    if (ret && ret->isValid())
+        return ret;
+//#endif
     return 0;
 }
 
