@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,20 +25,21 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
+#include <QDebug>
 #include "qgeoareamonitor_s60_p.h"
 #include "qgeopositioninfo.h"
 #include "qmlbackendmonitorinfo_s60_p.h"
@@ -50,6 +51,12 @@ TInt QGeoAreaMonitorS60::refCount = 0;
 
 QGeoAreaMonitorS60* QGeoAreaMonitorS60::NewL(QObject *aParent)
 {
+    RProcess thisProcess;
+    if (!thisProcess.HasCapability(ECapabilityLocation)) {
+        qWarning() << "QGeoAreaMonitor::createDefaultMonitor() requires the Symbian Location capability to succeed on the Symbian platform.";
+        return 0;
+    }
+
     QGeoAreaMonitorS60 *self = QGeoAreaMonitorS60::NewLC(aParent);
     CleanupStack::Pop();
     if (!self->isValid()) {
@@ -75,7 +82,7 @@ void QGeoAreaMonitorS60::setMonitoredArea(const QGeoCoordinate & aCoordinate, qr
     if ((ret1 != KErrNone) || (ret2 != KErrNone))
         return;
 
-    //Intialize the trigger and enable the trigger if atleast one slot is  connected to the areaEntered
+    //Initialize the trigger and enable the trigger if atleast one slot is  connected to the areaEntered
     //signal
     if ((iTriggerCreateAO->InitializeTrigger(this, EntryTrigger, coord, aRadius)) &&
             (receivers(SIGNAL(areaEntered(const QGeoPositionInfo&))) > 0)) {
@@ -83,7 +90,7 @@ void QGeoAreaMonitorS60::setMonitoredArea(const QGeoCoordinate & aCoordinate, qr
         iTriggerAO->NotifyFiredEvent();
     }
 
-    //Intialize the trigger and enable the trigger if atleast one slot is  connected to the areaExited
+    //Initialize the trigger and enable the trigger if atleast one slot is  connected to the areaExited
     //signal
     if ((iTriggerCreateAO->InitializeTrigger(this, ExitTrigger, coord, aRadius)) &&
             (receivers(SIGNAL(areaExited(const QGeoPositionInfo&))) > 0)) {
@@ -107,7 +114,7 @@ void QGeoAreaMonitorS60::setCenter(const QGeoCoordinate& coordinate)
         setMonitoredArea(coordinate, QGeoAreaMonitor::radius());
 }
 
-//virtual fucntion sets the radius of the monitorijng area to the radius
+//virtual function sets the radius of the monitorijng area to the radius
 void QGeoAreaMonitorS60::setRadius(qreal radius)
 {
     setMonitoredArea(QGeoAreaMonitor::center(), radius);
