@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,26 +25,21 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 #include "qgeocoordinate.h"
+#include "qgeocoordinate_p.h"
 #include "qlocationutils_p.h"
 
 #include <QDateTime>
@@ -55,6 +50,8 @@
 
 #include <math.h>
 
+#include <QDebug>
+
 #ifndef M_PI
 #define M_PI 3.14159265358979323846
 #endif
@@ -73,24 +70,20 @@ inline static double qgeocoordinate_radToDeg(double rad)
 }
 
 
-class QGeoCoordinatePrivate
-{
-public:
-    double lat;
-    double lng;
-    double alt;
-
-    QGeoCoordinatePrivate() {
-        lat = qQNaN();
-        lng = qQNaN();
-        alt = qQNaN();
-    }
-};
+QGeoCoordinatePrivate::QGeoCoordinatePrivate() {
+    lat = qQNaN();
+    lng = qQNaN();
+    alt = qQNaN();
+}
 
 
 /*!
     \class QGeoCoordinate
     \brief The QGeoCoordinate class defines a geographical position on the surface of the Earth.
+
+    \inmodule QtLocation
+    \since 1.0
+
     \ingroup location
 
     A QGeoCoordinate is defined by latitude, longitude, and optionally, altitude.
@@ -212,12 +205,22 @@ QGeoCoordinate &QGeoCoordinate::operator=(const QGeoCoordinate & other)
 /*!
     Returns true if the latitude, longitude and altitude of this
     coordinate are the same as those of \a other.
+
+    The longitude will be ignored if the latitude is +/- 90 degrees.
 */
 bool QGeoCoordinate::operator==(const QGeoCoordinate &other) const
 {
-    return ((qIsNaN(d->lat) && qIsNaN(other.d->lat)) || qFuzzyCompare(d->lat, other.d->lat))
-           && ((qIsNaN(d->lng) && qIsNaN(other.d->lng)) || qFuzzyCompare(d->lng, other.d->lng))
-           && ((qIsNaN(d->alt) && qIsNaN(other.d->alt)) || qFuzzyCompare(d->alt, other.d->alt));
+    bool latEqual = (qIsNaN(d->lat) && qIsNaN(other.d->lat))
+                        || qFuzzyCompare(d->lat, other.d->lat);
+    bool lngEqual = (qIsNaN(d->lng) && qIsNaN(other.d->lng))
+                        || qFuzzyCompare(d->lng, other.d->lng);
+    bool altEqual = (qIsNaN(d->alt) && qIsNaN(other.d->alt))
+                        || qFuzzyCompare(d->alt, other.d->alt);
+
+    if (!qIsNaN(d->lat) && ((d->lat == 90.0) || (d->lat == -90.0)))
+        lngEqual = true;
+
+    return (latEqual && lngEqual && altEqual);
 }
 
 /*!
@@ -348,11 +351,15 @@ qreal QGeoCoordinate::distanceTo(const QGeoCoordinate &other) const
     // Haversine formula
     double dlat = qgeocoordinate_degToRad(other.d->lat - d->lat);
     double dlon = qgeocoordinate_degToRad(other.d->lng - d->lng);
-    double y = sin(dlat / 2.0) * sin(dlat / 2.0)
-               + cos(qgeocoordinate_degToRad(d->lat))
-               * cos(qgeocoordinate_degToRad(other.d->lat))
-               * sin(dlon / 2.0) * sin(dlon / 2.0);
-    double x = 2 * atan2(sqrt(y), sqrt(1 - y));
+    double haversine_dlat = sin(dlat / 2.0);
+    haversine_dlat *= haversine_dlat;
+    double haversine_dlon = sin(dlon / 2.0);
+    haversine_dlon *= haversine_dlon;
+    double y = haversine_dlat
+             + cos(qgeocoordinate_degToRad(d->lat))
+             * cos(qgeocoordinate_degToRad(other.d->lat))
+             * haversine_dlon;
+    double x = 2 * asin(sqrt(y));
     return qreal(x * qgeocoordinate_EARTH_MEAN_RADIUS * 1000);
 }
 
@@ -360,8 +367,9 @@ qreal QGeoCoordinate::distanceTo(const QGeoCoordinate &other) const
     Returns the azimuth (or bearing) in degrees from this coordinate to the
     coordinate specified by \a other. Altitude is not used in the calculation.
 
-    There is an assumption that the Earth is spherical for the purpose of
-    this calculation.
+    The bearing returned is the bearing from the origin to \a other along the
+    great-circle between the two coordinates. There is an assumption that the
+    Earth is spherical for the purpose of this calculation.
 
     Returns 0 if the type of this coordinate or the type of \a other is
     QGeoCoordinate::InvalidCoordinate.
@@ -385,6 +393,59 @@ qreal QGeoCoordinate::azimuthTo(const QGeoCoordinate &other) const
     return qreal((int(whole + 360) % 360) + fraction);
 }
 
+void QGeoCoordinatePrivate::atDistanceAndAzimuth(const QGeoCoordinate &coord,
+                                                 qreal distance, qreal azimuth,
+                                                 double *lon, double *lat)
+{
+    double latRad = qgeocoordinate_degToRad(coord.d->lat);
+    double lonRad = qgeocoordinate_degToRad(coord.d->lng);
+    double cosLatRad = cos(latRad);
+    double sinLatRad = sin(latRad);
+
+    double azimuthRad = qgeocoordinate_degToRad(azimuth);
+
+    double ratio = (distance / (qgeocoordinate_EARTH_MEAN_RADIUS * 1000.0));
+    double cosRatio = cos(ratio);
+    double sinRatio = sin(ratio);
+
+    double resultLatRad = asin(sinLatRad * cosRatio
+                               + cosLatRad * sinRatio * cos(azimuthRad));
+    double resultLonRad  = lonRad
+                           + atan2(sin(azimuthRad) * sinRatio * cosLatRad,
+                                   cosRatio - sinLatRad * sin(resultLatRad));
+
+    *lat = qgeocoordinate_radToDeg(resultLatRad);
+    *lon = qgeocoordinate_radToDeg(resultLonRad);
+}
+
+/*!
+    Returns the coordinate that is reached by traveling \a distance metres
+    from the current coordinate at \a azimuth (or bearing) along a great-circle.
+    There is an assumption that the Earth is spherical for the purpose of this
+    calculation.
+
+    The altitude will have \a distanceUp added to it.
+
+    Returns an invalid coordinate if this coordinate is invalid.
+*/
+QGeoCoordinate QGeoCoordinate::atDistanceAndAzimuth(qreal distance, qreal azimuth, qreal distanceUp) const
+{
+    if (!isValid())
+        return QGeoCoordinate();
+
+    double resultLon, resultLat;
+    QGeoCoordinatePrivate::atDistanceAndAzimuth(*this, distance, azimuth,
+                                                &resultLon, &resultLat);
+
+    if (resultLon > 180.0)
+        resultLon -= 360.0;
+    else if (resultLon < -180.0)
+        resultLon += 360.0;
+
+    double resultAlt = d->alt + distanceUp;
+    return QGeoCoordinate(resultLat, resultLon, resultAlt);
+}
+
 /*!
     Returns this coordinate as a string in the specified \a format.
 
@@ -538,7 +599,7 @@ QDebug operator<<(QDebug dbg, const QGeoCoordinate &coord)
 
     Writes the given \a coordinate to the specified \a stream.
 
-    \sa {Format of the QDataStream Operators}
+    \sa {Serializing Qt Data Types}
 */
 
 QDataStream &operator<<(QDataStream &stream, const QGeoCoordinate &coordinate)
@@ -558,7 +619,7 @@ QDataStream &operator<<(QDataStream &stream, const QGeoCoordinate &coordinate)
     Reads a coordinate from the specified \a stream into the given
     \a coordinate.
 
-    \sa {Format of the QDataStream Operators}
+    \sa {Serializing Qt Data Types}
 */
 
 QDataStream &operator>>(QDataStream &stream, QGeoCoordinate &coordinate)
