@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,34 +25,30 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #include <QObject>
 #include <QDateTime>
+#include <QDebug>
 #include <limits.h>
 #include "qgeopositioninfosource_s60_p.h"
 #include "qgeopositioninfosource.h"
 #include "qmlbackendao_s60_p.h"
 
 
+
 QTM_BEGIN_NAMESPACE
 
 // constructor
@@ -65,6 +61,7 @@ CQGeoPositionInfoSourceS60::CQGeoPositionInfoSourceS60(QObject* aParent) : QGeoP
         mSupportedMethods(PositioningMethod(0)),
         mCurrentMethod(PositioningMethod(0)),
         mListSize(0),
+        mMinUpdateInterval(100),
         mStartUpdates(FALSE),
         mRegularUpdateTimedOut(FALSE),
         mModuleFlags(0)
@@ -100,6 +97,12 @@ CQGeoPositionInfoSourceS60* CQGeoPositionInfoSourceS60::NewLC(QObject* aParent)
 // static function NewL
 CQGeoPositionInfoSourceS60* CQGeoPositionInfoSourceS60::NewL(QObject * aParent)
 {
+    RProcess thisProcess;
+    if (!thisProcess.HasCapability(ECapabilityLocation)) {
+        qWarning() << "QGeoPositionInfoSource::createDefaultSource() requires the Symbian Location capability to succeed on the Symbian platform.";
+        return 0;
+    }
+
     CQGeoPositionInfoSourceS60* self = CQGeoPositionInfoSourceS60::NewLC(aParent);
     CleanupStack::Pop();
 
@@ -130,17 +133,18 @@ void CQGeoPositionInfoSourceS60::ConstructL()
 
         //update the list array with the available method initially
         updateDeviceStatus();
-        
+
         // Set the PreferredPositioningMethods based on Supported methods
-        QGeoPositionInfoSource::setPreferredPositioningMethods( mSupportedMethods );
+        QGeoPositionInfoSource::setPreferredPositioningMethods(mSupportedMethods);
 
         //devStatusUpdateAO->NotifyDeviceStatus(mStatusEvent);
 
         CleanupStack::PushL(mDevStatusUpdateAO);
 
-        if (mCurrentModuleId != TUid::Null())
+        if (mCurrentModuleId != TUid::Null()) {
             mRegUpdateAO = CQMLBackendAO::NewL(this, RegularUpdate, mCurrentModuleId);
-
+            mRegUpdateAO->setUpdateInterval(updateInterval());
+        }
         CleanupStack::Pop(2);
     }
 
@@ -174,11 +178,11 @@ QGeoPositionInfo CQGeoPositionInfoSourceS60::lastKnownPosition(bool aFromSatelli
         iLastKnownpositioner.Close();
 
         if ((error == KErrNone) || (error == KPositionPartialUpdate)) {
-        
+
             TPositionModuleInfo modInfo;
             mPositionServer.GetModuleInfoById(posInfo.ModuleId(), modInfo);
-            
-            if(!aFromSatellitePositioningMethodsOnly || (aFromSatellitePositioningMethodsOnly && (modInfo.Capabilities() & TPositionModuleInfo::ECapabilitySatellite))){
+
+            if (!aFromSatellitePositioningMethodsOnly || (aFromSatellitePositioningMethodsOnly && (modInfo.Capabilities() & TPositionModuleInfo::ECapabilitySatellite))) {
                 QGeoCoordinate  coord;
 
                 posInfo.GetPosition(pos);
@@ -193,7 +197,8 @@ QGeoPositionInfo CQGeoPositionInfoSourceS60::lastKnownPosition(bool aFromSatelli
                 TDateTime datetime = pos.Time().DateTime();
                 QDateTime dt(QDate(datetime.Year(), datetime.Month() + 1, datetime.Day() + 1),
                              QTime(datetime.Hour(), datetime.Minute(), datetime.Second(),
-                                   datetime.MicroSecond() / 1000));
+                                   datetime.MicroSecond() / 1000),
+                             Qt::UTC);
 
                 //store the time stamp
                 posUpdate.setTimestamp(dt);
@@ -217,10 +222,7 @@ int CQGeoPositionInfoSourceS60::minimumUpdateInterval() const
     if (mCurrentModuleId == TUid::Null())
         return 0;
 
-    TInt i = checkModule(mCurrentModuleId);
-    if (i != -1)
-        return mList[i].mTimeToNextFix.Int64() / 1000;           //divide by 1000, to convert microsecond to milisecond
-    return 0;
+    return mMinUpdateInterval;
 }
 
 
@@ -249,12 +251,15 @@ void CQGeoPositionInfoSourceS60::updateAvailableTypes()
 }
 
 //private function : to retrieve the index of the supplied module id from the mList array
-TInt CQGeoPositionInfoSourceS60::checkModule(TPositionModuleId aId)const
+TInt CQGeoPositionInfoSourceS60::checkModule(TPositionModuleId aId)//const
 {
+
     TInt i;
     for (i = 0; i < mListSize; i++)
-        if (mList[i].mUid == aId)
+        if (mList[i].mUid == aId) {
             return i;
+        }
+
     return -1;
 }
 
@@ -312,7 +317,7 @@ TInt CQGeoPositionInfoSourceS60::getMoreAccurateMethod(TInt aTimeout, TUint8 aBi
 
     for (TInt i = 0 ; i < mListSize; i++) {
         if (mList[i].mIsAvailable
-                //&& posMethods.testFlag(mList[i].mPosMethod)
+                && posMethods.testFlag(mList[i].mPosMethod)
                 && (mList[i].mStatus != TPositionModuleStatus::EDeviceUnknown)
                 && (mList[i].mStatus != TPositionModuleStatus::EDeviceError)
                 && (((aBits >> i) & 1))
@@ -333,7 +338,7 @@ TInt CQGeoPositionInfoSourceS60::getMoreAccurateMethod(TInt aTimeout, TUint8 aBi
 
     for (TInt i = 0 ; i < mListSize; i++) {
         if (mList[i].mIsAvailable
-                //&& posMethods.testFlag(mList[i].mPosMethod)
+                && posMethods.testFlag(mList[i].mPosMethod)
                 && (mList[i].mStatus != TPositionModuleStatus::EDeviceUnknown)
                 && (mList[i].mStatus != TPositionModuleStatus::EDeviceError)
                 && (((aBits >> i) & 1))) {
@@ -349,7 +354,7 @@ TInt CQGeoPositionInfoSourceS60::getMoreAccurateMethod(TInt aTimeout, TUint8 aBi
 }
 
 //private function : to update the mList array
-void CQGeoPositionInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TInt aStatus)
+void CQGeoPositionInfoSourceS60::updateStatus(TPositionModuleInfo &aModInfo, TInt aStatus)
 {
 
     TInt i, index;
@@ -385,8 +390,10 @@ void CQGeoPositionInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TInt
     time_to_next_fix = quality.TimeToNextFix();
 
 
+
     if ((i = checkModule(id)) == -1) {
         //update the properties of the module
+        QMutexLocker lLocker(&m_mutex);
 
         //TPositionModuleId of the module
         mList[mListSize].mUid = id;
@@ -411,15 +418,19 @@ void CQGeoPositionInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TInt
 
         //count on the mList array size
         mListSize++;
-        
+
         //update the supported source types based on the device status
         updateAvailableTypes();
-        
+
         //store the correct method in use from the mCurrentModuleId retireved earlier
         if (id == mCurrentModuleId) {
             mCurrentMethod = method;
+            mMinUpdateInterval = mList[mListSize-1].mTimeToNextFix.Int64() / 1000;
         }
+        lLocker.unlock();
     } else {
+
+        QMutexLocker lLocker(&m_mutex);
         //module's status has changed
         if (mList[i].mStatus != aStatus)
             mList[i].mStatus = aStatus;
@@ -439,10 +450,12 @@ void CQGeoPositionInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TInt
         //module's time to subsequent fix has changed
         if (mList[i].mTimeToNextFix != time_to_next_fix)
             mList[i].mTimeToFirstFix = time_to_next_fix;
-        
+
         //update the supported source types based on the device status
         updateAvailableTypes();
 
+        lLocker.unlock();
+
         //if the mCurrentModuleId is NULL, try updating the reg update with the available
         //positioning method
         if (mCurrentModuleId == TUid::Null() && (available == TRUE) &&
@@ -452,24 +465,33 @@ void CQGeoPositionInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TInt
 
             interval = QGeoPositionInfoSource::updateInterval();
 
-            TRAPD(ret, temp = CQMLBackendAO::NewL(this, RegularUpdate,
-                                                  mList[i].mUid));
+            TRAPD(ret, QT_TRYCATCH_LEAVING(temp = CQMLBackendAO::NewL(this, RegularUpdate,
+                                                  mList[i].mUid)));
+
+            QMutexLocker lRegLocker_interval(&m_mutex_interval);
+            mMinUpdateInterval = interval;
+            lRegLocker_interval.unlock();
 
             if ((ret == KErrNone) && (temp != NULL)) {
                 temp->setUpdateInterval(interval);
 
+                QMutexLocker lRegLocker(&m_mutex_RegUpAO);
                 if (mRegUpdateAO)
                     delete mRegUpdateAO;
                 mRegUpdateAO = temp;
+                lRegLocker.unlock();
 
                 //to be uncommented when startUpdates are done
 
                 if (mStartUpdates)
                     mRegUpdateAO->startUpdates();
 
+                QMutexLocker lRegLocker_interval1(&m_mutex_interval);
                 mCurrentModuleId = mList[i].mUid;
+                mMinUpdateInterval = mList[i].mTimeToNextFix.Int64() / 1000;
 
                 mCurrentMethod = mList[i].mPosMethod;
+                lRegLocker_interval1.unlock();
 
             }
         }
@@ -488,8 +510,10 @@ void CQGeoPositionInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TInt
 
                 interval = QGeoPositionInfoSource::updateInterval();
 
+                QMutexLocker lRegLocker1(&m_mutex_RegUpAO);
                 if (mRegUpdateAO)
                     delete  mRegUpdateAO;
+                lRegLocker1.unlock();
 
                 bits = mModuleFlags;
 
@@ -500,8 +524,8 @@ void CQGeoPositionInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TInt
                     index = getIndexPositionModule(bits);
 
                     if (index >= 0) {
-                        TRAPD(ret, temp = CQMLBackendAO::NewL(this, RegularUpdate,
-                                                              mList[index].mUid));
+                        TRAPD(ret, QT_TRYCATCH_LEAVING(temp = CQMLBackendAO::NewL(this, RegularUpdate,
+                                                              mList[index].mUid)));
 
                         if ((ret == KErrNone) && (temp != NULL))
                             break;
@@ -514,10 +538,16 @@ void CQGeoPositionInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TInt
                 if (temp != NULL) {
                     //successful in creating the subsession for the required
                     //method
-                    mRegUpdateAO = temp;
 
+                    QMutexLocker lRegLocker2(&m_mutex_RegUpAO);
+                    mRegUpdateAO = temp;
+                    lRegLocker2.unlock();
+
+                    QMutexLocker lRegLocker_interval2(&m_mutex_interval);
                     mCurrentModuleId = mList[index].mUid;
                     mCurrentMethod = mList[index].mPosMethod;
+                    mMinUpdateInterval = mList[index].mTimeToNextFix.Int64() / 1000;
+                    lRegLocker_interval2.unlock();
 
                     mRegUpdateAO->setUpdateInterval(interval);
 
@@ -528,10 +558,16 @@ void CQGeoPositionInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TInt
 
                 } else {
                     //no methods available,clean up the resources
+                    QMutexLocker lRegLocker3(&m_mutex_RegUpAO);
                     mRegUpdateAO = NULL;
+                    lRegLocker3.unlock();
+
+                    QMutexLocker lRegLocker_interval3(&m_mutex_interval);
                     mCurrentModuleId = TUid::Null();
+                    mMinUpdateInterval = interval;
                     mCurrentMethod = PositioningMethod(0);
-                    
+                    lRegLocker_interval3.unlock();
+
                     emit updateTimeout();
                 }
 
@@ -539,10 +575,13 @@ void CQGeoPositionInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TInt
 
             //check if device status of the request update module changed
             if (id == mReqModuleId) {
+                QMutexLocker lReqLocker(&m_mutex_ReqUpAO);
                 if (mRegUpdateAO)
                     delete mReqUpdateAO;
                 mReqUpdateAO = NULL;
                 mReqModuleId = TUid::Null();
+                lReqLocker.unlock();
+
                 emit updateTimeout();
             }
 
@@ -629,7 +668,8 @@ void CQGeoPositionInfoSourceS60::TPositionInfo2QGeoPositionInfo(
     TDateTime datetime = pos.Time().DateTime();
     QDateTime dt(QDate(datetime.Year() , datetime.Month() + 1, datetime.Day() + 1),
                  QTime(datetime.Hour() , datetime.Minute(), datetime.Second(),
-                       datetime.MicroSecond() / 1000));
+                       datetime.MicroSecond() / 1000),
+                 Qt::UTC);
 
     //store the time stamp
     aPosInfo2.setTimestamp(dt);
@@ -669,7 +709,7 @@ void CQGeoPositionInfoSourceS60::updatePosition(HPositionGenericInfo *aPosInfo,
 {
     QGeoPositionInfo  posInfo;
 
-    if (aError == KErrNone) {
+    if (aError == KErrNone && aPosInfo) {
         //fill posUpdate
         TPositionInfo2QGeoPositionInfo(aPosInfo, posInfo);
 
@@ -689,14 +729,7 @@ void CQGeoPositionInfoSourceS60::updatePosition(HPositionGenericInfo *aPosInfo,
         }
     } else {
         //posiitoning module is unable to return any position information
-        if (mStartUpdates) {
-            if (!mRegularUpdateTimedOut) {
-                mRegularUpdateTimedOut = true;
-                emit updateTimeout();
-            }
-        } else {
-            emit positionUpdated(posInfo);
-        }
+        emit updateTimeout();
     }
 }
 
@@ -713,7 +746,12 @@ void CQGeoPositionInfoSourceS60::requestUpdate(int aTimeout)
     TInt index = -1;
     TUint8 bits;
 
-    CQMLBackendAO *temp= NULL;
+    CQMLBackendAO *temp = NULL;
+
+    if (mRegUpdateAO == NULL || mCurrentModuleId == TUid::Null()) {
+        emit updateTimeout();
+        return;
+    }
 
     //return if already a request update is pending
     if (mReqUpdateAO && mReqUpdateAO->isRequestPending())
@@ -741,22 +779,25 @@ void CQGeoPositionInfoSourceS60::requestUpdate(int aTimeout)
         }
         //if the selected module for request update is same as the previous one reuse the request
         if (mList[index].mUid == mReqModuleId) {
-            mReqUpdateAO->requestUpdate(aTimeout);
-            return;
+            if (mReqUpdateAO) {
+                mReqUpdateAO->requestUpdate(aTimeout);
+                return;
+            }
         }
 
-        TRAPD(ret, temp = CQMLBackendAO::NewL(this, OnceUpdate, mList[index].mUid));
+        TRAPD(ret, QT_TRYCATCH_LEAVING(temp = CQMLBackendAO::NewL(this, OnceUpdate, mList[index].mUid)));
 
         if ((ret == KErrNone) && (temp != NULL)) {
+            QMutexLocker lReqLocker(&m_mutex_ReqUpAO);
             //delete the old reqest update
             if (mReqUpdateAO)
                 delete mReqUpdateAO;
 
             //set the requestAO to the newly created AO
             mReqUpdateAO = temp;
-
             //set the request module ID
             mReqModuleId = mList[index].mUid;
+            lReqLocker.unlock();
 
             //start the update
             mReqUpdateAO->requestUpdate(aTimeout);
@@ -770,9 +811,11 @@ void CQGeoPositionInfoSourceS60::requestUpdate(int aTimeout)
 
     //cleanup resources if the invalid requpdate is still stored
     if (mReqUpdateAO) {
+        QMutexLocker lReqLocker(&m_mutex_ReqUpAO);
         delete mReqUpdateAO;
         mReqUpdateAO = NULL;
         mReqModuleId = TUid::Null();
+        lReqLocker.unlock();
     }
 
 }
@@ -780,6 +823,11 @@ void CQGeoPositionInfoSourceS60::requestUpdate(int aTimeout)
 // starts the regular updates
 void CQGeoPositionInfoSourceS60::startUpdates()
 {
+    if (mRegUpdateAO == NULL || mCurrentModuleId == TUid::Null()) {
+        emit updateTimeout();
+        return;
+    }
+
     if (receivers(SIGNAL(positionUpdated(QGeoPositionInfo))) > 0 && !mStartUpdates)
         mRegUpdateAO->startUpdates();
     mRegularUpdateTimedOut = false;
@@ -790,13 +838,21 @@ void CQGeoPositionInfoSourceS60::startUpdates()
 void CQGeoPositionInfoSourceS60::stopUpdates()
 {
     mStartUpdates = false;
+
+    if (mRegUpdateAO == NULL || mCurrentModuleId == TUid::Null()) {
+        emit updateTimeout();
+        return;
+    }
+
     mRegUpdateAO->cancelUpdate();
 }
 
 void CQGeoPositionInfoSourceS60::setPreferredPositioningMethods(PositioningMethods aMethods)
 {
+
+
     QGeoPositionInfoSource::setPreferredPositioningMethods(aMethods);
-    
+
     PositioningMethods preferredMethod(PositioningMethods(0));
     TInt index = -1;
     // the poistioning methods are not supported
@@ -825,8 +881,8 @@ void CQGeoPositionInfoSourceS60::setPreferredPositioningMethods(PositioningMetho
 
         if (index >= 0) {
 
-            TRAPD(error, temp = CQMLBackendAO::NewL(this, RegularUpdate,
-                                                    mList[index].mUid));
+            TRAPD(error, QT_TRYCATCH_LEAVING(temp = CQMLBackendAO::NewL(this, RegularUpdate,
+                                                    mList[index].mUid)));
             if ((temp != NULL) && (error == KErrNone))
                 break;
 
@@ -835,33 +891,41 @@ void CQGeoPositionInfoSourceS60::setPreferredPositioningMethods(PositioningMetho
     } while (index >= 0);
 
 
+
     if (temp != NULL) {
         // this is needed as the previous setupdateinterval value should not be lost
         int updateInterval = QGeoPositionInfoSource::updateInterval();
+        QMutexLocker lRegLocker(&m_mutex_RegUpAO);
         if (mRegUpdateAO)
             delete mRegUpdateAO;
         mRegUpdateAO = temp;
+
         mCurrentModuleId = mList[index].mUid ;
+        lRegLocker.unlock();
 
         index = checkModule(mCurrentModuleId);
 
-        mCurrentMethod = mList[index].mPosMethod ;
-
-
-        if (updateInterval) {
-            int value = mRegUpdateAO->setUpdateInterval(updateInterval);
-            //as the poistioning module has changed
-            //possibility of the minimumupdateinterval being changed
-            if (value != updateInterval)
-                QGeoPositionInfoSource::setUpdateInterval(value);
-
+        if (index >= 0 && index < mListSize) {
+            QMutexLocker lRegLocker_interval(&m_mutex_interval);
+            mCurrentMethod = mList[index].mPosMethod ;
+            mMinUpdateInterval = mList[index].mTimeToNextFix.Int64() / 1000;
+            lRegLocker_interval.unlock();
         }
+
+        int value = mRegUpdateAO->setUpdateInterval(updateInterval);
+        //as the positioning module has changed,
+        //possibility of the minimumupdateinterval being changed
+        if (value != updateInterval)
+            QGeoPositionInfoSource::setUpdateInterval(value);
+
     }
 
 }
 
 void CQGeoPositionInfoSourceS60::setUpdateInterval(int aMilliSec)
 {
+
+
     if (mRegUpdateAO) {
         int interval = mRegUpdateAO->setUpdateInterval(aMilliSec);
         // as the above set value can be minimum value so
