@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,24 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
+
 #include <QObject>
 #include <QDateTime>
+#include <QDebug>
 #include <limits.h>
 #include "qgeopositioninfosource_s60_p.h"
 #include "qgeosatelliteinfosource_s60_p.h"
@@ -59,6 +61,7 @@ CQGeoSatelliteInfoSourceS60::CQGeoSatelliteInfoSourceS60(QObject* aParent) : QGe
         mReqUpdateAO(NULL),
         mRegUpdateAO(NULL),
         mListSize(0),
+        mMinUpdateInterval(0),
         mStartUpdates(FALSE),
         mModuleFlags(0)
 {
@@ -91,6 +94,12 @@ CQGeoSatelliteInfoSourceS60* CQGeoSatelliteInfoSourceS60::NewLC(QObject* aParent
 // static function NewL
 CQGeoSatelliteInfoSourceS60* CQGeoSatelliteInfoSourceS60::NewL(QObject * aParent)
 {
+    RProcess thisProcess;
+    if (!thisProcess.HasCapability(ECapabilityLocation)) {
+        qWarning() << "QGeoSatelliteInfoSource::createDefaultSource() requires the Symbian Location capability to succeed on the Symbian platform.";
+        return 0;
+    }
+
     CQGeoSatelliteInfoSourceS60* self = CQGeoSatelliteInfoSourceS60::NewLC(aParent);
     CleanupStack::Pop();
 
@@ -141,8 +150,8 @@ void CQGeoSatelliteInfoSourceS60::ConstructL()
             index = getIndexPositionModule(bits);
 
             if (index >= 0) {
-                TRAPD(ret, temp = CQMLBackendAO::NewL(this, RegularUpdate,
-                                                      mList[index].mUid));
+                TRAPD(ret, QT_TRYCATCH_LEAVING(temp = CQMLBackendAO::NewL(this, RegularUpdate,
+                                                      mList[index].mUid)));
 
                 if ((ret == KErrNone) && (temp != NULL))
                     break;
@@ -165,8 +174,9 @@ void CQGeoSatelliteInfoSourceS60::ConstructL()
 }
 
 //private function : to retrieve the index of the supplied module id from the mList array
-TInt CQGeoSatelliteInfoSourceS60::checkModule(TPositionModuleId aId)const
+TInt CQGeoSatelliteInfoSourceS60::checkModule(TPositionModuleId aId)//const
 {
+    QMutexLocker locker(&m_mutex);
     TInt i;
     for (i = 0; i < mListSize; i++)
         if (mList[i].mUid == aId)
@@ -180,10 +190,12 @@ int CQGeoSatelliteInfoSourceS60::minimumUpdateInterval() const
     if (mCurrentModuleId == TUid::Null())
         return 0;
 
-    TInt i = checkModule(mCurrentModuleId);
+    return mMinUpdateInterval;
+
+    /*TInt i = checkModule(mCurrentModuleId);
     if (i != -1)
         return mList[i].mTimeToNextFix.Int64() / 1000;           //divide by 1000, to convert microsecond to milisecond
-    return 0;
+    return 0;*/
 }
 
 //private function : get the index of the mList that supports the preferred method if
@@ -262,7 +274,7 @@ TInt CQGeoSatelliteInfoSourceS60::getMoreAccurateMethod(TInt aTimeout, TUint8 aB
 }
 
 //private function : to update the mList array
-void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TInt aStatus)
+void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo &aModInfo, TInt aStatus)
 {
 
     TInt i, index;
@@ -293,6 +305,7 @@ void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TIn
 
     if ((i = checkModule(id)) == -1) {
         //update the properties of the module
+        QMutexLocker lLocker(&m_mutex);
 
         //TPositionModuleId of the module
         mList[mListSize].mUid = id;
@@ -314,7 +327,13 @@ void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TIn
 
         //count on the mList array size
         mListSize++;
+
+        mMinUpdateInterval = mList[mListSize-1].mTimeToNextFix.Int64() / 1000;
+        lLocker.unlock();
     } else {
+
+        QMutexLocker lLocker(&m_mutex);
+
         //module's status has changed
         if (mList[i].mStatus != aStatus)
             mList[i].mStatus = aStatus;
@@ -335,6 +354,8 @@ void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TIn
         if (mList[i].mTimeToNextFix != time_to_next_fix)
             mList[i].mTimeToFirstFix = time_to_next_fix;
 
+        lLocker.unlock();
+
         //if the mCurrentModuleId is NULL, try updating the reg update with the available
         //positioning method
         if (mCurrentModuleId == TUid::Null() && (available == TRUE) &&
@@ -342,12 +363,13 @@ void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TIn
                 (aStatus != TPositionModuleStatus::EDeviceError)) {
             TInt interval = 0;
 
-            TRAPD(ret, temp = CQMLBackendAO::NewL(this, RegularUpdate,
-                                                  mList[i].mUid));
+            TRAPD(ret, QT_TRYCATCH_LEAVING(temp = CQMLBackendAO::NewL(this, RegularUpdate,
+                                                  mList[i].mUid)));
 
             if ((ret == KErrNone) && (temp != NULL)) {
                 temp->setUpdateInterval(interval);
 
+                QMutexLocker lRegLocker(&m_mutex_RegUpAO);
                 if (mRegUpdateAO)
                     delete mRegUpdateAO;
                 mRegUpdateAO = temp;
@@ -359,6 +381,8 @@ void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TIn
 
 
                 mCurrentModuleId = mList[i].mUid;
+                mMinUpdateInterval = mList[i].mTimeToNextFix.Int64() / 1000;
+                lRegLocker.unlock();
 
             }
         }
@@ -375,8 +399,10 @@ void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TIn
 
                 TUint8 bits;
 
+                QMutexLocker lRegLocker1(&m_mutex_RegUpAO);
                 if (mRegUpdateAO)
                     delete  mRegUpdateAO;
+                lRegLocker1.unlock();
 
                 bits = mModuleFlags;
 
@@ -386,8 +412,8 @@ void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TIn
                     index = getIndexPositionModule(bits);
 
                     if (index >= 0) {
-                        TRAPD(ret, temp = CQMLBackendAO::NewL(this, RegularUpdate,
-                                                              mList[index].mUid));
+                        TRAPD(ret, QT_TRYCATCH_LEAVING(temp = CQMLBackendAO::NewL(this, RegularUpdate,
+                                                              mList[index].mUid)));
 
                         if ((ret == KErrNone) && (temp != NULL))
                             break;
@@ -400,30 +426,37 @@ void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo aModInfo, TIn
                 if (temp != NULL) {
                     //successful in creating the subsession for the required
                     //method
+                    QMutexLocker lRegLocker2(&m_mutex_RegUpAO);
                     mRegUpdateAO = temp;
 
+                    mCurrentModuleId = mList[index].mUid;
+                    mMinUpdateInterval = mList[i].mTimeToNextFix.Int64() / 1000;
+                    lRegLocker2.unlock();
+
                     mRegUpdateAO->setUpdateInterval(interval);
 
                     if (mStartUpdates)
                         mRegUpdateAO->startUpdates();
 
-
-                    mCurrentModuleId = mList[index].mUid;
-
                 } else {
                     //no methods available,clean up the resources
+                    QMutexLocker lRegLocker3(&m_mutex_RegUpAO);
                     mRegUpdateAO = NULL;
                     mCurrentModuleId = TUid::Null();
+                    mMinUpdateInterval = interval;
+                    lRegLocker3.unlock();
                 }
 
             }
 
             //check if device status of the request update module changed
             if (id == mReqModuleId) {
+                QMutexLocker lReqLocker(&m_mutex_ReqUpAO);
                 if (mRegUpdateAO)
                     delete mReqUpdateAO;
                 mReqUpdateAO = NULL;
                 mReqModuleId = TUid::Null();
+                lReqLocker.unlock();
                 emit requestTimeout();
             }
 
@@ -487,7 +520,7 @@ void CQGeoSatelliteInfoSourceS60::updateDeviceStatus(void)
 
 //
 void CQGeoSatelliteInfoSourceS60::TPositionSatelliteInfo2QGeoSatelliteInfo(
-    TPositionSatelliteInfo  aSatInfo, QList<QGeoSatelliteInfo> &qListSatInView,
+    TPositionSatelliteInfo  &aSatInfo, QList<QGeoSatelliteInfo> &qListSatInView,
     QList<QGeoSatelliteInfo> &qListSatInUse)
 {
     TInt satInView = aSatInfo.NumSatellitesInView();
@@ -507,7 +540,7 @@ void CQGeoSatelliteInfoSourceS60::TPositionSatelliteInfo2QGeoSatelliteInfo(
     }
 }
 //
-void CQGeoSatelliteInfoSourceS60::updatePosition(TPositionSatelliteInfo aSatInfo,
+void CQGeoSatelliteInfoSourceS60::updatePosition(TPositionSatelliteInfo &aSatInfo,
         int aError, bool isStartUpdate)
 {
     QList<QGeoSatelliteInfo> qListSatInUse;
@@ -550,6 +583,11 @@ void CQGeoSatelliteInfoSourceS60::requestUpdate(int aTimeout)
 
     CQMLBackendAO *temp = NULL;
 
+    if (mRegUpdateAO == NULL || mCurrentModuleId == TUid::Null()) {
+        emit requestTimeout();
+        return;
+    }
+
     //requestupdate
     //return if already a request update is pending
     if (mReqUpdateAO && mReqUpdateAO->isRequestPending())
@@ -574,13 +612,17 @@ void CQGeoSatelliteInfoSourceS60::requestUpdate(int aTimeout)
         }
         //if the selected module for request update is same as the previous one reuse the request
         if (mList[index].mUid == mReqModuleId) {
-            mReqUpdateAO->requestUpdate(aTimeout);
-            return;
+            if (mReqUpdateAO) {
+                mReqUpdateAO->requestUpdate(aTimeout);
+                return;
+            }
         }
 
-        TRAPD(ret, temp = CQMLBackendAO::NewL(this, OnceUpdate, mList[index].mUid));
+        TRAPD(ret, QT_TRYCATCH_LEAVING(temp = CQMLBackendAO::NewL(this, OnceUpdate, mList[index].mUid)));
 
         if ((ret == KErrNone) && (temp != NULL)) {
+
+            QMutexLocker lReqLocker(&m_mutex_ReqUpAO);
             //delete the old reqest update
             if (mReqUpdateAO)
                 delete mReqUpdateAO;
@@ -590,6 +632,7 @@ void CQGeoSatelliteInfoSourceS60::requestUpdate(int aTimeout)
 
             //set the request module ID
             mReqModuleId = mList[index].mUid;
+            lReqLocker.unlock();
 
             //start the update
             mReqUpdateAO->requestUpdate(aTimeout);
@@ -603,8 +646,10 @@ void CQGeoSatelliteInfoSourceS60::requestUpdate(int aTimeout)
 
     //cleanup resources if the invalid requpdate is still stored
     if (mReqUpdateAO) {
+        QMutexLocker lReqLocker(&m_mutex_ReqUpAO);
         delete mReqUpdateAO;
         mReqUpdateAO = NULL;
+        lReqLocker.unlock();
         mReqModuleId = TUid::Null();
     }
 
@@ -613,6 +658,11 @@ void CQGeoSatelliteInfoSourceS60::requestUpdate(int aTimeout)
 // starts the regular updates
 void CQGeoSatelliteInfoSourceS60::startUpdates()
 {
+    if (mRegUpdateAO == NULL || mCurrentModuleId == TUid::Null()) {
+        emit requestTimeout();
+        return;
+    }
+
     if (mRegUpdateAO && ((receivers(SIGNAL(satellitesInViewUpdated(const QList<QGeoSatelliteInfo>&))) > 0) ||
                          (receivers(SIGNAL(satellitesInUseUpdated(const QList<QGeoSatelliteInfo>&))) > 0)))
         mRegUpdateAO->startUpdates();
@@ -624,6 +674,12 @@ void CQGeoSatelliteInfoSourceS60::startUpdates()
 void CQGeoSatelliteInfoSourceS60::stopUpdates()
 {
     mStartUpdates = false;
+
+    if (mRegUpdateAO == NULL || mCurrentModuleId == TUid::Null()) {
+        emit requestTimeout();
+        return;
+    }
+
     if (mReqUpdateAO)
         mRegUpdateAO->cancelUpdate();
 }
