@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -57,6 +57,7 @@
 #include <e32std.h>
 #include <e32base.h>
 #include <lbs.h>
+#include <qmutex.h>
 #include "qgeosatelliteinfosource.h"
 #include "notificationsatellitecallback_s60_p.h"
 
@@ -94,7 +95,7 @@ public:
  *
  */
 class CQGeoSatelliteInfoSourceS60 : public INotificationSatelliteCallback,
-            public QGeoSatelliteInfoSource
+        public QGeoSatelliteInfoSource
 
 {
 public:
@@ -123,7 +124,7 @@ public:
     /**
      * Update the position info
      */
-    void updatePosition(TPositionSatelliteInfo aPosSatInfo, int aError , bool isStartUpdate);
+    void updatePosition(TPositionSatelliteInfo &aPosSatInfo, int aError , bool isStartUpdate);
 
 
     /**
@@ -167,8 +168,8 @@ public slots :
 private:
 
     /**
-     * Constructor for performing 1st stage construction
-     */
+    * Constructor for performing 1st stage construction
+    */
     CQGeoSatelliteInfoSourceS60(QObject* aParent = 0);
 
     /**
@@ -176,10 +177,10 @@ private:
      */
     void ConstructL();
 
-    void updateStatus(TPositionModuleInfo aModInfo, TInt aStatus);
+    void updateStatus(TPositionModuleInfo &aModInfo, TInt aStatus);
 
     //get the index of the module in the List array
-    TInt checkModule(TPositionModuleId aId) const;
+    TInt checkModule(TPositionModuleId aId) ;//const;
 
     //get the index of the position module based on the preferred methods
     TInt getIndexPositionModule(TUint8 aBits) const;
@@ -187,7 +188,7 @@ private:
     //get the more accuarte method with time to first fix < than timeout
     TInt getMoreAccurateMethod(TInt aTimeout, TUint8 aBits);
 
-    void TPositionSatelliteInfo2QGeoSatelliteInfo(TPositionSatelliteInfo aSatInfo,
+    void TPositionSatelliteInfo2QGeoSatelliteInfo(TPositionSatelliteInfo &aSatInfo,
             QList<QGeoSatelliteInfo> &qListSatInView,
             QList<QGeoSatelliteInfo> &qListSatInUse);
 
@@ -249,11 +250,20 @@ private:
      */
     int mListSize;
 
+    int mMinUpdateInterval;
+
     /*
      * query for the status
      */
     TPositionModuleStatusEvent  mStatusEvent;
 
+    // mutex for making thread safe
+    QMutex          m_mutex;
+    // mutex for ReqUpdate Active Ojbect
+    QMutex          m_mutex_ReqUpAO;
+    // mutex for RegUpdate Active Ojbect
+    QMutex          m_mutex_RegUpAO;
+
     /*
      * maintain the startUpdates status
      */
