@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -188,11 +188,21 @@ QMessage EventLoggerEngine::eventToMessage(RTComElEvent & ev)
     else
       QMessagePrivate::setStandardFolder(message,QMessage::InboxFolder);
     //    qDebug() << "event_type:"  << ev.fld_event_type << ev.fld_event_type_id << "Outgoing:" << ev.fld_outgoing << " Folder:" << message.standardFolder();
-    message.setFrom(QMessageAddress(QMessageAddress::Phone, QString(ev.fld_remote_uid)));
-    QMessagePrivate::setSenderName(message, QString(ev.fld_remote_uid));
-    QMessageAddressList messageAddresslist;
-    messageAddresslist.append(QMessageAddress(QMessageAddress::Phone, QString(ev.fld_local_uid)));
-    message.setTo(messageAddresslist);
+
+    if (ev.fld_outgoing) {
+        // Outgoing message
+        message.setFrom(QMessageAddress(QMessageAddress::Phone, QString(ev.fld_local_uid)));
+        QMessagePrivate::setSenderName(message, QString(ev.fld_local_uid));
+        message.setTo(QMessageAddress(QMessageAddress::Phone, QString(ev.fld_remote_uid)));
+    } else {
+        // Incoming message
+        message.setFrom(QMessageAddress(QMessageAddress::Phone, QString(ev.fld_remote_uid)));
+        QMessagePrivate::setSenderName(message, QString(ev.fld_remote_uid));
+        QMessageAddressList messageAddresslist;
+        messageAddresslist.append(QMessageAddress(QMessageAddress::Phone, QString(ev.fld_local_uid)));
+        message.setTo(messageAddresslist);
+    }
+
     message.setBody(QString::fromUtf8(ev.fld_free_text));
     QMessagePrivate* privateMessage = QMessagePrivate::implementation(message);
     privateMessage->_id = QMessageId(QString("el")+QString::number(ev.fld_id));
@@ -284,11 +294,21 @@ additional_text=%s icon_name=%s pango_markup=%s\n",
 	 if (ev.fld_outgoing) QMessagePrivate::setStandardFolder(message,QMessage::SentFolder);
 	 else
 	   QMessagePrivate::setStandardFolder(message,QMessage::InboxFolder);
-         message.setFrom(QMessageAddress(QMessageAddress::Phone, QString(ev.fld_remote_uid)));
-         QMessagePrivate::setSenderName(message, QString(ev.fld_remote_uid));
-         QMessageAddressList messageAddresslist;
-         messageAddresslist.append(QMessageAddress(QMessageAddress::Phone, QString(ev.fld_local_uid)));
-         message.setTo(messageAddresslist);
+
+         if (ev.fld_outgoing) {
+             // Outgoing message
+             message.setFrom(QMessageAddress(QMessageAddress::Phone, QString(ev.fld_local_uid)));
+             QMessagePrivate::setSenderName(message, QString(ev.fld_local_uid));
+             message.setTo(QMessageAddress(QMessageAddress::Phone, QString(ev.fld_remote_uid)));
+         } else {
+             // Incoming message
+             message.setFrom(QMessageAddress(QMessageAddress::Phone, QString(ev.fld_remote_uid)));
+             QMessagePrivate::setSenderName(message, QString(ev.fld_remote_uid));
+             QMessageAddressList messageAddresslist;
+             messageAddresslist.append(QMessageAddress(QMessageAddress::Phone, QString(ev.fld_local_uid)));
+             message.setTo(messageAddresslist);
+         }
+
          message.setBody(QString::fromUtf8(ev.fld_free_text));
          QMessagePrivate* privateMessage = QMessagePrivate::implementation(message);
          privateMessage->_id = id;
@@ -342,7 +362,7 @@ void EventLoggerEngine::notification(int eventId, QString service,QMessageStoreP
                 } else if (service== "RTCOM_EL_SERVICE_CHAT") {
                     msg.setType(QMessage::InstantMessage);
                 } else {
-                    msg.setType(QMessage::NoType);  // Other type, as eample voice calll
+                    msg.setType(QMessage::NoType);  // Other type, as example voice calll
                 }
             }
             else if (!messageRetrieved) {
