@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -42,6 +42,9 @@
 #include "qmessage_symbian_p.h"
 #include "qmessagecontentcontainer_symbian_p.h"
 #include "qmessagemanager.h"
+#ifdef FREESTYLEMAILUSED
+#include "qfsengine_symbian_p.h"
+#endif
 
 QTM_BEGIN_NAMESPACE
 
@@ -295,6 +298,12 @@ void QMessage::setPriority(Priority newPriority)
 
 int QMessage::size() const
 {
+#ifdef FREESTYLEMAILUSED
+    QMessageContentContainerPrivate *msgPrivContainer(((QMessageContentContainer *)(this))->d_ptr);
+    if (!msgPrivContainer->_contentRetrieved) {
+        CFSEngine::instance()->retrieveMessageContentHeaders(*(QMessage*)this);
+    }
+#endif
     int size = 0;
     if (d_ptr->_size != 0) {
         size = d_ptr->_size;
@@ -312,6 +321,12 @@ int QMessage::size() const
 
 QMessageContentContainerId QMessage::bodyId() const
 {
+#ifdef FREESTYLEMAILUSED
+    QMessageContentContainerPrivate *msgPrivContainer(((QMessageContentContainer *)(this))->d_ptr);
+    if (!msgPrivContainer->_contentRetrieved) {
+        CFSEngine::instance()->retrieveMessageContentHeaders(*(QMessage*)this);
+    }
+#endif
     // TODO: Example body finding algorithm.
     // If the content type of the message is text, then that is the body
     // otherwise if the first part of the body is text then that is the body.
@@ -321,6 +336,12 @@ QMessageContentContainerId QMessage::bodyId() const
 
 void QMessage::setBody(const QString &body, const QByteArray &mimeType)
 {
+#ifdef FREESTYLEMAILUSED
+    QMessageContentContainerPrivate *msgPrivContainer(((QMessageContentContainer *)(this))->d_ptr);
+    if (!msgPrivContainer->_contentRetrieved) {
+        CFSEngine::instance()->retrieveMessageContentHeaders(*(QMessage*)this);
+    }
+#endif
     QByteArray mainType("text");
     QByteArray subType("plain");   
     QByteArray charset;
@@ -388,6 +409,12 @@ void QMessage::setBody(QTextStream &in, const QByteArray &mimeType)
 
 QMessageContentContainerIdList QMessage::attachmentIds() const
 {
+#ifdef FREESTYLEMAILUSED
+    QMessageContentContainerPrivate *msgPrivContainer(((QMessageContentContainer *)(this))->d_ptr);
+    if (!msgPrivContainer->_contentRetrieved) {
+        CFSEngine::instance()->retrieveMessageContentHeaders(*(QMessage*)this);
+    }
+#endif
 	QMessageContentContainerIdList ids;
 
 	QMessageContentContainerId msgBodyId(bodyId());
@@ -402,6 +429,12 @@ QMessageContentContainerIdList QMessage::attachmentIds() const
 
 void QMessage::appendAttachments(const QStringList &fileNames)
 {
+#ifdef FREESTYLEMAILUSED
+    QMessageContentContainerPrivate *msgPrivContainer(((QMessageContentContainer *)(this))->d_ptr);
+    if (!msgPrivContainer->_contentRetrieved) {
+        CFSEngine::instance()->retrieveMessageContentHeaders(*(QMessage*)this);
+    }
+#endif
 	if (!fileNames.isEmpty()) {
         d_ptr->_modified = true;
 
@@ -439,6 +472,12 @@ void QMessage::appendAttachments(const QStringList &fileNames)
 
 void QMessage::clearAttachments()
 {
+#ifdef FREESTYLEMAILUSED
+    QMessageContentContainerPrivate *msgPrivContainer(((QMessageContentContainer *)(this))->d_ptr);
+    if (!msgPrivContainer->_contentRetrieved) {
+        CFSEngine::instance()->retrieveMessageContentHeaders(*(QMessage*)this);
+    }
+#endif
 	d_ptr->_modified = true;
 	QMessageContentContainerPrivate *container(((QMessageContentContainer *)(this))->d_ptr);
 	container->_attachments.clear();
@@ -451,6 +490,12 @@ bool QMessage::isModified() const
 
 QMessage QMessage::createResponseMessage(ResponseType type) const
 {
+#ifdef FREESTYLEMAILUSED
+    QMessageContentContainerPrivate *msgPrivContainer(((QMessageContentContainer *)(this))->d_ptr);
+    if (!msgPrivContainer->_contentRetrieved) {
+        CFSEngine::instance()->retrieveMessageContentHeaders(*(QMessage*)this);
+    }
+#endif
 	QMessage message;
 	message.setType(d_ptr->_type);
 	message.setParentAccountId(d_ptr->_parentAccountId);
