@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -44,36 +44,37 @@
     \class QMessageAccount
 
     \brief The QMessageAccount class represents a messaging account in the messaging store.
-    
-    \inmodule QtMessaging
-    
-    \ingroup messaging
 
-    A QMessageAccount is a logical entity that groups messages according to the 
-    method by which they are sent and received.  An account may either transmit messages 
+    \inmodule QtMessaging
+
+    \ingroup messaging
+    \since 1.0
+
+    A QMessageAccount is a logical entity that groups messages according to the
+    method by which they are sent and received.  An account may either transmit messages
     receive messages or both.
-    
-    The QMessageAccount class is used for accessing properties of the account related 
-    to dealing with the account's folders and messages, rather than for modifying 
+
+    The QMessageAccount class is used for accessing properties of the account related
+    to dealing with the account's folders and messages, rather than for modifying
     the account itself.
-    
+
     \sa QMessageManager::account()
 */
 
 /*!
     \fn QMessageAccount::QMessageAccount()
-    
+
     Creates an empty and invalid account object.
 */
 
 /*!
     \fn QMessageAccount::QMessageAccount(const QMessageAccountId &id)
 
-    
-    Convenience constructor that creates a QMessageAccount by loading the data from the messaging 
-    store as specified by the QMessageAccountId \a id. If the account does not exist in the 
+
+    Convenience constructor that creates a QMessageAccount by loading the data from the messaging
+    store as specified by the QMessageAccountId \a id. If the account does not exist in the
     store, then this constructor will create an empty and invalid QMessageAccount.
-    
+
     \sa QMessageManager::account()
 */
 
@@ -83,37 +84,37 @@
     Constructs a copy of \a other.
 */
 
-/*! 
+/*!
     \internal
     \fn QMessageAccount::operator=(const QMessageAccount& other)
 */
 
 /*!
     \fn QMessageAccount::~QMessageAccount()
-    
+
     Destroys the account object.
 */
 
 /*!
     \fn QMessageAccount::id() const
-    
+
     Returns the identifier for this account.
 */
 
 /*!
     \fn QMessageAccount::name() const
-    
+
     Returns the name of the account for display purposes.
 */
 
 /*!
     \fn QMessageAccount::messageTypes() const
-    
+
     Returns the types of messages this account handles.
 */
 
 /*!
     \fn QMessageAccount::defaultAccount(QMessage::Type type)
-    
+
     Returns the default account for messages of type \a type.
 */
