@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -49,24 +49,25 @@ QTM_BEGIN_NAMESPACE
 
     \brief The QMessageAddress class provides an interface for a message address.
 
-    
+
     \inmodule QtMessaging
-    
+
     \ingroup messaging
-   
+    \since 1.0
+
     A message address consists of an addressee string and a type.
-*/    
+*/
 
 /*!
     \enum QMessageAddress::Type
 
     This enum type is used to describe the type of a message address.
-    
+
     \value System             A system address.
     \value Phone              A telephony address.
     \value Email              An Email, Internet Message Format address.
     \value InstantMessage     An Instant Messaging address.
-    
+
     \sa type(), setType()
 */
 
@@ -176,14 +177,14 @@ void QMessageAddress::setType(Type type)
     * \a name is set to the name part of the email address.
     * \a address is set to the address part of the email address.
     * \a suffix is set to the suffix part of the email address.
-    
-    If the starting delimeter between the name and address part of the email address is found 
+
+    If the starting delimeter between the name and address part of the email address is found
     then * \a startDelimeterFound is set to true; otherwise * \a startDelimeterFound is set to false;
 
     If the starting delimeter is not found, then the parsing is ambiguous and both * \a name and
     * \a address will be set to the input \a emailAddress.
 
-    If the ending delimeter of the address part of the email address is found 
+    If the ending delimeter of the address part of the email address is found
     then * \a endDelimeterFound is set to true; otherwise * \a endDelimeterFound is set to false;
 
 */
