@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -83,6 +83,7 @@ public:
 
     QMailTransmitAction _transmit;
     QMailRetrievalAction _retrieval;
+    QMailStorageAction _storage;
     QMailServiceAction *_active;
     QMessageManager::Error _error;
     bool _activeStoreAction;
@@ -108,6 +109,7 @@ signals:
 protected slots:
     void transmitActivityChanged(QMailServiceAction::Activity a);
     void retrievalActivityChanged(QMailServiceAction::Activity a);
+    void storageActivityChanged(QMailServiceAction::Activity a);
     void statusChanged(const QMailServiceAction::Status &s);
     void completed();
     void reportMatchingIds();
@@ -132,6 +134,9 @@ QMessageServicePrivate::QMessageServicePrivate()
 
     connect(&_retrieval, SIGNAL(activityChanged(QMailServiceAction::Activity)), this, SLOT(retrievalActivityChanged(QMailServiceAction::Activity)));
     connect(&_retrieval, SIGNAL(statusChanged(QMailServiceAction::Status)), this, SLOT(statusChanged(QMailServiceAction::Status)));
+
+    connect(&_storage, SIGNAL(activityChanged(QMailServiceAction::Activity)), this, SLOT(storageActivityChanged(QMailServiceAction::Activity)));
+    connect(&_storage, SIGNAL(statusChanged(QMailServiceAction::Status)), this, SLOT(statusChanged(QMailServiceAction::Status)));
 }
 
 bool QMessageServicePrivate::isBusy() const
@@ -202,6 +207,7 @@ void QMessageServicePrivate::retrievalActivityChanged(QMailServiceAction::Activi
     emit stateChanged(convert(a));
 }
 
+
 void QMessageServicePrivate::completed()
 {
     _activeStoreAction = false;
@@ -443,6 +449,15 @@ bool QMessageService::send(QMessage &message)
     // Mark this message as outgoing
     msg->setStatus(QMailMessage::Outbox, true);
 
+#ifdef Q_WS_MEEGO
+    QMessageAccount account(message.parentAccountId());
+    if (account.messageTypes() & QMessage::Sms) {
+        d_ptr->_error = QMessageManager::FrameworkFault;
+        qWarning() << "Sending SMS is not supported on this platform.";
+        return false;
+    }
+#endif
+
     if (msg->id().isValid()) {
         // Update the message
         if (!mailStoreInstance()->updateMessage(msg)) {
@@ -580,6 +595,40 @@ bool QMessageService::exportUpdates(const QMessageAccountId &id)
     return true;
 }
 
+void QMessageServicePrivate::storageActivityChanged(QMailServiceAction::Activity a)
+{
+    if ((a == QMailServiceAction::Failed) && (_error == QMessageManager::NoError)) {
+        _error = QMessageManager::RequestIncomplete;
+    }
+
+    emit stateChanged(convert(a));
+}
+
+bool QMessageService::moveMessages(const QMessageIdList &messageIds, const QMessageFolderId &toFolderId)
+{
+    if (d_ptr->isBusy()) {
+        return false;
+    }
+    d_ptr->_active = 0;
+    d_ptr->_error = QMessageManager::NoError;
+    d_ptr->_active = &d_ptr->_storage;
+    d_ptr->_storage.moveMessages(convert(messageIds), convert(toFolderId));
+    return true;
+}
+
+bool QMessageService::synchronize(const QMessageAccountId &id)
+{
+    if (d_ptr->isBusy()) {
+        return false;
+    }
+
+    d_ptr->_active = 0;
+    d_ptr->_error = QMessageManager::NoError;
+    d_ptr->_active = &d_ptr->_retrieval;
+    d_ptr->_retrieval.synchronize(convert(id), 1);
+    return true;
+}
+
 QMessageService::State QMessageService::state() const
 {
     if (d_ptr->_active) {
