@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -85,55 +85,51 @@ bool QMessageServicePrivate::sendMMS(QMessage &message)
 bool QMessageServicePrivate::sendEmail(QMessage &message)
 {
     switch (idType(message.parentAccountId())) {
-        case EngineTypeFreestyle:
+    case EngineTypeFreestyle:
 #ifdef FREESTYLEMAILUSED
-            bool retVal = CFSEngine::instance()->sendEmail(message);
-            if (retVal == true) {
-                setFinished(retVal);
-            }
-            return retVal;
+        {
+        bool retVal = CFSEngine::instance()->sendEmail(message);
+        if (retVal == true) {
+             setFinished(retVal);
+        }
+        return retVal;
+        }
 #else
-            return false;
+        return false;
 #endif
-            break;
-        case EngineTypeMTM:
-        default:
-            return CMTMEngine::instance()->sendEmail((QMessageServicePrivate&)*this, message);
-            break;
+    case EngineTypeMTM:
+    default:
+        return CMTMEngine::instance()->sendEmail((QMessageServicePrivate&)*this, message);
     }
 }
 
 bool QMessageServicePrivate::show(const QMessageId& id)
 {
     switch (idType(id)) {
-        case EngineTypeFreestyle:
+    case EngineTypeFreestyle:
 #ifdef FREESTYLEMAILUSED
-            return CFSEngine::instance()->showMessage(id);
+        return CFSEngine::instance()->showMessage(id);
 #else
-            return false;
+        return false;
 #endif
-            break;
-        case EngineTypeMTM:
-        default:
-            return CMTMEngine::instance()->showMessage(id);
-            break;
+    case EngineTypeMTM:
+    default:
+        return CMTMEngine::instance()->showMessage(id);
     }
 }
 
 bool QMessageServicePrivate::compose(const QMessage &message)
 {
     switch (idType(message.parentAccountId())) {
-        case EngineTypeFreestyle:
+    case EngineTypeFreestyle:
 #ifdef FREESTYLEMAILUSED
-            return CFSEngine::instance()->composeMessage(message);
+        return CFSEngine::instance()->composeMessage(message);
 #else
-            return false;
+        return false;
 #endif
-            break;
-        case EngineTypeMTM:
-        default:
-            return CMTMEngine::instance()->composeMessage(message);
-            break;
+    case EngineTypeMTM:
+    default:
+        return CMTMEngine::instance()->composeMessage(message);
     }
 }
 
@@ -206,54 +202,72 @@ bool QMessageServicePrivate::countMessages(const QMessageFilter &filter)
     return _active;
 }
 
+bool QMessageServicePrivate::moveMessages(const QMessageIdList &messageIds, const QMessageFolderId &toFolderId)
+{
+    bool ret = false;
+    // it'a already verified that messageIds has elements and they are of same type
+    switch (idType(messageIds.at(0))) {
+        case EngineTypeFreestyle: {
+#ifdef FREESTYLEMAILMAPI12USED
+            ret = CFSEngine::instance()->moveMessages( *this, messageIds, toFolderId );
+#else
+            // not supported
+            ret = false;
+#endif
+            break;
+        }
+        case EngineTypeMTM: // flow through
+        default: {
+            // not supported
+            ret = false;
+            break;
+        }
+    }
+    return ret;
+}
+
 bool QMessageServicePrivate::retrieve(const QMessageId &messageId, const QMessageContentContainerId &id)
 {
     switch (idType(messageId)) {
-        case EngineTypeFreestyle:
+    case EngineTypeFreestyle:
 #ifdef FREESTYLEMAILUSED
-            return CFSEngine::instance()->retrieve(*this, messageId, id);
+        return CFSEngine::instance()->retrieve(*this, messageId, id);
 #else
-            return false;
+        return false;
 #endif
-            break;
-        case EngineTypeMTM:
-        default:
-            return CMTMEngine::instance()->retrieve(*this, messageId, id);
-            break;
+    case EngineTypeMTM:
+    default:
+        return CMTMEngine::instance()->retrieve(*this, messageId, id);
     }
 }
 
 bool QMessageServicePrivate::retrieveBody(const QMessageId& id)
 {
     switch (idType(id)) {
-        case EngineTypeFreestyle:
+    case EngineTypeFreestyle:
 #ifdef FREESTYLEMAILUSED
-            return CFSEngine::instance()->retrieveBody(*this, id);
+        return CFSEngine::instance()->retrieveBody(*this, id);
 #else
-            return false;
+        return false;
 #endif
-            break;
-        case EngineTypeMTM:
-        default:
-            return CMTMEngine::instance()->retrieveBody(*this, id);
-            break;
+    case EngineTypeMTM:
+    default:
+        return CMTMEngine::instance()->retrieveBody(*this, id);
     }
 }
 
 bool QMessageServicePrivate::retrieveHeader(const QMessageId& id)
 {
     switch (idType(id)) {
-        case EngineTypeFreestyle:
+    case EngineTypeFreestyle:
 #ifdef FREESTYLEMAILUSED
-            return CFSEngine::instance()->retrieveHeader(*this, id);
+        return CFSEngine::instance()->retrieveHeader(*this, id);
 #else
-            return false;
+        return false;
 #endif
-            break;
-        case EngineTypeMTM:
-        default:
-            return CMTMEngine::instance()->retrieveHeader(*this, id);
-            break;
+    case EngineTypeMTM:
+    default:
+        return CMTMEngine::instance()->retrieveHeader(*this, id);
     }
 }
 
@@ -310,18 +324,18 @@ void QMessageServicePrivate::messagesCounted(int count)
     }
 }
 
-bool QMessageServicePrivate::exportUpdates(const QMessageAccountId &id)
+bool QMessageServicePrivate::synchronize(const QMessageAccountId &id)
 {
     switch (idType(id)) {
-            case EngineTypeFreestyle:
+    case EngineTypeFreestyle:
 #ifdef FREESTYLEMAILUSED
-                return CFSEngine::instance()->exportUpdates(id);
+        return CFSEngine::instance()->synchronize(*this, id);
 #else
-                return false;
+        return false;
 #endif
-            case EngineTypeMTM:
-            default:
-                return CMTMEngine::instance()->exportUpdates(*this, id);
+    case EngineTypeMTM:
+    default:
+        return CMTMEngine::instance()->exportUpdates(*this, id);
     }
 }
 
@@ -639,6 +653,50 @@ bool QMessageService::show(const QMessageId& id)
 }
 
 bool QMessageService::exportUpdates(const QMessageAccountId &id)
+{
+    return synchronize(id);
+}
+
+bool QMessageService::moveMessages(const QMessageIdList &messageIds, const QMessageFolderId &toFolderId)
+{
+    if (d_ptr->_active) {
+        return false;
+    }
+    
+    if (!toFolderId.isValid()) {
+        d_ptr->_error = QMessageManager::InvalidId;
+        return false;
+    }
+
+    const int count = messageIds.count();
+    if ( count == 0) {
+        return false;
+    }
+
+    // verify that messages are of same type and valid
+    EngineType expectedType = idType(messageIds[0]);
+    for( int i = 1; i < count; ++i ) {
+        if( idType( messageIds[i] ) != expectedType || 
+            !messageIds[i].isValid() ) {
+            // invalid message id or inconsistent type found
+            d_ptr->_error = QMessageManager::InvalidId;
+            return false;
+        }
+    }
+
+    d_ptr->_active = true;
+    d_ptr->_error = QMessageManager::NoError;
+    d_ptr->_state = QMessageService::ActiveState;
+    emit stateChanged(d_ptr->_state);
+
+    bool retVal = d_ptr->moveMessages( messageIds, toFolderId );
+    if (!retVal) {
+        d_ptr->setFinished(retVal);
+    }
+    return retVal;
+}
+
+bool QMessageService::synchronize(const QMessageAccountId &id)
 {
     if (d_ptr->_active) {
         return false;
@@ -656,7 +714,7 @@ bool QMessageService::exportUpdates(const QMessageAccountId &id)
     d_ptr->_state = QMessageService::ActiveState;
     emit stateChanged(d_ptr->_state);
     
-    retVal = d_ptr->exportUpdates(id);
+    retVal = d_ptr->synchronize(id);
     if (retVal == false) {
         d_ptr->setFinished(retVal);
     }
