@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -46,7 +46,7 @@
 #include "qmessagefolderid_p.h"
 #include "qmessageaccountid_p.h"
 #include "qmessage_p.h"
-#include "qmessagestore_p.h"
+#include "qmessagestore_p_p.h"
 #include "qmessagecontentcontainer_p.h"
 #include "qmessagecontentcontainerid_p.h"
 #include <QDebug>
@@ -390,7 +390,7 @@ bool QMessageServicePrivate::send(const QMessage& message, bool showComposer)
 
     QMessage outgoing(message);
 
-    //ensure the message is marked read otherwise MapiForm displays the message as incomming
+    //ensure the message is marked read otherwise MapiForm displays the message as incoming
     outgoing.setStatus(QMessage::Read,true);
 
     //set default account if unset
@@ -630,7 +630,7 @@ bool QMessageServicePrivate::markForDownload(const QMessageId& id, bool includeA
 
         mapiRelease(message);
 
-        //TODO investigate possiblity of interacting with mapi transport directly
+        //TODO investigate possibility of interacting with mapi transport directly
         /*
         QString transportName = mapiStore->transportName();
         if(transportName.isEmpty())
@@ -1008,6 +1008,21 @@ bool QMessageService::exportUpdates(const QMessageAccountId &id)
     return false;
 }
 
+bool QMessageService::synchronize(const QMessageAccountId& id)
+{
+    Q_UNUSED(id);
+
+    if(d_ptr->_active) {
+        qWarning() << "Service is currently busy";
+        return false;
+    }
+
+    d_ptr->_error = QMessageManager::NotYetImplemented;
+    d_ptr->setFinished(false);
+
+    return false;
+}
+
 QMessageService::State QMessageService::state() const
 {
     return d_ptr->_state;
