@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -81,7 +81,10 @@ class CAsynchronousMTMOperation;
 
 struct MessageEvent
 {
+    int sessionEvent;
+    TUid msgType;
     QMessageStorePrivate::NotificationType notificationType;
+    TMsvId folderId;
     TMsvId messageId;
     QMessageManager::NotificationFilterIdSet matchingFilters;
     bool unfiltered;
@@ -169,7 +172,9 @@ public:
                                         const QMessageFilter& filter);
     void unregisterNotificationFilter(QMessageManager::NotificationFilterId notificationFilterId);
 
-    void notification(TMsvSessionEvent aEvent, TUid aMsgType, TMsvId aFolderId, TMsvId aMessageId);
+    bool handleMessageSendingNotifications(TMsvSessionEvent aEvent, TUid aMsgType, TMsvId aFolderId,
+                                           TMsvId aMessageId, TUint sendingState);
+    void notification(TMsvSessionEvent aEvent, TUid aMsgType, TMsvId aFolderId, TMsvId aMessageId, CMsvEntry* pEntry);
     void filterAndOrderMessagesReady(bool success, int operationId, QMessageIdList ids, int numberOfHandledFilters,
                                      bool resultSetOrdered);
     
@@ -223,12 +228,10 @@ private:
     
     bool removeMessageL(const QMessageId &id, QMessageManager::RemovalOption option);
     void copyMessageL(TMsvId aMessageId, TMsvId aFolder);
-    QMessage messageL(const QMessageId& id) const;
-    QMessage smsMessageL(CMsvEntry& receivedEntry, long int messageId) const;
-    QMessage mmsMessageL(CMsvEntry& receivedEntry, long int messageId) const;
-    QMessage emailMessageL(CMsvEntry& receivedEntry, long int messageId) const;
-    QMessage pop3MessageL(CMsvEntry& receivedEntry, long int messageId) const;
-    QMessage imap4MessageL(CMsvEntry& receivedEntry, long int messageId) const;
+    QMessage messageL(const QMessageId& id, bool onlyBasicHeaderFields = false) const;
+    QMessage smsMessageL(CMsvEntry& receivedEntry, long int messageId, bool onlyBasicHeaderFields = false) const;
+    QMessage mmsMessageL(CMsvEntry& receivedEntry, long int messageId, bool onlyBasicHeaderFields = false) const;
+    QMessage emailMessageL(CMsvEntry& receivedEntry, long int messageId, bool onlyBasicHeaderFields = false) const;
     bool composeSMSL(const QMessage &message);
     bool composeMMSL(const QMessage &message);
     bool composeEmailL(const QMessage &message);
@@ -309,19 +312,23 @@ private:
     
     QMessageManager::NotificationFilterId _filterId;
     QMap<QMessageManager::NotificationFilterId, QMessageFilter> _filters;
+    bool iBasicFieldsAreEnoughForFiltering;
     
     mutable QHash<QString, QMessageAccount> iAccounts;
     mutable QMessageAccountId idefaultEmailAccountId;
     
     int                 iDeliveryTriesCounter;
     QList<MessageEvent> iUndeliveredMessageEvents;
+    QList<MessageEvent> iPendingMessageEvents;
     RTimer              iTimer; // Timer used for delaying delivering of received
                                 // messages until messages are ready to be read
+    QMap<TMsvId, TMsvSessionEvent>  iMessagesInPreparation;
     TMsvId iMessageId;
     bool iNewMessage;
     
     mutable int iOperationIds;
     mutable QList<MessageQueryInfo> iMessageQueries;
+    mutable QMap<QMessageServicePrivate*, CAsynchronousMTMOperation*> m_mtmOperations;
     mutable QList<PendingSend> iPendingSends;
     
     mutable QMessageAccountSortOrder iCurrentAccountOrdering;
@@ -446,6 +453,8 @@ private: // Data
     CMsvOperation*      ipMsvOperation;
     
     bool                isActive;
+
+    friend class CMTMEngine;
 };
 
 QTM_END_NAMESPACE
