@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -480,12 +480,26 @@ bool DevSoundWrapper::start()
 bool DevSoundWrapper::pause()
 {
     Q_ASSERT(StateInitialized == m_state);
+#ifndef PRE_S60_52_PLATFORM
+    if (m_mode == QAudio::AudioOutput ) {
+        m_devsound->Pause();
+        return true;
+    } else {
+        const bool canPause = isResumeSupported();
+        if (canPause)
+            m_devsound->Pause();
+        else
+            stop();
+        return canPause;
+    }
+#else
     const bool canPause = isResumeSupported();
     if (canPause)
         m_devsound->Pause();
     else
         stop();
     return canPause;
+#endif
 }
 
 void DevSoundWrapper::resume()
@@ -636,7 +650,12 @@ void DevSoundWrapper::DeviceMessage(TUid aMessageType, const TDesC8 &aMsg)
     // Ignore this callback.
 }
 
-
+#ifndef PRE_S60_52_PLATFORM
+int DevSoundWrapper::flush()
+{
+    return m_devsound->EmptyBuffers();
+}
+#endif
 } // namespace SymbianAudio
 
 QT_END_NAMESPACE
