@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -71,7 +71,6 @@ QAudioInputPrivate::QAudioInputPrivate(const QByteArray &device)
     period_time = 20000;
     totalTimeValue = 0;
     intervalTime = 1000;
-    audioBuffer = 0;
     errorState = QAudio::NoError;
     deviceState = QAudio::StoppedState;
     audioSource = 0;
@@ -439,8 +438,7 @@ bool QAudioInputPrivate::open()
     snd_pcm_sw_params(handle, swparams);
 
     // Step 4: Prepare audio
-    if(audioBuffer == 0)
-        audioBuffer = new char[buffer_size];
+    ringBuffer.resize(buffer_size);
     snd_pcm_prepare( handle );
     snd_pcm_start(handle);
 
@@ -469,8 +467,6 @@ void QAudioInputPrivate::close()
         snd_pcm_drop( handle );
         snd_pcm_close( handle );
         handle = 0;
-        delete [] audioBuffer;
-        audioBuffer=0;
     }
 }
 
@@ -501,79 +497,110 @@ int QAudioInputPrivate::bytesReady() const
 
 qint64 QAudioInputPrivate::read(char* data, qint64 len)
 {
-    Q_UNUSED(len)
-
     // Read in some audio data and write it to QIODevice, pull mode
     if ( !handle )
         return 0;
 
-    bytesAvailable = checkBytesReady();
+    int bytesRead = 0;
+    int bytesInRingbufferBeforeRead = ringBuffer.bytesOfDataInBuffer();
 
-    if (bytesAvailable < 0) {
-        // bytesAvailable as negative is error code, try to recover from it.
-        xrun_recovery(bytesAvailable);
-        bytesAvailable = checkBytesReady();
-        if (bytesAvailable < 0) {
-            // recovery failed must stop and set error.
-            close();
-            errorState = QAudio::IOError;
-            deviceState = QAudio::StoppedState;
-            emit stateChanged(deviceState);
-            return 0;
-        }
-    }
+    if (ringBuffer.bytesOfDataInBuffer() < len) {
 
-    int count=0, err = 0;
-    while(count < 5) {
-        int chunks = bytesAvailable/period_size;
-        int frames = chunks*period_frames;
-        if(frames > (int)buffer_frames)
-            frames = buffer_frames;
-        int readFrames = snd_pcm_readi(handle, audioBuffer, frames);
-        if (readFrames >= 0) {
-            err = snd_pcm_frames_to_bytes(handle, readFrames);
-#ifdef DEBUG_AUDIO
-            qDebug()<<QString::fromLatin1("read in bytes = %1 (frames=%2)").arg(err).arg(readFrames).toLatin1().constData();
-#endif
-            break;
-        } else if((readFrames == -EAGAIN) || (readFrames == -EINTR)) {
-            errorState = QAudio::IOError;
-            err = 0;
-            break;
-        } else {
-            if(readFrames == -EPIPE) {
-                errorState = QAudio::UnderrunError;
-                err = snd_pcm_prepare(handle);
-            } else if(readFrames == -ESTRPIPE) {
-                err = snd_pcm_prepare(handle);
-            }
-            if(err != 0) break;
-        }
-        count++;
-    }
-    if(err > 0) {
-        // got some send it onward
-#ifdef DEBUG_AUDIO
-        qDebug()<<"frames to write to QIODevice = "<<
-            snd_pcm_bytes_to_frames( handle, (int)err )<<" ("<<err<<") bytes";
-#endif
-        if(deviceState != QAudio::ActiveState && deviceState != QAudio::IdleState)
-            return 0;
-        if (pullMode) {
-            qint64 l = audioSource->write(audioBuffer,err);
-            if(l < 0) {
+        // bytesAvaiable is saved as a side effect of checkBytesReady().
+        int bytesToRead = checkBytesReady();
+
+        if (bytesToRead < 0) {
+            // bytesAvailable as negative is error code, try to recover from it.
+            xrun_recovery(bytesToRead);
+            bytesToRead = checkBytesReady();
+            if (bytesToRead < 0) {
+                // recovery failed must stop and set error.
                 close();
                 errorState = QAudio::IOError;
                 deviceState = QAudio::StoppedState;
                 emit stateChanged(deviceState);
-            } else if(l == 0) {
+                return 0;
+            }
+        }
+
+        bytesToRead = qMin<qint64>(len, bytesToRead);
+        bytesToRead = qMin<qint64>(ringBuffer.freeBytes(), bytesToRead);
+        bytesToRead -= bytesToRead % period_size;
+
+        int count=0;
+        int err = 0;
+        while(count < 5 && bytesToRead > 0) {
+            char buffer[bytesToRead];
+            int chunks = bytesToRead / period_size;
+            int frames = chunks * period_frames;
+            if (frames > (int)buffer_frames)
+                frames = buffer_frames;
+
+            int readFrames = snd_pcm_readi(handle, buffer, frames);
+
+            if (readFrames >= 0) {
+                bytesRead = snd_pcm_frames_to_bytes(handle, readFrames);
+                ringBuffer.write(buffer, bytesRead);
+#ifdef DEBUG_AUDIO
+                qDebug() << QString::fromLatin1("read in bytes = %1 (frames=%2)").arg(bytesRead).arg(readFrames).toLatin1().constData();
+#endif
+                break;
+            } else if((readFrames == -EAGAIN) || (readFrames == -EINTR)) {
+                errorState = QAudio::IOError;
+                err = 0;
+                break;
+            } else {
+                if(readFrames == -EPIPE) {
+                    errorState = QAudio::UnderrunError;
+                    err = snd_pcm_prepare(handle);
+                } else if(readFrames == -ESTRPIPE) {
+                    err = snd_pcm_prepare(handle);
+                }
+                if(err != 0) break;
+            }
+            count++;
+        }
+
+    }
+
+    bytesRead += bytesInRingbufferBeforeRead;
+
+    if (bytesRead > 0) {
+        // got some send it onward
+#ifdef DEBUG_AUDIO
+        qDebug() << "frames to write to QIODevice = " <<
+            snd_pcm_bytes_to_frames( handle, (int)bytesRead ) << " (" << bytesRead << ") bytes";
+#endif
+        if (deviceState != QAudio::ActiveState && deviceState != QAudio::IdleState)
+            return 0;
+
+        if (pullMode) {
+            qint64 l = 0;
+            qint64 bytesWritten = 0;
+            while (ringBuffer.bytesOfDataInBuffer() > 0) {
+                l = audioSource->write(ringBuffer.availableData(), ringBuffer.availableDataBlockSize());
+                if (l > 0) {
+                    ringBuffer.readBytes(l);
+                    bytesWritten += l;
+                } else {
+                    break;
+                }
+            }
+
+            if (l < 0) {
+                close();
+                errorState = QAudio::IOError;
+                deviceState = QAudio::StoppedState;
+                emit stateChanged(deviceState);
+            } else if (l == 0 && bytesWritten == 0) {
                 if (deviceState != QAudio::IdleState) {
                     errorState = QAudio::NoError;
                     deviceState = QAudio::IdleState;
                     emit stateChanged(deviceState);
                 }
             } else {
-                totalTimeValue += err;
+                bytesAvailable -= bytesWritten;
+                totalTimeValue += bytesWritten;
                 resuming = false;
                 if (deviceState != QAudio::ActiveState) {
                     errorState = QAudio::NoError;
@@ -581,20 +608,29 @@ qint64 QAudioInputPrivate::read(char* data, qint64 len)
                     emit stateChanged(deviceState);
                 }
             }
-            return l;
 
+            return bytesWritten;
         } else {
-            memcpy(data,audioBuffer,err);
-            totalTimeValue += err;
+            while (ringBuffer.bytesOfDataInBuffer() > 0) {
+                int size = ringBuffer.availableDataBlockSize();
+                memcpy(data, ringBuffer.availableData(), size);
+                data += size;
+                ringBuffer.readBytes(size);
+            }
+
+            bytesAvailable -= bytesRead;
+            totalTimeValue += bytesRead;
             resuming = false;
             if (deviceState != QAudio::ActiveState) {
                 errorState = QAudio::NoError;
                 deviceState = QAudio::ActiveState;
                 emit stateChanged(deviceState);
             }
-            return err;
+
+            return bytesRead;
         }
     }
+
     return 0;
 }
 
@@ -680,7 +716,7 @@ bool QAudioInputPrivate::deviceReady()
 {
     if(pullMode) {
         // reads some audio data and writes it to QIODevice
-        read(0,0);
+        read(0, buffer_size);
     } else {
         // emits readyRead() so user will call read() on QIODevice to get some audio data
         InputPrivate* a = qobject_cast<InputPrivate*>(audioSource);
@@ -725,6 +761,8 @@ void QAudioInputPrivate::reset()
 {
     if(handle)
         snd_pcm_reset(handle);
+    stop();
+    bytesAvailable = 0;
 }
 
 void QAudioInputPrivate::drain()
@@ -759,6 +797,71 @@ void InputPrivate::trigger()
     emit readyRead();
 }
 
+RingBuffer::RingBuffer() :
+        m_head(0),
+        m_tail(0)
+{
+}
+
+void RingBuffer::resize(int size)
+{
+    m_data.resize(size);
+}
+
+int RingBuffer::bytesOfDataInBuffer() const
+{
+    if (m_head < m_tail)
+        return m_tail - m_head;
+    else if (m_tail < m_head)
+        return m_data.size() + m_tail - m_head;
+    else
+        return 0;
+}
+
+int RingBuffer::freeBytes() const
+{
+    if (m_head > m_tail)
+        return m_head - m_tail - 1;
+    else if (m_tail > m_head)
+        return m_data.size() - m_tail + m_head - 1;
+    else
+        return m_data.size() - 1;
+}
+
+const char *RingBuffer::availableData() const
+{
+    return (m_data.constData() + m_head);
+}
+
+int RingBuffer::availableDataBlockSize() const
+{
+    if (m_head > m_tail)
+        return m_data.size() - m_head;
+    else if (m_tail > m_head)
+        return m_tail - m_head;
+    else
+        return 0;
+}
+
+void RingBuffer::readBytes(int bytes)
+{
+    m_head = (m_head + bytes) % m_data.size();
+}
+
+void RingBuffer::write(char *data, int len)
+{
+    if (m_tail + len < m_data.size()) {
+        memcpy(m_data.data() + m_tail, data, len);
+        m_tail += len;
+    } else {
+        int bytesUntilEnd = m_data.size() - m_tail;
+        memcpy(m_data.data() + m_tail, data, bytesUntilEnd);
+        if (len - bytesUntilEnd > 0)
+            memcpy(m_data.data(), data + bytesUntilEnd, len - bytesUntilEnd);
+        m_tail = len - bytesUntilEnd;
+    }
+}
+
 QT_END_NAMESPACE
 
 #include "moc_qaudioinput_alsa_p.cpp"
