@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -53,7 +47,7 @@
 // of other Qt classes.  This header file may change from version to
 // version without notice, or even be removed.
 //
-// We mean it.
+// INTERNAL USE ONLY: Do NOT use for any other purpose.
 //
 
 
@@ -77,6 +71,7 @@ QAudioInputPrivate::QAudioInputPrivate(const QByteArray &device)
     pullMode = true;
     resuming = false;
     finished = false;
+    waveBlockOffset = 0;
 }
 
 QAudioInputPrivate::~QAudioInputPrivate()
@@ -236,18 +231,45 @@ bool QAudioInputPrivate::open()
     qDebug()<<now.second()<<"s "<<now.msec()<<"ms :open()";
 #endif
     header = 0;
-    if(buffer_size == 0) {
-        // Default buffer size, 200ms, default period size is 40ms
-        buffer_size = settings.frequency()*settings.channels()*(settings.sampleSize()/8)*0.2;
-	period_size = buffer_size/5;
+
+    period_size = 0;
+
+    if (!settings.isValid()) {
+        qWarning("QAudioInput: open error, invalid format.");
+    } else if (settings.channelCount() <= 0) {
+        qWarning("QAudioInput: open error, invalid number of channels (%d).",
+                 settings.channelCount());
+    } else if (settings.sampleSize() <= 0) {
+        qWarning("QAudioInput: open error, invalid sample size (%d).",
+                 settings.sampleSize());
+    } else if (settings.frequency() < 8000 || settings.frequency() > 48000) {
+        qWarning("QAudioInput: open error, frequency out of range (%d).", settings.frequency());
+    } else if (buffer_size == 0) {
+
+        buffer_size
+                = (settings.frequency()
+                * settings.channelCount()
+                * settings.sampleSize()
+#ifndef Q_OS_WINCE  // Default buffer size, 200ms, default period size is 40ms
+                + 39) / 40;
+        period_size = buffer_size / 5;
     } else {
-        period_size = buffer_size/5;
-    }
-#ifdef Q_OS_WINCE
-    // For wince reduce size to 40ms for buffer size and 20ms period
-    buffer_size = settings.sampleRate()*settings.channelCount()*(settings.sampleSize()/8)*0.04;
-    period_size = buffer_size/2;
+        period_size = buffer_size / 5;
+#else               // For wince reduce size to 40ms for buffer size and 20ms period
+                + 199) / 200;
+        period_size = buffer_size / 2;
+    } else {
+        period_size = buffer_size / 2;
 #endif
+    }
+
+    if (period_size == 0) {
+        errorState = QAudio::OpenError;
+        deviceState = QAudio::StoppedState;
+        emit stateChanged(deviceState);
+        return false;
+    }
+
     timeStamp.restart();
     elapsedTimeOffset = 0;
     wfx.nSamplesPerSec = settings.frequency();
@@ -259,24 +281,11 @@ bool QAudioInputPrivate::open()
     wfx.nBlockAlign = (wfx.wBitsPerSample >> 3) * wfx.nChannels;
     wfx.nAvgBytesPerSec = wfx.nBlockAlign * wfx.nSamplesPerSec;
 
-    UINT_PTR devId = WAVE_MAPPER;
+    QDataStream ds(&m_device, QIODevice::ReadOnly);
+    quint32 deviceId;
+    ds >> deviceId;
 
-    WAVEINCAPS wic;
-    unsigned long iNumDevs,ii;
-    iNumDevs = waveInGetNumDevs();
-    for(ii=0;ii<iNumDevs;ii++) {
-        if(waveInGetDevCaps(ii, &wic, sizeof(WAVEINCAPS))
-	    == MMSYSERR_NOERROR) {
-	    QString tmp;
-            tmp = QString::fromWCharArray(wic.szPname);
-	    if(tmp.compare(QLatin1String(m_device)) == 0) {
-	        devId = ii;
-		break;
-	    }
-	}
-    }
-
-    if(waveInOpen(&hWaveIn, devId, &wfx,
+    if (waveInOpen(&hWaveIn, UINT_PTR(deviceId), &wfx,
                 (DWORD_PTR)&waveInProc,
                 (DWORD_PTR) this,
                 CALLBACK_FUNCTION) != MMSYSERR_NOERROR) {
@@ -287,6 +296,7 @@ bool QAudioInputPrivate::open()
         return false;
     }
     waveBlocks = allocateBlocks(period_size, buffer_size/period_size);
+    waveBlockOffset = 0;
 
     if(waveBlocks == 0) {
         errorState = QAudio::OpenError;
@@ -300,8 +310,6 @@ bool QAudioInputPrivate::open()
     waveFreeBlockCount = buffer_size/period_size;
     mutex.unlock();
 
-    waveCurrentBlock = 0;
-
     for(int i=0; i<buffer_size/period_size; i++) {
         result = waveInAddBuffer(hWaveIn, &waveBlocks[i], sizeof(WAVEHDR));
         if(result != MMSYSERR_NOERROR) {
@@ -371,8 +379,8 @@ qint64 QAudioInputPrivate::read(char* data, qint64 len)
         // Read in some audio data
         if(waveBlocks[header].dwBytesRecorded > 0 && waveBlocks[header].dwFlags & WHDR_DONE) {
             if(pullMode) {
-                l = audioSource->write(waveBlocks[header].lpData,
-                        waveBlocks[header].dwBytesRecorded);
+                l = audioSource->write(waveBlocks[header].lpData + waveBlockOffset,
+                        waveBlocks[header].dwBytesRecorded - waveBlockOffset);
 #ifdef DEBUG_AUDIO
                 qDebug()<<"IN: "<<waveBlocks[header].dwBytesRecorded<<", OUT: "<<l;
 #endif
@@ -387,7 +395,7 @@ qint64 QAudioInputPrivate::read(char* data, qint64 len)
                     errorState = QAudio::IOError;
 
                 } else {
-                    totalTimeValue += waveBlocks[header].dwBytesRecorded;
+                    totalTimeValue += l;
                     errorState = QAudio::NoError;
                     if (deviceState != QAudio::ActiveState) {
                         deviceState = QAudio::ActiveState;
@@ -396,13 +404,16 @@ qint64 QAudioInputPrivate::read(char* data, qint64 len)
 		    resuming = false;
                 }
             } else {
+                l = qMin<qint64>(len, waveBlocks[header].dwBytesRecorded - waveBlockOffset);
                 // push mode
-                memcpy(p,waveBlocks[header].lpData,waveBlocks[header].dwBytesRecorded);
-                l = waveBlocks[header].dwBytesRecorded;
+                memcpy(p, waveBlocks[header].lpData + waveBlockOffset, l);
+
+                len -= l;
+
 #ifdef DEBUG_AUDIO
                 qDebug()<<"IN: "<<waveBlocks[header].dwBytesRecorded<<", OUT: "<<l;
 #endif
-                totalTimeValue += waveBlocks[header].dwBytesRecorded;
+                totalTimeValue += l;
                 errorState = QAudio::NoError;
                 if (deviceState != QAudio::ActiveState) {
                     deviceState = QAudio::ActiveState;
@@ -415,51 +426,58 @@ qint64 QAudioInputPrivate::read(char* data, qint64 len)
             break;
         }
 
-        waveInUnprepareHeader(hWaveIn,&waveBlocks[header], sizeof(WAVEHDR));
+        if (l < waveBlocks[header].dwBytesRecorded - waveBlockOffset) {
+            waveBlockOffset += l;
+            done = true;
+        } else {
+            waveBlockOffset = 0;
 
-        mutex.lock();
-        waveFreeBlockCount++;
-        mutex.unlock();
+            waveInUnprepareHeader(hWaveIn,&waveBlocks[header], sizeof(WAVEHDR));
 
-        waveBlocks[header].dwBytesRecorded=0;
-        waveBlocks[header].dwFlags = 0L;
-        result = waveInPrepareHeader(hWaveIn,&waveBlocks[header], sizeof(WAVEHDR));
-        if(result != MMSYSERR_NOERROR) {
+            mutex.lock();
+            waveFreeBlockCount++;
+            mutex.unlock();
+
+            waveBlocks[header].dwBytesRecorded=0;
+            waveBlocks[header].dwFlags = 0L;
             result = waveInPrepareHeader(hWaveIn,&waveBlocks[header], sizeof(WAVEHDR));
-            qWarning("QAudioInput: failed to prepare block %d,err=%d",header,result);
-            errorState = QAudio::IOError;
+            if(result != MMSYSERR_NOERROR) {
+                result = waveInPrepareHeader(hWaveIn,&waveBlocks[header], sizeof(WAVEHDR));
+                qWarning("QAudioInput: failed to prepare block %d,err=%d",header,result);
+                errorState = QAudio::IOError;
+
+                mutex.lock();
+                waveFreeBlockCount--;
+                mutex.unlock();
+
+                return 0;
+            }
+            result = waveInAddBuffer(hWaveIn, &waveBlocks[header], sizeof(WAVEHDR));
+            if(result != MMSYSERR_NOERROR) {
+                qWarning("QAudioInput: failed to setup block %d,err=%d",header,result);
+                errorState = QAudio::IOError;
+
+                mutex.lock();
+                waveFreeBlockCount--;
+                mutex.unlock();
+
+                return 0;
+            }
+            header++;
+            if(header >= buffer_size/period_size)
+                header = 0;
+            p+=l;
 
             mutex.lock();
-            waveFreeBlockCount--;
+            if(!pullMode) {
+                if(len < period_size || waveFreeBlockCount == buffer_size/period_size)
+                    done = true;
+            } else {
+                if(waveFreeBlockCount == buffer_size/period_size)
+                    done = true;
+            }
             mutex.unlock();
-
-            return 0;
         }
-        result = waveInAddBuffer(hWaveIn, &waveBlocks[header], sizeof(WAVEHDR));
-        if(result != MMSYSERR_NOERROR) {
-            qWarning("QAudioInput: failed to setup block %d,err=%d",header,result);
-            errorState = QAudio::IOError;
-
-            mutex.lock();
-            waveFreeBlockCount--;
-            mutex.unlock();
-
-            return 0;
-        }
-        header++;
-        if(header >= buffer_size/period_size)
-            header = 0;
-        p+=l;
-
-        mutex.lock();
-        if(!pullMode) {
-	    if(l+period_size > len && waveFreeBlockCount == buffer_size/period_size)
-	        done = true;
-	} else {
-	    if(waveFreeBlockCount == buffer_size/period_size)
-	        done = true;
-	}
-        mutex.unlock();
 
 	written+=l;
     }
@@ -488,9 +506,9 @@ void QAudioInputPrivate::resume()
         waveFreeBlockCount = buffer_size/period_size;
         mutex.unlock();
 
-        waveCurrentBlock = 0;
         header = 0;
 	resuming = true;
+        waveBlockOffset = 0;
         waveInStart(hWaveIn);
         QTimer::singleShot(20,this,SLOT(feedback()));
         emit stateChanged(deviceState);
@@ -564,7 +582,7 @@ bool QAudioInputPrivate::deviceReady()
 
     if(pullMode) {
         // reads some audio data and writes it to QIODevice
-        read(0,0);
+        read(0, buffer_size);
     } else {
         // emits readyRead() so user will call read() on QIODevice to get some audio data
 	InputPrivate* a = qobject_cast<InputPrivate*>(audioSource);
@@ -589,7 +607,9 @@ qint64 QAudioInputPrivate::elapsedUSecs() const
 
 void QAudioInputPrivate::reset()
 {
-    close();
+    stop();
+    if (period_size > 0)
+        waveFreeBlockCount = buffer_size / period_size;
 }
 
 InputPrivate::InputPrivate(QAudioInputPrivate* audio)
@@ -624,3 +644,6 @@ void InputPrivate::trigger()
 }
 
 QT_END_NAMESPACE
+
+#include "moc_qaudioinput_win32_p.cpp"
+
