@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -53,7 +47,7 @@
 // of other Qt classes.  This header file may change from version to
 // version without notice, or even be removed.
 //
-// We mean it.
+// INTERNAL USE ONLY: Do NOT use for any other purpose.
 //
 
 #include <QtCore/qcoreapplication.h>
@@ -162,7 +156,7 @@ int QAudioOutputPrivate::xrun_recovery(int err)
 
 int QAudioOutputPrivate::setFormat()
 {
-    snd_pcm_format_t pcmformat = SND_PCM_FORMAT_S16;
+    snd_pcm_format_t pcmformat = SND_PCM_FORMAT_UNKNOWN;
 
     if(settings.sampleSize() == 8) {
         pcmformat = SND_PCM_FORMAT_U8;
@@ -215,7 +209,9 @@ int QAudioOutputPrivate::setFormat()
             pcmformat = SND_PCM_FORMAT_FLOAT64_BE;
     }
 
-    return snd_pcm_hw_params_set_format( handle, hwparams, pcmformat);
+    return pcmformat != SND_PCM_FORMAT_UNKNOWN
+            ? snd_pcm_hw_params_set_format( handle, hwparams, pcmformat)
+            : -1;
 }
 
 void QAudioOutputPrivate::start(QIODevice* device)
@@ -226,8 +222,10 @@ void QAudioOutputPrivate::start(QIODevice* device)
     errorState = QAudio::NoError;
 
     // Handle change of mode
-    if(audioSource && !pullMode)
+    if(audioSource && !pullMode) {
         delete audioSource;
+        audioSource = 0;
+    }
 
     close();
 
@@ -249,8 +247,10 @@ QIODevice* QAudioOutputPrivate::start()
     errorState = QAudio::NoError;
 
     // Handle change of mode
-    if(audioSource && !pullMode)
+    if(audioSource && !pullMode) {
         delete audioSource;
+        audioSource = 0;
+    }
 
     close();
 
@@ -290,15 +290,34 @@ bool QAudioOutputPrivate::open()
     elapsedTimeOffset = 0;
 
     int dir;
-    int err=-1;
+    int err = 0;
     int count=0;
     unsigned int freakuency=settings.frequency();
 
+    if (!settings.isValid()) {
+        qWarning("QAudioOutput: open error, invalid format.");
+    } else if (settings.sampleRate() <= 0) {
+        qWarning("QAudioOutput: open error, invalid sample rate (%d).",
+                 settings.sampleRate());
+    } else {
+        err = -1;
+    }
+
+    if (err == 0) {
+        errorState = QAudio::OpenError;
+        deviceState = QAudio::StoppedState;
+        emit errorChanged(errorState);
+        return false;
+    }
+
     QString dev = QString(QLatin1String(m_device.constData()));
     QList<QByteArray> devices = QAudioDeviceInfoInternal::availableDevices(QAudio::AudioOutput);
     if(dev.compare(QLatin1String("default")) == 0) {
 #if(SND_LIB_MAJOR == 1 && SND_LIB_MINOR == 0 && SND_LIB_SUBMINOR >= 14)
-        dev = QLatin1String(devices.first());
+        if (devices.size() > 0)
+            dev = QLatin1String(devices.first());
+        else
+            return false;
 #else
         dev = QLatin1String("hw:0,0");
 #endif
@@ -522,8 +541,20 @@ int QAudioOutputPrivate::bytesFree() const
 
     if(deviceState != QAudio::ActiveState && deviceState != QAudio::IdleState)
         return 0;
+
     int frames = snd_pcm_avail_update(handle);
-    if((int)frames > (int)buffer_frames)
+    if (frames == -EPIPE) {
+        // Try and handle buffer underrun
+        int err = snd_pcm_recover(handle, frames, 0);
+        if (err < 0)
+            return 0;
+        else
+            frames = snd_pcm_avail_update(handle);
+    } else if (frames < 0) {
+        return 0;
+    }
+
+    if ((int)frames > (int)buffer_frames)
         frames = buffer_frames;
 
     return snd_pcm_frames_to_bytes(handle, frames);
@@ -799,3 +830,5 @@ qint64 OutputPrivate::writeData(const char* data, qint64 len)
 }
 
 QT_END_NAMESPACE
+
+#include "moc_qaudiooutput_alsa_p.cpp"
