@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -109,11 +103,13 @@ QAudioOutputPrivate::QAudioOutputPrivate(const QByteArray &device)
     ,   m_clientBufferSize(SymbianAudio::DefaultBufferSize)
     ,   m_notifyInterval(SymbianAudio::DefaultNotifyInterval)
     ,   m_notifyTimer(new QTimer(this))
+    ,   m_lastNotifyPosition(0)
     ,   m_error(QAudio::NoError)
     ,   m_internalState(SymbianAudio::ClosedState)
     ,   m_externalState(QAudio::StoppedState)
     ,   m_pullMode(false)
     ,   m_source(0)
+    ,   m_devSound(0)
     ,   m_devSoundBuffer(0)
     ,   m_devSoundBufferSize(0)
     ,   m_bytesWritten(0)
@@ -125,12 +121,11 @@ QAudioOutputPrivate::QAudioOutputPrivate(const QByteArray &device)
     ,   m_samplesPlayed(0)
     ,   m_totalSamplesPlayed(0)
 {
-    connect(m_notifyTimer.data(), SIGNAL(timeout()), this, SIGNAL(notify()));
-
-    //SymbianAudio::Utils::formatQtToNative(m_format, m_nativeFourCC,
-    //                                      m_nativeFormat);
+    connect(m_notifyTimer.data(), SIGNAL(timeout()),
+            this, SLOT(notifyTimerExpired()));
 
     m_underflowTimer->setInterval(UnderflowTimerInterval);
+
     connect(m_underflowTimer.data(), SIGNAL(timeout()), this,
             SLOT(underflowTimerExpired()));
 }
@@ -142,9 +137,7 @@ QAudioOutputPrivate::~QAudioOutputPrivate()
 
 void QAudioOutputPrivate::setFormat(const QAudioFormat& fmt)
 {
-    m_format = const_cast<QAudioFormat&>(fmt);
-    SymbianAudio::Utils::formatQtToNative(m_format, m_nativeFourCC,
-            m_nativeFormat);
+    m_format = fmt;
 }
 
 void QAudioOutputPrivate::start(QIODevice *device)
@@ -186,48 +179,62 @@ void QAudioOutputPrivate::stop()
 
 void QAudioOutputPrivate::reset()
 {
+#ifndef PRE_S60_52_PLATFORM
+    int err =  m_devSound->flush();
+    if (err != 0)
+        setError(QAudio::FatalError);
+#else
     m_totalSamplesPlayed += getSamplesPlayed();
-    m_devSound->Stop();
+    m_devSound->stop();
     m_bytesPadding = 0;
     startPlayback();
+#endif
 }
 
 void QAudioOutputPrivate::suspend()
 {
     if (SymbianAudio::ActiveState == m_internalState
         || SymbianAudio::IdleState == m_internalState) {
-        m_notifyTimer->stop();
         m_underflowTimer->stop();
-
         const qint64 samplesWritten = SymbianAudio::Utils::bytesToSamples(
                                           m_format, m_bytesWritten);
-
         const qint64 samplesPlayed = getSamplesPlayed();
-
-        m_bytesWritten = 0;
-
-        // CMMFDevSound::Pause() is not guaranteed to work correctly in all
-        // implementations, for play-mode DevSound sessions.  We therefore
-        // have to implement suspend() by calling CMMFDevSound::Stop().
-        // Because this causes buffered data to be dropped, we replace the
-        // lost data with silence following a call to resume(), in order to
-        // ensure that processedUSecs() returns the correct value.
-        m_devSound->Stop();
+#ifdef PRE_S60_52_PLATFORM
         m_totalSamplesPlayed += samplesPlayed;
-
-        // Calculate the amount of data dropped
-        const qint64 paddingSamples = samplesWritten - samplesPlayed;
-        m_bytesPadding = SymbianAudio::Utils::samplesToBytes(m_format,
-                                                             paddingSamples);
-
-        setState(SymbianAudio::SuspendedState);
+        m_bytesWritten = 0;
+#endif
+        const bool paused = m_devSound->pause();
+        if (paused) {
+            setState(SymbianAudio::SuspendedPausedState);
+        } else {
+            m_devSoundBuffer = 0;
+            // Calculate the amount of data dropped
+            const qint64 paddingSamples = samplesWritten - samplesPlayed;
+            Q_ASSERT(paddingSamples >= 0);
+            m_bytesPadding = SymbianAudio::Utils::samplesToBytes(m_format,
+                                                                 paddingSamples);
+            setState(SymbianAudio::SuspendedStoppedState);
+        }
     }
 }
 
 void QAudioOutputPrivate::resume()
 {
-    if (SymbianAudio::SuspendedState == m_internalState)
-        startPlayback();
+    if (QAudio::SuspendedState == m_externalState) {
+        if (SymbianAudio::SuspendedPausedState == m_internalState) {
+#ifndef PRE_S60_52_PLATFORM
+            setState(SymbianAudio::ActiveState);
+            if (m_devSoundBuffer != 0)
+                devsoundBufferToBeFilled(m_devSoundBuffer);
+            m_devSound->start();
+#else
+//defined in else part of macro to enable compatibility of previous code
+            m_devSound->resume();
+#endif
+        } else {
+            startPlayback();
+        }
+    }
 }
 
 int QAudioOutputPrivate::bytesFree() const
@@ -265,11 +272,14 @@ int QAudioOutputPrivate::bufferSize() const
 
 void QAudioOutputPrivate::setNotifyInterval(int ms)
 {
-    if (ms > 0) {
-        const int oldNotifyInterval = m_notifyInterval;
+    if (ms >= 0) {
+        //const int oldNotifyInterval = m_notifyInterval;
         m_notifyInterval = ms;
-        if (m_notifyTimer->isActive() && ms != oldNotifyInterval)
+        if (m_notifyInterval && (SymbianAudio::ActiveState == m_internalState ||
+                                 SymbianAudio::IdleState == m_internalState))
             m_notifyTimer->start(m_notifyInterval);
+        else
+            m_notifyTimer->stop();
     }
 }
 
@@ -281,16 +291,22 @@ int QAudioOutputPrivate::notifyInterval() const
 qint64 QAudioOutputPrivate::processedUSecs() const
 {
     int samplesPlayed = 0;
-    if (m_devSound && SymbianAudio::SuspendedState != m_internalState)
+    if (m_devSound && QAudio::SuspendedState != m_externalState)
         samplesPlayed = getSamplesPlayed();
 
     // Protect against division by zero
     Q_ASSERT_X(m_format.frequency() > 0, Q_FUNC_INFO, "Invalid frequency");
 
+#ifndef PRE_S60_52_PLATFORM
+    const qint64 devSoundSamplesPlayed(m_devSound->samplesProcessed());
+    const qint64 result = qint64(1000000) *
+                          (devSoundSamplesPlayed)
+                        / m_format.frequency();
+#else
     const qint64 result = qint64(1000000) *
                           (samplesPlayed + m_totalSamplesPlayed)
                         / m_format.frequency();
-
+#endif
     return result;
 }
 
@@ -316,96 +332,23 @@ QAudioFormat QAudioOutputPrivate::format() const
     return m_format;
 }
 
-//-----------------------------------------------------------------------------
-// MDevSoundObserver implementation
-//-----------------------------------------------------------------------------
-
-void QAudioOutputPrivate::InitializeComplete(TInt aError)
-{
-    Q_ASSERT_X(SymbianAudio::InitializingState == m_internalState,
-        Q_FUNC_INFO, "Invalid state");
-
-    if (KErrNone == aError)
-        startPlayback();
-}
-
-void QAudioOutputPrivate::ToneFinished(TInt aError)
-{
-    Q_UNUSED(aError)
-    // This class doesn't use DevSound's tone playback functions, so should
-    // never receive this callback.
-    Q_ASSERT_X(false, Q_FUNC_INFO, "Unexpected callback");
-}
-
-void QAudioOutputPrivate::BufferToBeFilled(CMMFBuffer *aBuffer)
-{
-    // Following receipt of this callback, DevSound should not provide another
-    // buffer until we have returned the current one.
-    Q_ASSERT_X(!m_devSoundBuffer, Q_FUNC_INFO, "Buffer already held");
-
-    // Will be returned to DevSound by bufferFilled().
-    m_devSoundBuffer = static_cast<CMMFDataBuffer*>(aBuffer);
-
-    if (!m_devSoundBufferSize)
-        m_devSoundBufferSize = m_devSoundBuffer->Data().MaxLength();
-
-    writePaddingData();
-
-    if (m_pullMode && isDataReady() && !m_bytesPadding)
-        pullData();
-}
-
-void QAudioOutputPrivate::PlayError(TInt aError)
-{
-    switch (aError) {
-    case KErrUnderflow:
-        m_underflow = true;
-        if (m_pullMode && !m_lastBuffer)
-            setError(QAudio::UnderrunError);
-        else
-            setState(SymbianAudio::IdleState);
-        break;
-    default:
-        setError(QAudio::IOError);
-        break;
-    }
-}
-
-void QAudioOutputPrivate::BufferToBeEmptied(CMMFBuffer *aBuffer)
-{
-    Q_UNUSED(aBuffer)
-    // This class doesn't use DevSound in record mode, so should never receive
-    // this callback.
-    Q_ASSERT_X(false, Q_FUNC_INFO, "Unexpected callback");
-}
-
-void QAudioOutputPrivate::RecordError(TInt aError)
-{
-    Q_UNUSED(aError)
-    // This class doesn't use DevSound in record mode, so should never receive
-    // this callback.
-    Q_ASSERT_X(false, Q_FUNC_INFO, "Unexpected callback");
-}
-
-void QAudioOutputPrivate::ConvertError(TInt aError)
-{
-    Q_UNUSED(aError)
-    // This class doesn't use DevSound's format conversion functions, so
-    // should never receive this callback.
-    Q_ASSERT_X(false, Q_FUNC_INFO, "Unexpected callback");
-}
-
-void QAudioOutputPrivate::DeviceMessage(TUid aMessageType, const TDesC8 &aMsg)
-{
-    Q_UNUSED(aMessageType)
-    Q_UNUSED(aMsg)
-    // Ignore this callback.
-}
 
 //-----------------------------------------------------------------------------
 // Private functions
 //-----------------------------------------------------------------------------
 
+void QAudioOutputPrivate::notifyTimerExpired()
+{
+    const qint64 pos = processedUSecs();
+    if (pos > m_lastNotifyPosition) {
+        int count = (pos - m_lastNotifyPosition) / (m_notifyInterval * 1000);
+        while (count--) {
+            emit notify();
+            m_lastNotifyPosition += m_notifyInterval * 1000;
+        }
+    }
+}
+
 void QAudioOutputPrivate::dataReady()
 {
     // Client-provided QIODevice has data ready to read.
@@ -422,51 +365,106 @@ void QAudioOutputPrivate::underflowTimerExpired()
     const TInt samplesPlayed = getSamplesPlayed();
     if (m_samplesPlayed && (samplesPlayed == m_samplesPlayed)) {
         setError(QAudio::UnderrunError);
+#ifndef PRE_S60_52_PLATFORM
+        m_underflowTimer->stop();
+#endif
     } else {
         m_samplesPlayed = samplesPlayed;
         m_underflowTimer->start();
     }
 }
 
+void QAudioOutputPrivate::devsoundInitializeComplete(int err)
+{
+    Q_ASSERT_X(SymbianAudio::InitializingState == m_internalState,
+        Q_FUNC_INFO, "Invalid state");
+
+    if (!err && m_devSound->isFormatSupported(m_format))
+        startPlayback();
+    else
+        setError(QAudio::OpenError);
+}
+
+void QAudioOutputPrivate::devsoundBufferToBeFilled(CMMFBuffer *bufferBase)
+{
+    // Following receipt of this signal, DevSound should not provide another
+    // buffer until we have returned the current one.
+    Q_ASSERT_X(!m_devSoundBuffer, Q_FUNC_INFO, "Buffer already held");
+
+    // Will be returned to DevSoundWrapper by bufferProcessed().
+    m_devSoundBuffer = static_cast<CMMFDataBuffer*>(bufferBase);
+#ifndef PRE_S60_52_PLATFORM
+    if (m_externalState == QAudio::SuspendedState) {
+        // This condition occurs when buffertobefilled callback is received after
+        // pause command is processed.
+        return;
+     }
+#endif
+
+    if (!m_devSoundBufferSize)
+        m_devSoundBufferSize = m_devSoundBuffer->Data().MaxLength();
+
+    writePaddingData();
+
+    if (m_pullMode && isDataReady() && !m_bytesPadding)
+        pullData();
+}
+
+void QAudioOutputPrivate::devsoundPlayError(int err)
+{
+    switch (err) {
+    case KErrUnderflow:
+        m_underflow = true;
+        if (m_pullMode && !m_lastBuffer)
+            setError(QAudio::UnderrunError);
+        else
+            setState(SymbianAudio::IdleState);
+        break;
+    case KErrOverflow:
+        // Silently consume this error when in playback mode
+        break;
+    default:
+        setError(QAudio::IOError);
+        break;
+    }
+}
+
 void QAudioOutputPrivate::open()
 {
     Q_ASSERT_X(SymbianAudio::ClosedState == m_internalState,
         Q_FUNC_INFO, "DevSound already opened");
 
-    QT_TRAP_THROWING( m_devSound.reset(CMMFDevSound::NewL()) )
+    Q_ASSERT(!m_devSound);
+    m_devSound = new SymbianAudio::DevSoundWrapper(QAudio::AudioOutput, this);
 
-    QScopedPointer<SymbianAudio::DevSoundCapabilities> caps(
-        new SymbianAudio::DevSoundCapabilities(*m_devSound,
-                                               QAudio::AudioOutput));
+    connect(m_devSound, SIGNAL(initializeComplete(int)),
+            this, SLOT(devsoundInitializeComplete(int)));
+    connect(m_devSound, SIGNAL(bufferToBeProcessed(CMMFBuffer *)),
+            this, SLOT(devsoundBufferToBeFilled(CMMFBuffer *)));
+    connect(m_devSound, SIGNAL(processingError(int)),
+            this, SLOT(devsoundPlayError(int)));
 
-    int err = SymbianAudio::Utils::isFormatSupported(m_format, *caps) ?
-                  KErrNone : KErrNotSupported;
-
-    if (KErrNone == err) {
-        setState(SymbianAudio::InitializingState);
-        TRAP(err, m_devSound->InitializeL(*this, m_nativeFourCC,
-                                          EMMFStatePlaying));
-    }
-
-    if (KErrNone != err) {
-        setError(QAudio::OpenError);
-        m_devSound.reset();
-    }
+    setState(SymbianAudio::InitializingState);
+    m_devSound->initialize(m_format.codec());
 }
 
 void QAudioOutputPrivate::startPlayback()
 {
-    TRAPD(err, startDevSoundL());
-    if (KErrNone == err) {
+    bool ok = m_devSound->setFormat(m_format);
+    if (ok)
+        ok = m_devSound->start();
+
+    if (ok) {
         if (isDataReady())
             setState(SymbianAudio::ActiveState);
         else
             setState(SymbianAudio::IdleState);
 
-        m_notifyTimer->start(m_notifyInterval);
+        if (m_notifyInterval)
+            m_notifyTimer->start(m_notifyInterval);
         m_underflow = false;
 
-        Q_ASSERT(m_devSound->SamplesPlayed() == 0);
+        Q_ASSERT(m_devSound->samplesProcessed() == 0);
 
         writePaddingData();
 
@@ -478,14 +476,6 @@ void QAudioOutputPrivate::startPlayback()
     }
 }
 
-void QAudioOutputPrivate::startDevSoundL()
-{
-    TMMFCapabilities nativeFormat = m_devSound->Config();
-    m_nativeFormat.iBufferSize = nativeFormat.iBufferSize;
-    m_devSound->SetConfigL(m_nativeFormat);
-    m_devSound->PlayInitL();
-}
-
 void QAudioOutputPrivate::writePaddingData()
 {
     // See comments in suspend()
@@ -502,10 +492,11 @@ void QAudioOutputPrivate::writePaddingData()
         Mem::FillZ(ptr, paddingBytes);
         outputBuffer.SetLength(outputBuffer.Length() + paddingBytes);
         m_bytesPadding -= paddingBytes;
+        Q_ASSERT(m_bytesPadding >= 0);
 
         if (m_pullMode && m_source->atEnd())
             lastBufferFilled();
-        if (paddingBytes == outputBytes)
+        if ((paddingBytes == outputBytes) || !m_bytesPadding)
             bufferFilled();
     }
 }
@@ -559,9 +550,6 @@ void QAudioOutputPrivate::pullData()
     Q_ASSERT_X(m_pullMode, Q_FUNC_INFO,
         "pullData called when in push mode");
 
-    if (m_bytesPadding)
-        m_bytesPadding = 1;
-
     // writePaddingData() is called by BufferToBeFilled() before pullData(),
     // so we should never have any padding data left at this point.
     Q_ASSERT_X(0 == m_bytesPadding, Q_FUNC_INFO,
@@ -580,13 +568,18 @@ void QAudioOutputPrivate::pullData()
 
         char *outputPtr = (char*)(outputBuffer.Ptr() + outputBuffer.Length());
         const qint64 bytesCopied = m_source->read(outputPtr, copyBytes);
-        Q_ASSERT(bytesCopied == copyBytes);
+        
+        //Partial buffers can be sent to DevSound. This assert not required.
+        //Q_ASSERT(bytesCopied == copyBytes);
         outputBuffer.SetLength(outputBuffer.Length() + bytesCopied);
         inputBytes -= bytesCopied;
 
+        if(bytesCopied == 0)
+        	return;
+
         if (m_source->atEnd())
             lastBufferFilled();
-        else if (copyBytes == outputBytes)
+        else
             bufferFilled();
     }
 }
@@ -606,7 +599,7 @@ void QAudioOutputPrivate::bufferFilled()
     if (QAudio::UnderrunError == m_error)
         m_error = QAudio::NoError;
 
-    m_devSound->PlayData();
+    m_devSound->bufferProcessed();
 }
 
 void QAudioOutputPrivate::lastBufferFilled()
@@ -620,14 +613,16 @@ void QAudioOutputPrivate::lastBufferFilled()
 
 void QAudioOutputPrivate::close()
 {
-    m_notifyTimer->stop();
+    m_lastNotifyPosition = 0;
     m_underflowTimer->stop();
 
     m_error = QAudio::NoError;
 
     if (m_devSound)
-        m_devSound->Stop();
-    m_devSound.reset();
+        m_devSound->stop();
+    delete m_devSound;
+    m_devSound = 0;
+
     m_devSoundBuffer = 0;
     m_devSoundBufferSize = 0;
 
@@ -660,7 +655,7 @@ qint64 QAudioOutputPrivate::getSamplesPlayed() const
             // This is necessary because some DevSound implementations report
             // that they have played more data than has actually been provided to them
             // by the client.
-            const qint64 devSoundSamplesPlayed(m_devSound->SamplesPlayed());
+            const qint64 devSoundSamplesPlayed(m_devSound->samplesProcessed());
             result = qMin(devSoundSamplesPlayed, samplesWritten);
         }
     }
@@ -674,25 +669,29 @@ void QAudioOutputPrivate::setError(QAudio::Error error)
     // Although no state transition actually occurs here, a stateChanged event
     // must be emitted to inform the client that the call to start() was
     // unsuccessful.
-    if (QAudio::OpenError == error)
+    if (QAudio::OpenError == error) {
         emit stateChanged(QAudio::StoppedState);
-
-    if (QAudio::UnderrunError == error)
-        setState(SymbianAudio::IdleState);
-    else
-        // Close the DevSound instance.  This causes a transition to
-        // StoppedState.  This must be done asynchronously in case the
-        // current function was called from a DevSound event handler, in which
-        // case deleting the DevSound instance may cause an exception.
-        QMetaObject::invokeMethod(this, "close", Qt::QueuedConnection);
+    } else {
+        if (QAudio::UnderrunError == error)
+            setState(SymbianAudio::IdleState);
+        else
+            // Close the DevSound instance.  This causes a transition to
+            // StoppedState.  This must be done asynchronously in case the
+            // current function was called from a DevSound event handler, in which
+            // case deleting the DevSound instance may cause an exception.
+            QMetaObject::invokeMethod(this, "close", Qt::QueuedConnection);
+    }
 }
 
 void QAudioOutputPrivate::setState(SymbianAudio::State newInternalState)
 {
     const QAudio::State oldExternalState = m_externalState;
     m_internalState = newInternalState;
-    m_externalState = SymbianAudio::Utils::stateNativeToQt(
-                            m_internalState, initializingState());
+    m_externalState = SymbianAudio::Utils::stateNativeToQt(m_internalState);
+
+    if (m_externalState != QAudio::ActiveState &&
+        m_externalState != QAudio::IdleState)
+        m_notifyTimer->stop();
 
     if (m_externalState != oldExternalState)
         emit stateChanged(m_externalState);
@@ -705,9 +704,6 @@ bool QAudioOutputPrivate::isDataReady() const
         ||  m_pushDataReady;
 }
 
-QAudio::State QAudioOutputPrivate::initializingState() const
-{
-    return isDataReady() ? QAudio::ActiveState : QAudio::IdleState;
-}
-
 QT_END_NAMESPACE
+
+#include "moc_qaudiooutput_symbian_p.cpp"
