@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -54,17 +54,13 @@ QT_BEGIN_NAMESPACE
 /*!
     \class QCameraExposure
 
-    \preliminary
+
     \brief The QCameraExposure class provides interface for exposure related camera settings.
 
     \inmodule QtMultimediaKit
     \ingroup camera
+    \since 1.1
 
-The Camera API of Qt Mobility is still in \bold Technology Preview. It has
-not undergone the same level of review and testing as the rest of the APIs.
-
-The API exposed by the classes in this component are not stable, and will
-undergo modification or removal prior to the final release of Qt Mobility.
 */
 
 //#define DEBUG_EXPOSURE_CHANGES 1
@@ -146,6 +142,9 @@ void QCameraExposurePrivate::_q_exposureParameterChanged(int parameter)
     case QCameraExposureControl::ShutterSpeed:
         emit q->shutterSpeedChanged(q->shutterSpeed());
         break;
+    case QCameraExposureControl::ExposureCompensation:
+        emit q->exposureCompensationChanged(q->exposureCompensation());
+        break;
     }
 }
 
@@ -413,7 +412,7 @@ qreal QCameraExposure::aperture() const
 /*!
     Returns the list of aperture values camera supports.
     The apertures list can change depending on the focal length,
-    in such a case the apertureRangeChanged() signal is emited.
+    in such a case the apertureRangeChanged() signal is emitted.
 
     If the camera supports arbitrary aperture values within the supported range,
     *\a continuous is set to true, otherwise *\a continuous is set to false.
