@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -53,8 +53,9 @@ QT_BEGIN_NAMESPACE
     \class QMediaControl
     \inmodule QtMultimediaKit
     \ingroup multimedia
+    \since 1.0
+
 
-    \preliminary
     \brief The QMediaControl class provides a base interface for media service controls.
 
     Media controls provide an interface to individual features provided by a
@@ -66,19 +67,14 @@ QT_BEGIN_NAMESPACE
     the \l {QMediaService::requestControl()} member of QMediaService.  If the
     service doesn't implement a control it will instead return a null pointer.
 
-    \code
-    QMediaPlayerControl *control = qobject_cast<QMediaPlayerControl *>(
-            service->requestControl("com.nokia.Qt.QMediaPlayerControl/1.0"));
-    \endcode
+    \snippet doc/src/snippets/multimedia-snippets/media.cpp Request control
 
     Alternatively if the IId of the control has been declared using
     Q_MEDIA_DECLARE_CONTROL the template version of
     QMediaService::requestControl() can be used to request the service without
     explicitly passing the IId.
 
-    \code
-    QMediaPlayerControl *control = service->requestControl<QMediaPlayerControl *>();
-    \endcode
+    \snippet doc/src/snippets/multimedia-snippets/media.cpp Request control templated
 
     Most application code will not interface directly with a media service's
     controls, instead the QMediaObject which owns the service acts as an
@@ -98,9 +94,7 @@ QT_BEGIN_NAMESPACE
     be requested from QMediaService::requestControl() without explicitly
     passing the IId.
 
-    \code
-    QMediaPlayerControl *control = service->control<QMediaPlayerControl *>();
-    \endcode
+    \snippet doc/src/snippets/multimedia-snippets/media.cpp Request control templated
 
     \sa QMediaService::requestControl()
 */
