@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -88,10 +82,12 @@ private:
 
 /*!
     \class QAudioEncoderSettings
-    \preliminary
+    
     \brief The QAudioEncoderSettings class provides a set of audio encoder settings.
 
+    \inmodule QtMultimediaKit
     \ingroup multimedia
+    \since 1.0
 
     A audio encoder settings object is used to specify the audio encoder
     settings used by QMediaRecorder.  Audio encoder settings are selected by
@@ -99,13 +95,7 @@ private:
     and then passing it to a QMediaRecorder instance using the
     QMediaRecorder::setEncodingSettings() function.
 
-    \code
-    QAudioEncoderSettings audioSettings;
-    audioSettings.setCodec("audio/mpeg");
-    audioSettings.setChannelCount(2);
-
-    recorder->setEncodingSettings(audioSettings);
-    \endcode
+    \snippet doc/src/snippets/multimedia-snippets/media.cpp Audio encoder settings
 
     \sa QMediaRecorder, QAudioEncoderControl
 */
@@ -352,7 +342,7 @@ private:
 
 /*!
     \class QVideoEncoderSettings
-    \preliminary
+    
     \brief The QVideoEncoderSettings class provides a set of video encoder settings.
 
     A video encoder settings object is used to specify the video encoder
@@ -361,13 +351,7 @@ private:
     and then passing it to a QMediaRecorder instance using the
     QMediaRecorder::setEncodingSettings() function.
 
-    \code
-    QVideoEncoderSettings videoSettings;
-    videoSettings.setCodec("video/mpeg2");
-    videoSettings.setResolution(640, 480);
-
-    recorder->setEncodingSettings(audioSettings, videoSettings);
-    \endcode
+    \snippet doc/src/snippets/multimedia-snippets/media.cpp Video encoder settings
 
     \sa QMediaRecorder, QVideoEncoderControl
 */
@@ -625,24 +609,18 @@ private:
 
 /*!
     \class QImageEncoderSettings
-    \preliminary
+    
 
     \brief The QImageEncoderSettings class provides a set of image encoder
     settings.
 
     A image encoder settings object is used to specify the image encoder
-    settings used by QStillImageCapture.  Image encoder settings are selected
+    settings used by QCameraImageCapture.  Image encoder settings are selected
     by constructing a QImageEncoderSettings object, setting the desired
-    properties and then passing it to a QStillImageCapture instance using the
-    QStillImageCapture::setImageSettings() function.
+    properties and then passing it to a QCameraImageCapture instance using the
+    QCameraImageCapture::setImageSettings() function.
 
-    \code
-    QImageEncoderSettings imageSettings;
-    imageSettings.setCodec("image/jpeg");
-    imageSettings.setResolution(1600, 1200);
-
-    imageCapture->setImageSettings(imageSettings);
-    \endcode
+    \snippet doc/src/snippets/multimedia-snippets/media.cpp Image encoder settings
 
     \sa QImageEncoderControl
 */
