@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -42,19 +42,23 @@
 #ifndef QMEDIAPLAYER_H
 #define QMEDIAPLAYER_H
 
+
 #include "qmediaserviceprovider.h"
 #include "qmediaobject.h"
 #include "qmediacontent.h"
+#include "qmediaenumdebug.h"
+
+#include <QtNetwork/qnetworkconfiguration.h>
 
 QT_BEGIN_HEADER
 
 QT_BEGIN_NAMESPACE
 
+class QAbstractVideoSurface;
 class QMediaPlaylist;
 class QVideoWidget;
 class QGraphicsVideoItem;
 
-
 class QMediaPlayerPrivate;
 class Q_MULTIMEDIA_EXPORT QMediaPlayer : public QMediaObject
 {
@@ -75,6 +79,7 @@ class Q_MULTIMEDIA_EXPORT QMediaPlayer : public QMediaObject
     Q_PROPERTY(QString error READ errorString)
     Q_ENUMS(State)
     Q_ENUMS(MediaStatus)
+    Q_ENUMS(Error)
 
 public:
     enum State
@@ -100,7 +105,8 @@ public:
     enum Flag
     {
         LowLatency = 0x01,
-        StreamPlayback = 0x02
+        StreamPlayback = 0x02,
+        VideoSurface = 0x04
     };
     Q_DECLARE_FLAGS(Flags, Flag)
 
@@ -124,6 +130,7 @@ public:
 
     void setVideoOutput(QVideoWidget *);
     void setVideoOutput(QGraphicsVideoItem *);
+    void setVideoOutput(QAbstractVideoSurface *surface);
 
     QMediaContent media() const;
     const QIODevice *mediaStream() const;
@@ -148,6 +155,8 @@ public:
     Error error() const;
     QString errorString() const;
 
+    QNetworkConfiguration currentNetworkConfiguration() const;
+
 public Q_SLOTS:
     void play();
     void pause();
@@ -162,6 +171,8 @@ public Q_SLOTS:
     void setMedia(const QMediaContent &media, QIODevice *stream = 0);
     void setPlaylist(QMediaPlaylist *playlist);
 
+    void setNetworkConfigurations(const QList<QNetworkConfiguration> &configurations);
+
 Q_SIGNALS:
     void mediaChanged(const QMediaContent &media);
 
@@ -183,6 +194,7 @@ Q_SIGNALS:
 
     void error(QMediaPlayer::Error error);
 
+    void networkConfigurationChanged(const QNetworkConfiguration &configuration);
 public:
     virtual bool bind(QObject *);
     virtual void unbind(QObject *);
@@ -203,6 +215,10 @@ Q_DECLARE_METATYPE(QMediaPlayer::State)
 Q_DECLARE_METATYPE(QMediaPlayer::MediaStatus)
 Q_DECLARE_METATYPE(QMediaPlayer::Error)
 
+Q_MEDIA_ENUM_DEBUG(QMediaPlayer, State)
+Q_MEDIA_ENUM_DEBUG(QMediaPlayer, MediaStatus)
+Q_MEDIA_ENUM_DEBUG(QMediaPlayer, Error)
+
 QT_END_HEADER
 
 #endif  // QMEDIAPLAYER_H
