@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -70,9 +64,11 @@ Q_GLOBAL_STATIC_WITH_ARGS(QMediaPluginLoader, playlistIOLoader,
 
 /*!
     \class QMediaPlaylist
+    \inmodule QtMultimediaKit
     \ingroup multimedia
+    \since 1.0
+
 
-    \preliminary
     \brief The QMediaPlaylist class provides a list of media content to play.
 
     QMediaPlaylist is intended to be used with other media objects,
@@ -81,20 +77,7 @@ Q_GLOBAL_STATIC_WITH_ARGS(QMediaPluginLoader, playlistIOLoader,
     QMediaPlaylist allows to access the service intrinsic playlist functionality
     if available, otherwise it provides the the local memory playlist implementation.
 
-\code
-    player = new QMediaPlayer;
-
-    playlist = new QMediaPlaylist;
-    playlist->append(QUrl("http://example.com/movie1.mp4"));
-    playlist->append(QUrl("http://example.com/movie2.mp4"));
-    playlist->append(QUrl("http://example.com/movie3.mp4"));
-
-    playlist->setCurrentIndex(1);
-
-    player->setPlaylist(playlist);
-
-    player->play();
-\endcode
+    \snippet doc/src/snippets/multimedia-snippets/media.cpp Movie playlist
 
     Depending on playlist source implementation, most of the playlist mutating
     operations can be asynchronous.
@@ -123,7 +106,7 @@ Q_GLOBAL_STATIC_WITH_ARGS(QMediaPluginLoader, playlistIOLoader,
 
 
 /*!
-  Create a new playlist object for with the given \a parent.  
+  Create a new playlist object for with the given \a parent.
 */
 
 QMediaPlaylist::QMediaPlaylist(QObject *parent)
@@ -152,12 +135,17 @@ QMediaPlaylist::~QMediaPlaylist()
     delete d_ptr;
 }
 
+/*!
+  Returns the QMediaObject instance that this QMediaPlaylist is bound too,
+  or 0 otherwise.
+*/
 QMediaObject *QMediaPlaylist::mediaObject() const
 {
     return d_func()->mediaObject;
 }
 
 /*!
+  \internal
   If \a mediaObject is null or doesn't have an intrinsic playlist,
   internal local memory playlist source will be created.
 */
@@ -316,7 +304,7 @@ int QMediaPlaylist::mediaCount() const
 /*!
   Returns true if the playlist contains no items; otherwise returns false.
 
-  \sa size()
+  \sa mediaCount()
   */
 bool QMediaPlaylist::isEmpty() const
 {
@@ -326,7 +314,7 @@ bool QMediaPlaylist::isEmpty() const
 /*!
   Returns true if the playlist can be modified; otherwise returns false.
 
-  \sa size()
+  \sa mediaCount()
   */
 bool QMediaPlaylist::isReadOnly() const
 {
