@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -49,8 +49,9 @@ QT_BEGIN_NAMESPACE
     \class QMediaPlaylistControl
     \inmodule QtMultimediaKit
     \ingroup multimedia
+    \since 1.0
+
 
-    \preliminary
     \brief The QMediaPlaylistControl class provides access to the playlist
     functionality of a QMediaService.
 
@@ -178,19 +179,19 @@ QMediaPlaylistControl::~QMediaPlaylistControl()
 /*!
   \fn QMediaPlaylistControl::playlistProviderChanged()
 
-  Signal emited when the playlist provider has changed.
+  Signal emitted when the playlist provider has changed.
 */
 
 /*!
   \fn QMediaPlaylistControl::currentIndexChanged(int position)
 
-  Signal emited when the playlist \a position is changed.
+  Signal emitted when the playlist \a position is changed.
 */
 
 /*!
   \fn QMediaPlaylistControl::playbackModeChanged(QMediaPlaylist::PlaybackMode mode)
 
-  Signal emited when the playback \a mode is changed.
+  Signal emitted when the playback \a mode is changed.
 */
 
 /*!
