@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -81,11 +81,12 @@ public:
 
 /*!
     \class QMediaServiceProviderHint
-    \preliminary
+
     \brief The QMediaServiceProviderHint class describes what is required of a QMediaService.
 
     \inmodule QtMultimediaKit
     \ingroup multimedia
+    \since 1.0
 
     The QMediaServiceProvider class uses hints to select an appropriate media service.
 */
@@ -105,6 +106,10 @@ public:
 
     \value StreamPlayback
             The service is capable of playing QIODevice based streams.
+
+    \value VideoSurface
+            The service is capable of renderering to a QAbstractVideoSurface
+            output.
 */
 
 /*!
@@ -447,7 +452,7 @@ public:
                     qobject_cast<QMediaServiceSupportedFormatsInterface*>(obj);
 
 
-            if (flags & QMediaPlayer::LowLatency) {
+            if (flags) {
                 QMediaServiceFeaturesInterface *iface =
                         qobject_cast<QMediaServiceFeaturesInterface*>(obj);
 
@@ -464,6 +469,11 @@ public:
                     if ((flags & QMediaPlayer::StreamPlayback) &&
                         !(features & QMediaServiceProviderHint::StreamPlayback))
                             continue;
+
+                    //the same for QAbstractVideoSurface support
+                    if ((flags & QMediaPlayer::VideoSurface) &&
+                        !(features & QMediaServiceProviderHint::VideoSurface))
+                            continue;
                 }
             }
 
@@ -514,7 +524,7 @@ Q_GLOBAL_STATIC(QPluginServiceProvider, pluginProvider);
 
 /*!
     \class QMediaServiceProvider
-    \preliminary
+
     \brief The QMediaServiceProvider class provides an abstract allocator for media services.
 */
 
@@ -628,7 +638,7 @@ QMediaServiceProvider *QMediaServiceProvider::defaultServiceProvider()
 
 /*!
     \class QMediaServiceProviderPlugin
-    \preliminary
+
     \brief The QMediaServiceProviderPlugin class interface provides an interface for QMediaService
     plug-ins.
 
