@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,26 +25,22 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
+#include <QtCore/qdebug.h>
+
 #include "qmediatimerange.h"
 
 QT_BEGIN_NAMESPACE
@@ -52,7 +48,9 @@ QT_BEGIN_NAMESPACE
 /*!
     \class QMediaTimeInterval
     \brief The QMediaTimeInterval class represents a time interval with integer precision.
+    \inmodule QtMultimediaKit
     \ingroup multimedia
+    \since 1.0
 
     An interval is specified by an inclusive start() and end() time.  These
     must be set in the constructor, as this is an immutable class.  The
@@ -243,7 +241,7 @@ QMediaTimeRangePrivate::QMediaTimeRangePrivate(const QMediaTimeInterval &interva
 }
 
 void QMediaTimeRangePrivate::addInterval(const QMediaTimeInterval &interval)
-{    
+{
     // Handle normalized intervals only
     if(!interval.isNormal())
         return;
@@ -708,5 +706,17 @@ QMediaTimeRange operator-(const QMediaTimeRange &r1, const QMediaTimeRange &r2)
     return (QMediaTimeRange(r1) -= r2);
 }
 
+#ifndef QT_NO_DEBUG_STREAM
+QDebug operator<<(QDebug dbg, const QMediaTimeRange &range)
+{
+    dbg.nospace() << "QMediaTimeRange( ";
+    foreach (const QMediaTimeInterval &interval, range.intervals()) {
+        dbg.nospace() << "(" <<  interval.start() << ", " << interval.end() << ") ";
+    }
+    dbg.space() << ")";
+    return dbg;
+}
+#endif
+
 QT_END_NAMESPACE
 
