@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -65,10 +59,10 @@ QVideoSurfacePainter::~QVideoSurfacePainter()
 {
 }
 
-class QVideoSurfaceRasterPainter : public QVideoSurfacePainter
+class QVideoSurfaceGenericPainter : public QVideoSurfacePainter
 {
 public:
-    QVideoSurfaceRasterPainter();
+    QVideoSurfaceGenericPainter();
 
     QList<QVideoFrame::PixelFormat> supportedPixelFormats(
             QAbstractVideoBuffer::HandleType handleType) const;
@@ -94,7 +88,7 @@ private:
     QVideoSurfaceFormat::Direction m_scanLineDirection;
 };
 
-QVideoSurfaceRasterPainter::QVideoSurfaceRasterPainter()
+QVideoSurfaceGenericPainter::QVideoSurfaceGenericPainter()
     : m_imageFormat(QImage::Format_Invalid)
     , m_scanLineDirection(QVideoSurfaceFormat::TopToBottom)
 {
@@ -107,52 +101,74 @@ QVideoSurfaceRasterPainter::QVideoSurfaceRasterPainter()
         << QVideoFrame::Format_RGB565;
 }
 
-QList<QVideoFrame::PixelFormat> QVideoSurfaceRasterPainter::supportedPixelFormats(
+QList<QVideoFrame::PixelFormat> QVideoSurfaceGenericPainter::supportedPixelFormats(
         QAbstractVideoBuffer::HandleType handleType) const
 {
-    return handleType == QAbstractVideoBuffer::NoHandle
-        ? m_imagePixelFormats
-        : QList<QVideoFrame::PixelFormat>();
+    switch (handleType) {
+    case QAbstractVideoBuffer::QPixmapHandle:
+    case QAbstractVideoBuffer::NoHandle:
+        return m_imagePixelFormats;
+    default:
+        ;
+    }
+    return QList<QVideoFrame::PixelFormat>();
 }
 
-bool QVideoSurfaceRasterPainter::isFormatSupported(
+bool QVideoSurfaceGenericPainter::isFormatSupported(
         const QVideoSurfaceFormat &format, QVideoSurfaceFormat *) const
 {
-    return format.handleType() == QAbstractVideoBuffer::NoHandle
-            && m_imagePixelFormats.contains(format.pixelFormat())
-            && !format.frameSize().isEmpty();
+    switch (format.handleType()) {
+    case QAbstractVideoBuffer::QPixmapHandle:
+        return true;
+    case QAbstractVideoBuffer::NoHandle:
+        return m_imagePixelFormats.contains(format.pixelFormat())
+               && !format.frameSize().isEmpty();
+    default:
+        ;
+    }
+    return false;
 }
 
-QAbstractVideoSurface::Error QVideoSurfaceRasterPainter::start(const QVideoSurfaceFormat &format)
+QAbstractVideoSurface::Error QVideoSurfaceGenericPainter::start(const QVideoSurfaceFormat &format)
 {
     m_frame = QVideoFrame();
     m_imageFormat = QVideoFrame::imageFormatFromPixelFormat(format.pixelFormat());
     m_imageSize = format.frameSize();
     m_scanLineDirection = format.scanLineDirection();
 
-    return format.handleType() == QAbstractVideoBuffer::NoHandle
-            && m_imageFormat != QImage::Format_Invalid
-            && !m_imageSize.isEmpty()
-            ? QAbstractVideoSurface::NoError
-            : QAbstractVideoSurface::UnsupportedFormatError;
+    const QAbstractVideoBuffer::HandleType t = format.handleType();
+    if (t == QAbstractVideoBuffer::NoHandle) {
+        if (m_imageFormat != QImage::Format_Invalid
+#ifdef QT_OPENGL_ES
+                && format.pixelFormat() != QVideoFrame::Format_RGB24
+#endif
+                && !m_imageSize.isEmpty()) {
+            return QAbstractVideoSurface::NoError;
+        }
+    } else if (t == QAbstractVideoBuffer::QPixmapHandle) {
+        return QAbstractVideoSurface::NoError;
+    }
+    return QAbstractVideoSurface::UnsupportedFormatError;
 }
 
-void QVideoSurfaceRasterPainter::stop()
+void QVideoSurfaceGenericPainter::stop()
 {
     m_frame = QVideoFrame();
 }
 
-QAbstractVideoSurface::Error QVideoSurfaceRasterPainter::setCurrentFrame(const QVideoFrame &frame)
+QAbstractVideoSurface::Error QVideoSurfaceGenericPainter::setCurrentFrame(const QVideoFrame &frame)
 {
     m_frame = frame;
 
     return QAbstractVideoSurface::NoError;
 }
 
-QAbstractVideoSurface::Error QVideoSurfaceRasterPainter::paint(
+QAbstractVideoSurface::Error QVideoSurfaceGenericPainter::paint(
             const QRectF &target, QPainter *painter, const QRectF &source)
 {
-    if (m_frame.map(QAbstractVideoBuffer::ReadOnly)) {
+    if (m_frame.handleType() == QAbstractVideoBuffer::QPixmapHandle) {
+        painter->drawPixmap(target, m_frame.handle().value<QPixmap>(), source);
+    } else if (m_frame.map(QAbstractVideoBuffer::ReadOnly)) {
         QImage image(
                 m_frame.bits(),
                 m_imageSize.width(),
@@ -181,7 +197,7 @@ QAbstractVideoSurface::Error QVideoSurfaceRasterPainter::paint(
     return QAbstractVideoSurface::NoError;
 }
 
-void QVideoSurfaceRasterPainter::updateColors(int, int, int, int)
+void QVideoSurfaceGenericPainter::updateColors(int, int, int, int)
 {
 }
 
@@ -227,7 +243,11 @@ public:
 
     QAbstractVideoSurface::Error setCurrentFrame(const QVideoFrame &frame);
 
+    QAbstractVideoSurface::Error paint(
+            const QRectF &target, QPainter *painter, const QRectF &source);
+
     void updateColors(int brightness, int contrast, int hue, int saturation);
+    void viewportDestroyed();
 
 protected:
     void initRgbTextureInfo(GLenum internalFormat, GLuint format, GLenum type, const QSize &size);
@@ -247,6 +267,7 @@ protected:
     QGLContext *m_context;
     QAbstractVideoBuffer::HandleType m_handleType;
     QVideoSurfaceFormat::Direction m_scanLineDirection;
+    QVideoSurfaceFormat::YCbCrColorSpace m_colorSpace;
     GLenum m_textureFormat;
     GLuint m_textureInternalFormat;
     GLenum m_textureType;
@@ -262,6 +283,7 @@ QVideoSurfaceGLPainter::QVideoSurfaceGLPainter(QGLContext *context)
     : m_context(context)
     , m_handleType(QAbstractVideoBuffer::NoHandle)
     , m_scanLineDirection(QVideoSurfaceFormat::TopToBottom)
+    , m_colorSpace(QVideoSurfaceFormat::YCbCr_BT601)
     , m_textureFormat(0)
     , m_textureInternalFormat(0)
     , m_textureType(0)
@@ -277,17 +299,24 @@ QVideoSurfaceGLPainter::~QVideoSurfaceGLPainter()
 {
 }
 
+void QVideoSurfaceGLPainter::viewportDestroyed()
+{
+    m_context = 0;
+}
+
 QList<QVideoFrame::PixelFormat> QVideoSurfaceGLPainter::supportedPixelFormats(
         QAbstractVideoBuffer::HandleType handleType) const
 {
     switch (handleType) {
     case QAbstractVideoBuffer::NoHandle:
         return m_imagePixelFormats;
+    case QAbstractVideoBuffer::QPixmapHandle:
     case QAbstractVideoBuffer::GLTextureHandle:
         return m_glPixelFormats;
     default:
-        return QList<QVideoFrame::PixelFormat>();
+        ;
     }
+    return QList<QVideoFrame::PixelFormat>();
 }
 
 bool QVideoSurfaceGLPainter::isFormatSupported(
@@ -299,12 +328,14 @@ bool QVideoSurfaceGLPainter::isFormatSupported(
         switch (format.handleType()) {
         case QAbstractVideoBuffer::NoHandle:
             return m_imagePixelFormats.contains(format.pixelFormat());
+        case QAbstractVideoBuffer::QPixmapHandle:
         case QAbstractVideoBuffer::GLTextureHandle:
             return m_glPixelFormats.contains(format.pixelFormat());
         default:
-            return false;
+            ;
         }
     }
+    return false;
 }
 
 QAbstractVideoSurface::Error QVideoSurfaceGLPainter::setCurrentFrame(const QVideoFrame &frame)
@@ -334,13 +365,26 @@ QAbstractVideoSurface::Error QVideoSurfaceGLPainter::setCurrentFrame(const QVide
             glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT);
         }
         m_frame.unmap();
-    } else if (m_frame.isValid()) {
+    } else if (m_handleType != QAbstractVideoBuffer::QPixmapHandle && m_frame.isValid()) {
         return QAbstractVideoSurface::IncorrectFormatError;
     }
 
     return QAbstractVideoSurface::NoError;
 }
 
+QAbstractVideoSurface::Error QVideoSurfaceGLPainter::paint(
+        const QRectF &target, QPainter *painter, const QRectF &source)
+{
+    if (m_frame.handleType() == QAbstractVideoBuffer::QPixmapHandle) {
+        painter->drawPixmap(target, m_frame.handle().value<QPixmap>(), source);
+    } else if (m_frame.isValid()) {
+        return QAbstractVideoSurface::IncorrectFormatError;
+    } else {
+        painter->fillRect(target, Qt::black);
+    }
+    return QAbstractVideoSurface::NoError;
+}
+
 void QVideoSurfaceGLPainter::updateColors(int brightness, int contrast, int hue, int saturation)
 {
     const qreal b = brightness / 200.0;
@@ -394,11 +438,33 @@ void QVideoSurfaceGLPainter::updateColors(int brightness, int contrast, int hue,
     m_colorMatrix(3, 3) = 1.0;
 
     if (m_yuv) {
-        m_colorMatrix = m_colorMatrix * QMatrix4x4(
-                1.0,  0.000,  1.140, -0.5700,
-                1.0, -0.394, -0.581,  0.4875,
-                1.0,  2.028,  0.000, -1.0140,
-                0.0,  0.000,  0.000,  1.0000);
+        QMatrix4x4 colorSpaceMatrix;
+
+        switch (m_colorSpace) {
+        case QVideoSurfaceFormat::YCbCr_JPEG:
+            colorSpaceMatrix = QMatrix4x4(
+                        1.0,  0.000,  1.402, -0.701,
+                        1.0, -0.344, -0.714,  0.529,
+                        1.0,  1.772,  0.000, -0.886,
+                        0.0,  0.000,  0.000,  1.0000);
+            break;
+        case QVideoSurfaceFormat::YCbCr_BT709:
+        case QVideoSurfaceFormat::YCbCr_xvYCC709:
+            colorSpaceMatrix = QMatrix4x4(
+                        1.164,  0.000,  1.793, -0.5727,
+                        1.164, -0.534, -0.213,  0.3007,
+                        1.164,  2.115,  0.000, -1.1302,
+                        0.0,    0.000,  0.000,  1.0000);
+            break;
+        default: //BT 601:
+            colorSpaceMatrix = QMatrix4x4(
+                        1.164,  0.000,  1.596, -0.8708,
+                        1.164, -0.392, -0.813,  0.5296,
+                        1.164,  2.017,  0.000, -1.081,
+                        0.0,    0.000,  0.000,  1.0000);
+        }
+
+        m_colorMatrix = m_colorMatrix * colorSpaceMatrix;
     }
 }
 
@@ -417,38 +483,44 @@ void QVideoSurfaceGLPainter::initRgbTextureInfo(
 
 void QVideoSurfaceGLPainter::initYuv420PTextureInfo(const QSize &size)
 {
+    int bytesPerLine = (size.width() + 3) & ~3;
+    int bytesPerLine2 = (size.width() / 2 + 3) & ~3;
+
     m_yuv = true;
     m_textureInternalFormat = GL_LUMINANCE;
     m_textureFormat = GL_LUMINANCE;
     m_textureType = GL_UNSIGNED_BYTE;
     m_textureCount = 3;
-    m_textureWidths[0] = size.width();
+    m_textureWidths[0] = bytesPerLine;
     m_textureHeights[0] = size.height();
     m_textureOffsets[0] = 0;
-    m_textureWidths[1] = size.width() / 2;
+    m_textureWidths[1] = bytesPerLine2;
     m_textureHeights[1] = size.height() / 2;
-    m_textureOffsets[1] = size.width() * size.height();
-    m_textureWidths[2] = size.width() / 2;
+    m_textureOffsets[1] = bytesPerLine * size.height();
+    m_textureWidths[2] = bytesPerLine2;
     m_textureHeights[2] = size.height() / 2;
-    m_textureOffsets[2] = size.width() * size.height() * 5 / 4;
+    m_textureOffsets[2] = bytesPerLine * size.height() + bytesPerLine2 * size.height()/2;
 }
 
 void QVideoSurfaceGLPainter::initYv12TextureInfo(const QSize &size)
 {
+    int bytesPerLine = (size.width() + 3) & ~3;
+    int bytesPerLine2 = (size.width() / 2 + 3) & ~3;
+
     m_yuv = true;
     m_textureInternalFormat = GL_LUMINANCE;
     m_textureFormat = GL_LUMINANCE;
     m_textureType = GL_UNSIGNED_BYTE;
     m_textureCount = 3;
-    m_textureWidths[0] = size.width();
+    m_textureWidths[0] = bytesPerLine;
     m_textureHeights[0] = size.height();
     m_textureOffsets[0] = 0;
-    m_textureWidths[1] = size.width() / 2;
+    m_textureWidths[1] = bytesPerLine2;
     m_textureHeights[1] = size.height() / 2;
-    m_textureOffsets[1] = size.width() * size.height() * 5 / 4;
-    m_textureWidths[2] = size.width() / 2;
+    m_textureOffsets[1] = bytesPerLine * size.height() + bytesPerLine2 * size.height()/2;
+    m_textureWidths[2] = bytesPerLine2;
     m_textureHeights[2] = size.height() / 2;
-    m_textureOffsets[2] = size.width() * size.height();
+    m_textureOffsets[2] = bytesPerLine * size.height();
 }
 
 #ifndef QT_OPENGL_ES
@@ -670,6 +742,9 @@ QAbstractVideoSurface::Error QVideoSurfaceArbFpPainter::start(const QVideoSurfac
         default:
             break;
         }
+    } else if (format.handleType() == QAbstractVideoBuffer::QPixmapHandle) {
+        m_handleType = QAbstractVideoBuffer::QPixmapHandle;
+        return QAbstractVideoSurface::NoError;
     }
 
     if (!program) {
@@ -708,6 +783,7 @@ QAbstractVideoSurface::Error QVideoSurfaceArbFpPainter::start(const QVideoSurfac
                 m_handleType = format.handleType();
                 m_scanLineDirection = format.scanLineDirection();
                 m_frameSize = format.frameSize();
+                m_colorSpace = format.yCbCrColorSpace();
 
                 if (m_handleType == QAbstractVideoBuffer::NoHandle)
                     glGenTextures(m_textureCount, m_textureIds);
@@ -720,11 +796,13 @@ QAbstractVideoSurface::Error QVideoSurfaceArbFpPainter::start(const QVideoSurfac
 
 void QVideoSurfaceArbFpPainter::stop()
 {
-    m_context->makeCurrent();
+    if (m_context) {
+        m_context->makeCurrent();
 
-    if (m_handleType != QAbstractVideoBuffer::GLTextureHandle)
-        glDeleteTextures(m_textureCount, m_textureIds);
-    glDeleteProgramsARB(1, &m_programId);
+        if (m_handleType != QAbstractVideoBuffer::GLTextureHandle)
+            glDeleteTextures(m_textureCount, m_textureIds);
+        glDeleteProgramsARB(1, &m_programId);
+    }
 
     m_textureCount = 0;
     m_programId = 0;
@@ -734,7 +812,8 @@ void QVideoSurfaceArbFpPainter::stop()
 QAbstractVideoSurface::Error QVideoSurfaceArbFpPainter::paint(
         const QRectF &target, QPainter *painter, const QRectF &source)
 {
-    if (m_frame.isValid()) {
+    const QAbstractVideoBuffer::HandleType h = m_frame.handleType();
+    if (h == QAbstractVideoBuffer::NoHandle || h == QAbstractVideoBuffer::GLTextureHandle) {
         bool stencilTestEnabled = glIsEnabled(GL_STENCIL_TEST);
         bool scissorTestEnabled = glIsEnabled(GL_SCISSOR_TEST);
 
@@ -771,10 +850,10 @@ QAbstractVideoSurface::Error QVideoSurfaceArbFpPainter::paint(
 
         const GLfloat v_array[] =
         {
-            target.left()     , vBottom,
-            target.right() + 1, vBottom,
-            target.left()     , vTop,
-            target.right() + 1, vTop
+            GLfloat(target.left())     , GLfloat(vBottom),
+            GLfloat(target.right() + 1), GLfloat(vBottom),
+            GLfloat(target.left())     , GLfloat(vTop),
+            GLfloat(target.right() + 1), GLfloat(vTop)
         };
 
         glEnable(GL_FRAGMENT_PROGRAM_ARB);
@@ -826,8 +905,11 @@ QAbstractVideoSurface::Error QVideoSurfaceArbFpPainter::paint(
         glDisable(GL_FRAGMENT_PROGRAM_ARB);
 
         painter->endNativePainting();
+
+        return QAbstractVideoSurface::NoError;
     }
-    return QAbstractVideoSurface::NoError;
+
+    return QVideoSurfaceGLPainter::paint(target, painter, source);
 }
 
 #endif
@@ -1026,6 +1108,9 @@ QAbstractVideoSurface::Error QVideoSurfaceGlslPainter::start(const QVideoSurface
         default:
             break;
         }
+    } else if (format.handleType() == QAbstractVideoBuffer::QPixmapHandle) {
+        m_handleType = QAbstractVideoBuffer::QPixmapHandle;
+        return QAbstractVideoSurface::NoError;
     }
 
     if (!fragmentProgram) {
@@ -1046,6 +1131,7 @@ QAbstractVideoSurface::Error QVideoSurfaceGlslPainter::start(const QVideoSurface
         m_handleType = format.handleType();
         m_scanLineDirection = format.scanLineDirection();
         m_frameSize = format.frameSize();
+        m_colorSpace = format.yCbCrColorSpace();
 
         if (m_handleType == QAbstractVideoBuffer::NoHandle)
             glGenTextures(m_textureCount, m_textureIds);
@@ -1056,10 +1142,13 @@ QAbstractVideoSurface::Error QVideoSurfaceGlslPainter::start(const QVideoSurface
 
 void QVideoSurfaceGlslPainter::stop()
 {
-    m_context->makeCurrent();
+    if (m_context) {
+        m_context->makeCurrent();
+
+        if (m_handleType != QAbstractVideoBuffer::GLTextureHandle)
+            glDeleteTextures(m_textureCount, m_textureIds);
+    }
 
-    if (m_handleType != QAbstractVideoBuffer::GLTextureHandle)
-        glDeleteTextures(m_textureCount, m_textureIds);
     m_program.removeAllShaders();
 
     m_textureCount = 0;
@@ -1069,7 +1158,8 @@ void QVideoSurfaceGlslPainter::stop()
 QAbstractVideoSurface::Error QVideoSurfaceGlslPainter::paint(
         const QRectF &target, QPainter *painter, const QRectF &source)
 {
-    if (m_frame.isValid()) {
+    const QAbstractVideoBuffer::HandleType h = m_frame.handleType();
+    if (h == QAbstractVideoBuffer::NoHandle || h == QAbstractVideoBuffer::GLTextureHandle) {
         bool stencilTestEnabled = glIsEnabled(GL_STENCIL_TEST);
         bool scissorTestEnabled = glIsEnabled(GL_SCISSOR_TEST);
 
@@ -1091,25 +1181,25 @@ QAbstractVideoSurface::Error QVideoSurfaceGlslPainter::paint(
         const GLfloat positionMatrix[4][4] =
         {
             {
-                /*(0,0)*/ wfactor * transform.m11() - transform.m13(),
-                /*(0,1)*/ hfactor * transform.m12() + transform.m13(),
+                /*(0,0)*/ GLfloat(wfactor * transform.m11() - transform.m13()),
+                /*(0,1)*/ GLfloat(hfactor * transform.m12() + transform.m13()),
                 /*(0,2)*/ 0.0,
-                /*(0,3)*/ transform.m13()
+                /*(0,3)*/ GLfloat(transform.m13())
             }, {
-                /*(1,0)*/ wfactor * transform.m21() - transform.m23(),
-                /*(1,1)*/ hfactor * transform.m22() + transform.m23(),
+                /*(1,0)*/ GLfloat(wfactor * transform.m21() - transform.m23()),
+                /*(1,1)*/ GLfloat(hfactor * transform.m22() + transform.m23()),
                 /*(1,2)*/ 0.0,
-                /*(1,3)*/ transform.m23()
+                /*(1,3)*/ GLfloat(transform.m23())
             }, {
                 /*(2,0)*/ 0.0,
                 /*(2,1)*/ 0.0,
                 /*(2,2)*/ -1.0,
                 /*(2,3)*/ 0.0
             }, {
-                /*(3,0)*/ wfactor * transform.dx() - transform.m33(),
-                /*(3,1)*/ hfactor * transform.dy() + transform.m33(),
+                /*(3,0)*/ GLfloat(wfactor * transform.dx() - transform.m33()),
+                /*(3,1)*/ GLfloat(hfactor * transform.dy() + transform.m33()),
                 /*(3,2)*/ 0.0,
-                /*(3,3)*/ transform.m33()
+                /*(3,3)*/ GLfloat(transform.m33())
             }
         };
 
@@ -1123,10 +1213,10 @@ QAbstractVideoSurface::Error QVideoSurfaceGlslPainter::paint(
 
         const GLfloat vertexCoordArray[] =
         {
-            target.left()     , vBottom,
-            target.right() + 1, vBottom,
-            target.left()     , vTop,
-            target.right() + 1, vTop
+            GLfloat(target.left())     , GLfloat(vBottom),
+            GLfloat(target.right() + 1), GLfloat(vBottom),
+            GLfloat(target.left())     , GLfloat(vTop),
+            GLfloat(target.right() + 1), GLfloat(vTop)
         };
 
         const GLfloat txLeft = source.left() / m_frameSize.width();
@@ -1179,14 +1269,18 @@ QAbstractVideoSurface::Error QVideoSurfaceGlslPainter::paint(
         m_program.release();
 
         painter->endNativePainting();
+
+        return QAbstractVideoSurface::NoError;
     }
-    return QAbstractVideoSurface::NoError;
+
+    return QVideoSurfaceGLPainter::paint(target, painter, source);
 }
 
 #endif
 
 /*!
     \class QPainterVideoSurface
+    \since 1.0
     \internal
 */
 
@@ -1294,7 +1388,7 @@ bool QPainterVideoSurface::present(const QVideoFrame &frame)
     if (!m_ready) {
         if (!isActive())
             setError(StoppedError);
-    } else if (frame.isValid() 
+    } else if (frame.isValid()
             && (frame.pixelFormat() != m_pixelFormat || frame.size() != m_frameSize)) {
         setError(IncorrectFormatError);
 
@@ -1536,6 +1630,18 @@ void QPainterVideoSurface::setShaderType(ShaderType type)
 
 #endif
 
+void QPainterVideoSurface::viewportDestroyed()
+{
+    if (m_painter) {
+        m_painter->viewportDestroyed();
+
+        setError(ResourceError);
+        stop();
+        delete m_painter;
+        m_painter = 0;
+    }
+}
+
 void QPainterVideoSurface::createPainter()
 {
     Q_ASSERT(!m_painter);
@@ -1563,11 +1669,11 @@ void QPainterVideoSurface::createPainter()
         m_painter = new QVideoSurfaceGlslPainter(m_glContext);
         break;
     default:
-        m_painter = new QVideoSurfaceRasterPainter;
+        m_painter = new QVideoSurfaceGenericPainter;
         break;
     }
 #else
-    m_painter = new QVideoSurfaceRasterPainter;
+    m_painter = new QVideoSurfaceGenericPainter;
 #endif
 }
 
