@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -81,6 +75,13 @@ QVideoWidgetControlBackend::QVideoWidgetControlBackend(
     QBoxLayout *layout = new QVBoxLayout;
     layout->setMargin(0);
     layout->setSpacing(0);
+
+#ifdef Q_OS_SYMBIAN
+    // On some cases the flag is not reset automatically
+    // This would lead to viewfinder not being visible on Symbian
+    control->videoWidget()->setAttribute(Qt::WA_WState_ExplicitShowHide, false);
+#endif // Q_OS_SYMBIAN
+
     layout->addWidget(control->videoWidget());
 
     widget->setLayout(layout);
@@ -327,6 +328,8 @@ QWindowVideoWidgetBackend::QWindowVideoWidgetBackend(
     connect(control, SIGNAL(saturationChanged(int)), m_widget, SLOT(_q_saturationChanged(int)));
     connect(control, SIGNAL(fullScreenChanged(bool)), m_widget, SLOT(_q_fullScreenChanged(bool)));
     connect(control, SIGNAL(nativeSizeChanged()), m_widget, SLOT(_q_dimensionsChanged()));
+
+    control->setWinId(widget->winId());
 }
 
 QWindowVideoWidgetBackend::~QWindowVideoWidgetBackend()
@@ -383,10 +386,17 @@ void QWindowVideoWidgetBackend::showEvent()
     m_windowControl->setWinId(m_widget->winId());
 
     m_windowControl->setDisplayRect(m_widget->rect());
+
+#if defined(Q_WS_WIN)
+    m_widget->setUpdatesEnabled(false);
+#endif
 }
 
 void QWindowVideoWidgetBackend::hideEvent(QHideEvent *)
 {
+#if defined(Q_WS_WIN)
+    m_widget->setUpdatesEnabled(true);
+#endif
 }
 
 void QWindowVideoWidgetBackend::moveEvent(QMoveEvent *)
@@ -412,6 +422,16 @@ void QWindowVideoWidgetBackend::paintEvent(QPaintEvent *event)
     event->accept();
 }
 
+#if defined(Q_WS_WIN)
+bool QWindowVideoWidgetBackend::winEvent(MSG *message, long *)
+{
+    if (message->message == WM_PAINT)
+        m_windowControl->repaint();
+
+    return false;
+}
+#endif
+
 void QVideoWidgetPrivate::setCurrentControl(QVideoWidgetControlInterface *control)
 {
     if (currentControl != control) {
@@ -565,27 +585,20 @@ void QVideoWidgetPrivate::_q_dimensionsChanged()
 
 /*!
     \class QVideoWidget
-    \preliminary
+
 
     \brief The QVideoWidget class provides a widget which presents video
     produced by a media object.
     \ingroup multimedia
+    \inmodule QtMultimediaKit
+    \since 1.0
 
     Attaching a QVideoWidget to a QMediaObject allows it to display the
     video or image output of that media object.  A QVideoWidget is attached
     to media object by passing a pointer to the QMediaObject in its
     constructor, and detached by destroying the QVideoWidget.
 
-    \code
-        player = new QMediaPlayer;
-
-        widget = new QVideoWidget;
-        widget->show();
-
-        player->setVideoOutput(widget);
-        player->setMedia(QUrl("http://example.com/movie.mp4"));
-        player->play();
-    \endcode
+    \snippet doc/src/snippets/multimedia-snippets/video.cpp Video widget
 
     \bold {Note}: Only a single display output can be attached to a media
     object at one time.
@@ -605,6 +618,20 @@ QVideoWidget::QVideoWidget(QWidget *parent)
     d_ptr->q_ptr = this;
 }
 
+/*!
+  \internal
+*/
+QVideoWidget::QVideoWidget(QVideoWidgetPrivate &dd, QWidget *parent)
+    : QWidget(parent, 0)
+    , d_ptr(&dd)
+{
+    d_ptr->q_ptr = this;
+
+    QPalette palette = QWidget::palette();
+    palette.setColor(QPalette::Background, Qt::black);
+    setPalette(palette);
+}
+
 /*!
     Destroys a video widget.
 */
@@ -625,6 +652,9 @@ QMediaObject *QVideoWidget::mediaObject() const
     return d_func()->mediaObject;
 }
 
+/*!
+    \internal
+*/
 bool QVideoWidget::setMediaObject(QMediaObject *object)
 {
     Q_D(QVideoWidget);
@@ -704,7 +734,7 @@ void QVideoWidget::setFullScreen(bool fullScreen)
         flags |= Qt::Window;
         flags &= ~Qt::SubWindow;
         setWindowFlags(flags);
-        
+
         showFullScreen();
     } else {
         showNormal();
@@ -866,9 +896,9 @@ QSize QVideoWidget::sizeHint() const
 }
 
 /*!
-    \reimp
-    \internal
- */
+  Current event \a event.
+  Returns the value of the baseclass QWidget::event(QEvent *event) function.
+*/
 bool QVideoWidget::event(QEvent *event)
 {
     Q_D(QVideoWidget);
@@ -975,6 +1005,21 @@ void QVideoWidget::paintEvent(QPaintEvent *event)
     }
 }
 
+
+#if defined(Q_WS_WIN)
+/*!
+    \reimp
+    \internal
+*/
+bool QVideoWidget::winEvent(MSG *message, long *result)
+{
+    return d_func()->windowBackend && d_func()->windowBackend->winEvent(message, result)
+            ? true
+            : QWidget::winEvent(message, result);
+}
+#endif
+
+
 #include "moc_qvideowidget.cpp"
 #include "moc_qvideowidget_p.cpp"
 QT_END_NAMESPACE
