@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -52,6 +52,19 @@
 
 QT_BEGIN_NAMESPACE
 
+namespace
+{
+class QVideoFramePrivateRegisterMetaTypes
+{
+public:
+    QVideoFramePrivateRegisterMetaTypes()
+    {
+        qRegisterMetaType<QVideoFrame::PixelFormat>("QVideoFrame::PixelFormat");
+    }
+} _registerMetaTypes;
+}
+
+
 class QVideoFramePrivate : public QSharedData
 {
 public:
@@ -241,6 +254,15 @@ private:
     \value Format_Y16
     The frame is stored using a 16-bit linear greyscale format.  Little endian.
 
+    \value Format_Jpeg
+    The frame is stored in compressed Jpeg format.
+
+    \value Format_CameraRaw
+    The frame is stored using device specific camera raw format.
+
+    \value Format_AdobeDng
+    The frame is stored using raw Adobe Digital Negative (DNG) format.
+
     \value Format_User
     Start value for user defined pixel formats.
 */
@@ -732,6 +754,9 @@ QImage::Format QVideoFrame::imageFormatFromPixelFormat(PixelFormat format)
     case Format_IMC4:
     case Format_Y8:
     case Format_Y16:
+    case Format_Jpeg:
+    case Format_CameraRaw:
+    case Format_AdobeDng:
         return QImage::Format_Invalid;
     case Format_User:
         return QImage::Format_Invalid;
