@@ -2,16 +2,16 @@
 **
 ** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
-** OrganizerItem: Nokia Corporation (qt-info@nokia.com)
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -117,6 +117,7 @@ QTM_BEGIN_NAMESPACE
  */
 
 
+
 #define makestr(x) (#x)
 #define makename(x) makestr(x)
 
@@ -284,6 +285,12 @@ void QOrganizerManager::createEngine(const QString& managerName, const QMap<QStr
     connect(d->m_engine, SIGNAL(collectionsAdded(QList<QOrganizerCollectionId>)), this, SIGNAL(collectionsAdded(QList<QOrganizerCollectionId>)));
     connect(d->m_engine, SIGNAL(collectionsChanged(QList<QOrganizerCollectionId>)), this, SIGNAL(collectionsChanged(QList<QOrganizerCollectionId>)));
     connect(d->m_engine, SIGNAL(collectionsRemoved(QList<QOrganizerCollectionId>)), this, SIGNAL(collectionsRemoved(QList<QOrganizerCollectionId>)));
+
+    connect(d->m_engine, SIGNAL(itemsChanged(QList<QOrganizerItemId>)),
+            this, SLOT(_q_itemsUpdated(QList<QOrganizerItemId>)));
+    connect(d->m_engine, SIGNAL(itemsRemoved(QList<QOrganizerItemId>)),
+            this, SLOT(_q_itemsDeleted(QList<QOrganizerItemId>)));
+
 }
 
 /*!
@@ -331,6 +338,7 @@ QOrganizerManager::~QOrganizerManager()
   \value InvalidItemTypeError The most recent operation failed because the item given was of an invalid type for the operation
   \value InvalidCollectionError The most recent operation failed because the collection is invalid
   \value InvalidOccurrenceError The most recent operation failed because it was an attempt to save an occurrence without a correct InstanceOrigin detail
+  \value TimeoutError The most recent operation failed because it took longer than expected.  It may be possible to try again.
  */
 
 /*! Return the error code of the most recent operation */
@@ -355,7 +363,7 @@ QMap<int, QOrganizerManager::Error> QOrganizerManager::errorMap() const
 
 /*!
   Return the list of a maximum of \a maxCount organizer item instances which are occurrences of the given \a parentItem recurring item, which
-  occur between the given \a periodStart date and the given \a periodEnd date.
+  occur between the given \a periodStart date and the given \a periodEnd date, inclusive.
 
   If \a periodStart is after \a periodEnd, the operation will fail.
   If \a maxCount is negative, it is backend specific as to how many occurrences will be returned.
@@ -384,7 +392,7 @@ QList<QOrganizerItemId> QOrganizerManager::itemIds(const QOrganizerItemFilter& f
 
 /*!
   Returns a list of organizer item ids of persisted items that match the given \a filter, sorted according to the given list of \a sortOrders,
-  for any item which occurs (or has an occurrence which occurs) in the range specified by the given \a startDate and \a endDate.
+  for any item which occurs (or has an occurrence which occurs) in the range specified by the given \a startDate and \a endDate, inclusive.
   A default-constructed (invalid) \a startDate specifies an open start date (matches anything which occurs up until the \a endDate),
   and a default-constructed (invalid) \a endDate specifies an open end date (matches anything which occurs after the \a startDate).
   If both the \a startDate and \a endDate are invalid, this function will return the ids of all items which match the \a filter criteria.
@@ -405,12 +413,11 @@ QList<QOrganizerItemId> QOrganizerManager::itemIds(const QDateTime& startDate, c
   Depending on the manager implementation, this filtering operation might be slow and involve retrieving all
   organizer items and testing them against the supplied filter - see the \l isFilterSupported() function.
 
-  The \a fetchHint parameter describes the optimization hints that a manager may take.
-  If the \a fetchHint is the default constructed hint, all existing details and relationships
-  in the matching organizer items will be returned.  A client should not make changes to an organizer item which has
-  been retrieved using a fetch hint other than the default fetch hint.  Doing so will result in information
-  loss when saving the organizer item back to the manager (as the "new" restricted organizer item will
-  replace the previously saved organizer item in the backend).
+  The \a fetchHint parameter describes the optimization hints that a manager may take.  If the \a
+  fetchHint is the default constructed hint, all existing details in the matching organizer items
+  will be returned.  If a client makes changes to an organizer item which has been retrieved with a
+  fetch hint, they should save it back using a partial save, masked by the same set of detail names
+  in order to avoid information loss.
 
   \sa QOrganizerItemFetchHint
  */
@@ -423,7 +430,7 @@ QList<QOrganizerItem> QOrganizerManager::items(const QOrganizerItemFilter& filte
 
 /*!
   Returns a list of organizer items that match the given \a filter, sorted according to the given list of \a sortOrders,
-  for any item or occurrence of an item which occurs in the range specified by the given \a startDate and \a endDate.
+  for any item or occurrence of an item which occurs in the range specified by the given \a startDate and \a endDate, inclusive.
   A default-constructed (invalid) \a startDate specifies an open start date (matches anything which occurs up until the \a endDate),
   and a default-constructed (invalid) \a endDate specifies an open end date (matches anything which occurs after the \a startDate).
   If both the \a startDate and \a endDate are invalid, this function will return all items which match the \a filter criteria.
@@ -433,12 +440,13 @@ QList<QOrganizerItem> QOrganizerManager::items(const QOrganizerItemFilter& filte
   Depending on the manager implementation, this filtering operation might be slow and involve retrieving all
   organizer items and testing them against the supplied filter - see the \l isFilterSupported() function.
 
-  The \a fetchHint parameter describes the optimization hints that a manager may take.
-  If the \a fetchHint is the default constructed hint, all existing details and relationships
-  in the matching organizer items will be returned.  A client should not make changes to an organizer item which has
-  been retrieved using a fetch hint other than the default fetch hint.  Doing so will result in information
-  loss when saving the organizer item back to the manager (as the "new" restricted organizer item will
-  replace the previously saved organizer item in the backend).
+  If no sort order is provided, the list is returned sorted by date.
+
+  The \a fetchHint parameter describes the optimization hints that a manager may take.  If the \a
+  fetchHint is the default constructed hint, all existing details in the matching organizer items
+  will be returned.  If a client makes changes to an organizer item which has been retrieved with a
+  fetch hint, they should save it back using a partial save, masked by the same set of detail names
+  in order to avoid information loss.
 
   \sa QOrganizerItemFetchHint
  */
@@ -449,9 +457,39 @@ QList<QOrganizerItem> QOrganizerManager::items(const QDateTime& startDate, const
     return d->m_engine->items(startDate, endDate, filter, sortOrders, fetchHint, &d->m_error);
 }
 
+/*!
+  Returns a list of organizer items in the range specified by the given \a startDate and \a endDate,
+  inclusive.  The list will contain the first \a maxCount such items which match the given \a
+  filter.  A default-constructed (invalid) \a startDate specifies an open start date (matches
+  anything which occurs up until the \a endDate), and a default-constructed (invalid) \a endDate
+  specifies an open end date (matches anything which occurs after the \a startDate).  The list is
+  sorted by date.
+
+  This function will return both persisted and generated occurrences of items which match the
+  specified criteria.
+
+  Depending on the manager implementation, this filtering operation might be slow and involve
+  retrieving all organizer items and testing them against the supplied filter - see the \l
+  isFilterSupported() function.
+
+  The \a fetchHint parameter describes the optimization hints that a manager may take.  If the \a
+  fetchHint is the default constructed hint, all existing details in the matching organizer items
+  will be returned.  If a client makes changes to an organizer item which has been retrieved with a
+  fetch hint, they should save it back using a partial save, masked by the same set of detail names
+  in order to avoid information loss.
+
+  \sa QOrganizerItemFetchHint
+ */
+QList<QOrganizerItem> QOrganizerManager::items(const QDateTime& startDate, const QDateTime& endDate, int maxCount, const QOrganizerItemFilter& filter, const QOrganizerItemFetchHint& fetchHint) const
+{
+    d->m_error = QOrganizerManager::NoError;
+    d->m_errorMap.clear();
+    return d->m_engine->items(startDate, endDate, maxCount, filter, fetchHint, &d->m_error);
+}
+
 /*!
   Returns a list of organizer items that match the given \a filter, sorted according to the given list of \a sortOrders,
-  for any item which occurs (or has an occurrence which occurs) in the range specified by the given \a startDate and \a endDate.
+  for any item which occurs (or has an occurrence which occurs) in the range specified by the given \a startDate and \a endDate, inclusive.
   A default-constructed (invalid) \a startDate specifies an open start date (matches anything which occurs up until the \a endDate),
   and a default-constructed (invalid) \a endDate specifies an open end date (matches anything which occurs after the \a startDate).
   If both the \a startDate and \a endDate are invalid, this function will return all items which match the \a filter criteria.
@@ -461,12 +499,11 @@ QList<QOrganizerItem> QOrganizerManager::items(const QDateTime& startDate, const
   Depending on the manager implementation, this filtering operation might be slow and involve retrieving all
   organizer items and testing them against the supplied filter - see the \l isFilterSupported() function.
 
-  The \a fetchHint parameter describes the optimization hints that a manager may take.
-  If the \a fetchHint is the default constructed hint, all existing details and relationships
-  in the matching organizer items will be returned.  A client should not make changes to an organizer item which has
-  been retrieved using a fetch hint other than the default fetch hint.  Doing so will result in information
-  loss when saving the organizer item back to the manager (as the "new" restricted organizer item will
-  replace the previously saved organizer item in the backend).
+  The \a fetchHint parameter describes the optimization hints that a manager may take.  If the \a
+  fetchHint is the default constructed hint, all existing details in the matching organizer items
+  will be returned.  If a client makes changes to an organizer item which has been retrieved with a
+  fetch hint, they should save it back using a partial save, masked by the same set of detail names
+  in order to avoid information loss.
 
   \sa QOrganizerItemFetchHint
  */
@@ -478,29 +515,28 @@ QList<QOrganizerItem> QOrganizerManager::itemsForExport(const QDateTime& startDa
 }
 
 /*!
-  Returns the organizer item in the database identified by \a organizeritemId.
+  Returns the organizer item in the database identified by \a itemId.
 
   If the organizer item does not exist, an empty, default constructed QOrganizerItem will be returned,
   and the error returned by \l error() will be \c QOrganizerManager::DoesNotExistError.
 
-  The \a fetchHint parameter describes the optimization hints that a manager may take.
-  If the \a fetchHint is the default constructed hint, all existing details and relationships
-  in the matching organizer item will be returned.  A client should not make changes to an organizer item which has
-  been retrieved using a fetch hint other than the default fetch hint.  Doing so will result in information
-  loss when saving the organizer item back to the manager (as the "new" restricted organizer item will
-  replace the previously saved organizer item in the backend).
+  The \a fetchHint parameter describes the optimization hints that a manager may take.  If the \a
+  fetchHint is the default constructed hint, all existing details in the matching organizer items
+  will be returned.  If a client makes changes to an organizer item which has been retrieved with a
+  fetch hint, they should save it back using a partial save, masked by the same set of detail names
+  in order to avoid information loss.
 
   \sa QOrganizerItemFetchHint
  */
-QOrganizerItem QOrganizerManager::item(const QOrganizerItemId& organizeritemId, const QOrganizerItemFetchHint& fetchHint) const
+QOrganizerItem QOrganizerManager::item(const QOrganizerItemId& itemId, const QOrganizerItemFetchHint& fetchHint) const
 {
     d->m_error = QOrganizerManager::NoError;
     d->m_errorMap.clear();
-    return d->m_engine->item(organizeritemId, fetchHint, &d->m_error);
+    return d->m_engine->item(itemId, fetchHint, &d->m_error);
 }
 
 /*!
-  Adds the given \a organizeritem to the database if \a organizeritem has a
+  Adds the given \a item to the database if \a item has a
   default-constructed id, or an id with the manager URI set to the URI of
   this manager and a id of zero.  It will be saved in the collection whose
   id is reported by calling item->collectionId() if the specified collection exists,
@@ -509,15 +545,15 @@ QOrganizerItem QOrganizerManager::item(const QOrganizerItemId& organizeritemId,
   saved (if it is not a new item) or in the default collection (if it is a new item).
   As such, an item may be moved between collections with this save operation.
 
-  If the manager URI of the id of the \a organizeritem is neither empty nor equal to the URI of
-  this manager, or id of the \a organizeritem is non-zero but does not exist in the
+  If the manager URI of the id of the \a item is neither empty nor equal to the URI of
+  this manager, or id of the \a item is non-zero but does not exist in the
   manager, the operation will fail and calling error() will return
   \c QOrganizerManager::DoesNotExistError.
 
-  Alternatively, the function will update the existing organizer item in the database if \a organizeritem
+  Alternatively, the function will update the existing organizer item in the database if \a item
   has a non-zero id and currently exists in the database.
 
-  If the \a organizeritem contains one or more details whose definitions have
+  If the \a item contains one or more details whose definitions have
   not yet been saved with the manager, the operation will fail and calling
   error() will return \c QOrganizerManager::UnsupportedError.
 
@@ -533,12 +569,12 @@ QOrganizerItem QOrganizerManager::item(const QOrganizerItemId& organizeritemId,
 
   \sa managerUri()
  */
-bool QOrganizerManager::saveItem(QOrganizerItem* organizeritem)
+bool QOrganizerManager::saveItem(QOrganizerItem* item)
 {
     d->m_errorMap.clear();
-    if (organizeritem) {
+    if (item) {
         d->m_error = QOrganizerManager::NoError;
-        return d->m_engine->saveItem(organizeritem, &d->m_error);
+        return d->m_engine->saveItem(item, &d->m_error);
     } else {
         d->m_error = QOrganizerManager::BadArgumentError;
         return false;
@@ -546,22 +582,22 @@ bool QOrganizerManager::saveItem(QOrganizerItem* organizeritem)
 }
 
 /*!
-  Remove the organizer item identified by \a organizeritemId from the database.
+  Remove the organizer item identified by \a itemId from the database.
   Returns true if the organizer item was removed successfully, otherwise
   returns false.
  */
-bool QOrganizerManager::removeItem(const QOrganizerItemId& organizeritemId)
+bool QOrganizerManager::removeItem(const QOrganizerItemId& itemId)
 {
     d->m_error = QOrganizerManager::NoError;
     d->m_errorMap.clear();
-    return d->m_engine->removeItem(organizeritemId, &d->m_error);
+    return d->m_engine->removeItem(itemId, &d->m_error);
 }
 
 /*!
-  Adds the list of organizer items given by \a organizeritems list to the database.
+  Adds the list of organizer items given by \a items list to the database.
   Each item in the list will be saved in the collection whose
-  id is reported by calling item->collectionId() if the specified collection exists,
-  or if no collectionId is specified in the item, or the collectionId is the default
+  id is reported by calling item->collectionId() if the specified collection exists.
+  If no collectionId is specified in the item, or if the collectionId is the default
   collection id, it will be saved in the collection in which the item is currently
   saved (if it is not a new item) or in the default collection (if it is a new item).
   As such, an item may be moved between collections with this save operation.
@@ -572,21 +608,55 @@ bool QOrganizerManager::removeItem(const QOrganizerItemId& organizeritemId)
   if all organizer items were saved successfully.
 
   For each newly saved organizer item that was successful, the id of the organizer item
-  in the \a organizeritems list will be updated with the new value.  If a failure occurs
-  when saving a new item, the id will be cleared.
+  in the \a items list will be updated with the new value.
 
   \sa QOrganizerManager::saveItem()
  */
-bool QOrganizerManager::saveItems(QList<QOrganizerItem>* organizeritems)
+bool QOrganizerManager::saveItems(QList<QOrganizerItem>* items)
 {
     d->m_errorMap.clear();
-    if (!organizeritems) {
+    if (!items) {
         d->m_error = QOrganizerManager::BadArgumentError;
         return false;
     }
 
     d->m_error = QOrganizerManager::NoError;
-    return d->m_engine->saveItems(organizeritems, &d->m_errorMap, &d->m_error);
+    return d->m_engine->saveItems(items, &d->m_errorMap, &d->m_error);
+}
+
+/*!
+  Adds the list of organizer items given by \a items list to the database.
+  Each item in the list will be saved in the collection whose
+  id is reported by calling item->collectionId() if the specified collection exists.
+  If no collectionId is specified in the item, or if the collectionId is the default
+  collection id, it will be saved in the collection in which the item is currently
+  saved (if it is not a new item) or in the default collection (if it is a new item).
+  As such, an item may be moved between collections with this save operation.
+  Returns true if the organizer items were saved successfully, otherwise false.
+
+  This function accepts a \a definitionMask, which specifies which details of
+  the items should be updated.  Details with definition names not included in
+  the definitionMask will not be updated or added.
+
+  Calling \l errorMap() will return the per-input errors for the latest batch function.
+  The \l QOrganizerManager::error() function will only return \c QOrganizerManager::NoError
+  if all organizer items were saved successfully.
+
+  For each newly saved organizer item that was successful, the id of the organizer item
+  in the \a items list will be updated with the new value.
+
+  \sa QOrganizerManager::saveItem()
+ */
+bool QOrganizerManager::saveItems(QList<QOrganizerItem>* items, const QStringList& definitionMask)
+{
+    d->m_errorMap.clear();
+    if (!items) {
+        d->m_error = QOrganizerManager::BadArgumentError;
+        return false;
+    }
+
+    d->m_error = QOrganizerManager::NoError;
+    return d->m_engine->saveItems(items, definitionMask, &d->m_errorMap, &d->m_error);
 }
 
 /*!
@@ -855,7 +925,7 @@ QString QOrganizerManager::managerUri() const
 QList<QOrganizerItemId> QOrganizerManager::extractIds(const QList<QOrganizerItem>& items)
 {
     QList<QOrganizerItemId> ids;
-#if QT_VERSION > 0x040700    
+#if QT_VERSION > 0x040700
     ids.reserve(items.count());
 #endif
 
