@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -43,6 +43,10 @@
 #include <QDateTime>
 #include <QList>
 
+#ifndef QT_NO_DEBUG_STREAM
+#include <QDebug>
+#endif
+
 #include "qtorganizerglobal.h"
 #include "qorganizerrecurrencerule_p.h"
 #include "qorganizerrecurrencerule.h"
@@ -525,5 +529,74 @@ uint qHash(const QOrganizerRecurrenceRule& r)
     return hash * prime1;
 }
 
+#ifndef QT_NO_DEBUG_STREAM
+/*!
+  Outputs \a rule to the debug stream \a dbg
+ */
+QDebug operator<<(QDebug dbg, const QOrganizerRecurrenceRule& rule)
+{
+    dbg.nospace() << "QOrganizerRecurrenceRule(frequency=";
+    dbg.nospace() << rule.frequency();
+    dbg.nospace() << ",";
+    dbg.nospace() << "interval=";
+    dbg.nospace() << rule.interval();
+    dbg.nospace() << ",";
+    switch (rule.limitType()) {
+        case QOrganizerRecurrenceRule::CountLimit:
+            dbg.nospace() << "limitCount=";
+            dbg.nospace() << rule.limitCount();
+            break;
+        case QOrganizerRecurrenceRule::DateLimit:
+            dbg.nospace() << "limitDate=";
+            dbg.nospace() << rule.limitDate().toString();
+            break;
+        case QOrganizerRecurrenceRule::NoLimit:
+            dbg.nospace() << "no limit";
+            break;
+        default:
+            break;
+    }
+    dbg.nospace() << ",daysOfWeek=\"";
+    foreach(Qt::DayOfWeek day, rule.daysOfWeek()){
+        dbg.nospace() << static_cast<quint32>(day);
+        dbg.space();
+    }
+    dbg.nospace() << "\"";
+
+    dbg.nospace() << ",daysOfMonth=\"";
+    foreach(int day, rule.daysOfMonth()){
+        dbg.nospace() << day;
+        dbg.space();
+    }
+    dbg.nospace() << "\"";
+
+    dbg.nospace() << ",daysOfYear=\"";
+    foreach(int day, rule.daysOfYear()){
+        dbg.nospace() << day;
+        dbg.space();
+    }
+    dbg.nospace() << "\"";
+
+    dbg.nospace() << ",monthsOfYear=\"";
+    foreach(QOrganizerRecurrenceRule::Month month, rule.monthsOfYear()){
+        dbg.nospace() << static_cast<quint32>(month);
+        dbg.space();
+    }
+    dbg.nospace() << "\"";
+
+    dbg.nospace() << ",positions=\"";
+    foreach(int position, rule.positions()){
+        dbg.nospace() << position;
+        dbg.space();
+    }
+    dbg.nospace() << "\",";
+
+    dbg.nospace() << "firstDayOfWeek=";
+    dbg.nospace() << static_cast<quint32>(rule.firstDayOfWeek());
+    dbg.nospace() << ')';
+    return dbg.maybeSpace();
+}
+#endif
+
 QTM_END_NAMESPACE
 
