@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -67,7 +61,10 @@ QTM_BEGIN_NAMESPACE
     \class QAbstractValueSpaceLayer
     \brief The QAbstractValueSpaceLayer class provides support for adding new logical data layers
            to the Qt Value Space.
+    \inmodule QtPublishSubscribe
     \ingroup publishsubscribe
+    \internal
+    \since 1.0
 
     To create a new layer in the Value Space subclass this class and reimplement all of the virtual
     functions.  The new layer is installed by either calling QValueSpace::installLayer() or by
@@ -75,6 +72,8 @@ QTM_BEGIN_NAMESPACE
 */
 
 /*!
+    \internal
+
     \macro QVALUESPACE_AUTO_INSTALL_LAYER(className)
 
     \relates QAbstractValueSpaceLayer
@@ -307,6 +306,7 @@ void QAbstractValueSpaceLayer::emitInterestChanged(QValueSpacePublisher *publish
     \brief The QValueSpace namespace contains miscellaneous identifiers used throughtout the
            Publish and Subscribe API.
     \ingroup publishsubscribe
+    \inmodule QtPublishSubscribe
 */
 
 /*!
@@ -378,10 +378,12 @@ void QAbstractValueSpaceLayer::emitInterestChanged(QValueSpacePublisher *publish
 */
 void QValueSpace::initValueSpaceServer()
 {
-    QValueSpaceManager::instance()->initServer();
+    QValueSpaceManager::instance()->init(QAbstractValueSpaceLayer::Server);
 }
 
 /*!
+    \internal
+
     Used by Value Space layer implementations to install themselves into the system.  \a layer
     should be a pointer to the layer to install.
 
@@ -517,6 +519,16 @@ QString qCanonicalPath(const QString &path)
     return result;
 }
 
+#ifdef QT_SIMULATOR
+QString qAddSimulatorPrefix(const QString &path)
+{
+    QString result("/SimulatorPrivate");
+    result.append(path);
+    return result;
+}
+
+#endif
+
 #include "moc_qvaluespace_p.cpp"
 
 QTM_END_NAMESPACE
