@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -63,7 +57,9 @@ QTM_BEGIN_NAMESPACE
     \brief The QValueSpaceSubscriber class allows applications to read and subscribe to Value Space
            paths.
 
+    \inmodule QtPublishSubscribe
     \ingroup publishsubscribe
+    \since 1.0
 
     By default QValueSpaceSubscriber can read values from and report change notifications for all
     available Value Space layers.  Only data from the layer with the highest order and that
@@ -160,6 +156,9 @@ public:
     bool disconnect(QValueSpaceSubscriber * space);
 
     const QString path;
+#ifdef QT_SIMULATOR
+    const QString originalPath;
+#endif
     const LayerList readers;
 
     mutable QMutex lock;
@@ -205,7 +204,13 @@ static LayerList matchLayers(const QString &path, QValueSpace::LayerOptions filt
 
 QValueSpaceSubscriberPrivate::QValueSpaceSubscriberPrivate(const QString &path,
                                                            QValueSpace::LayerOptions filter)
-:   path(qCanonicalPath(path)), readers(matchLayers(this->path, filter)), connections(0)
+#ifndef QT_SIMULATOR
+:   path(qCanonicalPath(path)),
+#else
+:   path(qAddSimulatorPrefix(qCanonicalPath(path))),
+    originalPath(qCanonicalPath(path)),
+#endif
+    readers(matchLayers(this->path, filter)), connections(0)
 {
 }
 
@@ -237,7 +242,13 @@ static LayerList matchLayers(const QString &path, const QUuid &uuid)
 }
 
 QValueSpaceSubscriberPrivate::QValueSpaceSubscriberPrivate(const QString &path, const QUuid &uuid)
-:   path(qCanonicalPath(path)), readers(matchLayers(this->path, uuid)), connections(0)
+#ifndef QT_SIMULATOR
+:   path(qCanonicalPath(path)),
+#else
+:   path(qAddSimulatorPrefix(qCanonicalPath(path))),
+    originalPath(qCanonicalPath(path)),
+#endif
+    readers(matchLayers(this->path, uuid)), connections(0)
 {
 }
 
@@ -302,8 +313,7 @@ bool QValueSpaceSubscriberPrivate::disconnect(QValueSpaceSubscriber * space)
 /*!
     Constructs a QValueSpaceSubscriber with the specified \a parent that refers to the root path.
 
-    The constructed Value Space subscriber will access all available
-    \l {QAbstractValueSpaceLayer}{layers}.
+    The constructed Value Space subscriber will access all available layers.
 */
 QValueSpaceSubscriber::QValueSpaceSubscriber(QObject *parent)
 :   QObject(parent)
@@ -314,8 +324,7 @@ QValueSpaceSubscriber::QValueSpaceSubscriber(QObject *parent)
 /*!
     Constructs a QValueSpaceSubscriber with the specified \a parent that refers to \a path.
 
-    The constructed Value Space subscriber will access all available
-    \l {QAbstractValueSpaceLayer}{layers}.
+    The constructed Value Space subscriber will access all available layers.
 */
 QValueSpaceSubscriber::QValueSpaceSubscriber(const QString &path, QObject *parent)
 :   QObject(parent)
@@ -345,12 +354,12 @@ QValueSpaceSubscriber::QValueSpaceSubscriber(QValueSpace::LayerOptions filter,
     QValueSpaceSubscriber will only use the layer identified by \a uuid.
 
     Use of this constructor is not platform agnostic.  If possible use one of the constructors that
-    take a QAbstractValueSpaceLayer::LayerOptions parameter instead.
+    take a QValueSpace::LayerOptions parameter instead.
 
     If a layer with a matching \a uuid is not found, the constructed QValueSpaceSubscriber will be
     unconnected.
 
-    \sa QAbstractValueSpaceLayer::id(), QValueSpace, isConnected()
+    \sa QValueSpace, isConnected()
 */
 QValueSpaceSubscriber::QValueSpaceSubscriber(const QUuid &uuid,
                                              const QString &path,
@@ -378,7 +387,7 @@ QValueSpaceSubscriber::~QValueSpaceSubscriber()
 */
 void QValueSpaceSubscriber::setPath(const QString &path)
 {
-    if (d->path == path)
+    if (this->path() == path)
         return;
 
     d->disconnect(this);
@@ -407,7 +416,11 @@ void QValueSpaceSubscriber::setPath(QValueSpaceSubscriber *subscriber)
 
 QString QValueSpaceSubscriber::path() const
 {
+#ifndef QT_SIMULATOR
     return d->path;
+#else
+    return d->originalPath;
+#endif
 }
 
 /*!
@@ -419,7 +432,7 @@ void QValueSpaceSubscriber::cd(const QString &path)
     if (path.startsWith(QLatin1Char('/')))
         setPath(path);
     else
-        setPath(d->path + QLatin1Char('/') + path);
+        setPath(this->path() + QLatin1Char('/') + path);
 }
 
 /*!
@@ -427,10 +440,10 @@ void QValueSpaceSubscriber::cd(const QString &path)
 */
 void QValueSpaceSubscriber::cdUp()
 {
-    if (d->path == QLatin1String("/"))
+    if (path() == QLatin1String("/"))
         return;
 
-    QString p(d->path);
+    QString p(path());
 
     int index = p.lastIndexOf(QLatin1Char('/'));
 
@@ -457,10 +470,10 @@ bool QValueSpaceSubscriber::isConnected() const
 
     \code
         QValueSpaceSubscriber base("/Settings");
-        QValueSpaceSubscriber equiv("/Settings/Nokia/General/Mappings);
+        QValueSpaceSubscriber equiv("/Settings/Nokia/General/Mappings");
 
         // Is true
-        equiv.value() == base.value("Nokia/General/Mapping");
+        equiv.value() == base.value("Nokia/General/Mappings");
     \endcode
 */
 QVariant QValueSpaceSubscriber::value(const QString & subPath, const QVariant &def) const
