@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -50,13 +50,17 @@ IMPLEMENT_READING(QOrientationReading)
     \class QOrientationReading
     \ingroup sensors_reading
     \inmodule QtSensors
+    \since 1.0
 
     \brief The QOrientationReading class represents one reading from the
            orientation sensor.
 
-    It should be noted that the orientation sensor reports the orientation of the device
-    and not the UI. The orientation of the device will not change just because the UI is
-    rotated.
+    The orientation sensor reports the orientation of the device. As it operates below
+    the UI level it does not report on or even know how the UI is rotated. Most importantly
+    this means that this sensor cannot be used to detect if a device is in portrait or
+    landscape mode.
+
+    This sensor is useful to detect that a particular side of the device is pointing up.
 
     \section2 QOrientationReading Units
     The orientation sensor returns the orientation of the device using
@@ -87,7 +91,8 @@ IMPLEMENT_READING(QOrientationReading)
 
     It should be noted that the orientation sensor reports the orientation of the device
     and not the UI. The orientation of the device will not change just because the UI is
-    rotated.
+    rotated. This means this sensor cannot be used to detect if a device is in portrait
+    or landscape mode.
 */
 
 /*!
