@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -60,18 +60,42 @@ QTM_BEGIN_NAMESPACE
 
     Note that sensor timestamps from different sensors may not be directly
     comparable (as they may choose different fixed points for their reference).
+
+    \bold{Note that some platforms do not deliver timestamps correctly}.
+    Applications should be prepared for occasional issues that cause timestamps to jump
+    forwards or backwards. The \l{sensors-api.html#platform-notes}{platform notes} have
+    more details.
 */
 
-// A bit of a hack to call qRegisterMetaType when the library is loaded.
-static int qtimestamp_id = qRegisterMetaType<QtMobility::qtimestamp>("QtMobility::qtimestamp");
-static int qrange_id = qRegisterMetaType<QtMobility::qrange>("QtMobility::qrange");
-static int qrangelist_id = qRegisterMetaType<QtMobility::qrangelist>("QtMobility::qrangelist");
-static int qoutputrangelist_id = qRegisterMetaType<QtMobility::qoutputrangelist>("QtMobility::qoutputrangelist");
+/*!
+    \typedef qrange
+    \relates QSensor
 
-// =====================================================================
+    This type is defined as a QPair.
+
+    \code
+    typedef QPair<int,int> qrange;
+    \endcode
+
+    \sa QPair, qrangelist, QSensor::availableDataRates
+*/
+
+/*!
+    \typedef qrangelist
+    \relates QSensor
+
+    This type is defined as a list of qrange values.
+
+    \code
+    typedef QList<qrange> qrangelist;
+    \endcode
+
+    \sa QList, qrange, QSensor::availableDataRates
+*/
 
 /*!
     \class qoutputrange
+    \relates QSensor
     \brief The qoutputrange class holds the specifics of an output range.
 
     The class is defined as a simple struct.
@@ -99,7 +123,7 @@ static int qoutputrangelist_id = qRegisterMetaType<QtMobility::qoutputrangelist>
     256 possible values to report with. These values are scaled so that they can represent either
     -2G to +2G (with an accuracy value of 0.015G) or -8G to +8G (with an accuracy value of 0.06G).
 
-    \sa QSensor::outputRanges
+    \sa qoutputrangelist, QSensor::outputRanges
 */
 
 /*!
@@ -123,6 +147,25 @@ static int qoutputrangelist_id = qRegisterMetaType<QtMobility::qoutputrangelist>
     the sensor can detect and is expressed using the same units as the minimum and maximum.
 */
 
+/*!
+    \typedef qoutputrangelist
+    \relates QSensor
+
+    This type is defined as a list of qoutputrange values.
+
+    \code
+    typedef QList<qoutputrange> qoutputrangelist;
+    \endcode
+
+    \sa QList, qoutputrange, QSensor::outputRanges
+*/
+
+// A bit of a hack to call qRegisterMetaType when the library is loaded.
+static int qtimestamp_id = qRegisterMetaType<QtMobility::qtimestamp>("QtMobility::qtimestamp");
+static int qrange_id = qRegisterMetaType<QtMobility::qrange>("QtMobility::qrange");
+static int qrangelist_id = qRegisterMetaType<QtMobility::qrangelist>("QtMobility::qrangelist");
+static int qoutputrangelist_id = qRegisterMetaType<QtMobility::qoutputrangelist>("QtMobility::qoutputrangelist");
+
 // =====================================================================
 
 /*!
@@ -143,6 +186,8 @@ static int qoutputrangelist_id = qRegisterMetaType<QtMobility::qoutputrangelist>
     \endlist
 
     The sensor data is delivered via QSensorData and its sub-classes.
+
+    \sa QSensorReading
 */
 
 /*!
@@ -153,6 +198,7 @@ QSensor::QSensor(const QByteArray &type, QObject *parent)
     , d(new QSensorPrivate)
 {
     d->type = type;
+    registerInstance(); // so the availableSensorsChanged() signal works
 }
 
 /*!
@@ -205,7 +251,7 @@ QByteArray QSensor::identifier() const
 
 void QSensor::setIdentifier(const QByteArray &identifier)
 {
-    if (d->backend) {
+    if (isConnectedToBackend()) {
         qWarning() << "ERROR: Cannot call QSensor::setIdentifier while connected to a backend!";
         return;
     }
@@ -233,11 +279,25 @@ QByteArray QSensor::type() const
 */
 bool QSensor::connectToBackend()
 {
-    if (d->backend)
+    if (isConnectedToBackend())
         return true;
 
     d->backend = QSensorManager::createBackend(this);
-    return (d->backend != 0);
+
+    // Reset the properties to their default values and re-set them now so
+    // that the logic we've put into the setters gets called.
+    if (d->dataRate != 0) {
+        int tmp = d->dataRate;
+        d->dataRate = 0;
+        setDataRate(tmp);
+    }
+    if (d->outputRange != -1) {
+        int tmp = d->outputRange;
+        d->outputRange = -1;
+        setOutputRange(tmp);
+    }
+
+    return isConnectedToBackend();
 }
 
 /*!
@@ -263,14 +323,15 @@ bool QSensor::isBusy() const
 /*!
     \fn QSensor::busyChanged()
 
-    This signal is emitted when the busy state changes. This can
-    be used to grab a sensor when it becomes available.
-*/
+    This signal is emitted when the sensor is no longer busy.
+    This can be used to grab a sensor when it becomes available.
 
-/*!
-    \fn QSensor::activeChanged()
-
-    This signal is emitted when the active property changes.
+    \code
+    sensor.start();
+    if (sensor.isBusy()) {
+        // need to wait for busyChanged signal and try again
+    }
+    \endcode
 */
 
 /*!
@@ -278,10 +339,13 @@ bool QSensor::isBusy() const
     \brief a value to indicate if the sensor is active.
 
     This is true if the sensor is active (returning values). This is false otherwise.
+
+    Note that setting this value to true will not have an immediate effect. Instead,
+    the sensor will be started once the event loop has been reached.
 */
 void QSensor::setActive(bool active)
 {
-    if (active == d->active)
+    if (active == isActive())
         return;
 
     if (active)
@@ -309,7 +373,10 @@ bool QSensor::isActive() const
     See the sensor_explorer example for an example of how to interpret and use
     this information.
 
-    \sa QSensor::dataRate
+    Note that this information is not mandatory as not all sensors have a rate at which
+    they run. In such cases, the list will be empty.
+
+    \sa QSensor::dataRate, qrangelist
 */
 
 qrangelist QSensor::availableDataRates() const
@@ -350,7 +417,7 @@ int QSensor::dataRate() const
 
 void QSensor::setDataRate(int rate)
 {
-    if (rate == 0) {
+    if (rate == 0 || !isConnectedToBackend()) {
         d->dataRate = rate;
         return;
     }
@@ -363,7 +430,7 @@ void QSensor::setDataRate(int rate)
         }
     }
     if (warn) {
-        qWarning() << "setDataRate: rate" << rate << "is not supported by the sensor.";
+        qWarning() << "setDataRate:" << rate << "is not supported by the sensor.";
     }
 }
 
@@ -400,7 +467,7 @@ void QSensor::setDataRate(int rate)
 */
 bool QSensor::start()
 {
-    if (d->active)
+    if (isActive())
         return true;
     if (!connectToBackend())
         return false;
@@ -410,7 +477,7 @@ bool QSensor::start()
     // Backend will update the flags appropriately
     d->backend->start();
     Q_EMIT activeChanged();
-    return d->active;
+    return isActive();
 }
 
 /*!
@@ -422,7 +489,7 @@ bool QSensor::start()
 */
 void QSensor::stop()
 {
-    if (!d->active || !d->backend)
+    if (!isConnectedToBackend() || !isActive())
         return;
     d->active = false;
     d->backend->stop();
@@ -433,7 +500,10 @@ void QSensor::stop()
     \property QSensor::reading
     \brief the reading class.
 
-    The reading class provides access to sensor readings.
+    The reading class provides access to sensor readings. The reading object
+    is a volatile cache of the most recent sensor reading that has been received
+    so the application should process readings immediately or save the values
+    somewhere for later processing.
 
     Note that this will return 0 until a sensor backend is connected to a backend.
 
@@ -462,6 +532,7 @@ void QSensor::addFilter(QSensorFilter *filter)
         qWarning() << "addFilter: passed a null filter!";
         return;
     }
+    filter->setSensor(this);
     d->filters << filter;
 }
 
@@ -480,6 +551,16 @@ void QSensor::removeFilter(QSensorFilter *filter)
     filter->setSensor(0);
 }
 
+/*!
+    Returns the filters currently attached to the sensor.
+
+    \sa QSensorFilter
+*/
+QList<QSensorFilter*> QSensor::filters() const
+{
+    return d->filters;
+}
+
 /*!
     \fn QSensor::d_func() const
     \internal
@@ -488,14 +569,27 @@ void QSensor::removeFilter(QSensorFilter *filter)
 /*!
     \fn QSensor::readingChanged()
 
-    This signal is emitted when the reading has changed.
+    This signal is emitted when a new sensor reading is received.
 
-    Before this signal has been emitted for the first time, the sensor reading will
+    The sensor reading can be found in the QSensor::reading property. Note that the
+    reading object is a volatile cache of the most recent sensor reading that has
+    been received so the application should process the reading immediately or
+    save the values somewhere for later processing.
+
+    Before this signal has been emitted for the first time, the reading object will
     have uninitialized data.
 
     \sa start()
 */
 
+/*!
+    \fn QSensor::activeChanged()
+
+    This signal is emitted when the QSensor::active property has changed.
+
+    \sa QSensor::active
+*/
+
 /*!
     \property QSensor::outputRanges
     \brief a list of output ranges the sensor supports.
@@ -503,13 +597,11 @@ void QSensor::removeFilter(QSensorFilter *filter)
     A sensor may have more than one output range. Typically this is done
     to give a greater measurement range at the cost of lowering accuracy.
 
-    The qoutputrangelist type exists for the benefit of the meta-type system.
-    It is just a typedef.
-    \code
-    typedef qoutputrangelist QList<qoutputrange>;
-    \endcode
+    Note that this information is not mandatory. This information is typically only
+    available for sensors that have selectable output ranges (such as typical
+    accelerometers).
 
-    \sa QSensor::outputRange, qoutputrange
+    \sa QSensor::outputRange, qoutputrangelist
 */
 
 qoutputrangelist QSensor::outputRanges() const
@@ -542,11 +634,18 @@ int QSensor::outputRange() const
 
 void QSensor::setOutputRange(int index)
 {
-    if (index < -1 || index >= d->outputRanges.count()) {
-        qWarning() << "ERROR: Output range" << index << "is not valid";
+    if (index == -1 || !isConnectedToBackend()) {
+        d->outputRange = index;
         return;
     }
-    d->outputRange = index;
+    bool warn = true;
+    if (index >= 0 && index < d->outputRanges.count()) {
+        warn = false;
+        d->outputRange = index;
+    }
+    if (warn) {
+        qWarning() << "setOutputRange:" << index << "is not supported by the sensor.";
+    }
 }
 
 /*!
@@ -579,6 +678,19 @@ int QSensor::error() const
     You should call isActive() to determine if the sensor is still running.
 */
 
+/*!
+    \fn QSensor::availableSensorsChanged()
+
+    This signal is emitted when the list of available sensors has changed.
+    The sensors available to a program will not generally change over time
+    however some of the avilable sensors may represent hardware that is not
+    permanently connected. For example, a game controller that is connected
+    via bluetooth would become available when it was on and would become
+    unavailable when it was off.
+
+    \sa QSensor::sensorTypes(), QSensor::sensorsForType()
+*/
+
 // =====================================================================
 
 /*!
@@ -774,6 +886,12 @@ void QSensorReading::copyValuesFrom(QSensorReading *other)
     *(my_ptr) = *(other_ptr);
 }
 
+/*!
+    \fn QSensorReading::d_ptr()
+    \internal
+    No longer used. Exists to keep the winscw build happy.
+*/
+
 /*!
     \macro DECLARE_READING(classname)
     \relates QSensorReading
