@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -49,10 +49,8 @@
 
 QTM_BEGIN_NAMESPACE
 
-QSensorPluginLoader::QSensorPluginLoader(const char *iid, const QString &location)
-    : m_iid(iid)
+QSensorPluginLoader::QSensorPluginLoader()
 {
-    m_location = location + QLatin1String("/");
     load();
 }
 
@@ -65,23 +63,27 @@ QSensorPluginLoader::~QSensorPluginLoader()
     }
 }
 
+QList<QObject*> QSensorPluginLoader::plugins() const
+{
+    return m_plugins;
+}
+
 void QSensorPluginLoader::load()
 {
     if (!m_plugins.isEmpty())
         return;
 
-    QStringList plugins;
-    plugins = mobilityPlugins(QLatin1String("sensors"));
+    QStringList plugins = mobilityPlugins(QLatin1String("sensors"));
 
     /* Now discover the dynamic plugins */
-    for (int i=0; i < plugins.count(); i++) {
+    for (int i = 0; i < plugins.count(); i++) {
         QPluginLoader *loader = new QPluginLoader(plugins.at(i));
 
         QObject *o = loader->instance();
-        if (o != 0 && o->qt_metacast(m_iid) != 0) {
+        if (o != 0) {
             QSensorPluginInterface *p = qobject_cast<QSensorPluginInterface*>(o);
             if (p != 0) {
-                m_plugins << p;
+                m_plugins << o;
                 m_loaders << loader;
             } else {
                 loader->unload();
@@ -89,15 +91,6 @@ void QSensorPluginLoader::load()
             }
 
             continue;
-        } else {
-            qWarning() << "QSensorPluginLoader: Failed to load plugin";
-            if (o == 0) {
-                qWarning() << "Reason: o == 0";
-            } else if (o->qt_metacast(m_iid) == 0) {
-                qWarning() << "Reason: o->qt_metacast(m_iid) == 0";
-            }
-            qWarning() << "Plugin:" << plugins.at(i);
-            qWarning() << "Error:" << loader->errorString();
         }
         delete o;
         loader->unload();
