@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -245,6 +239,8 @@ bool lessThan(const QServiceInterfaceDescriptor &d1,
     data from both combined into a single dataset.
     When referring to a user scope database it means the
     user database only.
+
+    \since 1.0
 */
 
 /*
@@ -274,10 +270,16 @@ DatabaseManager::~DatabaseManager()
 
     //Aside: databases are implicitly closed
     //during deletion
-    delete m_userDb;
+    if(m_userDb){
+        m_userDb->close();
+        delete m_userDb;
+    }
     m_userDb = 0;
 
-    delete m_systemDb;
+    if(m_systemDb){
+        m_systemDb->close();
+        delete m_systemDb;
+    }
     m_systemDb = 0;
 }
 
@@ -306,6 +308,10 @@ void DatabaseManager::initDbPath(DbScope scope)
         db = m_userDb;
     }
 
+#ifdef QT_SIMULATOR
+    dbIdentifier.append("_simulator");
+#endif
+
     #ifdef Q_OS_SYMBIAN
         QDir dir(QDir::toNativeSeparators("C:\\Data\\temp\\QtServiceFW"));
     #else
