@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -48,10 +48,8 @@
 #include <QEventLoop>
 #include <QEvent>
 #include <QVarLengthArray>
-#ifdef Q_OS_WIN
-#  include <QCoreApplication>
-#  include <QTime>
-#endif
+#include <QTime>
+#include <QCoreApplication>
 
 QTM_BEGIN_NAMESPACE
 
@@ -173,8 +171,8 @@ ObjectEndPoint::ObjectEndPoint(Type type, QServiceIpcEndPoint* comm, QObject* pa
     d->endPointType = type;
 
     dispatch->setParent(this);
-    connect(dispatch, SIGNAL(readyRead()), this, SLOT(newPackageReady()));
-    connect(dispatch, SIGNAL(disconnected()), this, SLOT(disconnected()));
+    connect(dispatch, SIGNAL(readyRead()), this, SLOT(newPackageReady()), Qt::QueuedConnection);
+    connect(dispatch, SIGNAL(disconnected()), this, SLOT(disconnected()), Qt::QueuedConnection);
     if (type == Client) {
         return; //we are waiting for conctructProxy() call
     } else {
@@ -193,7 +191,9 @@ void ObjectEndPoint::disconnected()
     if (d->endPointType == Service) {
         InstanceManager::instance()->removeObjectInstance(d->entry, d->serviceInstanceId);
     }
-    deleteLater();
+    // deleteLater on symbian does not function properly from disconnect()
+    // maybe disconnect comes in on a thread?  Call from timer works.
+    QTimer::singleShot(0, this, SLOT(deleteLater()));
 }
 
 /*
@@ -495,16 +495,18 @@ void ObjectEndPoint::methodCall(const QServicePackage& p)
         Q_ASSERT(d->endPointType == ObjectEndPoint::Client);
 
         Response* response = openRequests()->value(p.d->messageId);
-        response->isFinished = true;
-        if (p.d->responseType == QServicePackage::Failed) {
-            response->result = 0;
-            QTimer::singleShot(0, this, SIGNAL(pendingRequestFinished()));
-            return;
-        }
-        QVariant* variant = new QVariant(p.d->payload);
-        response->result = reinterpret_cast<void *>(variant);
+        if(response){
+            response->isFinished = true;
+            if (p.d->responseType == QServicePackage::Failed) {
+                response->result = 0;
+                QTimer::singleShot(0, this, SIGNAL(pendingRequestFinished()));
+                return;
+            }
+            QVariant* variant = new QVariant(p.d->payload);
+            response->result = reinterpret_cast<void *>(variant);
 
-        QTimer::singleShot(0, this, SIGNAL(pendingRequestFinished()));
+            QTimer::singleShot(0, this, SIGNAL(pendingRequestFinished()));
+        }
     }
 }
 
@@ -614,28 +616,19 @@ QVariant ObjectEndPoint::invokeRemote(int metaIndex, const QVariantList& args, i
 
 void ObjectEndPoint::waitForResponse(const QUuid& requestId)
 {
+    qDebug() << "start ObjectEndPoint::waitForResponse";
     Q_ASSERT(d->endPointType == ObjectEndPoint::Client);
     if (openRequests()->contains(requestId) ) {
         Response* response = openRequests()->value(requestId);
-#ifdef Q_OS_WIN
-        QTime timer;
-        timer.start();
-        while(!response->isFinished) {
-            if(QCoreApplication::instance())
-                QCoreApplication::instance()->processEvents(QEventLoop::ExcludeUserInputEvents);
-            if(timer.elapsed() > 30000)
-                break;
-        }
-#else
         QEventLoop* loop = new QEventLoop( this );
-        connect(this, SIGNAL(pendingRequestFinished()), loop, SLOT(quit())); 
-
-        while(!response->isFinished) {
-            loop->exec();
-        }
+        QTimer::singleShot(30000, loop, SLOT(quit()));
+        connect(this, SIGNAL(pendingRequestFinished()), loop, SLOT(quit()));
+        loop->exec();
         delete loop;
-#endif
-    }
+        qDebug() << "- response->isFinished: " << response->isFinished;
+
+	}
+    qDebug() << "finished ObjectEndPoint::waitForResponse";
 }
 
 #include "moc_objectendpoint_p.cpp"
