@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -61,6 +61,7 @@ void printServicePackage(const QServicePackage& package)
     qDebug() << "QServicePackage packageType  : " << package.d->packageType;
     qDebug() << "QServicePackage QUuid        : " << package.d->messageId;
     qDebug() << "QServicePackage responseType : " << package.d->responseType;
+    qDebug() << "QServicePackage value        : " << package.d->payload;
   }
   else {
     qDebug() << "Invalid ServicePackage" << " LEAVING"; 
@@ -94,7 +95,8 @@ public:
     void PackageReceived(QServicePackage package)
     {
 #ifdef QT_SFW_SYMBIAN_IPC_DEBUG
-        qDebug() << "PackageReceived. Enqueueing and emiting ReadyRead()";
+        qDebug() << "SymbianClientEndPoint::PackageReceived. Enqueueing and emiting ReadyRead()";
+        printServicePackage(package);
 #endif
         incoming.enqueue(package);
         emit readyRead();
@@ -143,7 +145,8 @@ public:
     void packageReceived(QServicePackage package)
     {
 #ifdef QT_SFW_SYMBIAN_IPC_DEBUG      
-        qDebug() << "GTR SymbianServerEndPoint::packageReceived, putting to queue and emiting readyread.";
+        qDebug() << "SymbianServerEndPoint::packageReceived, putting to queue and emiting readyread.";
+        printServicePackage(package);
 #endif        
         incoming.enqueue(package);
         emit readyRead();
@@ -177,6 +180,11 @@ QRemoteServiceRegisterSymbianPrivate::QRemoteServiceRegisterSymbianPrivate(QObje
 {
 }
 
+QRemoteServiceRegisterSymbianPrivate::~QRemoteServiceRegisterSymbianPrivate()
+{
+    delete m_server;
+}
+
 void QRemoteServiceRegisterSymbianPrivate::publishServices(const QString &ident)
 {
     // Create service side of the Symbian Client-Server architecture.
@@ -265,11 +273,12 @@ QObject* QRemoteServiceRegisterPrivate::proxyForService(const QRemoteServiceRegi
 }
 
 RServiceSession::RServiceSession(QString address) 
-: iSize(0), iListener(0)
+: iSize(0), iListener(0), iDataSizes(KIpcBufferMinimumSize)
 {
 #ifdef QT_SFW_SYMBIAN_IPC_DEBUG
     qDebug() << "RServiceSession() for address: " << address;
 #endif
+    qt_symbian_throwIfError(iMessageFromServer.Create(KIpcBufferMinimumSize));
     iServerAddress = address;
 }
 
@@ -277,6 +286,7 @@ RServiceSession::~RServiceSession()
 {
     delete iListener;
     Close();
+    iMessageFromServer.Close();
 }
 
 void RServiceSession::setListener(ServiceMessageListener *listener)
@@ -348,6 +358,11 @@ void RServiceSession::SendServicePackage(const QServicePackage& aPackage)
     }
 }
 
+void RServiceSession::addDataSize(TInt dataSize)
+{
+    iDataSizes.addSample(dataSize);
+}
+
 // StartServer() checks if the service is already published by someone (i.e. can be found
 // from Kernel side). If not, it will start the process that provides the service.
 TInt RServiceSession::StartServer()
@@ -362,7 +377,7 @@ TInt RServiceSession::StartServer()
     // Looks up from Kernel-side if there are active servers with the given name.
     // If not found, a process providing the service needs to be started.    
     if (findServer.Next(name) != KErrNone) {
-#ifdef __WINS__
+#if defined(__WINS__) && !defined(SYMBIAN_EMULATOR_SUPPORTS_PERPROCESS_WSD)
           qWarning("WINS Support for QSFW OOP not implemented.");
 #else
 #ifdef QT_SFW_SYMBIAN_IPC_DEBUG
@@ -411,11 +426,52 @@ TInt RServiceSession::StartServer()
     return ret;
 }
 
+/* Since the average size will not change in the middle of a fragmented message
+ * trasnfer actual updates to buffer size will happen only when a new message
+ * arrives */
+void RServiceSession::updateIpcBufferSize()
+{
+   TInt weightedAvg = iDataSizes.averageWeighted();
+
+#ifdef QT_SFW_SYMBIAN_IPC_DEBUG          
+   qDebug() << "updateIpcBufferSize(): current weighted average of data size is: "<<weightedAvg;
+   qDebug() << "Current IPC Buffer size is: "<<iMessageFromServer.MaxLength();
+#endif
+   TInt newSize = iMessageFromServer.MaxLength();
+   if(weightedAvg > iMessageFromServer.MaxLength()){
+       newSize = iMessageFromServer.MaxLength()*2;
+   }
+   else if(weightedAvg < iMessageFromServer.MaxLength()/2){
+
+         newSize = iMessageFromServer.MaxLength()/2;
+#ifdef QT_SFW_SYMBIAN_IPC_DEBUG          
+   qDebug() << "updateIpcBufferSize(): current weighted average of data size is:(2) "<<weightedAvg<<" max/2";
+#endif
+   }
+   
+   if(newSize < KIpcBufferMinimumSize)
+       newSize = KIpcBufferMinimumSize;
+   else if(newSize > KIpcBufferMaximumSize)
+       newSize = KIpcBufferMaximumSize;
+
+
+   if(newSize != iMessageFromServer.MaxLength()) {
+
+        iMessageFromServer.SetLength(0);
+        //If realloc fails the old descriptor is left unchanged.
+        iMessageFromServer.ReAlloc(newSize); 
+#ifdef QT_SFW_SYMBIAN_IPC_DEBUG          
+       qDebug() << "updateIpcBufferSize():  New Size of IPC Buffer: "<<newSize;
+#endif
+   }
+}
+
 void RServiceSession::ListenForPackages(TRequestStatus& aStatus)
 {    
 #ifdef QT_SFW_SYMBIAN_IPC_DEBUG
     qDebug() << "GTR RServiceSession::ListenForPackages(), iSize: " << iSize();
 #endif
+    updateIpcBufferSize();
     iArgs.Set(0, &iMessageFromServer);
     // Total Size of returned messaage,which might differ from the amount of data in iMessageFromServer
     iArgs.Set(1, &iSize); 
@@ -460,11 +516,11 @@ static const TInt myRanges[myRangeCount] =
     };
 static const TUint8 myElementsIndex[myRangeCount] =
     {
-    CPolicyServer::EPass
+    CPolicyServer::EAlwaysPass
     };
 static const CPolicyServer::TPolicyElement myElements[] =
     {
-        {_INIT_SECURITY_POLICY_C1(ECapabilityDiskAdmin), CPolicyServer::EFailClient} // Dummy entry
+        {_INIT_SECURITY_POLICY_PASS } // Dummy entry
     };
 static const CPolicyServer::TPolicy myPolicy =
     {
@@ -592,7 +648,7 @@ void CServiceProviderServerSession::ServiceL(const RMessage2 &aMessage)
     switch (aMessage.Function()) 
     {
     case EServicePackage:
-        User::LeaveIfError(HandleServicePackageL(aMessage));
+        HandleServicePackageL(aMessage);
         aMessage.Complete(KErrNone);
         break;
     case EPackageRequest:
@@ -604,16 +660,16 @@ void CServiceProviderServerSession::ServiceL(const RMessage2 &aMessage)
     }
 }
 
-TInt CServiceProviderServerSession::HandleServicePackageL(const RMessage2& aMessage)
+void CServiceProviderServerSession::HandleServicePackageL(const RMessage2& aMessage)
 {
-    TInt ret = KErrNone;
     // Reproduce the serialized data.
     HBufC8* servicePackageBuf8 = HBufC8::New(aMessage.GetDesLength(0));
     if (!servicePackageBuf8) {
-        return KErrNoMemory;
+        User::Leave( KErrNoMemory );
     }
 
     TPtr8 ptrToBuf(servicePackageBuf8->Des());
+    TInt ret = KErrNone;
     TRAP(ret, aMessage.ReadL(0, ptrToBuf));
     if (ret != KErrNone) {
         // TODO: is this error handleing correct
@@ -623,7 +679,7 @@ TInt CServiceProviderServerSession::HandleServicePackageL(const RMessage2& aMess
         //iDb->lastError().setError(DBError::UnknownError);
         //aMessage.Write(1, LastErrorCode());
         delete servicePackageBuf8;
-        return ret;
+        User::Leave( ret );
     }
 
     QByteArray byteArray((const char*)ptrToBuf.Ptr(), ptrToBuf.Length());
@@ -636,7 +692,7 @@ TInt CServiceProviderServerSession::HandleServicePackageL(const RMessage2& aMess
     printServicePackage(results);
 #endif
     iOwner->packageReceived(results);
-    return ret;
+    delete servicePackageBuf8;
 }
 
 void CServiceProviderServerSession::SetParent(SymbianServerEndPoint *aOwner)
@@ -773,6 +829,11 @@ void ServiceMessageListener::RunL()
           // than were in the TDes
           User::Leave(KErrTooBig); 
         }
+
+        if(!iByteArray.length()){
+            /* Helps client session to calculate an optimum IPC buffer size */
+            iClientSession->addDataSize(iClientSession->iSize());
+        }
                 
         iByteArray.append((const char*)iClientSession->iMessageFromServer.Ptr(),
                              iClientSession->iMessageFromServer.Length());
