@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -100,7 +100,8 @@ QServiceMetaObjectDBus::QServiceMetaObjectDBus(QObject* service, bool signalsObj
 QServiceMetaObjectDBus::~QServiceMetaObjectDBus()
 {
     if (d->dbusMeta)
-        delete d->dbusMeta;
+        qFree(const_cast<QMetaObject*>(d->dbusMeta));
+    
     delete d;
 }
 
@@ -221,10 +222,10 @@ void QServiceMetaObjectDBus::activateMetaSignal(int id, const QVariantList& args
 const QMetaObject* QServiceMetaObjectDBus::dbusMetaObject(bool signalsObject) const
 {
     // Create a meta-object to represent all the contents of our service on DBus
-    QMetaObjectBuilder *builder = new QMetaObjectBuilder();
+    QMetaObjectBuilder builder;
   
-    builder->setClassName(d->serviceMeta->className());
-    builder->setSuperClass(d->serviceMeta->superClass()); // needed?
+    builder.setClassName(d->serviceMeta->className());
+    builder.setSuperClass(d->serviceMeta->superClass()); // needed?
 
     const QMetaObject* mo = d->serviceMeta;
     while (mo && strcmp(mo->className(), "QObject")) {
@@ -259,13 +260,13 @@ const QMetaObject* QServiceMetaObjectDBus::dbusMetaObject(bool signalsObject) co
             QMetaMethodBuilder method;
             switch (mm.methodType()) {
                 case QMetaMethod::Method:
-                    method = builder->addMethod(sig);
+                    method = builder.addMethod(sig);
                     break;
                 case QMetaMethod::Slot:
-                    method = builder->addSlot(sig);
+                    method = builder.addSlot(sig);
                     break;
                 case QMetaMethod::Signal:
-                    method = builder->addSignal(sig);
+                    method = builder.addSignal(sig);
                     break;
                 default:
                     break;
@@ -280,21 +281,21 @@ const QMetaObject* QServiceMetaObjectDBus::dbusMetaObject(bool signalsObject) co
         }
 
         if (signalsObject)
-            return builder->toMetaObject();
+            return builder.toMetaObject();
 
         // Add our property accessor methods
         // NOTE: required because read/reset properties over DBus require adaptors
         //       otherwise a metacall won't be invoked as QMetaObject::ReadProperty
         //       or QMetaObject::ResetProperty
         QMetaMethodBuilder readProp;
-        readProp = builder->addMethod(QByteArray("propertyRead(QString)"));
+        readProp = builder.addMethod(QByteArray("propertyRead(QString)"));
         readProp.setReturnType(QByteArray("QDBusVariant"));
         QList<QByteArray> params;
         params << QByteArray("name");
         readProp.setParameterNames(params);
 
         QMetaMethodBuilder resetProp;
-        resetProp = builder->addMethod(QByteArray("propertyReset(QString)"));
+        resetProp = builder.addMethod(QByteArray("propertyReset(QString)"));
         QList<QByteArray> paramsReset;
         paramsReset << QByteArray("name");
         resetProp.setParameterNames(paramsReset);
@@ -305,7 +306,7 @@ const QMetaObject* QServiceMetaObjectDBus::dbusMetaObject(bool signalsObject) co
         for (int i=0; i<propCount; i++) {
             QMetaProperty mp = d->serviceMeta->property(i);
 
-            QMetaPropertyBuilder property = builder->addProperty(mp.name(), mp.typeName());
+            QMetaPropertyBuilder property = builder.addProperty(mp.name(), mp.typeName());
             property.setReadable(mp.isReadable());
             property.setWritable(mp.isWritable());
             property.setResettable(mp.isResettable());
@@ -324,7 +325,7 @@ const QMetaObject* QServiceMetaObjectDBus::dbusMetaObject(bool signalsObject) co
     }
 
     // return our constructed dbus metaobject
-    return builder->toMetaObject();
+    return builder.toMetaObject();
 }
 
 /*! 
