@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -87,7 +87,7 @@ static QString qservicemanager_resolveLibraryPath(const QString &libNameOrPath)
             return libPath;
         }
 #else
-        QLibrary lib(libPath);  
+        QLibrary lib(libPath);
         if (lib.load()) {
             lib.unload();
             return lib.fileName();
@@ -202,8 +202,10 @@ private slots:
 /*!
     \class QServiceManager
     \ingroup servicefw
+    \inmodule QtServiceFramework
     \brief The QServiceManager class enables the loading of service plugins
     and the (de)registration of services.
+    \since 1.0
 
     A service is a stand-alone component that can be used by multiple clients.
     Each service implementation must derive from QObject. Clients request a
@@ -398,12 +400,13 @@ QObject* QServiceManager::loadInterface(const QServiceInterfaceDescriptor& descr
     }
 
     const QString location = descriptor.attribute(QServiceInterfaceDescriptor::Location).toString();
-    const bool isInterProcess = (descriptor.attribute(QServiceInterfaceDescriptor::ServiceType).toInt() 
+    const bool isInterProcess = (descriptor.attribute(QServiceInterfaceDescriptor::ServiceType).toInt()
                                 == QService::InterProcess);
     if (isInterProcess) {
         //ipc service
-        const QByteArray version = QString("%1.%2").arg(descriptor.majorVersion())
-                                                   .arg(descriptor.minorVersion()).toLatin1();
+        const int majorversion = descriptor.majorVersion();
+        const int minorversion = descriptor.minorVersion();
+        QString version = QString::number(majorversion) + "." + QString::number(minorversion);
 
         QRemoteServiceRegister::Entry serviceEntry;
         serviceEntry.d->iface = descriptor.interfaceName();
@@ -490,7 +493,7 @@ QObject* QServiceManager::loadInterface(const QServiceInterfaceDescriptor& descr
     the service manager will not perform any checks. Therefore it is assumed that
     the service manager client is trusted as it controls whether service capabilities
     are enforced during service loading.
-    
+
     \sa setInterfaceDefault(), interfaceDefault()
 */
 
@@ -577,7 +580,7 @@ bool QServiceManager::addService(QIODevice *device)
     ServiceMetaDataResults results = parser.parseResults();
 
     bool result = d->dbManager->registerService(results, scope);
-    
+
     if (results.type == QService::InterProcess)
         return result;
 
