@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -45,30 +45,32 @@ QTM_BEGIN_NAMESPACE
 /*!
     \class QServicePluginInterface
     \ingroup servicefw
+    \inmodule QtServiceFramework
     \brief The QServicePluginInterface class defines the interface
     that every plug-in based service must implement.
+    \since 1.0
 */
 
 /*!
     \internal
 */
-QServicePluginInterface::QServicePluginInterface() 
+QServicePluginInterface::QServicePluginInterface()
 {
 }
 
 /*!
     \internal
 */
-QServicePluginInterface::~QServicePluginInterface() 
+QServicePluginInterface::~QServicePluginInterface()
 {
 }
-    
+
 /*!
     \fn QObject* QServicePluginInterface::createInstance(const QServiceInterfaceDescriptor& descriptor, QServiceContext* context,
                                     QAbstractSecuritySession* securitySession)
 
     Creates a new instance of the service specified by \a descriptor. The service
-    may use the given \a context and \a securitySession. \a context and \a securitySession object are owned 
+    may use the given \a context and \a securitySession. \a context and \a securitySession object are owned
     by the client of the service.
 
     This function returns a null pointer if the plug-in doesn't
@@ -81,17 +83,17 @@ QServicePluginInterface::~QServicePluginInterface()
     This function is called by QServiceManager as part of the service registration process. It can be
     used to initialize the environment or the creation of external settings files which may be required
     during the execution of the service.
-    
+
     The default implementation for this function does nothing.
 
     \sa QServiceManager::addService()
 */
-void QServicePluginInterface::installService() 
+void QServicePluginInterface::installService()
 {
 }
 
 /*!
-    \fn bool QServicePluginInterface::uninstallService() 
+    \fn bool QServicePluginInterface::uninstallService()
 
     This function is called bu QServiceManager as part of the deregistration process for services. This
     gives the service the possibility to perform cleanup operations such as the removal of setting files
@@ -102,7 +104,7 @@ void QServicePluginInterface::installService()
     \sa QServiceManager::removeService()
 */
 
-void QServicePluginInterface::uninstallService() 
+void QServicePluginInterface::uninstallService()
 {
 }
 
