@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -63,18 +57,25 @@
 #include <QObject>
 #include <QSize>
 #include <QHash>
+#include "qsysteminfocommon_p.h"
 
 #include "qsysteminfo.h"
-#include <qmobilityglobal.h>
+
+#include "qsystemdeviceinfo.h"
+#include "qsystemdisplayinfo.h"
+#include "qsystemnetworkinfo.h"
+#include "qsystemscreensaver.h"
+#include "qsystemstorageinfo.h"
+#include "qsystembatteryinfo.h"
 
 #include <QTimer>
 #include <QtCore/qthread.h>
 #include <QtCore/qmutex.h>
-#include <QEventLoop>
-#include <IOKit/IOKitLib.h>
+ #include <QEventLoop>
 
 #include <SystemConfiguration/SystemConfiguration.h>
 //#include <CoreFoundation/CoreFoundation.h>
+#include <DiskArbitration/DiskArbitration.h>
 
 QT_BEGIN_HEADER
 
@@ -134,7 +135,7 @@ public:
     virtual ~QSystemNetworkInfoPrivate();
 
     QSystemNetworkInfo::NetworkStatus networkStatus(QSystemNetworkInfo::NetworkMode mode);
-    qint32 networkSignalStrength(QSystemNetworkInfo::NetworkMode mode);
+    int networkSignalStrength(QSystemNetworkInfo::NetworkMode mode);
     int cellId();
     int locationAreaCode();
 
@@ -153,7 +154,7 @@ public:
     QString getDefaultInterface();
     QSystemNetworkInfo::NetworkMode currentMode();
     void ethernetChanged();
-
+    QSystemNetworkInfo::CellDataTechnology cellDataTechnology();
 
 Q_SIGNALS:
    void networkStatusChanged(QSystemNetworkInfo::NetworkMode, QSystemNetworkInfo::NetworkStatus);
@@ -162,6 +163,7 @@ Q_SIGNALS:
    void currentMobileNetworkCodeChanged(const QString &);
    void networkNameChanged(QSystemNetworkInfo::NetworkMode, const QString &);
    void networkModeChanged(QSystemNetworkInfo::NetworkMode);
+   void cellIdChanged(int);//1.2
 
 public Q_SLOTS:
    void primaryInterface();
@@ -176,6 +178,7 @@ private:
 
 private Q_SLOTS:
     void rssiTimeout();
+
 protected:
     void startNetworkChangeLoop();
     bool isInterfaceActive(const char* netInterface);
@@ -183,6 +186,7 @@ protected:
     void connectNotify(const char *signal);
     void disconnectNotify(const char *signal);
     bool hasWifi;
+    bool networkThreadOk;
 
 };
 
@@ -197,8 +201,17 @@ public:
 
     int displayBrightness(int screen);
     int colorDepth(int screen);
+
+    QSystemDisplayInfo::DisplayOrientation orientation(int screen);
+    float contrast(int screen);
+    int getDPIWidth(int screen);
+    int getDPIHeight(int screen);
+    int physicalHeight(int screen);
+    int physicalWidth(int screen);
+    QSystemDisplayInfo::BacklightState backlightStatus(int screen); //1.2
 };
 
+class QDASessionThread;
 class QSystemStorageInfoPrivate : public QObject
 {
     Q_OBJECT
@@ -213,11 +226,33 @@ public:
     QStringList logicalDrives();
     QSystemStorageInfo::DriveType typeForDrive(const QString &driveVolume);
 
+    QString uriForDrive(const QString &driveVolume);//1.2
+    QSystemStorageInfo::StorageState getStorageState(const QString &volume);//1.2
+
+public Q_SLOTS:
+    void storageChanged( bool added,const QString &vol);
+
+Q_SIGNALS:
+    void logicalDriveChanged(bool added,const QString &vol);
+    void storageStateChanged(const QString &vol, QSystemStorageInfo::StorageState state); //1.2
+
 private:
-    QHash<QString, QString> mountEntriesHash;
+    QMap<QString, QString> mountEntriesMap;
     bool updateVolumesMap();
     void mountEntries();
+    bool sessionThread();
+    QMap<QString, QSystemStorageInfo::StorageState> stateMap;
+    QTimer *storageTimer;
 
+private Q_SLOTS:
+    void checkAvailableStorage();
+
+protected:
+    void connectNotify(const char *signal);
+    void disconnectNotify(const char *signal);
+
+    QDASessionThread *daSessionThread;
+    bool sessionThreadStarted;
 };
 
 class QBluetoothListenerThread;
@@ -245,20 +280,41 @@ public:
     QSystemDeviceInfo::Profile currentProfile();
 
     QSystemDeviceInfo::PowerState currentPowerState();
+    QSystemDeviceInfo::ThermalState currentThermalState();
     void setConnection();
     static QSystemDeviceInfoPrivate *instance();
 
     bool currentBluetoothPowerState();
     bool btThreadOk;
 
+    QSystemDeviceInfo::KeyboardTypeFlags keyboardTypes(); //1.2
+    bool isWirelessKeyboardConnected(); //1.2
+    bool isKeyboardFlippedOpen();//1.2
+
+    void keyboardConnected(bool connect);//1.2
+    bool keypadLightOn(QSystemDeviceInfo::KeypadType type); //1.2
+    void deviceLocked(bool isLocked); // 1.2
+    QByteArray uniqueDeviceID(); //1.2
+    QSystemDeviceInfo::LockTypeFlags lockStatus(); //1.2
+
+    int messageRingtoneVolume();//1.2
+    int voiceRingtoneVolume();//1.2
+    bool vibrationActive();//1.2
+
 Q_SIGNALS:
     void batteryLevelChanged(int);
     void batteryStatusChanged(QSystemDeviceInfo::BatteryStatus );
 
     void powerStateChanged(QSystemDeviceInfo::PowerState);
+    void thermalStateChanged(QSystemDeviceInfo::ThermalState);
     void currentProfileChanged(QSystemDeviceInfo::Profile);
     void bluetoothStateChanged(bool);
 
+    void wirelessKeyboardConnected(bool connected);//1.2
+    void keyboardFlipped(bool open);//1.2
+    void lockStatusChanged(QSystemDeviceInfo::LockTypeFlags); //1.2
+
+
 private:
     int batteryLevelCache;
     QSystemDeviceInfo::PowerState currentPowerStateCache;
@@ -266,6 +322,7 @@ private:
     static QSystemDeviceInfoPrivate *self;
     QBluetoothListenerThread *btThread;
 
+    bool hasWirelessKeyboardConnected;
 protected:
     void connectNotify(const char *signal);
     void disconnectNotify(const char *signal);
@@ -283,6 +340,7 @@ public:
 
     bool screenSaverInhibited();
     bool setScreenSaverInhibit();
+    void setScreenSaverInhibited(bool on);
 
 private:
     QString screenPath;
@@ -296,7 +354,7 @@ private Q_SLOTS:
 
 };
 
-class QRunLoopThread : public QThread
+class QRunLoopThread : public QObject
 {
     Q_OBJECT
 
@@ -306,19 +364,21 @@ public:
     bool keepRunning;
     void stop();
 
-protected:
-    void run();
+public Q_SLOTS:
+   void doWork();
 
+protected:
+   QThread t;
 private:
     void startNetworkChangeLoop();
     QMutex mutex;
-    SCDynamicStoreRef storeSession;// = NULL;
+    SCDynamicStoreRef storeSession;
     CFRunLoopSourceRef runloopSource;
 
 private Q_SLOTS:
 };
 
-class QLangLoopThread : public QThread
+class QLangLoopThread : public QObject
 {
     Q_OBJECT
 
@@ -328,15 +388,38 @@ public:
     bool keepRunning;
     void stop();
 
-protected:
-    void run();
+public Q_SLOTS:
+    void doWork();
 
 private:
     QMutex mutex;
-private Q_SLOTS:
+    QThread t;
 };
 
-class QBluetoothListenerThread : public QThread
+class QDASessionThread : public QObject
+{
+    Q_OBJECT
+
+public:
+    QDASessionThread(QObject *parent = 0);
+    ~QDASessionThread();
+    bool keepRunning;
+    void stop();
+    DASessionRef session;
+public Q_SLOTS:
+    void doWork();
+Q_SIGNALS:
+    void logicalDrivesChanged(bool added,const QString & vol);
+
+protected:
+    QThread t;
+
+private:
+    QMutex mutex;
+
+};
+
+class QBluetoothListenerThread : public QObject
 {
     Q_OBJECT
 
@@ -344,16 +427,18 @@ public:
     QBluetoothListenerThread(QObject *parent = 0);
     ~QBluetoothListenerThread();
     bool keepRunning;
+    QThread t;
+    void setupConnectNotify();
 
 public Q_SLOTS:
     void emitBtPower(bool);
     void stop();
+    void doWork();
 
 Q_SIGNALS:
     void bluetoothPower(bool);
 
 protected:
-    void run();
     IONotificationPortRef port;
     CFRunLoopRef rl;
     CFRunLoopSourceRef rls;
@@ -364,6 +449,61 @@ private:
 private Q_SLOTS:
 };
 
+class QSystemBatteryInfoPrivate : public QObject
+{
+    Q_OBJECT
+public:
+    QSystemBatteryInfoPrivate(QObject *parent = 0);
+    ~QSystemBatteryInfoPrivate();
+
+
+    QSystemBatteryInfo::ChargerType chargerType() const;
+    QSystemBatteryInfo::ChargingState chargingState() const;
+
+    int nominalCapacity() const;
+    int remainingCapacityPercent() const;
+    int remainingCapacity() const;
+
+    int voltage() const;
+    int remainingChargingTime() const;
+    int currentFlow() const;
+    int remainingCapacityBars() const;
+    int maxBars() const;
+    QSystemBatteryInfo::BatteryStatus batteryStatus() const;
+    QSystemBatteryInfo::EnergyUnit energyMeasurementUnit();
+    void getBatteryInfo();
+
+Q_SIGNALS:
+    void batteryLevelChanged(int level);
+    void batteryStatusChanged(QSystemBatteryInfo::BatteryStatus batteryStatus);
+
+
+    void chargingStateChanged(QSystemBatteryInfo::ChargingState chargingState);
+    void chargerTypeChanged(QSystemBatteryInfo::ChargerType chargerType);
+
+    void nominalCapacityChanged(int);
+    void remainingCapacityPercentChanged(int);
+    void remainingCapacityChanged(int);
+    void batteryCurrentFlowChanged(int);
+
+    void currentFlowChanged(int);
+    void cumulativeCurrentFlowChanged(int);
+    void remainingCapacityBarsChanged(int);
+    void remainingChargingTimeChanged(int);
+
+private:
+    QSystemBatteryInfo::BatteryStatus currentBatStatus;
+    QSystemBatteryInfo::ChargingState curChargeState;
+    QSystemBatteryInfo::ChargerType curChargeType;
+
+    int currentBatLevelPercent;
+    int currentVoltage;
+    int dischargeRate;
+    int capacity;
+    int timeToFull;
+    int remainingEnergy;
+};
+
 QTM_END_NAMESPACE
 
 QT_END_HEADER
