@@ -1,17 +1,17 @@
 /****************************************************************************
 **
-** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -56,6 +56,8 @@
 
 #include <QObject>
 #include <QStringList>
+#include <QTimer>
+#include <QDesktopWidget>
 
 #include "qmobilityglobal.h"
 #include "qsysteminfo.h"
@@ -65,11 +67,29 @@
 #include "chargingstatus_s60.h"
 #include "wlaninfo_s60.h"
 #include "storagestatus_s60.h"
+#include <w32std.h>
+#include "batterystatus_s60.h"
+#include "networkinfo_s60.h"
+#include <ProfileEngineSDKCRKeys.h>
+#include <hwrmvibrasdkcrkeys.h>
+
+#ifdef LOCKANDFLIP_SUPPORTED
+#include "lockandflipstatus_s60.h"
+#endif
+
+#ifdef DISKNOTIFY_SUPPORTED
+#include "storagedisknotifier_s60.h"
+#endif
+
+#ifdef THERMALSTATUS_SUPPORTED
+#include "thermalstatus_s60.h"
+#endif
 
 QT_BEGIN_HEADER
 
 QTM_BEGIN_NAMESPACE
 
+const int KMaxBatteryBars = 7; //Max number of battery bars (7 is fixed for all symbian devices now)
 
 //////// QSystemInfo
 class QSystemInfoPrivate : public QObject
@@ -97,7 +117,7 @@ private:
 };
 
 //////// QSystemNetworkInfo
-class QSystemNetworkInfoPrivate : public QObject, public MTelephonyInfoObserver
+class QSystemNetworkInfoPrivate : public QObject, public MTelephonyInfoObserver, public MNetworkInfoObserver
 {
     Q_OBJECT
 
@@ -123,6 +143,8 @@ public:
     QNetworkInterface interfaceForMode(QSystemNetworkInfo::NetworkMode mode);
     QSystemNetworkInfo::NetworkMode currentMode();
 
+    QSystemNetworkInfo::CellDataTechnology cellDataTechnology();
+
 Q_SIGNALS:
     void networkStatusChanged(QSystemNetworkInfo::NetworkMode, QSystemNetworkInfo::NetworkStatus);
     void networkSignalStrengthChanged(QSystemNetworkInfo::NetworkMode, int);
@@ -130,6 +152,8 @@ Q_SIGNALS:
     void currentMobileNetworkCodeChanged(const QString &);
     void networkNameChanged(QSystemNetworkInfo::NetworkMode,const QString &);
     void networkModeChanged(QSystemNetworkInfo::NetworkMode);
+    void cellIdChanged(int);//1.2
+    void cellDataTechnologyChanged(QSystemNetworkInfo::CellDataTechnology);
 
 protected:  //from MTelephonyInfoObserver
     void batteryLevelChanged(){};
@@ -142,6 +166,11 @@ protected:  //from MTelephonyInfoObserver
     void cellNetworkSignalStrengthChanged();
     void cellNetworkStatusChanged();
 
+    void changedCellId(int);
+    virtual void changedNetworkStatus();
+    virtual void changedNetworkMode();
+    virtual void changedCellDataTechnology();
+
 public slots:
     void wlanNetworkNameChanged();
     void wlanNetworkSignalStrengthChanged();
@@ -161,21 +190,38 @@ public:
     static int displayBrightness(int screen);
     static int colorDepth(int screen);
 
-//     QSystemDisplayInfo::DisplayOrientation getOrientation(int screen);
-//     float contrast(int screen);
-//     int getDPIWidth(int screen);
-//     int getDPIHeight(int screen);
-//     int physicalHeight(int screen);
-//     int physicalWidth(int screen);
+    QSystemDisplayInfo::DisplayOrientation orientation(int screen);
+    float contrast(int screen);
+    int getDPIWidth(int screen);
+    int getDPIHeight(int screen);
+    int physicalHeight(int screen);
+    int physicalWidth(int screen);
+    QSystemDisplayInfo::BacklightState backlightStatus(int screen); //1.2
 
+Q_SIGNALS:
+    void orientationChanged(QSystemDisplayInfo::DisplayOrientation newOrientation);
+
+public slots:
+    void rotationTimeout();
+
+private:
+    bool getSizeandRotation(int screen,TPixelsTwipsAndRotation& sizeAndRotation);
+
+    QSystemDisplayInfo::DisplayOrientation currentOrientation;
+    QTimer *rotationTimer;
 };
 
 //////// QSystemStorageInfo
 class QSystemStorageInfoPrivate : public QObject,
     public MStorageStatusObserver
+#ifdef DISKNOTIFY_SUPPORTED
+    ,public MStorageSpaceNotifyObserver
+#endif
 {
     Q_OBJECT
 
+private:
+    QSystemStorageInfo::StorageState CheckDiskSpaceThresholdLimit(const QString &);
 public:
     QSystemStorageInfoPrivate(QObject *parent = 0);
     virtual ~QSystemStorageInfoPrivate();
@@ -184,8 +230,15 @@ public:
     static QStringList logicalDrives();
     QSystemStorageInfo::DriveType typeForDrive(const QString &driveVolume);
 
+    QString uriForDrive(const QString &driveVolume);//1.2
+    QSystemStorageInfo::StorageState getStorageState(const QString &volume);//1.2
+
 protected: // from MStorageStatusObserver
     void storageStatusChanged(bool, const QString &);
+#ifdef DISKNOTIFY_SUPPORTED
+    // from MStorageSpaceNotifyObserver
+    void DiskSpaceChanged(const QString &);
+#endif
 
 private:
     RFs iFs;
@@ -193,6 +246,7 @@ private:
 
 Q_SIGNALS:
     void logicalDriveChanged(bool, const QString &);
+    void storageStateChanged(const QString &vol, QSystemStorageInfo::StorageState state); //1.2
 };
 
 //////// QSystemDeviceInfo
@@ -214,6 +268,12 @@ class QSystemDeviceInfoPrivate : public QObject,
     public MProEngProfileActivationObserver,
     public MCenRepNotifyHandlerCallback,
     public MChargingStatusObserver
+#ifdef LOCKANDFLIP_SUPPORTED
+    ,public MKeylockStatusObserver,public MFlipStatusObserver
+#endif
+#ifdef THERMALSTATUS_SUPPORTED
+    ,public MThermalStatusObserver
+#endif
 {
     Q_OBJECT
 
@@ -239,48 +299,83 @@ public:
     QSystemDeviceInfo::Profile currentProfile();
 
     QSystemDeviceInfo::PowerState currentPowerState();
+    QSystemDeviceInfo::ThermalState currentThermalState();
 
     bool currentBluetoothPowerState();
 
+    QSystemDeviceInfo::KeyboardTypeFlags keyboardTypes(); //1.2
+    bool isWirelessKeyboardConnected(); //1.2
+    bool isKeyboardFlippedOpen();//1.2
+    void keyboardConnected(bool connect);//1.2
+    bool keypadLightOn(QSystemDeviceInfo::KeypadType type); //1.2
+    QByteArray uniqueDeviceID(); //1.2
+    QSystemDeviceInfo::LockTypeFlags lockStatus(); //1.2
+
+    int messageRingtoneVolume();//1.2
+    int voiceRingtoneVolume();//1.2
+    bool vibrationActive();//1.2
 Q_SIGNALS:
     void batteryLevelChanged(int);
     void batteryStatusChanged(QSystemDeviceInfo::BatteryStatus);
     void bluetoothStateChanged(bool);
     void currentProfileChanged(QSystemDeviceInfo::Profile);
     void powerStateChanged(QSystemDeviceInfo::PowerState);
+    void thermalStateChanged(QSystemDeviceInfo::ThermalState);
 
-protected:  //From QObject
+    void wirelessKeyboardConnected(bool connected);//1.2
+    void keyboardFlipped(bool open);//1.2
+    void deviceLocked(bool isLocked); // 1.2
+    void lockStatusChanged(QSystemDeviceInfo::LockTypeFlags); //1.2
+
+protected:
+    //From QObject
     void connectNotify(const char *signal);
 
-protected: //From MProEngProfileActivationObserver
+//From MProEngProfileActivationObserver
     void HandleProfileActivatedL(TInt aProfileId);
 
-protected: //From MCenRepNotifyHandlerCallback
+    //From MCenRepNotifyHandlerCallback
     void HandleNotifyInt(TUint32 aId, TInt aNewValue);
-
-private:
-    QSystemDeviceInfo::Profile s60ProfileIdToProfile(TInt profileId) const;
-
-protected:  //from MTelephonyInfoObserver
+    //from MTelephonyInfoObserver
     void batteryLevelChanged();
 
     void countryCodeChanged(){};
     void networkCodeChanged(){};
     void networkNameChanged(){};
     void networkModeChanged(){};
+    void changedCellId(int){};
 
     void cellNetworkSignalStrengthChanged(){};
     void cellNetworkStatusChanged(){};
 
-protected:  //from MChargingStatusObserver
+    //from MChargingStatusObserver
     void chargingStatusChanged();
 
-private:    //data
+#ifdef LOCKANDFLIP_SUPPORTED
+    //from MKeylockStatusObserver
+    void keylockStatusChanged(TInt aLockType);
+
+    //from MFlipStatusObserver
+    void flipStatusChanged(TInt aFlipType , TInt aFilpKeyBoard );
+#endif
+
+#ifdef THERMALSTATUS_SUPPORTED
+    //from MThermalStatusObserver
+    void NotiftythermalStateChanged(TUint8 aThermalStatus);
+#endif
+private:
+    QSystemDeviceInfo::Profile s60ProfileIdToProfile(TInt profileId) const;
+
+//data
     MProEngEngine *m_profileEngine;
     MProEngNotifyHandler* m_proEngNotifyHandler;
 
     CRepository *m_bluetoothRepository;
     CCenRepNotifyHandler *m_bluetoothNotifyHandler;
+
+    bool hasWirelessKeyboardConnected;
+
+    QSystemDeviceInfo::BatteryStatus m_previousBatteryStatus;
 };
 
 //////// QSystemScreenSaver
@@ -293,12 +388,14 @@ public:
 
     bool screenSaverInhibited();
     bool setScreenSaverInhibit();
+    void setScreenSaverInhibited(bool on);
 
 private Q_SLOTS:
     void resetInactivityTime();
 
 private:    //data
     bool m_screenSaverInhibited;
+    QTimer *timer;
 };
 
 //////// DeviceInfo (singleton)
@@ -386,10 +483,74 @@ public:
         return m_mmcStorageStatus;
     }
 
+#ifdef DISKNOTIFY_SUPPORTED
+    CStorageDiskNotifier *storagedisknotifier()
+    {
+        if (!m_storagedisknotifier) {
+            TRAP_IGNORE(m_storagedisknotifier = CStorageDiskNotifier::NewL();)
+        }
+        return m_storagedisknotifier;
+    }
+#endif
+
+#ifdef LOCKANDFLIP_SUPPORTED
+    CKeylockStatus *keylockStatus()
+    {
+        if (!m_keylockStatus) {
+            m_keylockStatus = new CKeylockStatus;
+        }
+        return m_keylockStatus;
+    }
+
+    CFlipStatus *flipStatus()
+    {
+        if (!m_flipStatus) {
+            m_flipStatus = new CFlipStatus;
+        }
+        return m_flipStatus;
+    }
+#endif
+
+#ifdef THERMALSTATUS_SUPPORTED
+    CThermalStatus *thermalStatus()
+        {
+           if (!m_thermalStatus)
+            {
+             m_thermalStatus = new CThermalStatus;
+            }
+            return m_thermalStatus;
+        }
+#endif
+
+    CBatteryCommonInfo *batteryCommonInfo ()
+    {
+        if (!m_batteryCommonInfo) {
+            m_batteryCommonInfo = new CBatteryCommonInfo();
+        }
+        return m_batteryCommonInfo;
+    }
+
+    CNetworkInfo* networkInfo ()
+    {
+        if (!m_networkInfo) {
+           m_networkInfo = new  CNetworkInfo();
+        }
+        return m_networkInfo;
+    }
+
 private:
     DeviceInfo() : m_phoneInfo(NULL), m_subscriberInfo(NULL), m_chargingStatus(NULL),
         m_batteryInfo(NULL), m_cellNetworkInfo(NULL), m_cellNetworkRegistrationInfo(NULL),
-        m_cellSignalStrengthInfo(NULL), m_wlanInfo(NULL), m_mmcStorageStatus(NULL)
+        m_cellSignalStrengthInfo(NULL), m_wlanInfo(NULL), m_mmcStorageStatus(NULL), m_batteryCommonInfo(NULL), m_networkInfo(NULL)
+#ifdef LOCKANDFLIP_SUPPORTED
+        ,m_keylockStatus(NULL),m_flipStatus(NULL)
+#endif
+#ifdef DISKNOTIFY_SUPPORTED
+        ,m_storagedisknotifier(NULL)
+#endif
+#ifdef THERMALSTATUS_SUPPORTED
+        ,m_thermalStatus(NULL)
+#endif
     {
         m_telephony = CTelephony::NewL();
     };
@@ -406,8 +567,23 @@ private:
         delete m_telephony;
         delete m_wlanInfo;
         delete m_mmcStorageStatus;
+        delete m_batteryCommonInfo;
+        delete m_networkInfo;
+#ifdef LOCKANDFLIP_SUPPORTED
+        delete m_keylockStatus;
+        delete m_flipStatus;
+#endif
+#ifdef DISKNOTIFY_SUPPORTED
+        delete m_storagedisknotifier;
+#endif
+
+#ifdef THERMALSTATUS_SUPPORTED
+        delete m_thermalStatus;
+#endif
     }
 
+    DeviceInfo(const DeviceInfo &);
+
     static DeviceInfo *m_instance;
 
     CTelephony *m_telephony;
@@ -420,6 +596,71 @@ private:
     CCellSignalStrengthInfo *m_cellSignalStrengthInfo;
     CWlanInfo* m_wlanInfo;
     CMMCStorageStatus* m_mmcStorageStatus;
+    CBatteryCommonInfo* m_batteryCommonInfo;
+    CNetworkInfo* m_networkInfo;
+#ifdef LOCKANDFLIP_SUPPORTED
+    CKeylockStatus *m_keylockStatus;
+    CFlipStatus *m_flipStatus;
+#endif
+#ifdef DISKNOTIFY_SUPPORTED
+    CStorageDiskNotifier* m_storagedisknotifier;
+#endif
+
+#ifdef THERMALSTATUS_SUPPORTED
+    CThermalStatus* m_thermalStatus;
+#endif
+};
+
+class QSystemBatteryInfoPrivate : public QObject, public MBatteryInfoObserver, public MBatteryHWRMObserver
+{
+    Q_OBJECT
+public:
+    QSystemBatteryInfoPrivate(QObject *parent = 0);
+    ~QSystemBatteryInfoPrivate();
+
+    QSystemBatteryInfo::ChargerType chargerType() const;
+    QSystemBatteryInfo::ChargingState chargingState() const;
+
+    int nominalCapacity() const;
+    int remainingCapacityPercent() const;
+    int remainingCapacity() const;
+
+    int voltage() const;
+    int remainingChargingTime() const;
+    int currentFlow() const;
+    int remainingCapacityBars() const;
+    int maxBars() const;
+    QSystemBatteryInfo::BatteryStatus batteryStatus() const;
+    QSystemBatteryInfo::EnergyUnit energyMeasurementUnit() const;
+
+Q_SIGNALS:
+    void batteryLevelChanged(qint32 level);
+    void batteryStatusChanged(QSystemBatteryInfo::BatteryStatus batteryStatus);
+
+
+    void chargingStateChanged(QSystemBatteryInfo::ChargingState chargingState);
+    void chargerTypeChanged(QSystemBatteryInfo::ChargerType chargerType);
+
+    void nominalCapacityChanged(int);
+    void remainingCapacityPercentChanged(int);
+    void remainingCapacitymAhChanged(int);
+    void batteryCurrentFlowChanged(int);
+    void currentFlowChanged(int);
+    void cumulativeCurrentFlowChanged(int);
+    void remainingCapacityBarsChanged(int);
+
+protected:
+    void connectNotify(const char *signal);
+    void disconnectNotify(const char *signal);
+    void changedBatteryStatus() ;
+    void changedChargingState() ;
+    void changedChargerType() ;
+    void changedRemainingCapacityBars();
+    void changedCurrentFlow(int);
+
+private :
+    CBatteryHWRM *m_batteryHWRM;
+    QSystemBatteryInfo::ChargerType m_charger, m_previousChagrger;
 };
 
 QTM_END_NAMESPACE
