@@ -1,17 +1,17 @@
 /****************************************************************************
 **
-** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2010 Nokia Corporation and/or its subatteryStatusidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,26 +25,20 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
-#include "qsysteminfo.h"
+#include "qsysteminfocommon_p.h"
 #include "qsysteminfo_win_p.h"
 #include <qt_windows.h>
 
@@ -70,8 +64,9 @@
 #include <QTimer>
 #include <QBasicTimer>
 #include <QtCore/qlibrary.h>
-#include <QUuid>
 #include <QSysInfo>
+#include <QUuid>
+#include <QCryptographicHash>
 
 #include <qabstracteventdispatcher.h>
 
@@ -82,11 +77,16 @@
 #include <Winuser.h>
 #include <Pm.h>
 #endif
+#include <HighLevelMonitorConfigurationAPI.h>
 
+#include <PowrProf.h>
+#include <Setupapi.h>
+
+#include <BatClass.h>
 
 #if !defined( Q_CC_MINGW)
 #ifndef Q_OS_WINCE
-#include "qwmihelper_win_p.h"
+#include "windows/qwmihelper_win_p.h"
 
 
 
@@ -123,7 +123,7 @@ enum WLAN_INTF_OPCODE {
     wlan_intf_opcode_background_scan_enabled,
     wlan_intf_opcode_media_streaming_mode,
     wlan_intf_opcode_radio_state,
-    wlan_intf_opcode_bss_type,
+    wlan_intf_opcode_batteryStatuss_type,
     wlan_intf_opcode_interface_state,
     wlan_intf_opcode_current_connection,
     wlan_intf_opcode_channel_number,
@@ -233,10 +233,10 @@ enum DOT11_CIPHER_ALGORITHM {
 };
 
 
-enum DOT11_BSS_TYPE {
-    dot11_BSS_type_infrastructure = 1,
-    dot11_BSS_type_independent = 2,
-    dot11_BSS_type_any = 3
+enum DOT11_batteryStatusS_TYPE {
+    dot11_batteryStatusS_type_infrastructure = 1,
+    dot11_batteryStatusS_type_independent = 2,
+    dot11_batteryStatusS_type_any = 3
 };
 
 
@@ -249,8 +249,8 @@ typedef UCHAR DOT11_MAC_ADDRESS[6];
 
 struct WLAN_ASSOCIATION_ATTRIBUTES {
     DOT11_SSID dot11Ssid;
-    DOT11_BSS_TYPE dot11BssType;
-    DOT11_MAC_ADDRESS dot11Bssid;
+    DOT11_batteryStatusS_TYPE dot11batteryStatussType;
+    DOT11_MAC_ADDRESS dot11batteryStatussid;
     DOT11_PHY_TYPE dot11PhyType;
     ULONG uDot11PhyIndex;
     ULONG wlanSignalQuality;
@@ -259,7 +259,7 @@ struct WLAN_ASSOCIATION_ATTRIBUTES {
 };
 
 struct WLAN_SECURITY_ATTRIBUTES {
-    BOOL bSecurityEnabled;
+    BOOL batteryStatusecurityEnabled;
     BOOL bOneXEnabled;
     DOT11_AUTH_ALGORITHM dot11AuthAlgorithm;
     DOT11_CIPHER_ALGORITHM dot11CipherAlgorithm;
@@ -279,7 +279,7 @@ enum WLAN_NOTIFICATION_ACM {
     wlan_notification_acm_autoconf_disabled,
     wlan_notification_acm_background_scan_enabled,
     wlan_notification_acm_background_scan_disabled,
-    wlan_notification_acm_bss_type_change,
+    wlan_notification_acm_batteryStatuss_type_change,
     wlan_notification_acm_power_setting_change,
     wlan_notification_acm_scan_complete,
     wlan_notification_acm_scan_fail,
@@ -569,7 +569,7 @@ bool QSystemInfoPrivate::hasFeatureSupported(QSystemInfo::Feature feature)
 
             resolveLibrary();
             if(local_BluetoothFindFirstRadio == 0 ) {
-                qWarning() << "Bluetooth library could not resolve or be loaded";
+                qDebug() << "Bluetooth library could not resolve or be loaded";
                 return false;
             }
             BLUETOOTH_FIND_RADIO_PARAMS  radioParams = { sizeof(BLUETOOTH_FIND_RADIO_PARAMS)};
@@ -698,7 +698,8 @@ bool QSystemInfoPrivate::hasFeatureSupported(QSystemInfo::Feature feature)
         break;
     case QSystemInfo::HapticsFeature:
         break;
-    default:
+     case QSystemInfo::FmTransmitterFeature:
+     default:
         featureSupported = false;
         break;
     };
@@ -792,11 +793,11 @@ void QSystemNetworkInfoPrivate::startWifiCallback()
     if(local_WlanOpenHandle)
         result = local_WlanOpenHandle(2, NULL, &version, &hWlan );
     if( result != ERROR_SUCCESS ) {
-        qWarning() << "Error opening Wlanapi 2" << result ;
+        qDebug() << "Error opening Wlanapi 2" << result ;
         return ;
     }
     if( result != ERROR_SUCCESS) {
-        qWarning() << "Error in enumerating wireless interfaces" << result;
+        qDebug() << "Error in enumerating wireless interfaces" << result;
         return ;
     }
     if (ERROR_SUCCESS != local_WlanRegisterNotification(hWlan,
@@ -804,7 +805,7 @@ void QSystemNetworkInfoPrivate::startWifiCallback()
                                                   true,
                                                   WLAN_NOTIFICATION_CALLBACK(wlanNotificationCallback),
                                                   this, 0, 0)) {
-        qWarning() << "failed";
+        qDebug() << "failed";
     } else {
         wlanCallbackInitialized = true;
     }
@@ -993,7 +994,7 @@ int QSystemNetworkInfoPrivate::networkSignalStrength(QSystemNetworkInfo::Network
                 if (hWlan ==0) {
                     result = local_WlanOpenHandle( 2, NULL, &version, &hWlan );
                     if( result != ERROR_SUCCESS ) {
-                        qWarning() << "Error opening Wlanapi 3" << result ;
+                        qDebug() << "Error opening Wlanapi 3" << result ;
                         local_WlanCloseHandle(hWlan,  0);
                         return 0;
                     }
@@ -1001,7 +1002,7 @@ int QSystemNetworkInfoPrivate::networkSignalStrength(QSystemNetworkInfo::Network
                 result = local_WlanEnumInterfaces(hWlan, NULL, &interfacesInfoList);
 
                 if( result != ERROR_SUCCESS) {
-                    qWarning() << "Error in enumerating wireless interfaces" << result;
+                    qDebug() << "Error in enumerating wireless interfaces" << result;
                     local_WlanCloseHandle(hWlan,  0);
                     return 0;
                 }
@@ -1012,7 +1013,7 @@ int QSystemNetworkInfoPrivate::networkSignalStrength(QSystemNetworkInfo::Network
                     WLAN_INTERFACE_STATE wlanInterfaceState = interfaceInfo->isState;
 
                     if( wlanInterfaceState == wlan_interface_state_not_ready ) {
-                        qWarning() << "Interface not ready";
+                        qDebug() << "Interface not ready";
                         continue;
                     }
 
@@ -1161,7 +1162,11 @@ QNetworkInterface QSystemNetworkInfoPrivate::interfaceForMode(QSystemNetworkInfo
     QListIterator<QNetworkInterface> i(interfaceList);
     while(i.hasNext()) {
        QNetworkInterface netInterface = i.next();
-        if (!netInterface.isValid() || (netInterface.flags() & QNetworkInterface::IsLoopBack)) {
+        if (!netInterface.isValid()
+            || (netInterface.flags() & QNetworkInterface::IsLoopBack)
+            || !(netInterface.flags() & QNetworkInterface::IsUp)
+            || !(netInterface.flags() & QNetworkInterface::IsRunning)
+            || netInterface.addressEntries().isEmpty()) {
             continue;
         }
 
@@ -1187,7 +1192,7 @@ QNetworkInterface QSystemNetworkInfoPrivate::interfaceForMode(QSystemNetworkInfo
                                           &medium, sizeof(medium), &bytesWritten, 0);
             if (!result) {
                 CloseHandle(handle);
-                qWarning() << "DeviceIo result is false";
+                qDebug() << "DeviceIo result is false";
                 return QNetworkInterface();
                 continue;
             }
@@ -1197,7 +1202,6 @@ QNetworkInterface QSystemNetworkInfoPrivate::interfaceForMode(QSystemNetworkInfo
             result = DeviceIoControl(handle, IOCTL_NDIS_QUERY_GLOBAL_STATS, &oid, sizeof(oid),
                                      &physicalMedium, sizeof(physicalMedium), &bytesWritten, 0);
 
-
             if (!result) {
                 CloseHandle(handle);
                 if (medium == NdisMedium802_3 && mode == QSystemNetworkInfo::EthernetMode) {
@@ -1282,12 +1286,12 @@ bool QSystemNetworkInfoPrivate::isDefaultMode(QSystemNetworkInfo::NetworkMode mo
 QSystemNetworkInfo::NetworkMode QSystemNetworkInfoPrivate::currentMode()
 {
     QList <QSystemNetworkInfo::NetworkMode> modeList;
-    modeList << QSystemNetworkInfo::GsmMode
-            << QSystemNetworkInfo::CdmaMode
-            << QSystemNetworkInfo::WcdmaMode
+    modeList << QSystemNetworkInfo::EthernetMode
             << QSystemNetworkInfo::WlanMode
-            << QSystemNetworkInfo::EthernetMode
             << QSystemNetworkInfo::BluetoothMode
+            << QSystemNetworkInfo::WcdmaMode
+            << QSystemNetworkInfo::CdmaMode
+            << QSystemNetworkInfo::GsmMode
             << QSystemNetworkInfo::WimaxMode;
 
     for (int i = 0; i < modeList.size(); ++i) {
@@ -1298,13 +1302,19 @@ QSystemNetworkInfo::NetworkMode QSystemNetworkInfoPrivate::currentMode()
     return QSystemNetworkInfo::UnknownMode;
 }
 
+QSystemNetworkInfo::CellDataTechnology QSystemNetworkInfoPrivate::cellDataTechnology()
+{
+    return QSystemNetworkInfo::UnknownDataTechnology;
+}
+
 QSystemDisplayInfoPrivate::QSystemDisplayInfoPrivate(QObject *parent)
-        : QObject(parent)
+        : QObject(parent),deviceContextHandle(0)
 {
 }
 
 QSystemDisplayInfoPrivate::~QSystemDisplayInfoPrivate()
 {
+    ReleaseDC(NULL, deviceContextHandle);
 }
 
 int QSystemDisplayInfoPrivate::displayBrightness(int /*screen*/)
@@ -1318,12 +1328,11 @@ int QSystemDisplayInfoPrivate::displayBrightness(int /*screen*/)
     wHelper->setClassProperty(QStringList() << "CurrentBrightness");
 
     QVariant v = wHelper->getWMIData();
-
-    return v.toUInt();
+    return (quint8)v.toUInt();
 #else
-    // This could would detect the state of the backlight, which is as close as we're going to get 
+    // This could would detect the state of the backlight, which is as close as we're going to get
     // for WinCE.  Unfortunately, some devices don't honour the Microsoft power management API.
-    // This means that the following code is not portable across WinCE devices and so shouldn't 
+    // This means that the following code is not portable across WinCE devices and so shouldn't
     // be included.
 
     //CEDEVICE_POWER_STATE powerState;
@@ -1347,24 +1356,146 @@ int QSystemDisplayInfoPrivate::displayBrightness(int /*screen*/)
     return -1;
 }
 
+int QSystemDisplayInfoPrivate::getMonitorCaps(int caps, int screen)
+{
+    if(deviceContextHandle == 0) {
+        QDesktopWidget wid;
+        HWND hWnd = wid.screen(screen)->winId();
+        deviceContextHandle = GetDC(hWnd);
+    }
+    int out = GetDeviceCaps(deviceContextHandle ,caps);
+    return out;
+}
+
 int QSystemDisplayInfoPrivate::colorDepth(int screen)
 {
-    QDesktopWidget wid;
-    HWND hWnd = wid.screen(screen)->winId();
-    HDC deviceContextHandle = GetDC(hWnd);
-    int bpp = GetDeviceCaps(deviceContextHandle ,BITSPIXEL);
-    int planes = GetDeviceCaps(deviceContextHandle, PLANES);
+    int bpp = getMonitorCaps(BITSPIXEL, screen);
+    int planes = getMonitorCaps(PLANES, screen);
     if(planes > 1) {
         bpp = 1 << planes;
     }
-    ReleaseDC(NULL, deviceContextHandle);
-
     return bpp;
 }
 
-QSystemStorageInfoPrivate::QSystemStorageInfoPrivate(QObject *parent)
-        : QObject(parent)
+QSystemDisplayInfo::DisplayOrientation QSystemDisplayInfoPrivate::orientation(int screen)
 {
+    QSystemDisplayInfo::DisplayOrientation orientation = QSystemDisplayInfo::Unknown;
+
+    if(screen < 16 && screen > -1) {
+        if(physicalWidth(screen) > physicalHeight(screen)) {
+            orientation = QSystemDisplayInfo::Landscape;
+        } else {
+            orientation = QSystemDisplayInfo::Portrait;
+        }
+//        int rotation = 0;
+//        switch(rotation) {
+//        case 0:
+//        case 360:
+//            break;
+//        case 90:
+//            break;
+//        case 180:
+//            orientation = QSystemDisplayInfo::InvertedLandscape;
+//            break;
+//        case 270:
+//            orientation = QSystemDisplayInfo::InvertedPortrait;
+//            break;
+//        };
+    }
+    return orientation;
+}
+
+
+float QSystemDisplayInfoPrivate::contrast(int screen)
+{
+    DWORD current = 0;
+    if (QSysInfo::WindowsVersion >= QSysInfo::WV_VISTA) {
+
+        HMONITOR monHandle = NULL;
+        QDesktopWidget wid;
+        HWND hWnd = wid.screen(screen)->winId();
+
+        monHandle = MonitorFromWindow(hWnd, MONITOR_DEFAULTTOPRIMARY);
+        LPPHYSICAL_MONITOR physMon = 0;
+        DWORD numMonitors;
+
+        if(GetNumberOfPhysicalMonitorsFromHMONITOR(monHandle, &numMonitors)) {
+
+            physMon = (LPPHYSICAL_MONITOR)malloc( numMonitors* sizeof(PHYSICAL_MONITOR));
+
+            GetPhysicalMonitorsFromHMONITOR(monHandle, numMonitors, physMon);
+
+
+            DWORD caps, colorTemp;
+            GetMonitorCapabilities(monHandle, &caps, &colorTemp);
+            if (caps & MC_CAPS_CONTRAST ) {
+                DWORD min=0;
+                DWORD max = 0;
+                GetMonitorContrast(monHandle, &min, &current, &max);
+            }
+            DestroyPhysicalMonitors(numMonitors,physMon);
+            free(physMon);
+        }
+    }
+    return (float)current;
+}
+
+int QSystemDisplayInfoPrivate::getDPIWidth(int screen)
+{
+    int dpi = getMonitorCaps(LOGPIXELSX,screen);
+    if(screen < 16 && screen > -1) {
+//
+        }
+    return dpi;
+}
+
+int QSystemDisplayInfoPrivate::getDPIHeight(int screen)
+{
+    int dpi = getMonitorCaps(LOGPIXELSY,screen);
+    if(screen < 16 && screen > -1) {
+//Win32_VideoController
+    }
+    return dpi;
+}
+
+
+int QSystemDisplayInfoPrivate::physicalHeight(int screen)
+{
+    int height = getMonitorCaps(VERTSIZE,screen);
+    // root/wmi
+// WmiMonitorBasicDisplayParams MaxHorizontalImageSize MaxVerticalImageSize
+    return height;
+}
+
+int QSystemDisplayInfoPrivate::physicalWidth(int screen)
+{
+    int width = getMonitorCaps(HORZSIZE,screen);
+    return width;
+}
+
+QSystemDisplayInfo::BacklightState  QSystemDisplayInfoPrivate::backlightStatus(int screen)
+{
+    Q_UNUSED(screen)
+    return QSystemDisplayInfo::BacklightStateUnknown;
+}
+
+QSystemStorageInfoPrivate::QSystemStorageInfoPrivate(QObject *parent)
+    : QObject(parent)
+{
+    logicalDrives();
+#if !defined( Q_CC_MINGW)
+#if !defined( Q_OS_WINCE)
+    WMIHelper *wHelper;
+    wHelper =  WMIHelper::instance();
+    wHelper->setWmiNamespace("root/cimv2");
+    wHelper->setClassName("Win32_VolumeChangeEvent");
+    QString aString = "SELECT * FROM __InstanceOperationEvent WITHIN 1 WHERE (TargetInstance ISA 'Win32_LogicalDisk') AND (TargetInstance.DriveType = 5 OR TargetInstance.DriveType = 2)";
+
+    wHelper->setupNotfication("root/cimv2",aString,QStringList());
+
+    connect(wHelper,SIGNAL(wminotificationArrived()),this,SLOT(notificationArrived()));
+#endif
+#endif
 }
 
 
@@ -1372,6 +1503,34 @@ QSystemStorageInfoPrivate::~QSystemStorageInfoPrivate()
 {
 }
 
+void QSystemStorageInfoPrivate::notificationArrived()
+{
+    QMap<QString, QString> oldDrives;
+
+     oldDrives = mountEntriesMap;
+     mountEntries();
+     QString driveLetter;
+
+     if(mountEntriesMap.count() < oldDrives.count()) {
+         QMapIterator<QString, QString> i(oldDrives);
+          while (i.hasNext()) {
+              i.next();
+              if(!mountEntriesMap.contains(i.key())) {
+                  emit logicalDriveChanged(false, i.key());
+              }
+          }
+      } else if(mountEntriesMap.count() > oldDrives.count()) {
+         QMapIterator<QString, QString> i(mountEntriesMap);
+          while (i.hasNext()) {
+              i.next();
+
+              if(oldDrives.contains(i.key()))
+                  continue;
+                 emit logicalDriveChanged(true,i.key());
+         }
+     }
+ }
+
 qint64 QSystemStorageInfoPrivate::availableDiskSpace(const QString &driveVolume)
 {
     qint64 freeBytes;
@@ -1410,6 +1569,7 @@ qint64 QSystemStorageInfoPrivate::totalDiskSpace(const QString &driveVolume)
 
 QSystemStorageInfo::DriveType QSystemStorageInfoPrivate::typeForDrive(const QString &driveVolume)
 {
+    uriForDrive(driveVolume);
 #if !defined( Q_OS_WINCE)
     uint result =  GetDriveType((WCHAR *)driveVolume.utf16());
     switch(result) {
@@ -1438,6 +1598,7 @@ QSystemStorageInfo::DriveType QSystemStorageInfoPrivate::typeForDrive(const QStr
 
 QStringList QSystemStorageInfoPrivate::logicalDrives()
 {
+    mountEntriesMap.clear();
     QStringList drivesList;
     QFileInfoList drives = QDir::drives();
     foreach(QFileInfo drive, drives) {
@@ -1445,17 +1606,40 @@ QStringList QSystemStorageInfoPrivate::logicalDrives()
         letter.chop(1);
         if(totalDiskSpace(letter) > 0) {
             drivesList.append(letter);
+            mountEntriesMap.insert(letter,letter);
         }
     }
     return drivesList;
 }
 
+void QSystemStorageInfoPrivate::mountEntries()
+{
+    logicalDrives();
+}
+
+QString QSystemStorageInfoPrivate::uriForDrive(const QString &driveVolume)
+{
+    WCHAR volume[MAX_PATH];
+    if (GetVolumeNameForVolumeMountPoint(reinterpret_cast<const wchar_t *>(driveVolume.utf16()), volume, MAX_PATH)) {
+        QString returnStr(QString::fromUtf16(reinterpret_cast<const unsigned short *>(volume)));
+        qDebug() << returnStr;
+        return returnStr;
+    }
+    return QString();
+}
+
+QSystemStorageInfo::StorageState QSystemStorageInfoPrivate::getStorageState(const QString &driveVolume)
+{
+    QSystemStorageInfo::StorageState state = QSystemStorageInfo::UnknownStorageState;
+   return state;
+}
+
 #if defined(Q_OS_WINCE)
 QPowerNotificationThread::QPowerNotificationThread(QSystemDeviceInfoPrivate *parent)
     : parent(parent),
     done(false)
 {
-    wakeUpEvent = CreateEvent(NULL, FALSE, FALSE, NULL);
+    wakeUpEvent = CreateEvent(NULL, FA      LSE, FALSE, NULL);
 }
 
 QPowerNotificationThread::~QPowerNotificationThread() {
@@ -1471,9 +1655,10 @@ QPowerNotificationThread::~QPowerNotificationThread() {
     CloseHandle(wakeUpEvent);
 }
 
-void QPowerNotificationThread::run() {
+void QPowerNotificationThread::run()
+{
 
-    const int MaxMessageSize = sizeof(POWER_BROADCAST) + sizeof(POWER_BROADCAST_POWER_INFO) 
+    const int MaxMessageSize = sizeof(POWER_BROADCAST) + sizeof(POWER_BROADCAST_POWER_INFO)
         + MAX_PATH;
 
     MSGQUEUEOPTIONS messageQueueOptions = { 0 };
@@ -1488,9 +1673,7 @@ void QPowerNotificationThread::run() {
     if (messageQueue == NULL)
         return;
 
-    HANDLE powerNotificationHandle = RequestPowerNotifications(messageQueue, PBT_TRANSITION 
-            | PBT_POWERINFOCHANGE);
-
+    HANDLE powerNotificationHandle = RequestPowerNotifications(messageQueue, PBT_TRANSITION|PBT_POWERINFOCHANGE);
     if (messageQueue == NULL)
         return;
 
@@ -1521,10 +1704,10 @@ void QPowerNotificationThread::run() {
             }
 
             POWER_BROADCAST *broadcast = (POWER_BROADCAST*) (buffer);
-
             if (broadcast->Message == PBT_POWERINFOCHANGE) {
-                POWER_BROADCAST_POWER_INFO *info = (POWER_BROADCAST_POWER_INFO*) broadcast->SystemPowerState;                
-                parent->batteryLevel();
+                POWER_BROADCAST_POWER_INFO *info = (POWER_BROADCAST_POWER_INFO*) broadcast->SystemPowerState;
+                parent->notificationArrived();
+                qDebug() << "CHANGED!";
             }
 
             parent->currentPowerState();
@@ -1548,17 +1731,28 @@ void QPowerNotificationThread::run() {
 #endif
 
 QSystemDeviceInfoPrivate *QSystemDeviceInfoPrivate::self = 0;
+QSystemBatteryInfoPrivate *QSystemBatteryInfoPrivate::batself = 0;
 
 #if !defined(Q_OS_WINCE)
 bool qax_winEventFilter(void *message)
 {
     MSG *pMsg = (MSG*)message;
     if( pMsg->message == WM_POWERBROADCAST) {
+
+        qDebug() << Q_FUNC_INFO;
+        POWERBROADCAST_SETTING* pps = (POWERBROADCAST_SETTING*) pMsg->lParam;
+        if ( sizeof(int) == pps->DataLength &&
+                pps->PowerSetting == GUID_BATTERY_PERCENTAGE_REMAINING ) {
+            int nPercentLeft = *(int*)(DWORD_PTR) pps->Data;
+
+            qDebug() <<Q_FUNC_INFO << nPercentLeft;
+        }
         switch (pMsg->wParam) {
         case PBT_APMPOWERSTATUSCHANGE:
-            QSystemDeviceInfoPrivate::instance()->batteryLevel();
-            QSystemDeviceInfoPrivate::instance()->currentPowerState();
-            break;
+        {
+//            QSystemDeviceInfoPrivate::instance()->batteryLevel();
+//            QSystemDeviceInfoPrivate::instance()->currentPowerState();
+        }
             break;
         default:
             break;
@@ -1576,7 +1770,7 @@ QSystemDeviceInfoPrivate::QSystemDeviceInfoPrivate(QObject *parent)
     currentPowerStateCache = QSystemDeviceInfo::UnknownPower;
     batteryStatusCache = QSystemDeviceInfo::NoBatteryLevel;
 #if !defined(Q_OS_WINCE)
-    QAbstractEventDispatcher::instance()->setEventFilter(qax_winEventFilter);
+//    QAbstractEventDispatcher::instance()->setEventFilter(qax_winEventFilter);
 #else
     powerNotificationThread = new QPowerNotificationThread(this);
     powerNotificationThread->start();
@@ -1619,7 +1813,7 @@ QSystemDeviceInfo::InputMethodFlags QSystemDeviceInfoPrivate::inputMethodType()
         }
     }
 # endif
-#else 
+#else
     // detect the presence of a mouse
     RECT rect;
     if (GetClipCursor(&rect)) {
@@ -1628,15 +1822,15 @@ QSystemDeviceInfo::InputMethodFlags QSystemDeviceInfoPrivate::inputMethodType()
         }
     }
     // We could also try to detect the presence of a stylus / single touch input.
-    // A team from Microsoft was unable to do this in a way which scaled across multiple devices.    
+    // A team from Microsoft was unable to do this in a way which scaled across multiple devices.
     // For more details see:
     // http://blogs.msdn.com/netcfteam/archive/2006/10/02/Platform-detection-III_3A00_-How-to-detect-a-touch-screen-on-Windows-CE-in-.NET-CF.aspx
     // Since all non-Qt apps on non-compliant devices will be able to use the touch screen
-    // (by virtue of being written for one particular device) shipping a library which will cause 
+    // (by virtue of being written for one particular device) shipping a library which will cause
     // just the Qt apps to fail may not be the best move.
 #endif
-    int keyboardType = GetKeyboardType(0);
-    switch(keyboardType) {
+    int keyboardTypes = GetKeyboardType(0);
+    switch(keyboardTypes) {
     case 1:
     case 3:
         {
@@ -1705,6 +1899,11 @@ QSystemDeviceInfo::PowerState QSystemDeviceInfoPrivate::currentPowerState()
     return state;
 }
 
+QSystemDeviceInfo::ThermalState QSystemDeviceInfoPrivate::currentThermalState()
+{
+    return QSystemDeviceInfo::UnknownThermal;
+}
+
 QString QSystemDeviceInfoPrivate::imei()
 {
         return "";
@@ -1820,7 +2019,7 @@ int QSystemDeviceInfoPrivate::batteryLevel()
     if(GetSystemPowerStatusEx(&status, true) ) {
         bat = status.BatteryLifePercent;
     } else {
-       qWarning() << "Battery status failed";
+       qDebug() << "Battery status failed";
        return 0;
     }
 #else
@@ -1828,7 +2027,7 @@ int QSystemDeviceInfoPrivate::batteryLevel()
     if(GetSystemPowerStatus( &status) ) {
         bat = status.BatteryLifePercent;
     } else {
-       qWarning() << "Battery status failed";
+       qDebug() << "Battery status failed";
        return 0;
     }
 #endif
@@ -1881,9 +2080,13 @@ QSystemDeviceInfo::SimStatus QSystemDeviceInfoPrivate::simStatus()
     return QSystemDeviceInfo::SimNotAvailable;
 }
 
+bool QSystemDeviceInfoPrivate::currentBluetoothPowerState()
+{
+    return false;
+}
+
 bool QSystemDeviceInfoPrivate::isDeviceLocked()
 {
-    qWarning()<< __FUNCTION__;
 #ifdef Q_OS_WINCE
     HSIM handle;
     DWORD lockedState;
@@ -1904,6 +2107,78 @@ bool QSystemDeviceInfoPrivate::isDeviceLocked()
     return false;
 }
 
+QSystemDeviceInfo::KeyboardTypeFlags QSystemDeviceInfoPrivate::keyboardTypes()
+{
+    QSystemDeviceInfo::InputMethodFlags methods = inputMethodType();
+    QSystemDeviceInfo::KeyboardTypeFlags keyboardFlags = QSystemDeviceInfo::UnknownKeyboard;
+
+    if((methods & QSystemDeviceInfo::Keyboard)) {
+        keyboardFlags = (keyboardFlags | QSystemDeviceInfo::FullQwertyKeyboard);
+  }
+    if(isWirelessKeyboardConnected()) {
+        keyboardFlags = (keyboardFlags | QSystemDeviceInfo::WirelessKeyboard);
+    }
+// how to check softkeys on desktop?
+    return keyboardFlags;
+}
+
+bool QSystemDeviceInfoPrivate::isWirelessKeyboardConnected()
+{
+    return hasWirelessKeyboardConnected;
+}
+
+bool QSystemDeviceInfoPrivate::isKeyboardFlippedOpen()
+{
+    return false;
+}
+
+void QSystemDeviceInfoPrivate::keyboardConnected(bool connect)
+{
+    if(connect != hasWirelessKeyboardConnected)
+        hasWirelessKeyboardConnected = connect;
+    Q_EMIT wirelessKeyboardConnected(connect);
+}
+
+bool QSystemDeviceInfoPrivate::keypadLightOn(QSystemDeviceInfo::KeypadType type)
+{
+    return false;
+}
+
+QByteArray QSystemDeviceInfoPrivate::uniqueDeviceID()
+{
+    WMIHelper *wHelper;
+    wHelper = new WMIHelper(this);
+    wHelper->setWmiNamespace("root/cimv2");
+    wHelper->setClassName("Win32_ComputerSystemProduct");
+    wHelper->setClassProperty(QStringList() << "UUID");
+
+    QCryptographicHash hash(QCryptographicHash::Sha1);
+    QString id = wHelper->getWMIData().toString();
+    hash.addData(id.toLocal8Bit());
+
+    return  hash.result().toHex();
+}
+
+QSystemDeviceInfo::LockTypeFlags QSystemDeviceInfoPrivate::lockStatus()
+{
+    return QSystemDeviceInfo::UnknownLock;
+}
+
+int QSystemDeviceInfoPrivate::messageRingtoneVolume()
+{
+    return 0;
+}
+
+int QSystemDeviceInfoPrivate::voiceRingtoneVolume()
+{
+    return 0;
+}
+
+bool QSystemDeviceInfoPrivate::vibrationActive()
+{
+    return false;
+}
+
 QSystemScreenSaverPrivate::QSystemScreenSaverPrivate(QObject *parent)
         : QObject(parent)
 {
@@ -1922,7 +2197,6 @@ bool QSystemScreenSaverPrivate::screenSaverSecureEnabled()
 
     QSettings screenSettings(settingsPath, QSettings::NativeFormat);
     if(screenSettings.value("ScreenSaverIsSecure").toString() == "1") {
-        qWarning() << "screensaver enabled";
         screenSaverSecure = true;
     }
     screenPath = screenSettings.value("SCRNSAVE.EXE").toString();
@@ -1947,6 +2221,338 @@ bool QSystemScreenSaverPrivate::screenSaverInhibited()
     return !screenSettings.value("SCRNSAVE.EXE").toString().isEmpty();
 }
 
+QSystemBatteryInfoPrivate::QSystemBatteryInfoPrivate(QObject *parent)
+: QObject(parent)
+{
+    if(!batself)
+        batself = this;
+    setConnection();
+    getBatteryStatus();
+
+}
+
+void QSystemScreenSaverPrivate::setScreenSaverInhibited(bool on)
+{
+    if (on) {
+        setScreenSaverInhibit();
+    } else {
+
+    }
+}
+
+
+QSystemBatteryInfoPrivate::~QSystemBatteryInfoPrivate()
+{
+
+}
+
+
+QSystemBatteryInfo::ChargerType QSystemBatteryInfoPrivate::chargerType() const
+{
+    return curChargeType;
+}
+
+QSystemBatteryInfo::ChargingState QSystemBatteryInfoPrivate::chargingState() const
+{
+    return curChargeState;
+}
+
+
+int QSystemBatteryInfoPrivate::nominalCapacity() const
+{
+    return capacity;
+}
+
+int QSystemBatteryInfoPrivate::remainingCapacityPercent() const
+{
+    return currentBatLevelPercent;
+}
+
+int QSystemBatteryInfoPrivate::remainingCapacity() const
+{
+    return remainingEnergy;
+}
+
+
+int QSystemBatteryInfoPrivate::voltage() const
+{
+    return currentVoltage;
+}
+
+int QSystemBatteryInfoPrivate::remainingChargingTime() const
+{
+    return timeToFull;
+}
+
+int QSystemBatteryInfoPrivate::currentFlow() const
+{
+    return dischargeRate;
+}
+
+int QSystemBatteryInfoPrivate::remainingCapacityBars() const
+{
+    return 0;
+}
+
+int QSystemBatteryInfoPrivate::maxBars() const
+{
+    return 0;
+}
+
+QSystemBatteryInfo::BatteryStatus QSystemBatteryInfoPrivate::batteryStatus() const
+{
+   return QSystemBatteryInfo::BatteryUnknown;
+}
+
+void QSystemBatteryInfoPrivate::connectNotify(const char *signal)
+{
+   if (QLatin1String(signal) == QLatin1String(QMetaObject::normalizedSignature(SIGNAL(
+            batteryStatusChanged(QSystemBatteryInfo::BatteryStatus))))) {
+    }
+
+    if (QLatin1String(signal) == QLatin1String(QMetaObject::normalizedSignature(SIGNAL(
+            chargingStateChanged(QSystemBatteryInfo::ChargingState))))) {
+    }
+
+    if (QLatin1String(signal) == QLatin1String(QMetaObject::normalizedSignature(SIGNAL(
+            chargerTypeChanged(QSystemBatteryInfo::ChargerType))))) {
+    }
+
+    if (QLatin1String(signal) == QLatin1String(QMetaObject::normalizedSignature(SIGNAL(
+            nominalCapacityChanged(int))))) {
+    }
+
+    if (QLatin1String(signal) == QLatin1String(QMetaObject::normalizedSignature(SIGNAL(
+            remainingCapacityPercentChanged(int))))) {
+    }
+
+    if (QLatin1String(signal) == QLatin1String(QMetaObject::normalizedSignature(SIGNAL(
+            remainingCapacityChanged(int))))) {
+    }
+
+    if (QLatin1String(signal) == QLatin1String(QMetaObject::normalizedSignature(SIGNAL(
+            currentFlowChanged(int))))) {
+    }
+
+    if (QLatin1String(signal) == QLatin1String(QMetaObject::normalizedSignature(SIGNAL(
+            remainingCapacityBarsChanged(int))))) {
+    }
+    if (QLatin1String(signal) == QLatin1String(QMetaObject::normalizedSignature(SIGNAL(
+            remainingChargingTimeChanged(int))))) {
+    }
+}
+
+void QSystemBatteryInfoPrivate::setConnection()
+{
+#if !defined(Q_OS_WINCE)
+    QAbstractEventDispatcher::instance()->setEventFilter(qax_winEventFilter);
+#else
+    powerNotificationThread = new QPowerNotificationThread(this);
+    powerNotificationThread->start();
+#endif
+
+    QTimer *timer = new QTimer(this);
+    connect(timer,SIGNAL(timeout()),this,SLOT(notificationArrived()));
+    timer->start(1000);
+
+#if !defined( Q_CC_MINGW)
+#if !defined( Q_OS_WINCE)
+//    WMIHelper *wHelper;
+//    wHelper =  WMIHelper::instance();
+//    wHelper->setWmiNamespace("root/cimv2");
+//    wHelper->setClassName("Win32_PowerManagementEvent");
+//    QString aString = "SELECT * FROM Win32_PowerManagementEvent";
+//    wHelper->setupNotfication("root/cimv2",aString,QStringList());
+
+//    connect(wHelper,SIGNAL(wminotificationArrived()),this,SLOT(notificationArrived()));
+#endif
+#endif
+}
+
+void QSystemBatteryInfoPrivate::notificationArrived()
+{
+    getBatteryStatus();
+}
+
+void QSystemBatteryInfoPrivate::disconnectNotify(const char *signal)
+{
+
+}
+
+QSystemBatteryInfo::EnergyUnit QSystemBatteryInfoPrivate::energyMeasurementUnit()
+{
+   return QSystemBatteryInfo::UnitmWh;
+}
+
+void QSystemBatteryInfoPrivate::getBatteryStatus()
+{
+    int cLevel = 0;
+    int cEnergy = 0;
+    int cVoltage = 0;
+    int cTime = 0;
+    int rEnergy = 0;
+
+    QSystemBatteryInfo::ChargingState cState = QSystemBatteryInfo::ChargingError;
+    QSystemBatteryInfo::ChargerType cType = QSystemBatteryInfo::UnknownCharger;
+    QSystemBatteryInfo::BatteryStatus batStatus = QSystemBatteryInfo::BatteryUnknown;
+
+    NTSTATUS powerStatus;
+    SYSTEM_BATTERY_STATE systemBatteryState;
+    powerStatus = CallNtPowerInformation(SystemBatteryState,NULL,0,&systemBatteryState,sizeof(systemBatteryState));
+
+    if(systemBatteryState.Charging) {
+        cState = QSystemBatteryInfo::Charging;
+    } else {
+        cState = QSystemBatteryInfo::NotCharging;
+    }
+
+    if(cState != curChargeState ) {
+        curChargeState = cState;
+        emit chargingStateChanged(curChargeState);
+    }
+
+
+    capacity = systemBatteryState.MaxCapacity;
+
+    rEnergy = systemBatteryState.RemainingCapacity;
+    if(rEnergy != remainingEnergy) {
+        remainingEnergy = rEnergy;
+        emit remainingCapacityChanged(remainingEnergy);
+    }
+
+    cEnergy = systemBatteryState.Rate;
+    if (cEnergy != dischargeRate) {
+        dischargeRate = cEnergy;
+        emit currentFlowChanged(dischargeRate);
+    }
+
+    if (systemBatteryState.AcOnLine) {
+        cType = QSystemBatteryInfo::WallCharger;
+    } else {
+        cType = QSystemBatteryInfo::NoCharger;
+    }
+    if (cType != curChargeType) {
+        curChargeType = cType;
+        emit chargerTypeChanged(curChargeType);
+    }
+
+    cTime = systemBatteryState.EstimatedTime;
+    if(cTime != timeToFull) {
+        timeToFull = cTime;
+        emit remainingChargingTimeChanged(timeToFull);
+    }
+
+    SYSTEM_POWER_STATUS status;
+    if(GetSystemPowerStatus( &status) ) {
+
+        cLevel = status.BatteryLifePercent;
+        if(cLevel != currentBatLevelPercent) {
+            currentBatLevelPercent = cLevel;
+            emit remainingCapacityPercentChanged(currentBatLevelPercent);
+        }
+        switch(status.BatteryFlag) {
+        case (1):
+            batStatus = QSystemBatteryInfo::BatteryOk;
+            break;
+        case (2):
+            batStatus = QSystemBatteryInfo::BatteryLow;
+            break;
+        case (3):
+            batStatus = QSystemBatteryInfo::BatteryVeryLow;
+            break;
+        case (4):
+            batStatus = QSystemBatteryInfo::BatteryCritical;
+            break;
+        case (128):
+        case (255):
+            batStatus = QSystemBatteryInfo::BatteryUnknown;
+            break;
+        }
+    }
+    if(batStatus != currentBatStatus) {
+        currentBatStatus = batStatus;
+        emit batteryStatusChanged(currentBatStatus);
+    }
+
+
+#define HASBATTERY 0x1
+#define ONBATTERY  0x2
+
+    QUuid guidDeviceBattery(0x72631e54L,0x78A4,0x11d0,0xbc,0xf7,0x00,0xaa,0x00,0xb7,0xb3,0x2a);
+    GUID GUID_DEVICE_BATTERY = static_cast<GUID>(guidDeviceBattery);
+
+    DWORD dwResult = ONBATTERY;
+    HDEVINFO hdevInfo = SetupDiGetClassDevs(&GUID_DEVICE_BATTERY,0,0,DIGCF_PRESENT | DIGCF_DEVICEINTERFACE);
+    if (INVALID_HANDLE_VALUE != hdevInfo) {
+        for (int i = 0; i < 100; i++) {
+            SP_DEVICE_INTERFACE_DATA deviceInterfaceData = {0};
+            deviceInterfaceData.cbSize = sizeof(deviceInterfaceData);
+
+            if (SetupDiEnumDeviceInterfaces(hdevInfo,0,&GUID_DEVICE_BATTERY,i,&deviceInterfaceData)){
+                DWORD cbRequired = 0;
+
+                SetupDiGetDeviceInterfaceDetail(hdevInfo, &deviceInterfaceData,0, 0, &cbRequired, 0);
+                if (ERROR_INSUFFICIENT_BUFFER == GetLastError()) {
+                    PSP_DEVICE_INTERFACE_DETAIL_DATA deviceInterfaceDetail =
+                            (PSP_DEVICE_INTERFACE_DETAIL_DATA)LocalAlloc(LPTR, cbRequired);
+                    if (deviceInterfaceDetail){
+                        deviceInterfaceDetail->cbSize = sizeof(*deviceInterfaceDetail);
+                        if (SetupDiGetDeviceInterfaceDetail(hdevInfo, &deviceInterfaceData, deviceInterfaceDetail, cbRequired, &cbRequired, 0)) {
+
+                            HANDLE batteryHandle = CreateFile(deviceInterfaceDetail->DevicePath, GENERIC_READ | GENERIC_WRITE, FILE_SHARE_READ | FILE_SHARE_WRITE,
+                                                         NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
+                            if (INVALID_HANDLE_VALUE != batteryHandle){
+
+                                BATTERY_QUERY_INFORMATION batteryQueryInfo = {0};
+
+                                DWORD inBuf = 0;
+                                DWORD dwOut;
+
+                                if (DeviceIoControl(batteryHandle,IOCTL_BATTERY_QUERY_TAG, &inBuf, sizeof(inBuf), &batteryQueryInfo.BatteryTag, sizeof(batteryQueryInfo.BatteryTag), &dwOut, NULL)
+                                        && batteryQueryInfo.BatteryTag) {
+                                    BATTERY_INFORMATION batteryInfo = {0};
+                                    batteryQueryInfo.InformationLevel = BatteryInformation;
+
+                                    if (DeviceIoControl(batteryHandle, IOCTL_BATTERY_QUERY_INFORMATION,&batteryQueryInfo,sizeof(batteryQueryInfo),&batteryInfo,sizeof(batteryInfo), &dwOut, NULL)) {
+
+                                        if (batteryInfo.Capabilities & BATTERY_SYSTEM_BATTERY) {
+                                            if (!(batteryInfo.Capabilities & BATTERY_IS_SHORT_TERM)) {
+                                                dwResult |= HASBATTERY;
+                                            }
+
+                                            BATTERY_WAIT_STATUS batteryWaitStatus = {0};
+                                            batteryWaitStatus.BatteryTag = batteryQueryInfo.BatteryTag;
+
+                                            BATTERY_STATUS batteryStatus;
+                                            if (DeviceIoControl(batteryHandle, IOCTL_BATTERY_QUERY_STATUS, &batteryWaitStatus, sizeof(batteryWaitStatus), &batteryStatus, sizeof(batteryStatus), &dwOut, NULL)) {
+                                                if (batteryStatus.PowerState & BATTERY_POWER_ON_LINE) {
+                                                    dwResult &= ~ONBATTERY;
+                                                }
+                                                cVoltage = batteryStatus.Voltage;
+                                                if(cVoltage != currentVoltage) {
+                                                    currentVoltage= cVoltage;
+                                                }
+                                            }
+                                        }
+                                    }
+                                }
+                                CloseHandle(batteryHandle);
+                            }
+                        }
+                        LocalFree(deviceInterfaceDetail);
+                    }
+                }
+            }
+            else  if (ERROR_NO_MORE_ITEMS == GetLastError()) {
+                break;
+            }
+        }
+        SetupDiDestroyDeviceInfoList(hdevInfo);
+    }
+    if (!(dwResult & HASBATTERY))
+        dwResult &= ~ONBATTERY;
+}
+
 
 #include "moc_qsysteminfo_win_p.cpp"
 
