@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -89,7 +89,7 @@ QVersitContactExporterPrivate::QVersitContactExporterPrivate(const QStringList&
     int versitPropertyCount =
         sizeof(versitContactDetailMappings)/sizeof(VersitDetailMapping);
     // Put them in in reverse order so the entries at the top of the list take precedence
-    for (int i=versitPropertyCount; i >= 0; i--) {
+    for (int i = versitPropertyCount-1; i >= 0; i--) {
         mPropertyMappings.insert(
                 QLatin1String(versitContactDetailMappings[i].detailDefinitionName),
                 QLatin1String(versitContactDetailMappings[i].versitPropertyName));
@@ -129,10 +129,9 @@ QVersitContactExporterPrivate::~QVersitContactExporterPrivate()
 /*!
  * Export QT Contact into Versit Document.
  */
-bool QVersitContactExporterPrivate::exportContact(
+void QVersitContactExporterPrivate::exportContact(
     const QContact& contact,
-    QVersitDocument& document,
-    QVersitContactExporter::Error* error)
+    QVersitDocument& document)
 {
     QList<QContactDetail> allDetails = contact.details();
     foreach (const QContactDetail& detail, allDetails) {
@@ -185,8 +184,6 @@ bool QVersitContactExporterPrivate::exportContact(
             encodeOnlineAccount(detail, &generatedProperties, &processedFields);
         } else if (detail.definitionName() == QContactFamily::DefinitionName) {
             encodeFamily(detail, &generatedProperties, &processedFields);
-        } else if (detail.definitionName() == QContactDisplayLabel::DefinitionName) {
-            encodeDisplayLabel(detail, document, &removedProperties, &generatedProperties, &processedFields);
         }
 
         // run plugin handlers
@@ -221,35 +218,22 @@ bool QVersitContactExporterPrivate::exportContact(
         mDetailHandler2->contactProcessed(contact, &document);
     }
 
-    ensureDocumentContainsName(contact, &document);
-    return true;
+    ensureDocumentContainsName(&document);
+    return;
 }
 
 /*!
- * Returns true if and only if \a document has a "FN" or "N" property.
+ * Adds to \a document an empty "N" property if it doesn't already have one.
  */
-void QVersitContactExporterPrivate::ensureDocumentContainsName(const QContact& contact,
-                                                               QVersitDocument* document)
+void QVersitContactExporterPrivate::ensureDocumentContainsName(QVersitDocument* document)
 {
     bool containsN = false;
-    bool containsFN = false;
-    QString fnValue;
     foreach (const QVersitProperty& property, document->properties()) {
         const QString& name = property.name();
-        if (name == QLatin1String("FN")) {
-            containsFN = true;
-            fnValue = property.value();
-        } else if (name == QLatin1String("N")) {
+        if (name == QLatin1String("N")) {
             containsN = true;
         }
     }
-    if (!containsFN) {
-        QVersitProperty fnProperty;
-        fnProperty.setName(QLatin1String("FN"));
-        fnValue = QVersitContactImporterPrivate::synthesizedDisplayLabel(contact);
-        fnProperty.setValue(fnValue);
-        document->addProperty(fnProperty);
-    }
 
     if (!containsN) {
         QVersitProperty nProperty;
@@ -291,6 +275,13 @@ void QVersitContactExporterPrivate::encodeName(
         *generatedProperties << property;
     }
 
+    if (!contactName.customLabel().isEmpty()) {
+        QVersitProperty fnProperty;
+        fnProperty.setName(QLatin1String("FN"));
+        fnProperty.setValue(contactName.customLabel());
+        *generatedProperties << fnProperty;
+    }
+
     *processedFields << QContactName::FieldLastName
                      << QContactName::FieldFirstName
                      << QContactName::FieldMiddleName
@@ -455,7 +446,15 @@ void QVersitContactExporterPrivate::encodeBirthDay(
     QContactBirthday bday = static_cast<QContactBirthday>(detail);
     QVersitProperty property;
     property.setName(mPropertyMappings.value(detail.definitionName()));
-    QString value = bday.date().toString(Qt::ISODate);
+    QVariant variant = bday.variantValue(QContactBirthday::FieldBirthday);
+    QString value;
+    if (variant.type() == QVariant::Date) {
+        value = variant.toDate().toString(Qt::ISODate);
+    } else if (variant.type() == QVariant::DateTime) {
+        value = variant.toDateTime().toString(Qt::ISODate);
+    } else {
+        return;
+    }
     property.setValue(value);
     *generatedProperties << property;
     *processedFields << QContactBirthday::FieldBirthday;
@@ -602,13 +601,15 @@ void QVersitContactExporterPrivate::encodeAvatar(
     QUrl imageUrl(contactAvatar.imageUrl());
     // XXX: fix up this mess: checking the scheme here and in encodeContentFromFile,
     // organisation logo and ringtone are QStrings but avatar is a QUrl
-    if (!imageUrl.scheme().isEmpty() && !imageUrl.host().isEmpty()) {
+    if (!imageUrl.scheme().isEmpty()
+            && !imageUrl.host().isEmpty()
+            && imageUrl.scheme() != QLatin1String("file")) {
         property.insertParameter(QLatin1String("VALUE"), QLatin1String("URL"));
         property.setValue(imageUrl.toString());
         *generatedProperties << property;
         *processedFields << QContactAvatar::FieldImageUrl;
     } else {
-        if (encodeContentFromFile(contactAvatar.imageUrl().toString(), property)) {
+        if (encodeContentFromFile(contactAvatar.imageUrl().toLocalFile(), property)) {
             *generatedProperties << property;
             *processedFields << QContactAvatar::FieldImageUrl;
         }
@@ -701,21 +702,40 @@ void QVersitContactExporterPrivate::encodeOnlineAccount(
 {
     QContactOnlineAccount onlineAccount = static_cast<QContactOnlineAccount>(detail);
     QStringList subTypes = onlineAccount.subTypes();
+    QString protocol = onlineAccount.protocol();
 
-    if (subTypes.contains(QContactOnlineAccount::SubTypeSip) ||
-        subTypes.contains(QContactOnlineAccount::SubTypeSipVoip) ||
-        subTypes.contains(QContactOnlineAccount::SubTypeVideoShare) ||
-        subTypes.contains(QContactOnlineAccount::SubTypeImpp)) {
+    QString propertyName;
+
+    if (protocol == QContactOnlineAccount::ProtocolJabber) {
+        propertyName = QLatin1String("X-JABBER");
+    } else if (protocol == QContactOnlineAccount::ProtocolAim) {
+        propertyName = QLatin1String("X-AIM");
+    } else if (protocol == QContactOnlineAccount::ProtocolIcq) {
+        propertyName = QLatin1String("X-ICQ");
+    } else if (protocol == QContactOnlineAccount::ProtocolMsn) {
+        propertyName = QLatin1String("X-MSN");
+    } else if (protocol == QContactOnlineAccount::ProtocolQq) {
+        propertyName = QLatin1String("X-QQ");
+    } else if (protocol == QContactOnlineAccount::ProtocolYahoo) {
+        propertyName = QLatin1String("X-YAHOO");
+    } else if (protocol == QContactOnlineAccount::ProtocolSkype) {
+        propertyName = QLatin1String("X-SKYPE");
+    } else if (subTypes.contains(QContactOnlineAccount::SubTypeSip) ||
+               subTypes.contains(QContactOnlineAccount::SubTypeSipVoip) ||
+               subTypes.contains(QContactOnlineAccount::SubTypeVideoShare)) {
+        propertyName = QLatin1String("X-SIP");
+    } else if (subTypes.contains(QContactOnlineAccount::SubTypeImpp)) {
+        propertyName = QLatin1String("X-IMPP");
+    }
+
+    if (!propertyName.isEmpty()) {
         QVersitProperty property;
         encodeParameters(property, onlineAccount.contexts(), subTypes);
-        QString name(QLatin1String("X-SIP"));
-        if (subTypes.contains(QContactOnlineAccount::SubTypeImpp))
-            name = QLatin1String("X-IMPP");
-        property.setName(name);
+        property.setName(propertyName);
         property.setValue(onlineAccount.accountUri());
         *generatedProperties << property;
         *processedFields << QContactOnlineAccount::FieldSubTypes
-                          << QContactOnlineAccount::FieldAccountUri;
+                         << QContactOnlineAccount::FieldAccountUri;
     }
 }
 
@@ -747,29 +767,6 @@ void QVersitContactExporterPrivate::encodeFamily(
     }
 }
 
-
-/*!
- * Encode family versit property if its supported in Versit Document
- */
-void QVersitContactExporterPrivate::encodeDisplayLabel(
-    const QContactDetail &detail,
-    const QVersitDocument& document,
-    QList<QVersitProperty>* removedProperties,
-    QList<QVersitProperty>* generatedProperties,
-    QSet<QString>* processedFields)
-{
-    // Override any previous FN property
-    QVersitProperty property =
-        VersitUtils::takeProperty(document, QLatin1String("FN"), removedProperties);
-    property.setName(mPropertyMappings.value(detail.definitionName()));
-    QContactDisplayLabel displayLabel = static_cast<QContactDisplayLabel>(detail);
-    if (!displayLabel.label().isEmpty()) {
-        property.setValue(displayLabel.label());
-        *generatedProperties << property;
-        *processedFields << QContactDisplayLabel::FieldLabel;
-    }
-}
-
 /*!
  * Check if \a resourceIdentifier represents a valid remote resource
  */
