@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -166,6 +166,7 @@ bool QVersitContactImporterPrivate::importContact(
     contact->setType(QContactType::TypeContact);
     QContactManagerEngine::setContactDisplayLabel(contact, QVersitContactImporterPrivate::synthesizedDisplayLabel(*contact));
 
+    mRestoreHandler.documentProcessed();
     // run plugin handlers
     foreach (QVersitContactImporterPropertyHandlerV2* handler, mPluginPropertyHandlers) {
         handler->documentProcessed(document, contact);
@@ -231,6 +232,9 @@ void QVersitContactImporterPrivate::importProperty(
         success = createNameValueDetail(property, contact, &updatedDetails);
     }
 
+    if (mRestoreHandler.propertyProcessed(property, &updatedDetails))
+        success = true;
+
     // run plugin handlers
     foreach (QVersitContactImporterPropertyHandlerV2* handler, mPluginPropertyHandlers) {
         handler->propertyProcessed(document, property, *contact, &success, &updatedDetails);
@@ -440,15 +444,9 @@ bool QVersitContactImporterPrivate::createTimeStamp(
     Q_UNUSED(contact)
     QContactTimestamp timeStamp;
     QString value(property.value());
-    bool utc = value.endsWith(QLatin1Char('Z'), Qt::CaseInsensitive);
-    if (utc)
-        value.chop(1); // take away z from end;
-
-    QDateTime dateTime = parseDateTime(value,QLatin1String("yyyyMMddThhmmss"));
+    QDateTime dateTime = parseDateTime(value);
     if (!dateTime.isValid())
         return false;
-    if (utc)
-        dateTime.setTimeSpec(Qt::UTC);
     timeStamp.setLastModified(dateTime);
     saveDetailWithContext(updatedDetails, timeStamp, extractContexts(property));
     return true;
@@ -464,10 +462,14 @@ bool QVersitContactImporterPrivate::createAnniversary(
 {
     Q_UNUSED(contact)
     QContactAnniversary anniversary;
-    QDateTime dateTime = parseDateTime(property.value(), QLatin1String("yyyyMMdd"));
+    bool justDate = false;
+    QDateTime dateTime = parseDateTime(property.value(), &justDate);
     if (!dateTime.isValid())
         return false;
-    anniversary.setOriginalDate(dateTime.date());
+    if (justDate)
+        anniversary.setOriginalDate(dateTime.date());
+    else
+        anniversary.setOriginalDateTime(dateTime);
     saveDetailWithContext(updatedDetails, anniversary, extractContexts(property));
     return true;
 }
@@ -482,10 +484,14 @@ bool QVersitContactImporterPrivate::createBirthday(
 {
     Q_UNUSED(contact)
     QContactBirthday bday;
-    QDateTime dateTime = parseDateTime(property.value(), QLatin1String("yyyyMMdd"));
+    bool justDate = false;
+    QDateTime dateTime = parseDateTime(property.value(), &justDate);
     if (!dateTime.isValid())
         return false;
-    bday.setDate(dateTime.date());
+    if (justDate)
+        bday.setDate(dateTime.date());
+    else
+        bday.setDateTime(dateTime);
     saveDetailWithContext(updatedDetails, bday, extractContexts(property));
     return true;
 }
@@ -574,9 +580,24 @@ bool QVersitContactImporterPrivate::createOnlineAccount(
             subTypes.append(QContactOnlineAccount::SubTypeSip);
         onlineAccount.setSubTypes(subTypes);
     } else if (property.name() == QLatin1String("X-IMPP") ||
-               property.name() == QLatin1String("IMPP") ||
-               property.name() == QLatin1String("X-JABBER")) {
+               property.name() == QLatin1String("IMPP")) {
         onlineAccount.setSubTypes(QContactOnlineAccount::SubTypeImpp);
+    } else if (property.name() == QLatin1String("X-JABBER")) {
+        onlineAccount.setSubTypes(QContactOnlineAccount::SubTypeImpp);
+        onlineAccount.setProtocol(QContactOnlineAccount::ProtocolJabber);
+    } else if (property.name() == QLatin1String("X-AIM")) {
+        onlineAccount.setProtocol(QContactOnlineAccount::ProtocolAim);
+    } else if (property.name() == QLatin1String("X-ICQ")) {
+        onlineAccount.setProtocol(QContactOnlineAccount::ProtocolIcq);
+    } else if (property.name() == QLatin1String("X-MSN")) {
+        onlineAccount.setProtocol(QContactOnlineAccount::ProtocolMsn);
+    } else if (property.name() == QLatin1String("X-QQ")) {
+        onlineAccount.setProtocol(QContactOnlineAccount::ProtocolQq);
+    } else if (property.name() == QLatin1String("X-YAHOO")) {
+        onlineAccount.setProtocol(QContactOnlineAccount::ProtocolYahoo);
+    } else if (property.name() == QLatin1String("X-SKYPE") ||
+            property.name() == QLatin1String("X-SKYPE-USERNAME")) {
+        onlineAccount.setProtocol(QContactOnlineAccount::ProtocolSkype);
     }
 
     saveDetailWithContext(updatedDetails, onlineAccount, extractContexts(property));
@@ -788,16 +809,36 @@ QString QVersitContactImporterPrivate::takeFirst(QList<QString>& list) const
 /*!
  * Parses a date and time from text
  */
-QDateTime QVersitContactImporterPrivate::parseDateTime(
-    const QString& value,
-    const QString& format) const
+QDateTime QVersitContactImporterPrivate::parseDateTime(QString value, bool *justDate) const
 {
+    bool hasTime = false;
+    bool utc = value.endsWith(QLatin1Char('Z'), Qt::CaseInsensitive);
+    if (utc)
+        value.chop(1); // take away z from end;
+
     QDateTime dateTime;
     if (value.contains(QLatin1Char('-'))) {
         dateTime = QDateTime::fromString(value,Qt::ISODate);
+        hasTime = dateTime.isValid() && value.contains(QLatin1Char('T'));
     } else {
-        dateTime = QDateTime::fromString(value, format);
+        switch (value.length()) {
+        case 8:
+            dateTime = QDateTime::fromString(value, QLatin1String("yyyyMMdd"));
+            break;
+        case 15:
+            dateTime = QDateTime::fromString(value, QLatin1String("yyyyMMddThhmmss"));
+            hasTime = true;
+            break;
+        // default: return invalid
+        }
     }
+
+    if (utc)
+        dateTime.setTimeSpec(Qt::UTC);
+
+    if (justDate)
+        *justDate = !hasTime && !utc; // UTC implies a time of midnight
+
     return dateTime;
 }
 
