@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -50,6 +50,7 @@ QTM_USE_NAMESPACE
 /*!
   \class QVersitDocumentWriter
   \internal
+    \since 1.0
   \brief The QVersitDocumentWriter class provides an interface for writing a
   single versit document into a vCard text string.
  */
@@ -64,20 +65,17 @@ QVersitDocumentWriter::QVersitDocumentWriter(QVersitDocument::VersitType type)
     : mType(type),
     mDevice(0),
     mCodec(0),
+    mCodecIsAscii(false),
     mEncoder(0),
-    mUtf8Encoder(QTextCodec::codecForName("UTF-8")->makeEncoder()),
     mSuccessful(true),
     mCurrentLineLength(0)
 {
-    // Hack so the encoder doesn't output a byte order mark for UTF-8.
-    mUtf8Encoder->fromUnicode(QString());
 }
 
 QVersitDocumentWriter::~QVersitDocumentWriter()
 {
     if (mEncoder)
         delete mEncoder;
-    delete mUtf8Encoder;
 }
 
 /*!
@@ -100,6 +98,15 @@ void QVersitDocumentWriter::setCodec(QTextCodec *codec)
                              || mCodec->name().startsWith("UTF-32"));
 }
 
+/*!
+  Specifies that the codec is actually ASCII (setCodec must also be called with an ASCII-compatible
+  codec.
+ */
+void QVersitDocumentWriter::setAsciiCodec()
+{
+    mCodecIsAscii = true;
+}
+
 /*!
   Sets the device to write to.
   */
@@ -205,14 +212,12 @@ void QVersitDocumentWriter::writeBytes(const QByteArray &value)
 
 /*!
   Writes \a value to the device.
-  If \a useUtf8 is true, uses the UTF-8 codec instead of the one set in setCodec().
 
   This function tracks how many characters have been written to the line and folds (wraps) the line
   according to RFC2425.
   */
-void QVersitDocumentWriter::writeString(const QString &value, bool useUtf8)
+void QVersitDocumentWriter::writeString(const QString &value)
 {
-    QTextEncoder* encoder = useUtf8 ? mUtf8Encoder : mEncoder;
     int spaceRemaining = MAX_LINE_LENGTH - mCurrentLineLength;
     int charsWritten = 0;
     QString crlfSpace(QLatin1String("\r\n "));
@@ -220,14 +225,48 @@ void QVersitDocumentWriter::writeString(const QString &value, bool useUtf8)
         // Write the first "spaceRemaining" characters
         QStringRef line(&value, charsWritten, spaceRemaining);
         charsWritten += spaceRemaining;
-        if (mDevice->write(encoder->fromUnicode(line.constData(), line.length())) < 0
-               || mDevice->write(encoder->fromUnicode(crlfSpace)) < 0)
+        if (mDevice->write(mEncoder->fromUnicode(line.constData(), line.length())) < 0
+               || mDevice->write(mEncoder->fromUnicode(crlfSpace)) < 0)
             mSuccessful = false;
         spaceRemaining = MAX_LINE_LENGTH - 1; // minus 1 for the space at the front.
         mCurrentLineLength = 1;
     }
 
-    if (mDevice->write(encoder->fromUnicode(value.mid(charsWritten))) < 0)
+    if (mDevice->write(mEncoder->fromUnicode(value.mid(charsWritten))) < 0)
+        mSuccessful = false;
+    mCurrentLineLength += value.length() - charsWritten;
+}
+
+/*!
+  Writes \a value to the device.
+
+  This function tracks how many characters have been written to the line and wraps the line
+  according to RFC2045 (a Quoted-Printable soft line break is an EQUALS-CR-LF sequence)
+  */
+void QVersitDocumentWriter::writeStringQp(const QString &value)
+{
+    int spaceRemaining = MAX_LINE_LENGTH - mCurrentLineLength - 1;
+                                             // minus 1 for the equals required at the end
+    int charsWritten = 0;
+    QString softBreak(QLatin1String("=\r\n"));
+    while (spaceRemaining < value.length() - charsWritten) {
+        // Write the first "spaceRemaining" characters
+        if (value[charsWritten + spaceRemaining - 2] == QLatin1Char('=')) {
+            spaceRemaining -= 2;
+        } else if (value[charsWritten + spaceRemaining - 1] == QLatin1Char('=')) {
+            spaceRemaining -= 1;
+        }
+        QStringRef line(&value, charsWritten, spaceRemaining);
+
+        charsWritten += spaceRemaining;
+        if (mDevice->write(mEncoder->fromUnicode(line.constData(), line.length())) < 0
+               || mDevice->write(mEncoder->fromUnicode(softBreak)) < 0)
+            mSuccessful = false;
+        spaceRemaining = MAX_LINE_LENGTH - 1; // minus 1 for the equals required at the end
+        mCurrentLineLength = 0;
+    }
+
+    if (mDevice->write(mEncoder->fromUnicode(value.mid(charsWritten))) < 0)
         mSuccessful = false;
     mCurrentLineLength += value.length() - charsWritten;
 }
