@@ -7,11 +7,11 @@
 ** This file is part of the test suite of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -55,12 +49,31 @@
 
 #include "wavheader.h"
 
+//TESTED_COMPONENT=src/multimedia
+
 #define AUDIO_BUFFER 192000
 
 #if defined(Q_OS_SYMBIAN)
 #define SRCDIR ""
 #endif
 
+#ifndef QTRY_VERIFY2
+#define QTRY_VERIFY2(__expr,__msg) \
+    do { \
+        const int __step = 50; \
+        const int __timeout = 5000; \
+        if (!(__expr)) { \
+            QTest::qWait(0); \
+        } \
+        for (int __i = 0; __i < __timeout && !(__expr); __i+=__step) { \
+            QTest::qWait(__step); \
+        } \
+        QVERIFY2(__expr,__msg); \
+    } while(0)
+#endif
+
+Q_DECLARE_METATYPE(QAudioFormat)
+
 class tst_QAudioInput : public QObject
 {
     Q_OBJECT
@@ -71,6 +84,7 @@ private slots:
     void initTestCase();
 
     void format();
+    void invalidFormat_data();
     void invalidFormat();
 
     void bufferSize();
@@ -88,6 +102,8 @@ private slots:
     void push();
     void pushSuspendResume();
 
+    void reset();
+
     void cleanupTestCase();
 
 private:
@@ -131,10 +147,14 @@ QString tst_QAudioInput::workingDir()
 
 void tst_QAudioInput::initTestCase()
 {
+    qRegisterMetaType<QAudioFormat>();
+
     // Only perform tests if audio output device exists
     const QList<QAudioDeviceInfo> devices =
         QAudioDeviceInfo::availableDevices(QAudio::AudioInput);
-    QVERIFY(devices.size() > 0);
+
+    if (devices.size() <= 0)
+        QSKIP("No audio backend", SkipAll);
 
     audioDevice = QAudioDeviceInfo::defaultInputDevice();
 
@@ -210,10 +230,34 @@ void tst_QAudioInput::format()
             QString("sampleType: requested=%1, actual=%2").arg(requested.sampleType()).arg(actual.sampleType()).toLocal8Bit().constData());
 }
 
+void tst_QAudioInput::invalidFormat_data()
+{
+    QTest::addColumn<QAudioFormat>("invalidFormat");
+
+    QAudioFormat format;
+
+    QTest::newRow("Null Format")
+            << format;
+
+    format = audioDevice.preferredFormat();
+    format.setChannelCount(0);
+    QTest::newRow("Channel count 0")
+            << format;
+
+    format = audioDevice.preferredFormat();
+    format.setSampleRate(0);
+    QTest::newRow("Sample rate 0")
+            << format;
+
+    format = audioDevice.preferredFormat();
+    format.setSampleSize(0);
+    QTest::newRow("Sample size 0")
+            << format;
+}
+
 void tst_QAudioInput::invalidFormat()
 {
-    QAudioFormat invalidFormat;
-    invalidFormat.setFrequency(0);
+    QFETCH(QAudioFormat, invalidFormat);
 
     QVERIFY2(!audioDevice.isFormatSupported(invalidFormat),
             "isFormatSupported() is returning true on an invalid format");
@@ -225,9 +269,8 @@ void tst_QAudioInput::invalidFormat()
     QVERIFY2((audioInput.error() == QAudio::NoError), "error() was not set to QAudio::NoError before start()");
 
     audioInput.start();
-
     // Check that error is raised
-    QVERIFY2((audioInput.error() == QAudio::OpenError),"error() was not set to QAudio::OpenError after start()");
+    QTRY_VERIFY2((audioInput.error() == QAudio::OpenError),"error() was not set to QAudio::OpenError after start()");
 }
 
 void tst_QAudioInput::bufferSize()
@@ -396,9 +439,8 @@ void tst_QAudioInput::pull()
         QVERIFY(wavHeader.write(*audioFiles.at(i)));
 
         audioInput.start(audioFiles.at(i));
-
         // Check that QAudioInput immediately transitions to ActiveState or IdleState
-        QVERIFY2((stateSignal.count() > 0),"didn't emit signals on start()");
+        QTRY_VERIFY2((stateSignal.count() > 0),"didn't emit signals on start()");
         QVERIFY2((audioInput.state() == QAudio::ActiveState || audioInput.state() == QAudio::IdleState),
                 "didn't transition to ActiveState or IdleState after start()");
         QVERIFY2((audioInput.error() == QAudio::NoError), "error state is not equal to QAudio::NoError after start()");
@@ -455,9 +497,8 @@ void tst_QAudioInput::pullSuspendResume()
         QVERIFY(wavHeader.write(*audioFiles.at(i)));
 
         audioInput.start(audioFiles.at(i));
-
         // Check that QAudioInput immediately transitions to ActiveState or IdleState
-        QVERIFY2((stateSignal.count() > 0),"didn't emit signals on start()");
+        QTRY_VERIFY2((stateSignal.count() > 0),"didn't emit signals on start()");
         QVERIFY2((audioInput.state() == QAudio::ActiveState || audioInput.state() == QAudio::IdleState),
                 "didn't transition to ActiveState or IdleState after start()");
         QVERIFY2((audioInput.error() == QAudio::NoError), "error state is not equal to QAudio::NoError after start()");
@@ -550,7 +591,7 @@ void tst_QAudioInput::push()
         QIODevice* feed = audioInput.start();
 
         // Check that QAudioInput immediately transitions to IdleState
-        QVERIFY2((stateSignal.count() == 1),"didn't emit IdleState signal on start()");
+        QTRY_VERIFY2((stateSignal.count() == 1),"didn't emit IdleState signal on start()");
         QVERIFY2((audioInput.state() == QAudio::IdleState),
                 "didn't transition to IdleState after start()");
         QVERIFY2((audioInput.error() == QAudio::NoError), "error state is not equal to QAudio::NoError after start()");
@@ -563,12 +604,12 @@ void tst_QAudioInput::push()
 
         qint64 totalBytesRead = 0;
         bool firstBuffer = true;
-        char buffer[AUDIO_BUFFER];
+        QByteArray buffer(AUDIO_BUFFER, 0);
         qint64 len = (testFormats.at(i).frequency()*testFormats.at(i).channels()*(testFormats.at(i).sampleSize()/8)*2); // 2 seconds
         while (totalBytesRead < len) {
-            if (audioInput.bytesReady() > audioInput.periodSize()) {
-                qint64 bytesRead = feed->read(buffer, audioInput.periodSize());
-                audioFiles.at(i)->write(buffer,bytesRead);
+            if (audioInput.bytesReady() >= audioInput.periodSize()) {
+                qint64 bytesRead = feed->read(buffer.data(), audioInput.periodSize());
+                audioFiles.at(i)->write(buffer.constData(),bytesRead);
                 totalBytesRead+=bytesRead;
                 if (firstBuffer && bytesRead) {
                     // Check for transition to ActiveState when data is provided
@@ -629,7 +670,7 @@ void tst_QAudioInput::pushSuspendResume()
         QIODevice* feed = audioInput.start();
 
         // Check that QAudioInput immediately transitions to IdleState
-        QVERIFY2((stateSignal.count() == 1),"didn't emit IdleState signal on start()");
+        QTRY_VERIFY2((stateSignal.count() == 1),"didn't emit IdleState signal on start()");
         QVERIFY2((audioInput.state() == QAudio::IdleState),
                 "didn't transition to IdleState after start()");
         QVERIFY2((audioInput.error() == QAudio::NoError), "error state is not equal to QAudio::NoError after start()");
@@ -642,12 +683,12 @@ void tst_QAudioInput::pushSuspendResume()
 
         qint64 totalBytesRead = 0;
         bool firstBuffer = true;
-        char buffer[AUDIO_BUFFER];
+        QByteArray buffer(AUDIO_BUFFER, 0);
         qint64 len = (testFormats.at(i).frequency()*testFormats.at(i).channels()*(testFormats.at(i).sampleSize()/8)); // 1 seconds
         while (totalBytesRead < len) {
-            if (audioInput.bytesReady() > audioInput.periodSize()) {
-                qint64 bytesRead = feed->read(buffer, audioInput.periodSize());
-                audioFiles.at(i)->write(buffer,bytesRead);
+            if (audioInput.bytesReady() >= audioInput.periodSize()) {
+                qint64 bytesRead = feed->read(buffer.data(), audioInput.periodSize());
+                audioFiles.at(i)->write(buffer.constData(),bytesRead);
                 totalBytesRead+=bytesRead;
                 if (firstBuffer && bytesRead) {
                     // Check for transition to ActiveState when data is provided
@@ -701,8 +742,8 @@ void tst_QAudioInput::pushSuspendResume()
         firstBuffer = true;
         while (totalBytesRead < len) {
             if (audioInput.bytesReady() >= audioInput.periodSize()) {
-                qint64 bytesRead = feed->read(buffer, audioInput.periodSize());
-                audioFiles.at(i)->write(buffer,bytesRead);
+                qint64 bytesRead = feed->read(buffer.data(), audioInput.periodSize());
+                audioFiles.at(i)->write(buffer.constData(),bytesRead);
                 totalBytesRead+=bytesRead;
             } else
                 QTest::qWait(20);
@@ -726,6 +767,38 @@ void tst_QAudioInput::pushSuspendResume()
     }
 }
 
+void tst_QAudioInput::reset()
+{
+    for(int i=0; i<audioFiles.count(); i++) {
+        QAudioInput audioInput(testFormats.at(i), this);
+
+        audioInput.setNotifyInterval(100);
+
+        QSignalSpy notifySignal(&audioInput, SIGNAL(notify()));
+        QSignalSpy stateSignal(&audioInput, SIGNAL(stateChanged(QAudio::State)));
+
+        // Check that we are in the default state before calling start
+        QVERIFY2((audioInput.state() == QAudio::StoppedState), "state() was not set to StoppedState before start()");
+        QVERIFY2((audioInput.error() == QAudio::NoError), "error() was not set to QAudio::NoError before start()");
+        QVERIFY2((audioInput.elapsedUSecs() == qint64(0)),"elapsedUSecs() not zero on creation");
+
+        audioInput.start();
+        // Check that QAudioInput immediately transitions to IdleState
+        QTRY_VERIFY2((stateSignal.count() == 1),"didn't emit IdleState signal on start()");
+        QVERIFY2((audioInput.state() == QAudio::IdleState), "didn't transition to IdleState after start()");
+        QVERIFY2((audioInput.error() == QAudio::NoError), "error state is not equal to QAudio::NoError after start()");
+        QVERIFY(audioInput.periodSize() > 0);
+        QTest::qWait(500);
+        QVERIFY(audioInput.bytesReady() > 0);
+        stateSignal.clear();
+
+        audioInput.reset();
+        QTRY_VERIFY2((stateSignal.count() == 1),"didn't emit StoppedState signal after reset()");
+        QVERIFY2((audioInput.state() == QAudio::StoppedState), "didn't transitions to StoppedState after reset()");
+        QVERIFY2((audioInput.bytesReady() == 0), "buffer not cleared after reset()");
+    }
+}
+
 void tst_QAudioInput::cleanupTestCase()
 {
     QFile* file;
