@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -44,6 +44,7 @@
 #include <QtTest/QtTest>
 #include <QDebug>
 
+#include <qabstractvideosurface.h>
 #include <qcameracontrol.h>
 #include <qcameralockscontrol.h>
 #include <qcameraexposurecontrol.h>
@@ -52,14 +53,21 @@
 #include <qcameraimagecapturecontrol.h>
 #include <qimageencodercontrol.h>
 #include <qcameraimageprocessingcontrol.h>
+#include <qcameracapturebufferformatcontrol.h>
+#include <qcameracapturedestinationcontrol.h>
 #include <qmediaservice.h>
 #include <qcamera.h>
 #include <qcameraimagecapture.h>
 #include <qgraphicsvideoitem.h>
+#include <qvideorenderercontrol.h>
+#include <qvideowidget.h>
+#include <qvideowindowcontrol.h>
 
 QT_USE_NAMESPACE
 class MockCaptureControl;
 
+Q_DECLARE_METATYPE(QtMultimediaKit::MetaData)
+
 class MockCameraControl : public QCameraControl
 {
     friend class MockCaptureControl;
@@ -268,9 +276,22 @@ public:
 private Q_SLOTS:
     void captured()
     {
-        if (!m_captureCanceled)
+        if (!m_captureCanceled) {
             emit imageCaptured(m_captureRequest, QImage());
 
+            emit imageMetadataAvailable(m_captureRequest,
+                                        QtMultimediaKit::FocalLengthIn35mmFilm,
+                                        QVariant(50));
+
+            emit imageMetadataAvailable(m_captureRequest,
+                                        QtMultimediaKit::DateTimeOriginal,
+                                        QVariant(QDateTime::currentDateTime()));
+
+            emit imageMetadataAvailable(m_captureRequest,
+                                        QLatin1String("Answer to the Ultimate Question of Life, the Universe, and Everything"),
+                                        QVariant(42));
+        }
+
         if (!m_ready)
             emit readyForCaptureChanged(m_ready = true);
 
@@ -288,6 +309,74 @@ private:
     bool m_captureCanceled;
 };
 
+class MockCaptureDestinationControl : public QCameraCaptureDestinationControl
+{
+    Q_OBJECT
+public:
+    MockCaptureDestinationControl(QObject *parent = 0):
+            QCameraCaptureDestinationControl(parent),
+            m_destination(QCameraImageCapture::CaptureToFile)
+    {
+    }
+
+    bool isCaptureDestinationSupported(QCameraImageCapture::CaptureDestinations destination) const
+    {
+        return destination == QCameraImageCapture::CaptureToBuffer ||
+               destination == QCameraImageCapture::CaptureToFile;
+    }
+
+    QCameraImageCapture::CaptureDestinations captureDestination() const
+    {
+        return m_destination;
+    }
+
+    void setCaptureDestination(QCameraImageCapture::CaptureDestinations destination)
+    {
+        if (isCaptureDestinationSupported(destination) && destination != m_destination) {
+            m_destination = destination;
+            emit captureDestinationChanged(m_destination);
+        }
+    }
+
+private:
+    QCameraImageCapture::CaptureDestinations m_destination;
+};
+
+class MockCaptureBufferFormatControl : public QCameraCaptureBufferFormatControl
+{
+    Q_OBJECT
+public:
+    MockCaptureBufferFormatControl(QObject *parent = 0):
+            QCameraCaptureBufferFormatControl(parent),
+            m_format(QVideoFrame::Format_Jpeg)
+    {
+    }
+
+    QList<QVideoFrame::PixelFormat> supportedBufferFormats() const
+    {
+        return QList<QVideoFrame::PixelFormat>()
+                << QVideoFrame::Format_Jpeg
+                << QVideoFrame::Format_RGB32
+                << QVideoFrame::Format_AdobeDng;
+    }
+
+    QVideoFrame::PixelFormat bufferFormat() const
+    {
+        return m_format;
+    }
+
+    void setBufferFormat(QVideoFrame::PixelFormat format)
+    {
+        if (format != m_format && supportedBufferFormats().contains(format)) {
+            m_format = format;
+            emit bufferFormatChanged(m_format);
+        }
+    }
+
+private:
+    QVideoFrame::PixelFormat m_format;
+};
+
 class MockCameraExposureControl : public QCameraExposureControl
 {
     Q_OBJECT
@@ -718,6 +807,53 @@ private:
     QMap<QString, QString> m_codecDescriptions;
 };
 
+class MockVideoSurface : public QAbstractVideoSurface
+{
+public:
+    QList<QVideoFrame::PixelFormat> supportedPixelFormats(
+            const QAbstractVideoBuffer::HandleType) const
+    {
+        return QList<QVideoFrame::PixelFormat>();
+    }
+
+    bool present(const QVideoFrame &) { return false; }
+};
+
+class MockVideoRendererControl : public QVideoRendererControl
+{
+public:
+    MockVideoRendererControl(QObject *parent) : QVideoRendererControl(parent), m_surface(0) {}
+
+    QAbstractVideoSurface *surface() const { return m_surface; }
+    void setSurface(QAbstractVideoSurface *surface) { m_surface = surface; }
+
+    QAbstractVideoSurface *m_surface;
+};
+
+class MockVideoWindowControl : public QVideoWindowControl
+{
+public:
+    MockVideoWindowControl(QObject *parent) : QVideoWindowControl(parent) {}
+    WId winId() const { return 0; }
+    void setWinId(WId) {}
+    QRect displayRect() const { return QRect(); }
+    void setDisplayRect(const QRect &) {}
+    bool isFullScreen() const { return false; }
+    void setFullScreen(bool) {}
+    void repaint() {}
+    QSize nativeSize() const { return QSize(); }
+    Qt::AspectRatioMode aspectRatioMode() const { return Qt::KeepAspectRatio; }
+    void setAspectRatioMode(Qt::AspectRatioMode) {}
+    int brightness() const { return 0; }
+    void setBrightness(int) {}
+    int contrast() const { return 0; }
+    void setContrast(int) {}
+    int hue() const { return 0; }
+    void setHue(int) {}
+    int saturation() const { return 0; }
+    void setSaturation(int) {}
+};
+
 class MockSimpleCameraService : public QMediaService
 {
     Q_OBJECT
@@ -757,8 +893,14 @@ public:
         mockFlashControl = new MockCameraFlashControl(this);
         mockFocusControl = new MockCameraFocusControl(this);
         mockCaptureControl = new MockCaptureControl(mockControl, this);
+        mockCaptureBufferControl = new MockCaptureBufferFormatControl(this);
+        mockCaptureDestinationControl = new MockCaptureDestinationControl(this);
         mockImageProcessingControl = new MockImageProcessingControl(this);
         mockImageEncoderControl = new MockImageEncoderControl(this);
+        rendererControl = new MockVideoRendererControl(this);
+        windowControl = new MockVideoWindowControl(this);
+        rendererRef = 0;
+        windowRef = 0;
     }
 
     ~MockCameraService()
@@ -785,25 +927,54 @@ public:
         if (qstrcmp(iid, QCameraImageCaptureControl_iid) == 0)
             return mockCaptureControl;
 
+        if (qstrcmp(iid, QCameraCaptureBufferFormatControl_iid) == 0)
+            return mockCaptureBufferControl;
+
+        if (qstrcmp(iid, QCameraCaptureDestinationControl_iid) == 0)
+            return mockCaptureDestinationControl;
+
         if (qstrcmp(iid, QCameraImageProcessingControl_iid) == 0)
             return mockImageProcessingControl;
 
         if (qstrcmp(iid, QImageEncoderControl_iid) == 0)
             return mockImageEncoderControl;
 
+        if (qstrcmp(iid, QVideoRendererControl_iid) == 0) {
+            if (rendererRef == 0) {
+                rendererRef += 1;
+                return rendererControl;
+            }
+        } else if (qstrcmp(iid, QVideoWindowControl_iid) == 0) {
+            if (windowRef == 0) {
+                windowRef += 1;
+                return windowControl;
+            }
+        }
         return 0;
     }
 
-    void releaseControl(QMediaControl*) {}
+    void releaseControl(QMediaControl *control)
+    {
+        if (control == rendererControl)
+            rendererRef -= 1;
+        else if (control == windowControl)
+            windowRef -= 1;
+    }
 
     MockCameraControl *mockControl;
     MockCameraLocksControl *mockLocksControl;
     MockCaptureControl *mockCaptureControl;
+    MockCaptureBufferFormatControl *mockCaptureBufferControl;
+    MockCaptureDestinationControl *mockCaptureDestinationControl;
     MockCameraExposureControl *mockExposureControl;
     MockCameraFlashControl *mockFlashControl;
     MockCameraFocusControl *mockFocusControl;
     MockImageProcessingControl *mockImageProcessingControl;
     MockImageEncoderControl *mockImageEncoderControl;
+    MockVideoRendererControl *rendererControl;
+    MockVideoWindowControl *windowControl;
+    int rendererRef;
+    int windowRef;
 };
 
 class MockProvider : public QMediaServiceProvider
@@ -838,15 +1009,28 @@ private slots:
     void testSimpleCameraFocus();
     void testSimpleCameraCapture();
     void testSimpleCameraLock();
+    void testSimpleCaptureDestination();
+    void testSimpleCaptureFormat();
 
     void testCameraWhiteBalance();
     void testCameraExposure();
     void testCameraFocus();
     void testCameraCapture();
+    void testCameraCaptureMetadata();
     void testImageSettings();
     void testCameraLock();
     void testCameraLockCancel();
     void testCameraEncodingProperyChange();
+    void testCaptureDestination();
+    void testCaptureFormat();
+
+
+    void testSetVideoOutput();
+    void testSetVideoOutputNoService();
+    void testSetVideoOutputNoControl();
+    void testSetVideoOutputDestruction();
+
+    void testEnumDebug();
 
 private:
     MockSimpleCameraService  *mockSimpleCameraService;
@@ -858,6 +1042,7 @@ void tst_QCamera::initTestCase()
     provider = new MockProvider;
     mockSimpleCameraService = new MockSimpleCameraService;
     provider->service = mockSimpleCameraService;
+    qRegisterMetaType<QtMultimediaKit::MetaData>("QtMultimediaKit::MetaData");
 }
 
 void tst_QCamera::cleanupTestCase()
@@ -1077,6 +1262,86 @@ void tst_QCamera::testSimpleCameraLock()
     QCOMPARE(lockStatusChangedSignal.count(), 1);
 }
 
+void tst_QCamera::testSimpleCaptureDestination()
+{
+    QCamera camera(0, provider);
+    QCameraImageCapture imageCapture(&camera);
+
+    QVERIFY(imageCapture.isCaptureDestinationSupported(QCameraImageCapture::CaptureToFile));
+    QVERIFY(!imageCapture.isCaptureDestinationSupported(QCameraImageCapture::CaptureToBuffer));
+    QVERIFY(!imageCapture.isCaptureDestinationSupported(
+                QCameraImageCapture::CaptureToBuffer | QCameraImageCapture::CaptureToFile));
+
+    QCOMPARE(imageCapture.captureDestination(), QCameraImageCapture::CaptureToFile);
+    imageCapture.setCaptureDestination(QCameraImageCapture::CaptureToBuffer);
+    QCOMPARE(imageCapture.captureDestination(), QCameraImageCapture::CaptureToFile);
+}
+
+void tst_QCamera::testSimpleCaptureFormat()
+{
+    QCamera camera(0, provider);
+    QCameraImageCapture imageCapture(&camera);
+
+    QCOMPARE(imageCapture.bufferFormat(), QVideoFrame::Format_Invalid);
+    QVERIFY(imageCapture.supportedBufferFormats().isEmpty());
+
+    imageCapture.setBufferFormat(QVideoFrame::Format_AdobeDng);
+    QCOMPARE(imageCapture.bufferFormat(), QVideoFrame::Format_Invalid);
+}
+
+void tst_QCamera::testCaptureDestination()
+{
+    MockCameraService service;
+    provider->service = &service;
+    QCamera camera(0, provider);
+    QCameraImageCapture imageCapture(&camera);
+
+    QVERIFY(imageCapture.isCaptureDestinationSupported(QCameraImageCapture::CaptureToFile));
+    QVERIFY(imageCapture.isCaptureDestinationSupported(QCameraImageCapture::CaptureToBuffer));
+    QVERIFY(!imageCapture.isCaptureDestinationSupported(
+                QCameraImageCapture::CaptureToBuffer | QCameraImageCapture::CaptureToFile));
+
+    QSignalSpy destinationChangedSignal(&imageCapture, SIGNAL(captureDestinationChanged(QCameraImageCapture::CaptureDestinations)));
+
+    QCOMPARE(imageCapture.captureDestination(), QCameraImageCapture::CaptureToFile);
+    imageCapture.setCaptureDestination(QCameraImageCapture::CaptureToBuffer);
+    QCOMPARE(imageCapture.captureDestination(), QCameraImageCapture::CaptureToBuffer);
+    QCOMPARE(destinationChangedSignal.size(), 1);
+    QCOMPARE(destinationChangedSignal.first().first().value<QCameraImageCapture::CaptureDestinations>(),
+             QCameraImageCapture::CaptureToBuffer);
+
+    //not supported combination
+    imageCapture.setCaptureDestination(QCameraImageCapture::CaptureToBuffer | QCameraImageCapture::CaptureToFile);
+    QCOMPARE(imageCapture.captureDestination(), QCameraImageCapture::CaptureToBuffer);
+    QCOMPARE(destinationChangedSignal.size(), 1);
+}
+
+void tst_QCamera::testCaptureFormat()
+{
+    MockCameraService service;
+    provider->service = &service;
+    QCamera camera(0, provider);
+    QCameraImageCapture imageCapture(&camera);
+
+    QSignalSpy formatChangedSignal(&imageCapture, SIGNAL(bufferFormatChanged(QVideoFrame::PixelFormat)));
+
+    QCOMPARE(imageCapture.bufferFormat(), QVideoFrame::Format_Jpeg);
+    QCOMPARE(imageCapture.supportedBufferFormats().size(), 3);
+
+    imageCapture.setBufferFormat(QVideoFrame::Format_AdobeDng);
+    QCOMPARE(imageCapture.bufferFormat(), QVideoFrame::Format_AdobeDng);
+
+    QCOMPARE(formatChangedSignal.size(), 1);
+    QCOMPARE(formatChangedSignal.first().first().value<QVideoFrame::PixelFormat>(),
+             QVideoFrame::Format_AdobeDng);
+
+    imageCapture.setBufferFormat(QVideoFrame::Format_Y16);
+    QCOMPARE(imageCapture.bufferFormat(), QVideoFrame::Format_AdobeDng);
+
+    QCOMPARE(formatChangedSignal.size(), 1);
+}
+
+
 void tst_QCamera::testCameraCapture()
 {
     MockCameraService service;
@@ -1111,6 +1376,45 @@ void tst_QCamera::testCameraCapture()
     QCOMPARE(imageCapture.error(), QCameraImageCapture::NoError);
 }
 
+void tst_QCamera::testCameraCaptureMetadata()
+{
+    MockCameraService service;
+    provider->service = &service;
+    QCamera camera(0, provider);
+    QCameraImageCapture imageCapture(&camera);
+
+    QSignalSpy metadataSignal(&imageCapture, SIGNAL(imageMetadataAvailable(int,QtMultimediaKit::MetaData,QVariant)));
+    QSignalSpy extendedMetadataSignal(&imageCapture, SIGNAL(imageMetadataAvailable(int,QString,QVariant)));
+    QSignalSpy savedSignal(&imageCapture, SIGNAL(imageSaved(int,QString)));
+
+    camera.start();
+    int id = imageCapture.capture(QString::fromLatin1("/dev/null"));
+
+    for (int i=0; i<100 && savedSignal.isEmpty(); i++)
+        QTest::qWait(10);
+
+    QCOMPARE(savedSignal.size(), 1);
+
+    QCOMPARE(metadataSignal.size(), 2);
+
+    QVariantList metadata = metadataSignal[0];
+    QCOMPARE(metadata[0].toInt(), id);
+    QCOMPARE(metadata[1].value<QtMultimediaKit::MetaData>(), QtMultimediaKit::FocalLengthIn35mmFilm);
+    QCOMPARE(metadata[2].value<QVariant>().toInt(), 50);
+
+    metadata = metadataSignal[1];
+    QCOMPARE(metadata[0].toInt(), id);
+    QCOMPARE(metadata[1].value<QtMultimediaKit::MetaData>(), QtMultimediaKit::DateTimeOriginal);
+    QDateTime captureTime = metadata[2].value<QVariant>().value<QDateTime>();
+    QVERIFY(qAbs(captureTime.secsTo(QDateTime::currentDateTime()) < 5)); //it should not takes more than 5 seconds for signal to arrive here
+
+    QCOMPARE(extendedMetadataSignal.size(), 1);
+    metadata = extendedMetadataSignal.first();
+    QCOMPARE(metadata[0].toInt(), id);
+    QCOMPARE(metadata[1].toString(), QLatin1String("Answer to the Ultimate Question of Life, the Universe, and Everything"));
+    QCOMPARE(metadata[2].value<QVariant>().toInt(), 42);
+}
+
 
 void tst_QCamera::testCameraWhiteBalance()
 {
@@ -1568,7 +1872,6 @@ void tst_QCamera::testCameraEncodingProperyChange()
     camera.setCaptureMode(QCamera::CaptureStillImage);
     imageCapture.setEncodingSettings(QImageEncoderSettings());
     imageCapture.setEncodingSettings(QImageEncoderSettings());
-    QTest::ignoreMessage(QtWarningMsg, "QMediaObject: Trying to unbind not connected helper object ");
     camera.setViewfinder(new QGraphicsVideoItem());
 
     QCOMPARE(stateChangedSignal.count(), 0);
@@ -1576,6 +1879,133 @@ void tst_QCamera::testCameraEncodingProperyChange()
 
 }
 
+void tst_QCamera::testSetVideoOutput()
+{
+    QVideoWidget widget;
+    QGraphicsVideoItem item;
+    MockVideoSurface surface;
+
+    MockCameraService service;
+    MockProvider provider;
+    provider.service = &service;
+    QCamera camera(0, &provider);
+
+    camera.setViewfinder(&widget);
+    QVERIFY(widget.mediaObject() == &camera);
+
+    camera.setViewfinder(&item);
+    QVERIFY(widget.mediaObject() == 0);
+    QVERIFY(item.mediaObject() == &camera);
+
+    camera.setViewfinder(reinterpret_cast<QVideoWidget *>(0));
+    QVERIFY(item.mediaObject() == 0);
+
+    camera.setViewfinder(&widget);
+    QVERIFY(widget.mediaObject() == &camera);
+
+    camera.setViewfinder(reinterpret_cast<QGraphicsVideoItem *>(0));
+    QVERIFY(widget.mediaObject() == 0);
+
+    camera.setViewfinder(&surface);
+    QVERIFY(service.rendererControl->surface() == &surface);
+
+    camera.setViewfinder(reinterpret_cast<QAbstractVideoSurface *>(0));
+    QVERIFY(service.rendererControl->surface() == 0);
+
+    camera.setViewfinder(&surface);
+    QVERIFY(service.rendererControl->surface() == &surface);
+
+    camera.setViewfinder(&widget);
+    QVERIFY(service.rendererControl->surface() == 0);
+    QVERIFY(widget.mediaObject() == &camera);
+
+    camera.setViewfinder(&surface);
+    QVERIFY(service.rendererControl->surface() == &surface);
+    QVERIFY(widget.mediaObject() == 0);
+}
+
+
+void tst_QCamera::testSetVideoOutputNoService()
+{
+    QVideoWidget widget;
+    QGraphicsVideoItem item;
+    MockVideoSurface surface;
+
+    MockProvider provider;
+    provider.service = 0;
+    QCamera camera(0, &provider);
+
+    camera.setViewfinder(&widget);
+    QVERIFY(widget.mediaObject() == 0);
+
+    camera.setViewfinder(&item);
+    QVERIFY(item.mediaObject() == 0);
+
+    camera.setViewfinder(&surface);
+    // Nothing we can verify here other than it doesn't assert.
+}
+
+void tst_QCamera::testSetVideoOutputNoControl()
+{
+    QVideoWidget widget;
+    QGraphicsVideoItem item;
+    MockVideoSurface surface;
+
+    MockCameraService service;
+    service.rendererRef = 1;
+    service.windowRef = 1;
+
+    MockProvider provider;
+    provider.service = &service;
+    QCamera camera(0, &provider);
+
+    camera.setViewfinder(&widget);
+    QVERIFY(widget.mediaObject() == 0);
+
+    camera.setViewfinder(&item);
+    QVERIFY(item.mediaObject() == 0);
+
+    camera.setViewfinder(&surface);
+    QVERIFY(service.rendererControl->surface() == 0);
+}
+
+void tst_QCamera::testSetVideoOutputDestruction()
+{
+    MockVideoSurface surface;
+
+    MockCameraService service;
+    MockProvider provider;
+    provider.service = &service;
+
+    {
+        QCamera camera(0, &provider);
+        camera.setViewfinder(&surface);
+        QVERIFY(service.rendererControl->surface() == &surface);
+        QCOMPARE(service.rendererRef, 1);
+    }
+    QVERIFY(service.rendererControl->surface() == 0);
+    QCOMPARE(service.rendererRef, 0);
+}
+
+void tst_QCamera::testEnumDebug()
+{
+    QTest::ignoreMessage(QtDebugMsg, "QCamera::ActiveState ");
+    qDebug() << QCamera::ActiveState;
+    QTest::ignoreMessage(QtDebugMsg, "QCamera::ActiveStatus ");
+    qDebug() << QCamera::ActiveStatus;
+    QTest::ignoreMessage(QtDebugMsg, "QCamera::CaptureVideo ");
+    qDebug() << QCamera::CaptureVideo;
+    QTest::ignoreMessage(QtDebugMsg, "QCamera::CameraError ");
+    qDebug() << QCamera::CameraError;
+    QTest::ignoreMessage(QtDebugMsg, "QCamera::Unlocked ");
+    qDebug() << QCamera::Unlocked;
+    QTest::ignoreMessage(QtDebugMsg, "QCamera::LockAcquired ");
+    qDebug() << QCamera::LockAcquired;
+    QTest::ignoreMessage(QtDebugMsg, "QCamera::NoLock ");
+    qDebug() << QCamera::NoLock;
+    QTest::ignoreMessage(QtDebugMsg, "QCamera::LockExposure ");
+    qDebug() << QCamera::LockExposure;
+}
 
 QTEST_MAIN(tst_QCamera)
 
