@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -51,7 +45,7 @@
 #include "qcontactid.h"
 #include <QSet>
 
-
+//TESTED_COMPONENT=src/contacts
 //TESTED_CLASS=
 //TESTED_FILES=
 
@@ -66,13 +60,16 @@ public:
 
 private slots:
     void details();
+    void preferences();
     void relationships();
     void displayName();
     void type();
+    void tags();
     void emptiness();
     void idLessThan();
     void idHash();
     void hash();
+    void datastream();
     void traits();
     void idTraits();
     void localIdTraits();
@@ -88,6 +85,32 @@ tst_QContact::~tst_QContact()
 
 void tst_QContact::details()
 {
+    // Check that detail keys are unique, regardless of order of initialisation
+    // First, construct the detail first, then the contact
+    QContactOrganization org;
+    org.setTitle("Example Title");
+    QContact keyTest;
+    QVERIFY(keyTest.saveDetail(&org));
+    QList<QContactDetail> allDetails = keyTest.details();
+    QList<int> detailKeys;
+    foreach (const QContactDetail& det, allDetails) {
+        int currKey = det.key();
+        QVERIFY(!detailKeys.contains(currKey));
+        detailKeys.append(currKey);
+    }
+    // Second, construct the detail after the contact has been constructed
+    QContactPhoneNumber num;
+    num.setNumber("123456");
+    QVERIFY(keyTest.saveDetail(&num));
+    allDetails = keyTest.details();
+    detailKeys.clear();
+    foreach (const QContactDetail& det, allDetails) {
+        int currKey = det.key();
+        QVERIFY(!detailKeys.contains(currKey));
+        detailKeys.append(currKey);
+    }
+
+    // now test for default construction sanity
     QContact c;
 
     // Test there are no details (apart from display label + type) by default
@@ -212,6 +235,15 @@ void tst_QContact::details()
     QCOMPARE(c.detail<QContactPhoneNumber>(), p);
     QVERIFY(c.removeDetail(&p2));
 
+    // now try removing a detail for which we've set a preference
+    QContactEmailAddress pref;
+    pref.setEmailAddress("test@test");
+    c.saveDetail(&pref);
+    c.setPreferredDetail("SendEmail", pref);
+    QVERIFY(c.isPreferredDetail(QString(), pref));
+    QVERIFY(c.removeDetail(&pref));
+    QVERIFY(!c.isPreferredDetail(QString(), pref));
+
     // Now try adding a detail to multiple contacts
 
     QContact c2;
@@ -367,6 +399,95 @@ void tst_QContact::details()
     QCOMPARE(c.id(), oldId); // id shouldn't change.
 }
 
+void tst_QContact::preferences()
+{
+    QContact c;
+
+    // test first set
+    QContactDetail det("TestId");
+    det.setValue("test", QVariant("test1"));
+    c.saveDetail(&det);
+    QCOMPARE(c.isPreferredDetail("testAction", det), false);
+
+    QCOMPARE(c.setPreferredDetail("testAction", det), true);
+
+    QCOMPARE(c.isPreferredDetail("testAction", det), true);
+
+    QCOMPARE(c.isPreferredDetail(QString(), det), true);
+
+    QCOMPARE(c.preferredDetail("testAction"), det);
+
+    // test replacement
+    QContactDetail det2("TestId");
+    det2.setValue("test", QVariant("test2"));
+    c.saveDetail(&det2);
+    QCOMPARE(c.isPreferredDetail("testAction", det2), false);
+
+    QCOMPARE(c.setPreferredDetail("testAction", det2), true);
+
+    QCOMPARE(c.isPreferredDetail("testAction", det2), true);
+
+    QCOMPARE(c.isPreferredDetail("testAction", det), false);
+
+    QCOMPARE(c.preferredDetail("testAction"), det2);
+
+    // test for detail that is not part of the contact
+    QContactDetail det3("TestId");
+    det3.setValue("test", QVariant("test3"));
+    QCOMPARE(c.setPreferredDetail("testAction", det3), false);
+
+    QCOMPARE(c.preferredDetail("testAction"), det2); // shouldn't have changed.
+
+    // test invalid set
+    QCOMPARE(c.setPreferredDetail(QString(), det3), false);
+
+    QCOMPARE(c.setPreferredDetail(QString(), QContactDetail()), false);
+
+    QCOMPARE(c.setPreferredDetail("testAction", QContactDetail()), false);
+
+    QCOMPARE(c.preferredDetail("testAction"), det2); // shouldn't have changed.
+
+    // test invalid query
+    QContactDetail det4;
+    det4.setValue("test", QVariant("test4"));
+    c.saveDetail(&det4);
+    QCOMPARE(c.isPreferredDetail(QString(), QContactDetail()), false);
+
+    QCOMPARE(c.isPreferredDetail(QString(), det4), false); // valid detail, but no pref set.
+
+    QCOMPARE(c.isPreferredDetail("testAction", QContactDetail()), false);
+
+    // test retrieving preferred details
+    QContactDetail pd = c.preferredDetail(QString());
+    QVERIFY(pd.isEmpty());
+    pd = c.preferredDetail("testAction");
+    QVERIFY(pd == det2); // shouldn't have changed.
+
+    // test for preference for action that hasn't been added
+    QVERIFY(c.preferredDetail("NonexistentAction").isEmpty());
+
+    // Remove a non preferred detail
+    QContactDetail det2copy("TestId");
+    det2copy.setValue("test", QVariant("test2"));
+    QVERIFY(c.saveDetail(&det2copy));
+
+    QVERIFY(c.isPreferredDetail("testAction", det2) == true);
+    QVERIFY(c.isPreferredDetail("testAction", det2copy) == false);
+    QVERIFY(c.removeDetail(&det2copy));
+    QVERIFY(c.isPreferredDetail("testAction", det2) == true);
+    QVERIFY(c.isPreferredDetail("testAction", det2copy) == false);
+
+    // Add it again
+    QVERIFY(c.saveDetail(&det2copy));
+    QVERIFY(c.isPreferredDetail("testAction", det2) == true);
+    QVERIFY(c.isPreferredDetail("testAction", det2copy) == false);
+
+    // Remove the preferred detail (the copy should not become preferred)
+    QVERIFY(c.removeDetail(&det2));
+    QVERIFY(c.isPreferredDetail("testAction", det2) == false);
+    QVERIFY(c.isPreferredDetail("testAction", det2copy) == false);
+}
+
 void tst_QContact::relationships()
 {
     QContact c;
@@ -454,6 +575,32 @@ void tst_QContact::type()
     QVERIFY(c.isEmpty() == true); // type doesn't affect emptiness
 }
 
+void tst_QContact::tags()
+{
+    QContact c;
+    QVERIFY(c.tags().isEmpty());
+
+    c.addTag("tag 1");
+    QStringList tags;
+    tags.append("tag 1");
+    QCOMPARE(c.tags(), tags);
+    QList<QContactTag> tagDetails = c.details<QContactTag>();
+    QCOMPARE(tagDetails.size(), 1);
+    QCOMPARE(tagDetails.first().tag(), QLatin1String("tag 1"));
+
+    c.clearTags();
+    QVERIFY(c.tags().isEmpty());
+    QVERIFY(c.details<QContactTag>().isEmpty());
+
+    tags.append("tag 2"); // tags is now "tag 1", "tag 2"
+    c.setTags(tags);
+    QCOMPARE(c.tags(), tags);
+    tagDetails = c.details<QContactTag>();
+    QCOMPARE(tagDetails.size(), 2);
+    QCOMPARE(tagDetails.at(0).tag(), QLatin1String("tag 1"));
+    QCOMPARE(tagDetails.at(1).tag(), QLatin1String("tag 2"));
+}
+
 void tst_QContact::emptiness()
 {
     QContact c;
@@ -535,6 +682,7 @@ void tst_QContact::hash()
     QContact contact5; // preferred details and relationships shouldn't affect the hash
     contact5.setId(id);
     contact5.saveDetail(&detail1);
+    contact5.setPreferredDetail("action", detail1);
     QContactRelationship rel;
     QContactManagerEngine::setContactRelationships(&contact5, QList<QContactRelationship>() << rel);
     QVERIFY(qHash(contact1) == qHash(contact2));
@@ -543,6 +691,28 @@ void tst_QContact::hash()
     QVERIFY(qHash(contact1) == qHash(contact5));
 }
 
+void tst_QContact::datastream()
+{
+    QByteArray buffer;
+    QDataStream stream1(&buffer, QIODevice::WriteOnly);
+    QContact contactIn;
+    QContactId id;
+    id.setManagerUri("manager");
+    id.setLocalId(1234);
+    contactIn.setId(id);
+    QContactPhoneNumber phone;
+    phone.setNumber("5678");
+    contactIn.saveDetail(&phone);
+    stream1 << contactIn;
+
+    QVERIFY(buffer.size() > 0);
+
+    QDataStream stream2(buffer);
+    QContact contactOut;
+    stream2 >> contactOut;
+    QCOMPARE(contactOut, contactIn);
+}
+
 void tst_QContact::traits()
 {
     QVERIFY(sizeof(QContact) == sizeof(void *));
