@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -78,6 +78,7 @@ private slots:
     void metaData_data();
     void metaData();
     void error();
+    void loops();
 };
 
 Q_DECLARE_METATYPE(QtMultimediaKit::MetaData);
@@ -162,7 +163,13 @@ public:
         emit mediaStatusChanged(m_mediaStatus);
     }
 
-    void play() { emit stateChanged(m_state = QMediaPlayer::PlayingState); }
+    void play()
+    {
+        m_state = QMediaPlayer::PlayingState;
+        if (m_mediaStatus == QMediaPlayer::EndOfMedia)
+            updateMediaStatus(QMediaPlayer::LoadedMedia);
+        emit stateChanged(m_state);
+    }
     void pause() { emit stateChanged(m_state = QMediaPlayer::PausedState); }
     void stop() { emit stateChanged(m_state = QMediaPlayer::StoppedState); }
 
@@ -285,7 +292,6 @@ public:
     QByteArray requestedService;
 };
 
-
 void tst_QDeclarativeAudio::initTestCase()
 {
     qRegisterMetaType<QDeclarativeAudio::Error>();
@@ -476,6 +482,7 @@ void tst_QDeclarativeAudio::playing()
     int stopped = 0;
 
     audio.componentComplete();
+    audio.setSource(QUrl("http://example.com"));
 
     QCOMPARE(audio.isPlaying(), false);
 
@@ -572,6 +579,7 @@ void tst_QDeclarativeAudio::paused()
     int stopped = 0;
 
     audio.componentComplete();
+    audio.setSource(QUrl("http://example.com"));
 
     QCOMPARE(audio.isPlaying(), false);
     QCOMPARE(audio.isPaused(), false);
@@ -1199,6 +1207,94 @@ void tst_QDeclarativeAudio::error()
     QCOMPARE(errorChangedSpy.count(), 2);
 }
 
+void tst_QDeclarativeAudio::loops()
+{
+    QtTestMediaServiceProvider provider;
+    QDeclarativeAudio audio;
+
+    QSignalSpy loopsChangedSpy(&audio, SIGNAL(loopCountChanged()));
+    QSignalSpy playingChangedSpy(&audio, SIGNAL(playingChanged()));
+    QSignalSpy stoppedSpy(&audio, SIGNAL(stopped()));
+
+    int playingChanged = 0;
+    int stopped = 0;
+    int loopsChanged = 0;
+
+    audio.classBegin();
+    audio.componentComplete();
+
+    QCOMPARE(audio.isPlaying(), false);
+
+    //setLoopCount(3) when stopped.
+    audio.setLoopCount(3);
+    QCOMPARE(audio.loopCount(), 3);
+    QCOMPARE(loopsChangedSpy.count(), ++loopsChanged);
+
+    //play till end
+    audio.play();
+    QCOMPARE(audio.isPlaying(), true);
+    QCOMPARE(provider.playerControl()->state(), QMediaPlayer::PlayingState);
+    QCOMPARE(playingChangedSpy.count(), ++playingChanged);
+
+    // setPlaying(true) when playing.
+    audio.setPlaying(true);
+    QCOMPARE(audio.isPlaying(), true);
+    QCOMPARE(provider.playerControl()->state(), QMediaPlayer::PlayingState);
+    QCOMPARE(playingChangedSpy.count(),   playingChanged);
+    QCOMPARE(stoppedSpy.count(),          stopped);
+
+    provider.playerControl()->updateMediaStatus(QMediaPlayer::EndOfMedia, QMediaPlayer::StoppedState);
+    QCOMPARE(audio.isPlaying(), true);
+    QCOMPARE(provider.playerControl()->state(), QMediaPlayer::PlayingState);
+    QCOMPARE(playingChangedSpy.count(),   playingChanged);
+
+    //play to end
+    provider.playerControl()->updateMediaStatus(QMediaPlayer::EndOfMedia, QMediaPlayer::StoppedState);
+    //play to end
+    provider.playerControl()->updateMediaStatus(QMediaPlayer::EndOfMedia, QMediaPlayer::StoppedState);
+    QCOMPARE(audio.isPlaying(), false);
+    QCOMPARE(provider.playerControl()->state(), QMediaPlayer::StoppedState);
+    QCOMPARE(playingChangedSpy.count(), ++playingChanged);
+    QCOMPARE(stoppedSpy.count(),        ++stopped);
+
+    // stop when playing
+    audio.play();
+    QCOMPARE(provider.playerControl()->state(), QMediaPlayer::PlayingState);
+    QCOMPARE(playingChangedSpy.count(), ++playingChanged);
+    provider.playerControl()->updateMediaStatus(QMediaPlayer::EndOfMedia, QMediaPlayer::StoppedState);
+    audio.stop();
+    QCOMPARE(audio.isPlaying(), false);
+    QCOMPARE(provider.playerControl()->state(), QMediaPlayer::StoppedState);
+    QCOMPARE(playingChangedSpy.count(), ++playingChanged);
+    QCOMPARE(stoppedSpy.count(),        ++stopped);
+
+    //setPlaying(true) with infinite loop
+    audio.setLoopCount(-1);
+    QCOMPARE(audio.loopCount(), -1);
+    QCOMPARE(loopsChangedSpy.count(), ++loopsChanged);
+    audio.setPlaying(true);
+    QCOMPARE(audio.isPlaying(), true);
+    QCOMPARE(playingChangedSpy.count(), ++playingChanged);
+    QCOMPARE(provider.playerControl()->state(), QMediaPlayer::PlayingState);
+    provider.playerControl()->updateMediaStatus(QMediaPlayer::EndOfMedia, QMediaPlayer::StoppedState);
+    QCOMPARE(audio.isPlaying(), true);
+    QCOMPARE(provider.playerControl()->state(), QMediaPlayer::PlayingState);
+    QCOMPARE(playingChangedSpy.count(), playingChanged);
+
+    // play() when playing.
+    audio.play();
+    QCOMPARE(audio.isPlaying(), true);
+    QCOMPARE(provider.playerControl()->state(), QMediaPlayer::PlayingState);
+    QCOMPARE(playingChangedSpy.count(),   playingChanged);
+    QCOMPARE(stoppedSpy.count(),          stopped);
+
+    // setPlaying(false) when playing in infinite loop.
+    audio.setPlaying(false);
+    QCOMPARE(audio.isPlaying(), false);
+    QCOMPARE(provider.playerControl()->state(), QMediaPlayer::StoppedState);
+    QCOMPARE(playingChangedSpy.count(), ++playingChanged);
+    QCOMPARE(stoppedSpy.count(),        ++stopped);
+}
 
 QTEST_MAIN(tst_QDeclarativeAudio)
 
