@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -51,6 +51,7 @@
 #include <qmediaplayercontrol.h>
 #include <qmediaservice.h>
 #include <qvideorenderercontrol.h>
+#include <qvideowindowcontrol.h>
 #include <qvideosurfaceformat.h>
 
 #include <QtGui/qapplication.h>
@@ -192,6 +193,65 @@ private:
     QAbstractVideoSurface *m_surface;
 };
 
+class QtTestWindowControl : public QVideoWindowControl
+{
+public:
+    QtTestWindowControl(QObject *parent)
+        : QVideoWindowControl(parent)
+        , m_winId(0)
+        , m_repaintCount(0)
+        , m_brightness(0)
+        , m_contrast(0)
+        , m_saturation(0)
+        , m_aspectRatioMode(Qt::KeepAspectRatio)
+        , m_fullScreen(0)
+    {
+    }
+
+    WId winId() const { return m_winId; }
+    void setWinId(WId id) { m_winId = id; }
+
+    QRect displayRect() const { return m_displayRect; }
+    void setDisplayRect(const QRect &rect) { m_displayRect = rect; }
+
+    bool isFullScreen() const { return m_fullScreen; }
+    void setFullScreen(bool fullScreen) { emit fullScreenChanged(m_fullScreen = fullScreen); }
+
+    int repaintCount() const { return m_repaintCount; }
+    void setRepaintCount(int count) { m_repaintCount = count; }
+    void repaint() { ++m_repaintCount; }
+
+    QSize nativeSize() const { return m_nativeSize; }
+    void setNativeSize(const QSize &size) { m_nativeSize = size; emit nativeSizeChanged(); }
+
+    Qt::AspectRatioMode aspectRatioMode() const { return m_aspectRatioMode; }
+    void setAspectRatioMode(Qt::AspectRatioMode mode) { m_aspectRatioMode = mode; }
+
+    int brightness() const { return m_brightness; }
+    void setBrightness(int brightness) { emit brightnessChanged(m_brightness = brightness); }
+
+    int contrast() const { return m_contrast; }
+    void setContrast(int contrast) { emit contrastChanged(m_contrast = contrast); }
+
+    int hue() const { return m_hue; }
+    void setHue(int hue) { emit hueChanged(m_hue = hue); }
+
+    int saturation() const { return m_saturation; }
+    void setSaturation(int saturation) { emit saturationChanged(m_saturation = saturation); }
+
+private:
+    WId m_winId;
+    int m_repaintCount;
+    int m_brightness;
+    int m_contrast;
+    int m_hue;
+    int m_saturation;
+    Qt::AspectRatioMode m_aspectRatioMode;
+    QRect m_displayRect;
+    QSize m_nativeSize;
+    bool m_fullScreen;
+};
+
 class QtTestMediaService : public QMediaService
 {
     Q_OBJECT
@@ -199,10 +259,12 @@ public:
     QtTestMediaService(
             QtTestMediaPlayerControl *playerControl,
             QtTestRendererControl *rendererControl,
+            QtTestWindowControl *windowControl,
             QObject *parent)
         : QMediaService(parent)
         , playerControl(playerControl)
         , rendererControl(rendererControl)
+        , windowControl(windowControl)
     {
     }
 
@@ -212,6 +274,8 @@ public:
             return playerControl;
         else if (qstrcmp(name, QVideoRendererControl_iid) == 0)
             return rendererControl;
+        else if (qstrcmp(name, QVideoWindowControl_iid) == 0)
+            return windowControl;
         else
             return 0;
     }
@@ -220,6 +284,7 @@ public:
 
     QtTestMediaPlayerControl *playerControl;
     QtTestRendererControl *rendererControl;
+    QtTestWindowControl *windowControl;
 };
 
 class QtTestMediaServiceProvider : public QMediaServiceProvider
@@ -231,6 +296,7 @@ public:
             new QtTestMediaService(
             new QtTestMediaPlayerControl(this),
             new QtTestRendererControl(this),
+            new QtTestWindowControl(this),
             this))
     {
         setDefaultServiceProvider(this);
@@ -244,8 +310,9 @@ public:
 
     QtTestMediaServiceProvider(
             QtTestMediaPlayerControl *playerControl,
-            QtTestRendererControl *rendererControl)
-        : service(new QtTestMediaService(playerControl, rendererControl, this))
+            QtTestRendererControl *rendererControl,
+            QtTestWindowControl *windowControl)
+        : service(new QtTestMediaService(playerControl, rendererControl, windowControl, this))
     {
         setDefaultServiceProvider(this);
     }
@@ -281,7 +348,7 @@ void tst_QDeclarativeVideo::initTestCase()
 
 void tst_QDeclarativeVideo::nullPlayerControl()
 {
-    QtTestMediaServiceProvider provider(0, 0);
+    QtTestMediaServiceProvider provider(0, 0, 0);
 
     QDeclarativeVideo video;
     video.classBegin();
@@ -393,6 +460,7 @@ void tst_QDeclarativeVideo::playing()
     QDeclarativeVideo video;
     video.classBegin();
     video.componentComplete();
+    video.setSource(QUrl("http://example.com"));
 
     QSignalSpy playingChangedSpy(&video, SIGNAL(playingChanged()));
     QSignalSpy startedSpy(&video, SIGNAL(started()));
@@ -482,6 +550,7 @@ void tst_QDeclarativeVideo::paused()
     QDeclarativeVideo video;
     video.classBegin();
     video.componentComplete();
+    video.setSource(QUrl("http://example.com"));
 
     QSignalSpy playingChangedSpy(&video, SIGNAL(playingChanged()));
     QSignalSpy pausedChangedSpy(&video, SIGNAL(pausedChanged()));
@@ -898,15 +967,17 @@ void tst_QDeclarativeVideo::geometry()
     }
 
     QAbstractVideoSurface *surface = provider.rendererControl()->surface();
-    QVERIFY(surface);
 
-    QVideoSurfaceFormat format(QSize(640, 480), QVideoFrame::Format_RGB32);
+    //video item can use overlay, QAbstractVideoSurface is not used than.
+    if (surface) {
+        QVideoSurfaceFormat format(QSize(640, 480), QVideoFrame::Format_RGB32);
 
-    QVERIFY(surface->start(format));
-    QCoreApplication::processEvents();
+        QVERIFY(surface->start(format));
+        QCoreApplication::processEvents();
 
-    QCOMPARE(video.implicitWidth(), qreal(640));
-    QCOMPARE(video.implicitHeight(), qreal(480));
+        QCOMPARE(video.implicitWidth(), qreal(640));
+        QCOMPARE(video.implicitHeight(), qreal(480));
+    }
 
     video.setWidth(560);
     video.setHeight(328);
