@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,23 +25,23 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 //TESTED_COMPONENT=src/location
 
-#include "../qlocationtestutils_p.h"
+#include "qlocationtestutils_p.h"
 
 #include <qgeocoordinate.h>
 #include <qtest.h>
@@ -510,6 +510,60 @@ private slots:
                 << NORTH_POLE << SOUTH_POLE << qreal(180.0);
     }
 
+    void atDistanceAndAzimuth()
+    {
+        QFETCH(QGeoCoordinate, origin);
+        QFETCH(qreal, distance);
+        QFETCH(qreal, azimuth);
+        QFETCH(QGeoCoordinate, result);
+
+        QCOMPARE(result, origin.atDistanceAndAzimuth(distance, azimuth));
+    }
+
+    void atDistanceAndAzimuth_data()
+    {
+        QTest::addColumn<QGeoCoordinate>("origin");
+        QTest::addColumn<qreal>("distance");
+        QTest::addColumn<qreal>("azimuth");
+        QTest::addColumn<QGeoCoordinate>("result");
+
+        QTest::newRow("invalid coord")
+            << QGeoCoordinate() 
+            << qreal(1000.0) 
+            << qreal(10.0) 
+            << QGeoCoordinate();
+        QTest::newRow("brisbane -> melbourne")
+            << BRISBANE 
+            << qreal(1374820.1618767744)
+            << qreal(211.1717286649)
+// the following platforms use float for qreal
+#if !defined(QT_NO_FPU) && !defined(QT_ARCH_ARM) && !defined(QT_ARCH_WINDOWSCE) && !defined(QT_ARCH_SYMBIAN) 
+            << MELBOURNE;
+#else
+            << QGeoCoordinate(-37.8142515084775, 144.963170622944);
+#endif
+        QTest::newRow("london -> new york")
+            << LONDON
+            << qreal(5570538.4987236429)
+            << qreal(288.3388804508)
+// the following platforms use float for qreal
+#if !defined(QT_NO_FPU) && !defined(QT_ARCH_ARM) && !defined(QT_ARCH_WINDOWSCE) && !defined(QT_ARCH_SYMBIAN) 
+            << NEW_YORK;
+#else
+            << QGeoCoordinate(40.7145220608416, -74.0071216045375);
+#endif
+        QTest::newRow("north pole -> south pole")
+            << NORTH_POLE
+            << qreal(20015109.4154876769)
+            << qreal(180.0)
+// the following platforms use float for qreal
+#if !defined(QT_NO_FPU) && !defined(QT_ARCH_ARM) && !defined(QT_ARCH_WINDOWSCE) && !defined(QT_ARCH_SYMBIAN) 
+            << SOUTH_POLE;
+#else
+            << QGeoCoordinate(-89.9999947369857, -90.0);
+#endif
+    }
+
     void degreesToString()
     {
         QFETCH(QGeoCoordinate, coord);
