@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -62,10 +62,6 @@
 #include <qabstractvideosurface.h>
 #include <qvideosurfaceformat.h>
 
-#if defined(Q_OS_SYMBIAN)
-# define TESTDATA_DIR "./tst_qmediaimageviewer_images"
-#endif
-
 QT_USE_NAMESPACE
 class QtTestNetworkAccessManager;
 
@@ -87,24 +83,21 @@ private slots:
     void elapsedTime();
     void rendererControl();
     void setVideoOutput();
+    void debugEnums();
 
 public:
-    tst_QMediaImageViewer() : m_network(0), m_imageDir(QLatin1String(TESTDATA_DIR)) {}
+    tst_QMediaImageViewer() : m_network(0) {}
 
 private:
     QUrl imageUrl(const char *fileName) const {
-        return QUrl::fromLocalFile(m_imageDir.absoluteFilePath(QLatin1String(fileName))); }
+        return QUrl(QLatin1String("qrc:///images/") + QLatin1String(fileName)); }
     QString imageFileName(const char *fileName) {
-        return m_imageDir.absoluteFilePath(QLatin1String(fileName)); }
+        return QLatin1String(":/images/") + QLatin1String(fileName); }
 
     QtTestNetworkAccessManager *m_network;
-    QDir m_imageDir;
     QString m_fileProtocol;
 };
 
-Q_DECLARE_METATYPE(QMediaImageViewer::State)
-Q_DECLARE_METATYPE(QMediaImageViewer::MediaStatus)
-
 class QtTestVideoSurface : public QAbstractVideoSurface
 {
 public:
@@ -983,9 +976,18 @@ void tst_QMediaImageViewer::rendererControl()
 void tst_QMediaImageViewer::setVideoOutput()
 {
     QMediaImageViewer imageViewer;
+    imageViewer.setMedia(QMediaContent(imageUrl("image.png")));
+
+    connect(&imageViewer, SIGNAL(mediaStatusChanged(QMediaImageViewer::MediaStatus)),
+            &QTestEventLoop::instance(), SLOT(exitLoop()));
+    QTestEventLoop::instance().enterLoop(2);
+
+    if (imageViewer.mediaStatus() != QMediaImageViewer::LoadedMedia)
+        QSKIP("failed to load test image", SkipSingle);
 
     QVideoWidget widget;
     QGraphicsVideoItem item;
+    QtTestVideoSurface surface;
 
     imageViewer.setVideoOutput(&widget);
     QVERIFY(widget.mediaObject() == &imageViewer);
@@ -1002,6 +1004,31 @@ void tst_QMediaImageViewer::setVideoOutput()
 
     imageViewer.setVideoOutput(reinterpret_cast<QGraphicsVideoItem *>(0));
     QVERIFY(widget.mediaObject() == 0);
+
+    imageViewer.setVideoOutput(&surface);
+    QVERIFY(surface.isActive());
+
+    imageViewer.setVideoOutput(reinterpret_cast<QAbstractVideoSurface *>(0));
+    QVERIFY(!surface.isActive());
+
+    imageViewer.setVideoOutput(&surface);
+    QVERIFY(surface.isActive());
+
+    imageViewer.setVideoOutput(&widget);
+    QVERIFY(!surface.isActive());
+    QVERIFY(widget.mediaObject() == &imageViewer);
+
+    imageViewer.setVideoOutput(&surface);
+    QVERIFY(surface.isActive());
+    QVERIFY(widget.mediaObject() == 0);
+}
+
+void tst_QMediaImageViewer::debugEnums()
+{
+    QTest::ignoreMessage(QtDebugMsg, "QMediaImageViewer::PlayingState ");
+    qDebug() << QMediaImageViewer::PlayingState;
+    QTest::ignoreMessage(QtDebugMsg, "QMediaImageViewer::NoMedia ");
+    qDebug() << QMediaImageViewer::NoMedia;
 }
 
 QTEST_MAIN(tst_QMediaImageViewer)
