@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,286 +25,59 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
-#include <QtTest/QtTest>
-#include <QtCore/qdebug.h>
-#include <QtCore/qbuffer.h>
+//TESTED_COMPONENT=src/multimedia
 
-#include <qmediaplayer.h>
-#include <qmediaplayercontrol.h>
-#include <qmediaplaylist.h>
-#include <qmediaservice.h>
-#include <qmediastreamscontrol.h>
+#include "tst_qmediaplayer.h"
 
+#include <qgraphicsvideoitem.h>
+#include <QtNetwork/qnetworkconfigmanager.h>
+
+// Encouraging successful diversity through copy and paste.
+#ifndef QTRY_COMPARE
+#define QTRY_COMPARE(__expr, __expected) \
+    do { \
+        const int __step = 50; \
+        const int __timeout = 5000; \
+        if ((__expr) != (__expected)) { \
+            QTest::qWait(0); \
+        } \
+        for (int __i = 0; __i < __timeout && ((__expr) != (__expected)); __i+=__step) { \
+            QTest::qWait(__step); \
+        } \
+        QCOMPARE(__expr, __expected); \
+    } while(0)
+#endif
+
+#ifndef QTRY_VERIFY
+#define QTRY_VERIFY(__expr) \
+    do { \
+        const int __step = 50; \
+        const int __timeout = 5000; \
+        if (!(__expr)) { \
+            QTest::qWait(0); \
+        } \
+        for (int __i = 0; __i < __timeout && !(__expr); __i+=__step) { \
+            QTest::qWait(__step); \
+        } \
+        QVERIFY(__expr); \
+    } while(0)
+#endif
 
 QT_USE_NAMESPACE
-class AutoConnection
-{
-public:
-    AutoConnection(QObject *sender, const char *signal, QObject *receiver, const char *method)
-            : sender(sender), signal(signal), receiver(receiver), method(method)
-    {
-        QObject::connect(sender, signal, receiver, method);
-    }
-
-    ~AutoConnection()
-    {
-        QObject::disconnect(sender, signal, receiver, method);
-    }
-
-private:
-    QObject *sender;
-    const char *signal;
-    QObject *receiver;
-    const char *method;
-};
-
-
-class MockPlayerControl : public QMediaPlayerControl
-{
-    friend class MockPlayerService;
-
-public:
-    MockPlayerControl():QMediaPlayerControl(0) {}
-
-    QMediaPlayer::State state() const { return _state; }
-    QMediaPlayer::MediaStatus mediaStatus() const { return _mediaStatus; }
-
-    qint64 duration() const { return _duration; }
-
-    qint64 position() const { return _position; }
-
-    void setPosition(qint64 position) { if (position != _position) emit positionChanged(_position = position); }
-
-    int volume() const { return _volume; }
-    void setVolume(int volume) { emit volumeChanged(_volume = volume); }
-
-    bool isMuted() const { return _muted; }
-    void setMuted(bool muted) { if (muted != _muted) emit mutedChanged(_muted = muted); }
-
-    int bufferStatus() const { return _bufferStatus; }
-
-    bool isAudioAvailable() const { return _audioAvailable; }
-    bool isVideoAvailable() const { return _videoAvailable; }
-
-    bool isSeekable() const { return _isSeekable; }
-    QMediaTimeRange availablePlaybackRanges() const { return QMediaTimeRange(_seekRange.first, _seekRange.second); }
-    void setSeekRange(qint64 minimum, qint64 maximum) { _seekRange = qMakePair(minimum, maximum); }
-
-    qreal playbackRate() const { return _playbackRate; }
-    void setPlaybackRate(qreal rate) { if (rate != _playbackRate) emit playbackRateChanged(_playbackRate = rate); }
-
-    QMediaContent media() const { return _media; }
-    void setMedia(const QMediaContent &content, QIODevice *stream)
-    {
-        _stream = stream;
-        _media = content;
-        if (_state != QMediaPlayer::StoppedState) {
-            _mediaStatus = _media.isNull() ? QMediaPlayer::NoMedia : QMediaPlayer::LoadingMedia;
-            emit stateChanged(_state = QMediaPlayer::StoppedState);
-            emit mediaStatusChanged(_mediaStatus);
-        }
-        emit mediaChanged(_media = content);
-    }
-    QIODevice *mediaStream() const { return _stream; }
-
-    void play() { if (_isValid && !_media.isNull() && _state != QMediaPlayer::PlayingState) emit stateChanged(_state = QMediaPlayer::PlayingState); }
-    void pause() { if (_isValid && !_media.isNull() && _state != QMediaPlayer::PausedState) emit stateChanged(_state = QMediaPlayer::PausedState); }
-    void stop() { if (_state != QMediaPlayer::StoppedState) emit stateChanged(_state = QMediaPlayer::StoppedState); }
-
-    QMediaPlayer::State _state;
-    QMediaPlayer::MediaStatus _mediaStatus;
-    QMediaPlayer::Error _error;
-    qint64 _duration;
-    qint64 _position;
-    int _volume;
-    bool _muted;
-    int _bufferStatus;
-    bool _audioAvailable;
-    bool _videoAvailable;
-    bool _isSeekable;
-    QPair<qint64, qint64> _seekRange;
-    qreal _playbackRate;
-    QMediaContent _media;
-    QIODevice *_stream;
-    bool _isValid;
-    QString _errorString;
-};
-
-class MockStreamsControl : public QMediaStreamsControl
-{
-public:
-    MockStreamsControl(QObject *parent = 0) : QMediaStreamsControl(parent) {}
-
-    int streamCount() { return _streams.count(); }
-    void setStreamCount(int count) { _streams.resize(count); }
-
-    StreamType streamType(int index) { return _streams.at(index).type; }
-    void setStreamType(int index, StreamType type) { _streams[index].type = type; }
-
-    QVariant metaData(int index, QtMultimediaKit::MetaData key) {
-        return _streams.at(index).metaData.value(key); }
-    void setMetaData(int index, QtMultimediaKit::MetaData key, const QVariant &value) {
-        _streams[index].metaData.insert(key, value); }
-
-    bool isActive(int index) { return _streams.at(index).active; }
-    void setActive(int index, bool state) { _streams[index].active = state; }
-
-private:
-    struct Stream
-    {
-        Stream() : type(UnknownStream), active(false) {}
-        StreamType type;
-        QMap<QtMultimediaKit::MetaData, QVariant> metaData;
-        bool active;
-    };
-
-    QVector<Stream> _streams;
-};
-
-class MockPlayerService : public QMediaService
-{
-    Q_OBJECT
-
-public:
-    MockPlayerService():QMediaService(0)
-    {
-        mockControl = new MockPlayerControl;
-        mockStreamsControl = new MockStreamsControl;
-    }
-
-    ~MockPlayerService()
-    {
-        delete mockControl;
-        delete mockStreamsControl;
-    }
-
-    QMediaControl* requestControl(const char *iid)
-    {
-        if (qstrcmp(iid, QMediaPlayerControl_iid) == 0)
-            return mockControl;
-
-        return 0;
-    }
-
-    void releaseControl(QMediaControl *)
-    {
-    }
-
-    void setState(QMediaPlayer::State state) { emit mockControl->stateChanged(mockControl->_state = state); }
-    void setState(QMediaPlayer::State state, QMediaPlayer::MediaStatus status) {
-        mockControl->_state = state;
-        mockControl->_mediaStatus = status;
-        emit mockControl->mediaStatusChanged(status);
-        emit mockControl->stateChanged(state);
-    }
-    void setMediaStatus(QMediaPlayer::MediaStatus status) { emit mockControl->mediaStatusChanged(mockControl->_mediaStatus = status); }
-    void setIsValid(bool isValid) { mockControl->_isValid = isValid; }
-    void setMedia(QMediaContent media) { mockControl->_media = media; }
-    void setDuration(qint64 duration) { mockControl->_duration = duration; }
-    void setPosition(qint64 position) { mockControl->_position = position; }
-    void setSeekable(bool seekable) { mockControl->_isSeekable = seekable; }
-    void setVolume(int volume) { mockControl->_volume = volume; }
-    void setMuted(bool muted) { mockControl->_muted = muted; }
-    void setVideoAvailable(bool videoAvailable) { mockControl->_videoAvailable = videoAvailable; }
-    void setBufferStatus(int bufferStatus) { mockControl->_bufferStatus = bufferStatus; }
-    void setPlaybackRate(qreal playbackRate) { mockControl->_playbackRate = playbackRate; }
-    void setError(QMediaPlayer::Error error) { mockControl->_error = error; emit mockControl->error(mockControl->_error, mockControl->_errorString); }
-    void setErrorString(QString errorString) { mockControl->_errorString = errorString; emit mockControl->error(mockControl->_error, mockControl->_errorString); }
-
-    void reset()
-    {
-        mockControl->_state = QMediaPlayer::StoppedState;
-        mockControl->_mediaStatus = QMediaPlayer::UnknownMediaStatus;
-        mockControl->_error = QMediaPlayer::NoError;
-        mockControl->_duration = 0;
-        mockControl->_position = 0;
-        mockControl->_volume = 0;
-        mockControl->_muted = false;
-        mockControl->_bufferStatus = 0;
-        mockControl->_videoAvailable = false;
-        mockControl->_isSeekable = false;
-        mockControl->_playbackRate = 0.0;
-        mockControl->_media = QMediaContent();
-        mockControl->_stream = 0;
-        mockControl->_isValid = false;
-        mockControl->_errorString = QString();
-    }
-
-    MockPlayerControl *mockControl;
-    MockStreamsControl *mockStreamsControl;
-};
-
-class MockProvider : public QMediaServiceProvider
-{
-public:
-    MockProvider(MockPlayerService *service):mockService(service) {}
-    QMediaService *requestService(const QByteArray &, const QMediaServiceProviderHint &)
-    {
-        return mockService;
-    }
-
-    void releaseService(QMediaService *service) { delete service; }
-
-    MockPlayerService *mockService;
-};
-
-class tst_QMediaPlayer: public QObject
-{
-    Q_OBJECT
-
-public slots:
-    void initTestCase_data();
-    void initTestCase();
-    void cleanupTestCase();
-    void init();
-    void cleanup();
-
-private slots:
-    void testNullService();
-    void testValid();
-    void testMedia();
-    void testDuration();
-    void testPosition();
-    void testVolume();
-    void testMuted();
-    void testVideoAvailable();
-    void testBufferStatus();
-    void testSeekable();
-    void testPlaybackRate();
-    void testError();
-    void testErrorString();
-    void testService();
-    void testPlay();
-    void testPause();
-    void testStop();
-    void testMediaStatus();
-    void testPlaylist();
-
-private:
-    MockProvider *mockProvider;
-    MockPlayerService  *mockService;
-    QMediaPlayer *player;
-};
 
 void tst_QMediaPlayer::initTestCase_data()
 {
@@ -392,6 +165,8 @@ void tst_QMediaPlayer::testNullService()
     QCOMPARE(player.isSeekable(), false);
     QCOMPARE(player.playbackRate(), qreal(0));
     QCOMPARE(player.error(), QMediaPlayer::ServiceMissingError);
+    QCOMPARE(player.isAvailable(), false);
+    QCOMPARE(player.availabilityError(), QtMultimediaKit::ServiceMissingError);
 
     {
         QFETCH_GLOBAL(QMediaContent, mediaContent);
@@ -669,6 +444,12 @@ void tst_QMediaPlayer::testErrorString()
     QVERIFY(player->errorString() == errorString);
 }
 
+void tst_QMediaPlayer::testIsAvailable()
+{
+    QCOMPARE(player->isAvailable(), true);
+    QCOMPARE(player->availabilityError(), QtMultimediaKit::NoError);
+}
+
 void tst_QMediaPlayer::testService()
 {
     /*
@@ -1038,8 +819,201 @@ void tst_QMediaPlayer::testPlaylist()
 
     QVERIFY(player->playlist() == 0);
     QCOMPARE(player->media(), QMediaContent());
+
+    // Test when the player service encounters an invalid media, the player moves onto
+    // the next item without stopping
+    {
+        QSignalSpy ss(player, SIGNAL(stateChanged(QMediaPlayer::State)));
+        QSignalSpy ms(player, SIGNAL(mediaStatusChanged(QMediaPlayer::MediaStatus)));
+
+        player->setPlaylist(playlist);
+        player->play();
+        QCOMPARE(ss.count(), 1);
+
+        mockService->setState(QMediaPlayer::StoppedState, QMediaPlayer::InvalidMedia);
+        QCOMPARE(player->state(), QMediaPlayer::PlayingState);
+        QCOMPARE(player->mediaStatus(), QMediaPlayer::InvalidMedia);
+        QCOMPARE(ss.count(), 1);
+        QCOMPARE(ms.count(), 1);
+
+        // NOTE: status should begin transitioning through to BufferedMedia.
+        QCOMPARE(player->media(), content2);
+    }
+
+}
+
+void tst_QMediaPlayer::testNetworkAccess()
+{
+    QNetworkConfigurationManager manager;
+    QList<QNetworkConfiguration> configs = manager.allConfigurations();
+
+    if (configs.count() >= 1) {
+        QSignalSpy spy(player, SIGNAL(networkConfigurationChanged(QNetworkConfiguration)));
+        int index = qFloor((configs.count())/2);
+        player->setNetworkConfigurations(configs);
+        mockService->selectCurrentConfiguration(configs.at(index));
+
+        QVERIFY(spy.count() == 1);
+        QList<QVariant> args = spy.takeFirst();
+        QNetworkConfiguration config = args.at(0).value<QNetworkConfiguration>();
+        QCOMPARE(config.identifier() , configs.at(index).identifier());
+        QCOMPARE(player->currentNetworkConfiguration().identifier() , config.identifier());
+    }
+
+    // invalidate current network configuration
+    QSignalSpy spy(player, SIGNAL(networkConfigurationChanged(QNetworkConfiguration)));
+    mockService->selectCurrentConfiguration(QNetworkConfiguration());
+    QVERIFY(spy.count() == 1);
+    QList<QVariant> args = spy.takeFirst();
+    QNetworkConfiguration config = args.at(0).value<QNetworkConfiguration>();
+    QVERIFY(config.isValid() == false);
+    QVERIFY(player->currentNetworkConfiguration().isValid() == false);
+}
+
+void tst_QMediaPlayer::testSetVideoOutput()
+{
+    QVideoWidget widget;
+    QGraphicsVideoItem item;
+    MockVideoSurface surface;
+
+    MockPlayerService service;
+    MockProvider provider(&service);
+    provider.deleteServiceOnRelease = false;
+    QMediaPlayer player(0, 0, &provider);
+
+    player.setVideoOutput(&widget);
+    QVERIFY(widget.mediaObject() == &player);
+
+    player.setVideoOutput(&item);
+    QVERIFY(widget.mediaObject() == 0);
+    QVERIFY(item.mediaObject() == &player);
+
+    player.setVideoOutput(reinterpret_cast<QVideoWidget *>(0));
+    QVERIFY(item.mediaObject() == 0);
+
+    player.setVideoOutput(&widget);
+    QVERIFY(widget.mediaObject() == &player);
+
+    player.setVideoOutput(reinterpret_cast<QGraphicsVideoItem *>(0));
+    QVERIFY(widget.mediaObject() == 0);
+
+    player.setVideoOutput(&surface);
+    QVERIFY(service.rendererControl->surface() == &surface);
+
+    player.setVideoOutput(reinterpret_cast<QAbstractVideoSurface *>(0));
+    QVERIFY(service.rendererControl->surface() == 0);
+
+    player.setVideoOutput(&surface);
+    QVERIFY(service.rendererControl->surface() == &surface);
+
+    player.setVideoOutput(&widget);
+    QVERIFY(service.rendererControl->surface() == 0);
+    QVERIFY(widget.mediaObject() == &player);
+
+    player.setVideoOutput(&surface);
+    QVERIFY(service.rendererControl->surface() == &surface);
+    QVERIFY(widget.mediaObject() == 0);
+}
+
+
+void tst_QMediaPlayer::testSetVideoOutputNoService()
+{
+    QVideoWidget widget;
+    QGraphicsVideoItem item;
+    MockVideoSurface surface;
+
+    MockProvider provider(0);
+    QMediaPlayer player(0, 0, &provider);
+
+    player.setVideoOutput(&widget);
+    QVERIFY(widget.mediaObject() == 0);
+
+    player.setVideoOutput(&item);
+    QVERIFY(item.mediaObject() == 0);
+
+    player.setVideoOutput(&surface);
+    // Nothing we can verify here other than it doesn't assert.
+}
+
+void tst_QMediaPlayer::testSetVideoOutputNoControl()
+{
+    QVideoWidget widget;
+    QGraphicsVideoItem item;
+    MockVideoSurface surface;
+
+    MockPlayerService service;
+    service.rendererRef = 1;
+    service.windowRef = 1;
+
+    MockProvider provider(&service);
+    provider.deleteServiceOnRelease = false;
+    QMediaPlayer player(0, 0, &provider);
+
+    player.setVideoOutput(&widget);
+    QVERIFY(widget.mediaObject() == 0);
+
+    player.setVideoOutput(&item);
+    QVERIFY(item.mediaObject() == 0);
+
+    player.setVideoOutput(&surface);
+    QVERIFY(service.rendererControl->surface() == 0);
+}
+
+void tst_QMediaPlayer::testSetVideoOutputDestruction()
+{
+    MockVideoSurface surface;
+
+    MockPlayerService service;
+    MockProvider provider(&service);
+    provider.deleteServiceOnRelease = false;
+
+    {
+        QMediaPlayer player(0, 0, &provider);
+        player.setVideoOutput(&surface);
+        QVERIFY(service.rendererControl->surface() == &surface);
+        QCOMPARE(service.rendererRef, 1);
+    }
+    QVERIFY(service.rendererControl->surface() == 0);
+    QCOMPARE(service.rendererRef, 0);
+}
+
+void tst_QMediaPlayer::testPositionPropertyWatch()
+{
+    QMediaContent content0(QUrl(QLatin1String("test://audio/song1.mp3")));
+    QMediaContent content1(QUrl(QLatin1String("test://audio/song2.mp3")));
+
+    mockService->setIsValid(true);
+    mockService->setState(QMediaPlayer::StoppedState, QMediaPlayer::NoMedia);
+
+    QMediaPlaylist *playlist = new QMediaPlaylist;
+
+    playlist->addMedia(content0);
+    playlist->addMedia(content1);
+
+    player->setPlaylist(playlist);
+    player->setNotifyInterval(5);
+
+    player->play();
+    QSignalSpy positionSpy(player, SIGNAL(positionChanged(qint64)));
+    playlist->next();
+    QCOMPARE(player->state(), QMediaPlayer::PlayingState);
+    QTRY_VERIFY(positionSpy.count() > 0);
+
+    playlist->next();
+    QCOMPARE(player->state(), QMediaPlayer::StoppedState);
+
+    positionSpy.clear();
+    QTRY_COMPARE(positionSpy.count(), 0);
+}
+
+void tst_QMediaPlayer::debugEnums()
+{
+    QTest::ignoreMessage(QtDebugMsg, "QMediaPlayer::PlayingState ");
+    qDebug() << QMediaPlayer::PlayingState;
+    QTest::ignoreMessage(QtDebugMsg, "QMediaPlayer::NoMedia ");
+    qDebug() << QMediaPlayer::NoMedia;
+    QTest::ignoreMessage(QtDebugMsg, "QMediaPlayer::NetworkError ");
+    qDebug() << QMediaPlayer::NetworkError;
 }
 
-QTEST_MAIN(tst_QMediaPlayer)
 
-#include "tst_qmediaplayer.moc"
