@@ -7,11 +7,11 @@
 ** This file is part of the test suite of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,23 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 //TESTED_COMPONENT=src/serviceframework
 
+#include <qmobilityglobal.h>
 #include <QtTest/QtTest>
 #include <QtCore/qlocale.h>
 #include <qmetaobjectbuilder_p.h>
@@ -1009,6 +1010,11 @@ void tst_QMetaObjectBuilder::serialize()
     QMap<QByteArray, const QMetaObject *> references;
     references.insert(QByteArray("QLocale"), &QLocale::staticMetaObject);
     builder2.deserialize(stream2, references);
+#ifdef Q_NO_DATA_RELOCATION
+    //the related meta objects will be function pointers
+    //which you have to add to the builder manually.
+    builder2.addRelatedMetaObject(QLocale::getStaticMetaObject);
+#endif
     builder2.setStaticMetacallFunction(builder.staticMetacallFunction());
     QMetaObject *meta2 = builder2.toMetaObject();
 
