@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,26 +25,21 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
+//TESTED_COMPONENT=src/multimedia
 
 #include <qpaintervideosurface_p.h>
 #include <QtTest/QtTest>
@@ -229,13 +224,22 @@ void tst_QPainterVideoSurface::supportedFormat_data()
             << QAbstractVideoBuffer::NoHandle
             << QVideoFrame::Format_RGB24
             << QSize(1024, 768)
+#ifndef QT_OPENGL_ES
             << true
             << true;
+#else
+            << false
+            << false;
+#endif
     QTest::newRow("rgb24 -1024x-768")
             << QAbstractVideoBuffer::NoHandle
             << QVideoFrame::Format_RGB24
             << QSize(-1024, -768)
+#ifndef QT_OPENGL_ES
             << true
+#else
+            << false
+#endif
             << false;
     QTest::newRow("rgb565 0x0")
             << QAbstractVideoBuffer::NoHandle
@@ -321,6 +325,20 @@ void tst_QPainterVideoSurface::supportedFormat_data()
             << QSize(256, 256)
             << false
             << false;
+#if !defined(Q_OS_MAC)
+    QTest::newRow("Pixmap: rgb32 640x480")
+            << QAbstractVideoBuffer::QPixmapHandle
+            << QVideoFrame::Format_RGB32
+            << QSize(640, 480)
+            << true
+            << true;
+    QTest::newRow("Pixmap: YUV420P 640x480")
+            << QAbstractVideoBuffer::QPixmapHandle
+            << QVideoFrame::Format_YUV420P
+            << QSize(640, 480)
+            << false
+            << true;
+#endif
 }
 
 void tst_QPainterVideoSurface::supportedFormat()
@@ -368,6 +386,7 @@ void tst_QPainterVideoSurface::present_data()
             << int(sizeof(argb32ImageData))
             << 8;
 
+#ifndef QT_OPENGL_ES
     QTest::newRow("rgb32 -> rgb24")
             << QVideoFrame::Format_RGB32
             << QSize(2, 2)
@@ -379,6 +398,7 @@ void tst_QPainterVideoSurface::present_data()
             << static_cast<const uchar *>(rgb24ImageData)
             << int(sizeof(rgb24ImageData))
             << 8;
+#endif
 
     QTest::newRow("rgb32 -> rgb565")
             << QVideoFrame::Format_RGB32
@@ -392,6 +412,7 @@ void tst_QPainterVideoSurface::present_data()
             << int(sizeof(rgb565ImageData))
             << 4;
 
+#ifndef QT_OPENGL_ES
     QTest::newRow("rgb24 -> rgb565")
             << QVideoFrame::Format_RGB24
             << QSize(2, 2)
@@ -403,6 +424,7 @@ void tst_QPainterVideoSurface::present_data()
             << static_cast<const uchar *>(rgb565ImageData)
             << int(sizeof(rgb565ImageData))
             << 4;
+#endif
 }
 
 void tst_QPainterVideoSurface::present()
@@ -752,14 +774,23 @@ void tst_QPainterVideoSurface::shaderSupportedFormat_data()
                 << QAbstractVideoBuffer::NoHandle
                 << QVideoFrame::Format_RGB24
                 << QSize(1024, 768)
+#ifndef QT_OPENGL_ES
                 << true
                 << true;
+#else
+                << false
+                << false;
+#endif
         QTest::newRow((type.second + "rgb24 -1024x-768").constData())
                 << type.first
                 << QAbstractVideoBuffer::NoHandle
                 << QVideoFrame::Format_RGB24
                 << QSize(-1024, -768)
+#ifndef QT_OPENGL_ES
                 << true
+#else
+                << false
+#endif
                 << false;
 #ifndef Q_WS_MAC
         QTest::newRow((type.second + "YUV420P 640x480").constData())
