@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -51,6 +51,26 @@
 #include <qservice.h>
 #include <qremoteserviceregister.h>
 
+#ifndef QT_NO_DBUS
+#include <QtDBus/QtDBus>
+#if QT_VERSION < 0x040800
+inline QDBusArgument &operator<<(QDBusArgument &arg, const QVariantHash &map)
+{
+    arg.beginMap(QVariant::String, qMetaTypeId<QDBusVariant>());
+    QVariantHash::ConstIterator it = map.constBegin();
+    QVariantHash::ConstIterator end = map.constEnd();
+    for ( ; it != end; ++it) {
+        arg.beginMapEntry();
+        arg << it.key() << QDBusVariant(it.value());
+        arg.endMapEntry();
+    }
+    arg.endMap();
+    return arg;
+}
+#endif
+#endif
+
+
 #define QTRY_VERIFY(a)                       \
     for (int _i = 0; _i < 5000; _i += 100) {    \
         if (a) break;                  \
@@ -62,12 +82,12 @@ QTM_USE_NAMESPACE
 Q_DECLARE_METATYPE(QServiceFilter);
 Q_DECLARE_METATYPE(QVariant);
 Q_DECLARE_METATYPE(QList<QString>);
+Q_DECLARE_METATYPE(QVariantHash);
 
 class tst_QServiceManager_IPC: public QObject
 {
     Q_OBJECT
 public:
-    bool requiresLackey();
 
 protected slots:
     void ipcError(QService::UnrecoverableIPCError error);
@@ -105,60 +125,44 @@ private slots:
     void testSignalling();
 
     void verifyServiceClass();
+    void verifyFailures();
+
 
     void testIpcFailure();
 
+
 private:
     QObject* serviceUnique;
     QObject* serviceUniqueOther;
     QObject* serviceShared;
     QObject* serviceSharedOther;
+    QObject* miscTest;
     QServiceManager* manager;
     bool verbose;
-    QProcess* lackey;
     bool ipcfailure;
 };
 
-/*
-    TODO:
-    -Test service with multiple inheritance hierarchy
-*/
-bool tst_QServiceManager_IPC::requiresLackey()
-{
-    //return false;
-
-// Temporarily commented out for initial development on Symbian
-#ifdef Q_OS_SYMBIAN
-    return false; //service is started when requested
-#endif
-
-#ifdef QT_NO_DBUS
-    return false;
-#endif
-
-#ifdef Q_OS_WIN
-    return false;
-#endif
-
-    return true;
-
-}
-
 void tst_QServiceManager_IPC::initTestCase()
 {
     //verbose = true;
     ipcfailure = false;
     verbose = false;
-    lackey = 0;
     serviceUnique = 0;
     serviceUniqueOther = 0;
     serviceSharedOther = 0;
     serviceShared = 0;
     serviceSharedOther = 0;
+    miscTest = 0;
     qRegisterMetaType<QServiceFilter>("QServiceFilter");
     qRegisterMetaTypeStreamOperators<QServiceFilter>("QServiceFilter");
     qRegisterMetaType<QList<QString> >("QList<QString>");
     qRegisterMetaTypeStreamOperators<QList<QString> >("QList<QString>");
+    qRegisterMetaTypeStreamOperators<QVariantHash>("QVariantHash");
+    qRegisterMetaType<QVariantHash>("QVariantHash");
+#ifndef QT_NO_DBUS
+    qDBusRegisterMetaType<QVariantHash>();
+#endif
+
 
     QServiceManager* manager = new QServiceManager(this);
 
@@ -170,48 +174,64 @@ void tst_QServiceManager_IPC::initTestCase()
         qWarning() << "Cannot register IPCExampleService" << path;
 #endif
 
-    //start lackey that represents the service
-    if (requiresLackey()) {
-        lackey = new QProcess(this);
-        QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
-        lackey->setProcessEnvironment(env);
-        if (verbose)
-            lackey->setProcessChannelMode(QProcess::ForwardedChannels);
-        lackey->start("./qt_sfw_example_ipc_unittest");
-        qDebug() << lackey->error() << lackey->errorString();
-        QVERIFY(lackey->waitForStarted());
-        //Give the lackey some time to come up;
-        QTest::qWait(700);
+    // D-Bus auto registration
+#ifndef QT_NO_DBUS
+    const QString &file = QDir::homePath() + "/.local/share/dbus-1/services/" +
+                                             "com.nokia.qt.ipcunittest.service";
+    QFile data(file);
+    if (data.open(QFile::WriteOnly)) {
+        QTextStream out(&data);
+        out << "[D-BUS Service]\n"
+            << "Name=com.nokia.qtmobility.sfw.IPCExampleService" << '\n'
+            << "Exec=" << QFileInfo("./qt_sfw_example_ipc_unittest").absoluteFilePath();
+        data.close();
     }
+#endif
 
     //test that the service is installed
     QList<QServiceInterfaceDescriptor> list = manager->findInterfaces("IPCExampleService");
-    QVERIFY2(list.count() == 2,"unit test specific IPCExampleService not registered/found" );
-    serviceUnique = manager->loadInterface(list[0]);
-    serviceUniqueOther = manager->loadInterface(list[0]);
-    serviceShared = manager->loadInterface(list[1]);
-    serviceSharedOther = manager->loadInterface(list[1]);
-  
+    QVERIFY2(list.count() == 5,"unit test specific IPCExampleService not registered/found" );
+    QServiceInterfaceDescriptor d;
+    foreach(d, list){
+        if(d.majorVersion() == 3 && d.minorVersion() == 5){
+            serviceUnique = manager->loadInterface(d);
+            serviceUniqueOther = manager->loadInterface(d);
+        }
+        if(d.majorVersion() == 3 && d.minorVersion() == 4){
+            serviceShared = manager->loadInterface(d);
+            serviceSharedOther = manager->loadInterface(d);
+        }
+        if(d.majorVersion() == 3 && d.minorVersion() == 8){
+            miscTest = manager->loadInterface(d);
+        }
+
+    }
+
     QString errorCode = "Cannot find service. Error: %1";
     errorCode = errorCode.arg(manager->error());
     QVERIFY2(serviceUnique,errorCode.toLatin1());
     QVERIFY2(serviceUniqueOther,errorCode.toLatin1());
     QVERIFY2(serviceShared,errorCode.toLatin1());
     QVERIFY2(serviceSharedOther,errorCode.toLatin1());
-    
-    connect(serviceUnique, SIGNAL(errorUnrecoverableIPCFault(QService::UnrecoverableIPCError)), this, SLOT(ipcError(QService::UnrecoverableIPCError)));
-    connect(serviceUniqueOther, SIGNAL(errorUnrecoverableIPCFault(QService::UnrecoverableIPCError)), this, SLOT(ipcError(QService::UnrecoverableIPCError)));
-    connect(serviceShared, SIGNAL(errorUnrecoverableIPCFault(QService::UnrecoverableIPCError)), this, SLOT(ipcError(QService::UnrecoverableIPCError)));
+
+    // all objects come from the same service, just need to connect to 1 signal
     connect(serviceSharedOther, SIGNAL(errorUnrecoverableIPCFault(QService::UnrecoverableIPCError)), this, SLOT(ipcError(QService::UnrecoverableIPCError)));
 }
 
 void tst_QServiceManager_IPC::ipcError(QService::UnrecoverableIPCError err)
 {  
+    Q_UNUSED(err);
     ipcfailure = true;  
 }
 
 void tst_QServiceManager_IPC::cleanupTestCase()
 {
+#ifndef QT_NO_DBUS
+    const QString &file = QDir::homePath() + "/.local/share/dbus-1/services/" +
+                                             "com.nokia.qt.ipcunittest.service";
+    QFile::remove(file);
+#endif
+
     if (serviceUnique) {
         delete serviceUnique;
     }
@@ -228,22 +248,6 @@ void tst_QServiceManager_IPC::cleanupTestCase()
         delete serviceSharedOther;
     }
 
-    if (requiresLackey() && lackey) {
-        lackey->terminate();
-       
-        // terminate didnt cause process to exit
-        if (!lackey->waitForFinished(10000))
-            lackey->kill();
-
-        switch(lackey->exitCode()) {
-        case 0:
-            qDebug("Lackey returned exit success(0)");
-            break; 
-        default:
-            qDebug("Lackey failed.");
-            break;
-        }
-    }
     // clean up the unit, don't leave it registered
     QServiceManager m;
     m.removeService("IPCExampleService");
@@ -342,10 +346,14 @@ void tst_QServiceManager_IPC::verifySharedServiceObject()
     QCOMPARE(mo->className(), "SharedTestService");
     QVERIFY(mo->superClass());
     QCOMPARE(mo->superClass()->className(), "QObject");
-    QCOMPARE(mo->methodCount()-mo-> methodOffset(), 18);
-    QCOMPARE(mo->methodCount(), 22); //20 meta functions available
+    QCOMPARE(mo->methodCount()-mo-> methodOffset(), 19);
+    QCOMPARE(mo->methodCount(), 23); //20 meta functions available
     //actual function presence will be tested later
     
+//    for(int i = 0; i < mo->methodCount(); i++){
+//        qDebug() << "Methods" << i << mo->method(i).signature();
+//    }
+    
     //test properties
     QCOMPARE(mo->propertyCount()-mo->propertyOffset(), 1);
     QCOMPARE(mo->propertyCount(), 2);
@@ -424,6 +432,8 @@ void tst_QServiceManager_IPC::verifySharedMethods_data()
         << QByteArray("testSlotWithArgs(QByteArray,int,QVariant)") <<  (int)( QMetaMethod::Slot) << QByteArray("");
     QTest::newRow("testSlotWithCustomArg(QServiceFilter)") 
         << QByteArray("testSlotWithCustomArg(QServiceFilter)") <<  (int)( QMetaMethod::Slot) << QByteArray("");
+    QTest::newRow("testSlotWidthComplexArg(QVariantHash)")
+            << QByteArray("testSlotWithComplexArg(QVariantHash)") <<  (int)( QMetaMethod::Slot) << QByteArray("");
 
     //QServiceInterfaceDescriptor has not been declared as meta type
     QTest::newRow("testSlotWithUnknownArg(QServiceInterfaceDescriptor)") 
@@ -530,9 +540,13 @@ void tst_QServiceManager_IPC::verifyUniqueServiceObject()
     QVERIFY(mo->superClass());
     QCOMPARE(mo->superClass()->className(), "QObject");
     // TODO adding the ipc failure signal seems to break these    
-    QCOMPARE(mo->methodCount()-mo-> methodOffset(), 21); // 17+1 added signal for error signal added by library
-    QCOMPARE(mo->methodCount(), 25); //21 meta functions available + 1 signal
+    QCOMPARE(mo->methodCount()-mo-> methodOffset(), 22); // 17+1 added signal for error signal added by library
+    QCOMPARE(mo->methodCount(), 26); //21 meta functions available + 1 signal
     //actual function presence will be tested later
+    
+//    for(int i = 0; i < mo->methodCount(); i++){
+//        qDebug() << "Methods" << i << mo->method(i).signature();
+//    }
 
     //test properties
     QCOMPARE(mo->propertyCount()-mo->propertyOffset(), 3);
@@ -993,6 +1007,30 @@ void tst_QServiceManager_IPC::testSlotInvokation()
     QMetaObject::invokeMethod(service, "slotConfirmation",
                               Q_RETURN_ARG(uint, hash));
     QCOMPARE(hash, expectedHash);
+
+    // Test slot with QHash<QString, QVariant>
+    QHash<QString, QVariant> hashv;
+    hashv["test"] = QVariant::fromValue(1);
+    hashv["test2"] = QVariant::fromValue(QString("test2 string"));
+    hashv["test3"] = QVariant::fromValue(true);
+    QHashIterator<QString, QVariant> i(hashv);
+    output.clear();
+    while (i.hasNext()) {
+        i.next();
+        output += i.key();
+        output += "=";
+        output += i.value().toString();
+        output += ", ";
+    }
+    expectedHash = qHash(output);
+
+    QMetaObject::invokeMethod(serviceUnique, "testSlotWithComplexArg",
+                              Q_ARG(QVariantHash, hashv));
+    QMetaObject::invokeMethod(service, "slotConfirmation",
+                              Q_RETURN_ARG(uint, hash));
+    QCOMPARE(hash, expectedHash);
+
+
 }
 
 void tst_QServiceManager_IPC::verifyServiceClass()
@@ -1025,13 +1063,41 @@ void tst_QServiceManager_IPC::testIpcFailure()
     
     QVERIFY(ipcfailure);
   
-// TODO restart the connection
-//  service = manager->loadInterface("com.nokia.qt.ipcunittest");
-//  QString errorCode = "Cannot find service. Error: %1";
-//  errorCode = errorCode.arg(manager->error());
-//  QVERIFY2(service,errorCode.toLatin1());
-//  connect(service, SIGNAL(errorUnrecoverableIPCFault(QService::UnrecoverableIPCError)), this, SLOT(ipcError(QService::UnrecoverableIPCError)));  
+    // TODO restart the connection
+    //initTestCase();
 }
 
+void tst_QServiceManager_IPC::verifyFailures()
+{
+    bool result;
+
+    QServiceManager* manager = new QServiceManager(this);
+    QList<QServiceInterfaceDescriptor> list = manager->findInterfaces("IPCExampleService");
+    QServiceInterfaceDescriptor d;
+    foreach(d, list){
+        if(d.majorVersion() == 3 && d.minorVersion() == 6){
+            QObject *o = manager->loadInterface(d);
+            QVERIFY2(o == 0, "Failure to allocate remote object returns null");
+        }
+        if(d.majorVersion() == 3 && d.minorVersion() == 7){
+            QObject *o = manager->loadInterface(d);
+            QVERIFY2(o == 0, "Failure to allocate remote object returns null");
+        }
+    }
+
+    QMetaObject::invokeMethod(miscTest, "addTwice",
+                              Q_RETURN_ARG(bool, result));
+    QVERIFY2(result, "Added the same service twice, returned different entries");
+
+    QMetaObject::invokeMethod(miscTest, "getInvalidEntry",
+                              Q_RETURN_ARG(bool, result));
+    QVERIFY2(result, "Invalid entry returns invalid meta data");
+
+    delete manager;
+
+}
+
+
+
 QTEST_MAIN(tst_QServiceManager_IPC);
 #include "tst_qservicemanager_ipc.moc"
