@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -42,6 +42,8 @@
 //TESTED_COMPONENT=src/systeminfo
 
 #include <QtTest/QtTest>
+ #include <QDesktopWidget>
+
 #include "qsysteminfo.h"
 
 QTM_USE_NAMESPACE
@@ -50,9 +52,10 @@ class tst_QSystemScreenSaver : public QObject
     Q_OBJECT
 
 private slots:
-        void initTestCase();
+   void initTestCase();
     void tst_screenSaverInhibited();
     void tst_setScreenSaverInhibit();
+    void tst_setScreenSaverInhibited();
 
 };
 
@@ -64,15 +67,39 @@ private slots:
 void tst_QSystemScreenSaver::tst_screenSaverInhibited()
 {
     QSystemScreenSaver si;
-    bool enabled = si.screenSaverInhibited();
-    QVERIFY( enabled || !enabled);
+    QDesktopWidget wid;
+   bool enabled = si.setScreenSaverInhibit();
+    if(wid.screenCount() > 0) {
+        QVERIFY( si.screenSaverInhibited() && enabled);
+    } else{
+        QVERIFY(!si.screenSaverInhibited() && !enabled);
+    }
 }
 
 void tst_QSystemScreenSaver::tst_setScreenSaverInhibit()
 {
     QSystemScreenSaver si;
+    QDesktopWidget wid;
     bool enabled = si.setScreenSaverInhibit();
-    QVERIFY( enabled || !enabled);
+    if(wid.screenCount() > 0) {
+        QVERIFY(enabled);
+    } else{
+        QVERIFY(!enabled);
+    }
+}
+
+void tst_QSystemScreenSaver::tst_setScreenSaverInhibited()
+{
+    QSystemScreenSaver si;
+    QDesktopWidget wid;
+    si.setScreenSaverInhibited(true);
+    if(wid.screenCount() > 0) {
+        QVERIFY(si.screenSaverInhibited());
+    } else{
+        QVERIFY(!si.screenSaverInhibited());
+    }
+    si.setScreenSaverInhibited(false);
+    QVERIFY(!si.screenSaverInhibited());
 }
 
 QTEST_MAIN(tst_QSystemScreenSaver)
