@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -53,6 +53,7 @@
 #include <QProcess>
 #include <QFile>
 #include <QThread>
+#include <QCoreApplication>
 #include <QTimer>
 #include <math.h>
 
@@ -115,6 +116,9 @@ void tst_QValueSpaceSubscriber::initTestCase()
     qRegisterMetaType<QVariant>("QVariant");
     qRegisterMetaType<QValueSpace::LayerOptions>("QValueSpace::LayerOptions");
 
+    QCoreApplication::setOrganizationDomain("tests.qt.nokia.com");
+    QCoreApplication::setApplicationName("qvaluespacesubscriber");
+
 #ifdef Q_OS_WIN
     HKEY key;
     long result = RegOpenKeyEx(HKEY_CURRENT_USER, L"Software\\Nokia",
@@ -170,6 +174,10 @@ void tst_QValueSpaceSubscriber::initTestCase()
 
         busys.insert(layers.at(i), busy);
     }
+
+#if defined(Q_WS_MAEMO_6) || defined(Q_WS_MEEGO)
+    QTest::qWait(1000);
+#endif
 }
 
 void tst_QValueSpaceSubscriber::cleanupTestCase()
@@ -270,6 +278,9 @@ void tst_QValueSpaceSubscriber::dataVersatility()
     QValueSpacePublisher publisher(layer->id(), "/usr/data");
     publisher.setValue(typeString, data);
     publisher.sync();
+#if defined(Q_WS_MAEMO_6) || defined(Q_WS_MEEGO)
+    QTest::qWait(1000);
+#endif
     QValueSpaceSubscriber subscriber(layer->id(), "/usr/data");
     QVariant v = subscriber.value(typeString);
 
@@ -1131,6 +1142,9 @@ void WriteThread::run()
         publisher.setValue("value", value);
         publisher.sync();
         QTest::qWait(100);
+#if defined(Q_WS_MAEMO_6) || defined(Q_WS_MEEGO)
+    QTest::qWait(1000);
+#endif
         value += 100;
     }
 }
