@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -57,6 +57,10 @@ const QString KATAKANA_NOKIA(QString::fromUtf8("\xe3\x83\x8e\xe3\x82\xad\xe3\x82
 QTM_USE_NAMESPACE
 
 Q_DECLARE_METATYPE(QVersitProperty)
+
+// Because the QFETCH macro balks on the comma in QMultiHash<QString,QString>
+typedef QMultiHash<QString,QString> StringHash;
+Q_DECLARE_METATYPE(StringHash)
 #ifdef QT_BUILD_INTERNAL
 void tst_QVCard21Writer::init()
 {
@@ -82,7 +86,11 @@ void tst_QVCard21Writer::testEncodeVersitProperty()
     buffer.open(QIODevice::WriteOnly);
 
     mWriter->encodeVersitProperty(property);
-    QCOMPARE(encodedProperty, expectedResult);
+    if (encodedProperty != expectedResult) {
+        qDebug() << "Encoded: " << encodedProperty;
+        qDebug() << "Expected: " << expectedResult;
+        QVERIFY(false);
+    }
 }
 
 void tst_QVCard21Writer::testEncodeVersitProperty_data()
@@ -114,6 +122,32 @@ void tst_QVCard21Writer::testEncodeVersitProperty_data()
     expectedResult = "N;ENCODING=QUOTED-PRINTABLE:La\\;st;Fi,rst;Mi:ddle;Pr=5Cefix;Suffix\r\n";
     QTest::newRow("N property") << property << expectedResult << codec;
 
+    // Structured N - there was a bug where if two fields had to be escaped,
+    // two ENCODING parameters were added
+    property.setName(QLatin1String("N"));
+    property.setValue(QStringList()
+                      << QLatin1String("La\\st")
+                      << QLatin1String("Fi\\rst")
+                      << QString()
+                      << QString()
+                      << QString());
+    property.setValueType(QVersitProperty::CompoundType);
+    expectedResult = "N;ENCODING=QUOTED-PRINTABLE:La=5Cst;Fi=5Crst;;;\r\n";
+    QTest::newRow("N property, double-encoded") << property << expectedResult << codec;
+
+    // Structured N - one field needs to be encoded in UTF-8 while the other doesn't
+    // correct behaviour is to encode the whole thing in UTF-8
+    property.setName(QLatin1String("N"));
+    property.setValue(QStringList()
+                      << QString::fromUtf8("\xE2\x82\xAC") // euro sign
+                      << QString::fromLatin1("\xA3") // pound sign (upper Latin-1)
+                      << QString()
+                      << QString()
+                      << QString());
+    property.setValueType(QVersitProperty::CompoundType);
+    expectedResult = "N;CHARSET=UTF-8;ENCODING=QUOTED-PRINTABLE:=E2=82=AC;=C2=A3;;;\r\n";
+    QTest::newRow("N property, double-encoded") << property << expectedResult << codec;
+
     // Structured CATEGORIES - escaping should happen for commas, not semicolons
     property.setName(QLatin1String("CATEGORIES"));
     property.setValue(QStringList()
@@ -171,11 +205,31 @@ END:VCARD\r\n\
     QTest::newRow("base64 encoded") << property << expectedResult << codec;
 
     // Characters other than ASCII:
-    expectedResult = "ORG;CHARSET=UTF-8:" + KATAKANA_NOKIA.toUtf8() + "\r\n";
+    // Note: KATAKANA_NOKIA is defined as: QString::fromUtf8("\xe3\x83\x8e\xe3\x82\xad\xe3\x82\xa2")
+    // The expected behaviour is to convert to UTF8, then encode with quoted-printable.
+    // Because the result overflows one line, it should be split onto two lines using a
+    // quoted-printable soft line break (EQUALS-CR-LF).  (Note: Versit soft line breaks
+    // (CR-LF-SPACE) are not supported by the native Symbian vCard importers).
+    expectedResult = "ORG;CHARSET=UTF-8;ENCODING=QUOTED-PRINTABLE:=E3=83=8E=E3=82=AD=E3=82=A2=E3=\r\n"
+                     "=83=8E=E3=82=AD=E3=82=A2\r\n";
     property = QVersitProperty();
     property.setName(QLatin1String("ORG"));
-    property.setValue(KATAKANA_NOKIA);
-    QTest::newRow("non-ASCII") << property << expectedResult << codec;
+    property.setValue(KATAKANA_NOKIA + KATAKANA_NOKIA);
+    QTest::newRow("non-ASCII 1") << property << expectedResult << codec;
+
+    expectedResult = "ORG;CHARSET=UTF-8;ENCODING=QUOTED-PRINTABLE:a=E3=83=8E=E3=82=AD=E3=82=A2=E3=\r\n"
+                     "=83=8E=E3=82=AD=E3=82=A2\r\n";
+    property = QVersitProperty();
+    property.setName(QLatin1String("ORG"));
+    property.setValue("a" + KATAKANA_NOKIA + KATAKANA_NOKIA);
+    QTest::newRow("non-ASCII 2") << property << expectedResult << codec;
+
+    expectedResult = "ORG;CHARSET=UTF-8;ENCODING=QUOTED-PRINTABLE:aa=E3=83=8E=E3=82=AD=E3=82=A2=\r\n"
+                     "=E3=83=8E=E3=82=AD=E3=82=A2\r\n";
+    property = QVersitProperty();
+    property.setName(QLatin1String("ORG"));
+    property.setValue("aa" + KATAKANA_NOKIA + KATAKANA_NOKIA);
+    QTest::newRow("non-ASCII 3") << property << expectedResult << codec;
 
     // In Shift-JIS codec.
     QTextCodec* jisCodec = QTextCodec::codecForName("Shift-JIS");
@@ -185,67 +239,69 @@ END:VCARD\r\n\
     property.setName(QLatin1String("ORG"));
     property.setValue(KATAKANA_NOKIA);
     QTest::newRow("JIS codec") << property << expectedResult << QByteArray("Shift-JIS");
-
-    // CHARSET and QUOTED-PRINTABLE
-    expectedResult = "EMAIL;CHARSET=UTF-8;ENCODING=QUOTED-PRINTABLE:john=40"
-                     + KATAKANA_NOKIA.toUtf8() + ".com\r\n";
-    property = QVersitProperty();
-    property.setName(QLatin1String("EMAIL"));
-    property.setValue(QString::fromAscii("john@%1.com").arg(KATAKANA_NOKIA));
-    QTest::newRow("Charset and QP") << property << expectedResult << codec;
 }
 
 void tst_QVCard21Writer::testEncodeParameters()
 {
+    QFETCH(StringHash, parameters);
+    QFETCH(QByteArray, expected);
+
     QByteArray encodedParameters;
     QBuffer buffer(&encodedParameters);
     mWriter->setDevice(&buffer);
     buffer.open(QIODevice::WriteOnly);
 
-    QString typeParameterName(QString::fromAscii("TYPE"));
-    QString encodingParameterName(QString::fromAscii("ENCODING"));
-
     // No parameters
+    mWriter->encodeParameters(parameters);
+    if (encodedParameters != expected) {
+        qDebug() << "Encoded: " << encodedParameters;
+        qDebug() << "Expected: " << expected;
+        QVERIFY(false);
+    }
+}
+
+void tst_QVCard21Writer::testEncodeParameters_data()
+{
+    QTest::addColumn< QMultiHash<QString, QString> >("parameters");
+    QTest::addColumn<QByteArray>("expected");
+
     QMultiHash<QString,QString> parameters;
-    mWriter->encodeParameters(parameters);
-    QCOMPARE(encodedParameters, QByteArray(""));
 
-    // One TYPE parameter
-    mWriter->writeCrlf(); // so it doesn't start folding
-    buffer.close();
-    encodedParameters.clear();
-    buffer.open(QIODevice::WriteOnly);
-    parameters.insert(typeParameterName,QString::fromAscii("HOME"));
-    mWriter->encodeParameters(parameters);
-    QCOMPARE(encodedParameters, QByteArray(";HOME"));
+    QTest::newRow("No parameters") << parameters << QByteArray("");
 
-    // Two TYPE parameters
-    mWriter->writeCrlf(); // so it doesn't start folding
-    buffer.close();
-    encodedParameters.clear();
-    buffer.open(QIODevice::WriteOnly);
-    parameters.insert(typeParameterName,QString::fromAscii("VOICE"));
-    mWriter->encodeParameters(parameters);
-    QCOMPARE(encodedParameters, QByteArray(";VOICE;HOME"));
+    parameters.insert(QLatin1String("TYPE"), QString::fromAscii("HOME"));
+    QTest::newRow("One TYPE parameter") << parameters << QByteArray(";HOME");
+
+    // HOME should appear before VOICE because it is more "important" and some vCard
+    // parsers may ignore everything after the first TYPE
+    parameters.insert(QLatin1String("TYPE"), QString::fromAscii("VOICE"));
+    QTest::newRow("Two TYPE parameters") << parameters << QByteArray(";HOME;VOICE");
 
-    // One ENCODING parameter
-    mWriter->writeCrlf(); // so it doesn't start folding
-    buffer.close();
-    encodedParameters.clear();
-    buffer.open(QIODevice::WriteOnly);
     parameters.clear();
-    parameters.insert(encodingParameterName,QString::fromAscii("8BIT"));
-    mWriter->encodeParameters(parameters);
-    QCOMPARE(encodedParameters, QByteArray(";ENCODING=8BIT"));
+    parameters.insert(QLatin1String("ENCODING"), QString::fromAscii("8BIT"));
+    QTest::newRow("One ENCODING parameter") << parameters << QByteArray(";ENCODING=8BIT");
 
-    // Two parameters
-    mWriter->writeCrlf(); // so it doesn't start folding
-    buffer.close();
-    encodedParameters.clear();
-    buffer.open(QIODevice::WriteOnly);
     parameters.insert(QString::fromAscii("X-PARAM"),QString::fromAscii("VALUE"));
-    mWriter->encodeParameters(parameters);
-    QCOMPARE(encodedParameters, QByteArray(";X-PARAM=VALUE;ENCODING=8BIT"));
+    QTest::newRow("Two parameters") << parameters << QByteArray(";X-PARAM=VALUE;ENCODING=8BIT");
+
+    parameters.clear();
+    parameters.insert(QLatin1String("TYPE"), QLatin1String("VOICE"));
+    parameters.insert(QLatin1String("TYPE"), QLatin1String("CELL"));
+    parameters.insert(QLatin1String("TYPE"), QLatin1String("MODEM"));
+    parameters.insert(QLatin1String("TYPE"), QLatin1String("CAR"));
+    parameters.insert(QLatin1String("TYPE"), QLatin1String("VIDEO"));
+    parameters.insert(QLatin1String("TYPE"), QLatin1String("FAX"));
+    parameters.insert(QLatin1String("TYPE"), QLatin1String("BBS"));
+    parameters.insert(QLatin1String("TYPE"), QLatin1String("PAGER"));
+    parameters.insert(QLatin1String("TYPE"), QLatin1String("HOME"));
+    parameters.insert(QLatin1String("TYPE"), QLatin1String("WORK"));
+    // Ensure CELL and FAX are at the front because they are "more important" and some vCard
+    // parsers may ignore everything after the first TYPE
+    // Ensure WORK and HOME come next.
+    // Besides these conditions, there are no other ordering constraints.  The data here is simply
+    // what the writer produces (as dictated by its internal data structures).
+    QTest::newRow("TYPE parameters order") << parameters
+        << QByteArray(";CELL;FAX;WORK;HOME;MODEM;CAR;VIDEO;BBS;PAGER;VOICE");
 }
 
 void tst_QVCard21Writer::testEncodeGroupsAndName()
