@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -636,6 +636,7 @@ void tst_QVersitContactImporter::testAnniversary()
     QContact contact = mImporter->contacts().first();
     QContactAnniversary anniversary = contact.detail<QContactAnniversary>();
     QCOMPARE(anniversary.originalDate(), QDate(1981, 5, 20));
+    QCOMPARE(anniversary.variantValue(QContactAnniversary::FieldOriginalDate).type(), QVariant::Date);
 
     // Evolution format
     property.setName(QLatin1String("X-EVOLUTION-ANNIVERSARY"));
@@ -645,6 +646,7 @@ void tst_QVersitContactImporter::testAnniversary()
     contact = mImporter->contacts().first();
     anniversary = contact.detail<QContactAnniversary>();
     QCOMPARE(anniversary.originalDate(), QDate(1981, 5, 20));
+    QCOMPARE(anniversary.variantValue(QContactAnniversary::FieldOriginalDate).type(), QVariant::Date);
 
     // Date : ISO 8601 in basic format
     property.setName(QLatin1String("X-ANNIVERSARY"));
@@ -654,6 +656,27 @@ void tst_QVersitContactImporter::testAnniversary()
     contact = mImporter->contacts().first();
     anniversary = contact.detail<QContactAnniversary>();
     QCOMPARE(anniversary.originalDate(), QDate(1981, 5, 20));
+    QCOMPARE(anniversary.variantValue(QContactAnniversary::FieldOriginalDate).type(), QVariant::Date);
+
+    // Date time tests
+    property.setName(QLatin1String("X-ANNIVERSARY"));
+    property.setValue(QLatin1String("19810520T000102")); // localtime
+    document = createDocumentWithProperty(property);
+    QVERIFY(mImporter->importDocuments(QList<QVersitDocument>() << document));
+    contact = mImporter->contacts().first();
+    anniversary = contact.detail<QContactAnniversary>();
+    QCOMPARE(anniversary.originalDate(), QDate(1981, 5, 20));
+    QCOMPARE(anniversary.originalDateTime(), QDateTime(QDate(1981, 5, 20), QTime(0,1,2), Qt::LocalTime));
+    QCOMPARE(anniversary.variantValue(QContactAnniversary::FieldOriginalDate).type(), QVariant::DateTime);
+
+    property.setValue(QLatin1String("19810520T010203Z")); // utc
+    document = createDocumentWithProperty(property);
+    QVERIFY(mImporter->importDocuments(QList<QVersitDocument>() << document));
+    contact = mImporter->contacts().first();
+    anniversary = contact.detail<QContactAnniversary>();
+    QCOMPARE(anniversary.originalDate(), QDate(1981, 5, 20));
+    QCOMPARE(anniversary.originalDateTime(), QDateTime(QDate(1981, 5, 20), QTime(1,2,3), Qt::UTC));
+    QCOMPARE(anniversary.variantValue(QContactAnniversary::FieldOriginalDate).type(), QVariant::DateTime);
 }
 
 void tst_QVersitContactImporter::testBirthday()
@@ -667,8 +690,8 @@ void tst_QVersitContactImporter::testBirthday()
     QVERIFY(mImporter->importDocuments(QList<QVersitDocument>() << document));
     QContact contact = mImporter->contacts().first();
     QContactBirthday bday = contact.detail<QContactBirthday>();
-    QCOMPARE(bday.date().toString(Qt::ISODate),
-             dateValue);
+    QCOMPARE(bday.date().toString(Qt::ISODate), dateValue);
+    QCOMPARE(bday.variantValue(QContactBirthday::FieldBirthday).type(), QVariant::Date);
 
     // Date : ISO 8601 in basic format
     dateValue = QLatin1String("19810520");
@@ -677,9 +700,53 @@ void tst_QVersitContactImporter::testBirthday()
     QVERIFY(mImporter->importDocuments(QList<QVersitDocument>() << document));
     contact = mImporter->contacts().first();
     bday = contact.detail<QContactBirthday>();
-    QCOMPARE(bday.date().toString(QLatin1String("yyyyMMdd")),
-             dateValue);
+    QCOMPARE(bday.date(), QDate(1981, 5, 20));
+    QCOMPARE(bday.variantValue(QContactBirthday::FieldBirthday).type(), QVariant::Date);
 
+    dateValue = QLatin1String("1981-05-20");
+    property.setValue(dateValue);
+    document = createDocumentWithProperty(property);
+    QVERIFY(mImporter->importDocuments(QList<QVersitDocument>() << document));
+    contact = mImporter->contacts().first();
+    bday = contact.detail<QContactBirthday>();
+    QCOMPARE(bday.date(), QDate(1981, 5, 20));
+    QCOMPARE(bday.variantValue(QContactBirthday::FieldBirthday).type(), QVariant::Date);
+
+    dateValue = QLatin1String("19810520T100000");
+    property.setValue(dateValue);
+    document = createDocumentWithProperty(property);
+    QVERIFY(mImporter->importDocuments(QList<QVersitDocument>() << document));
+    contact = mImporter->contacts().first();
+    bday = contact.detail<QContactBirthday>();
+    QCOMPARE(bday.dateTime(), QDateTime(QDate(1981, 5, 20), QTime(10, 0, 0), Qt::LocalTime));
+    QCOMPARE(bday.variantValue(QContactBirthday::FieldBirthday).type(), QVariant::DateTime);
+
+    dateValue = QLatin1String("1981-05-20T10:00:00");
+    property.setValue(dateValue);
+    document = createDocumentWithProperty(property);
+    QVERIFY(mImporter->importDocuments(QList<QVersitDocument>() << document));
+    contact = mImporter->contacts().first();
+    bday = contact.detail<QContactBirthday>();
+    QCOMPARE(bday.dateTime(), QDateTime(QDate(1981, 5, 20), QTime(10, 0, 0), Qt::LocalTime));
+    QCOMPARE(bday.variantValue(QContactBirthday::FieldBirthday).type(), QVariant::DateTime);
+
+    dateValue = QLatin1String("19810520T100000Z");
+    property.setValue(dateValue);
+    document = createDocumentWithProperty(property);
+    QVERIFY(mImporter->importDocuments(QList<QVersitDocument>() << document));
+    contact = mImporter->contacts().first();
+    bday = contact.detail<QContactBirthday>();
+    QCOMPARE(bday.dateTime(), QDateTime(QDate(1981, 5, 20), QTime(10, 0, 0), Qt::UTC));
+    QCOMPARE(bday.variantValue(QContactBirthday::FieldBirthday).type(), QVariant::DateTime);
+
+    dateValue = QLatin1String("1981-05-20T10:00:00Z");
+    property.setValue(dateValue);
+    document = createDocumentWithProperty(property);
+    QVERIFY(mImporter->importDocuments(QList<QVersitDocument>() << document));
+    contact = mImporter->contacts().first();
+    bday = contact.detail<QContactBirthday>();
+    QCOMPARE(bday.dateTime(), QDateTime(QDate(1981, 5, 20), QTime(10, 0, 0), Qt::UTC));
+    QCOMPARE(bday.variantValue(QContactBirthday::FieldBirthday).type(), QVariant::DateTime);
 }
 
 void tst_QVersitContactImporter::testGender()
@@ -1020,13 +1087,13 @@ void tst_QVersitContactImporter::testDisplayLabel()
 void tst_QVersitContactImporter::testOnlineAccount()
 {
     QString accountUri(QLatin1String("sip:john.citizen@example.com"));
+    QVersitDocument document;
 
     // Plain X-SIP, no TYPE ->
-    QVersitDocument document(QVersitDocument::VCard30Type);
     QVersitProperty property;
     property.setName(QLatin1String("X-SIP"));
     property.setValue(accountUri);
-    document.addProperty(property);
+    document = createDocumentWithProperty(property);
     QVERIFY(mImporter->importDocuments(QList<QVersitDocument>() << document));
     QContact contact = mImporter->contacts().first();
     QContactOnlineAccount onlineAccount = contact.detail<QContactOnlineAccount>();
@@ -1036,15 +1103,13 @@ void tst_QVersitContactImporter::testOnlineAccount()
     QVERIFY(subTypes.first() == QContactOnlineAccount::SubTypeSip);
 
     // X-SIP;SWIS
-    document.clear();
-    document.setType(QVersitDocument::VCard30Type);
     property = QVersitProperty();
     property.setName(QLatin1String("X-SIP"));
     property.setValue(accountUri);
     QMultiHash<QString,QString> params;
     params.insert(QLatin1String("TYPE"),QLatin1String("SWIS"));
     property.setParameters(params);
-    document.addProperty(property);
+    document = createDocumentWithProperty(property);
     QVERIFY(mImporter->importDocuments(QList<QVersitDocument>() << document));
     contact = mImporter->contacts().first();
     onlineAccount =  contact.detail<QContactOnlineAccount>();
@@ -1054,15 +1119,13 @@ void tst_QVersitContactImporter::testOnlineAccount()
     QVERIFY(subTypes.first() == QContactOnlineAccount::SubTypeVideoShare);
 
     // X-SIP;VOIP
-    document.clear();
-    document.setType(QVersitDocument::VCard30Type);
     property = QVersitProperty();
     property.setName(QLatin1String("X-SIP"));
     property.setValue(accountUri);
     params.clear();
     params.insert(QLatin1String("TYPE"),QLatin1String("VOIP"));
     property.setParameters(params);
-    document.addProperty(property);
+    document = createDocumentWithProperty(property);
     QVERIFY(mImporter->importDocuments(QList<QVersitDocument>() << document));
     contact = mImporter->contacts().first();
     onlineAccount =  contact.detail<QContactOnlineAccount>();
@@ -1072,12 +1135,10 @@ void tst_QVersitContactImporter::testOnlineAccount()
     QVERIFY(subTypes.first() == QContactOnlineAccount::SubTypeSipVoip);
 
     // X-IMPP
-    document.clear();
-    document.setType(QVersitDocument::VCard30Type);
     property = QVersitProperty();
     property.setName(QLatin1String("X-IMPP"));
     property.setValue(accountUri);
-    document.addProperty(property);
+    document = createDocumentWithProperty(property);
     QVERIFY(mImporter->importDocuments(QList<QVersitDocument>() << document));
     contact = mImporter->contacts().first();
     onlineAccount =  contact.detail<QContactOnlineAccount>();
@@ -1087,12 +1148,10 @@ void tst_QVersitContactImporter::testOnlineAccount()
     QVERIFY(subTypes.first() == QContactOnlineAccount::SubTypeImpp);
 
     // IMPP
-    document.clear();
-    document.setType(QVersitDocument::VCard30Type);
     property = QVersitProperty();
     property.setName(QLatin1String("IMPP"));
     property.setValue(accountUri);
-    document.addProperty(property);
+    document = createDocumentWithProperty(property);
     QVERIFY(mImporter->importDocuments(QList<QVersitDocument>() << document));
     contact = mImporter->contacts().first();
     onlineAccount =  contact.detail<QContactOnlineAccount>();
@@ -1102,12 +1161,10 @@ void tst_QVersitContactImporter::testOnlineAccount()
     QVERIFY(subTypes.first() == QContactOnlineAccount::SubTypeImpp);
 
     // X-JABBER
-    document.clear();
-    document.setType(QVersitDocument::VCard30Type);
     property = QVersitProperty();
     property.setName(QLatin1String("X-JABBER"));
     property.setValue(accountUri);
-    document.addProperty(property);
+    document = createDocumentWithProperty(property);
     QVERIFY(mImporter->importDocuments(QList<QVersitDocument>() << document));
     contact = mImporter->contacts().first();
     onlineAccount =  contact.detail<QContactOnlineAccount>();
@@ -1115,6 +1172,58 @@ void tst_QVersitContactImporter::testOnlineAccount()
     subTypes = onlineAccount.subTypes();
     QCOMPARE(subTypes.count(),1);
     QVERIFY(subTypes.first() == QContactOnlineAccount::SubTypeImpp);
+    QVERIFY(onlineAccount.protocol() == QContactOnlineAccount::ProtocolJabber);
+
+    document = QVersitDocument(QVersitDocument::VCard30Type);
+    property.setName("X-AIM");
+    property.setValue("a");
+    document.addProperty(property);
+    property.setName("X-ICQ");
+    property.setValue("b");
+    document.addProperty(property);
+    property.setName("X-MSN");
+    property.setValue("c");
+    document.addProperty(property);
+    property.setName("X-QQ");
+    property.setValue("d");
+    document.addProperty(property);
+    property.setName("X-YAHOO");
+    property.setValue("e");
+    document.addProperty(property);
+    property.setName("X-SKYPE");
+    property.setValue("f");
+    document.addProperty(property);
+    property.setName("X-SKYPE-USERNAME");
+    property.setValue("g");
+    document.addProperty(property);
+    property.setName("X-MS-IMADDRESS");
+    property.setValue("h");
+    document.addProperty(property);
+    property.setName("X-KADDRESSBOOK-X-IMADDRESS");
+    property.setValue("i");
+    document.addProperty(property);
+    QVERIFY(mImporter->importDocuments(QList<QVersitDocument>() << document));
+    contact = mImporter->contacts().first();
+    QList<QContactOnlineAccount> onlineAccounts = contact.details<QContactOnlineAccount>();
+    QCOMPARE(onlineAccounts.size(), 9);
+    QVERIFY(onlineAccounts[0].protocol() == QContactOnlineAccount::ProtocolAim);
+    QVERIFY(onlineAccounts[0].accountUri() == "a");
+    QVERIFY(onlineAccounts[1].protocol() == QContactOnlineAccount::ProtocolIcq);
+    QVERIFY(onlineAccounts[1].accountUri() == "b");
+    QVERIFY(onlineAccounts[2].protocol() == QContactOnlineAccount::ProtocolMsn);
+    QVERIFY(onlineAccounts[2].accountUri() == "c");
+    QVERIFY(onlineAccounts[3].protocol() == QContactOnlineAccount::ProtocolQq);
+    QVERIFY(onlineAccounts[3].accountUri() == "d");
+    QVERIFY(onlineAccounts[4].protocol() == QContactOnlineAccount::ProtocolYahoo);
+    QVERIFY(onlineAccounts[4].accountUri() == "e");
+    QVERIFY(onlineAccounts[5].protocol() == QContactOnlineAccount::ProtocolSkype);
+    QVERIFY(onlineAccounts[5].accountUri() == "f");
+    QVERIFY(onlineAccounts[6].protocol() == QContactOnlineAccount::ProtocolSkype);
+    QVERIFY(onlineAccounts[6].accountUri() == "g");
+    QVERIFY(onlineAccounts[7].protocol().isEmpty());
+    QVERIFY(onlineAccounts[7].accountUri() == "h");
+    QVERIFY(onlineAccounts[8].protocol().isEmpty());
+    QVERIFY(onlineAccounts[8].accountUri() == "i");
 }
 
 void tst_QVersitContactImporter::testFamily()
