@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -295,6 +295,28 @@ void tst_QVersitOrganizerExporter::testExportEventDetails_data()
             << properties;
     }
 
+    {
+        QList<QVersitProperty> properties;
+        QVersitProperty dtstart;
+        dtstart.setName(QLatin1String("DTSTART"));
+        dtstart.setValue(QLatin1String("20100102"));
+        dtstart.insertParameter(QLatin1String("VALUE"), QLatin1String("DATE"));
+        properties << dtstart;
+        QVersitProperty dtend;
+        dtend.setName(QLatin1String("DTEND"));
+        // Note: in iCalendar, the end date is exclusive while in Qt Organizer, it is inclusive.
+        // Hence, this is an event that occurs all day on 2 January (not including 3 January)
+        dtend.setValue(QLatin1String("20100103"));
+        dtend.insertParameter(QLatin1String("VALUE"), QLatin1String("DATE"));
+        properties << dtend;
+        QOrganizerEventTime etr;
+        etr.setStartDateTime(QDateTime(QDate(2010, 1, 2), QTime(3, 4, 5)));
+        etr.setEndDateTime(QDateTime(QDate(2010, 1, 2), QTime(3, 4, 6)));
+        etr.setAllDay(true);
+        QTest::newRow("all day event") << (QList<QOrganizerItemDetail>() << etr)
+            << properties;
+    }
+
     {
         QList<QVersitProperty> properties;
         QVersitProperty created;
@@ -633,6 +655,26 @@ void tst_QVersitOrganizerExporter::testExportTodoDetails_data()
     QTest::addColumn<QList<QOrganizerItemDetail> >("details");
     QTest::addColumn<QList<QVersitProperty> >("expectedProperties");
 
+    {
+        QList<QVersitProperty> properties;
+        QVersitProperty dtstart;
+        dtstart.setName(QLatin1String("DTSTART"));
+        dtstart.setValue(QLatin1String("20100102"));
+        dtstart.insertParameter(QLatin1String("VALUE"), QLatin1String("DATE"));
+        properties << dtstart;
+        QVersitProperty due;
+        due.setName(QLatin1String("DUE"));
+        due.setValue(QLatin1String("20100103"));
+        due.insertParameter(QLatin1String("VALUE"), QLatin1String("DATE"));
+        properties << due;
+        QOrganizerTodoTime todoTime;
+        todoTime.setStartDateTime(QDateTime(QDate(2010, 1, 2), QTime(3, 4, 5)));
+        todoTime.setDueDateTime(QDateTime(QDate(2010, 1, 3), QTime(3, 4, 6)));
+        todoTime.setAllDay(true);
+        QTest::newRow("all day todo") << (QList<QOrganizerItemDetail>() << todoTime)
+            << properties;
+    }
+
     {
         QVersitProperty property;
         property.setName(QLatin1String("STATUS"));
@@ -691,4 +733,31 @@ QList<QVersitProperty> tst_QVersitOrganizerExporter::findPropertiesByName(
     return retval;
 }
 
+void tst_QVersitOrganizerExporter::testEmptyItemShouldNotBeExported()
+{
+    QVersitOrganizerExporter exporter;
+    QList<QOrganizerItem> items;
+
+    QOrganizerEvent ev;
+    QVERIFY(ev.isEmpty());
+    QOrganizerItem item1;
+    QVERIFY(item1.isEmpty());
+    items << static_cast<QOrganizerItem>(ev)<<item1;
+
+    QVERIFY(!exporter.exportItems(items));
+    QVERIFY(!exporter.errorMap().isEmpty());
+
+    QVersitOrganizerExporter::Error errorCode = exporter.errorMap().value(0);
+    QVERIFY2(errorCode == QVersitOrganizerExporter::EmptyOrganizerError,
+             QString("exporter.errorMap().value(0) == "
+                     + QString::number(errorCode)).toStdString().c_str());
+    errorCode = exporter.errorMap().value(1);
+    QVERIFY2(errorCode == QVersitOrganizerExporter::EmptyOrganizerError
+             || errorCode == QVersitOrganizerExporter::UnknownComponentTypeError,
+             QString("exporter.errorMap().value(1) == "
+                     + QString::number(errorCode)).toStdString().c_str() );
+    items.clear();
+    exporter.errorMap().clear();
+}
+
 QTEST_MAIN(tst_QVersitOrganizerExporter)
