@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -128,6 +128,26 @@ void tst_QVersitReader::testDevice()
     QVERIFY(mReader->device() == mInputDevice);
 }
 
+void tst_QVersitReader::testNullDevice()
+{
+    QVersitReader vr;
+    QVERIFY(vr.device() == NULL);
+    QVERIFY(vr.startReading() == false);
+    QVERIFY(vr.error() == QVersitReader::IOError);
+
+    vr.setDevice(NULL);
+    QVERIFY(vr.device() == NULL);
+    QVERIFY(vr.startReading() == false);
+    QVERIFY(vr.error() == QVersitReader::IOError);
+
+    QFile f("does not exist or else");
+    vr.setDevice(&f);
+    QVERIFY(vr.device() == &f);
+    QVERIFY(vr.startReading() == false);
+    QVERIFY(vr.error() == QVersitReader::IOError);
+
+}
+
 void tst_QVersitReader::testDefaultCodec()
 {
     QVERIFY(mReader->defaultCodec() == 0);
@@ -331,7 +351,7 @@ void tst_QVersitReader::testDetectCodec_data()
     }
     {
         // some Scandinavian characters, note that "\xe4\xe4" is invalid UTF-8, as is "\xf6n"
-        const QByteArray& document = 
+        const QByteArray& document =
             "BEGIN:VCARD\r\nVERSION:2.1\r\n"
             "FN:P\xe4\xe4kk\xf6nen\r\n"
             "END:VCARD\r\n";
@@ -340,7 +360,7 @@ void tst_QVersitReader::testDetectCodec_data()
     }
     {
         // as above, but quoted-printable
-        const QByteArray& document = 
+        const QByteArray& document =
             "BEGIN:VCARD\r\nVERSION:2.1\r\n"
             "FN;ENCODING=QUOTED-PRINTABLE:P=E4=E4kk=F6nen\r\n"
             "END:VCARD\r\n";
