@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -63,6 +57,19 @@
 #include <metadatabase.h>
 #include <commsdat.h>
 
+#ifdef FREESTYLEMAILUSED
+const TInt KDefaultImapFetchSize = 10;
+const TInt KDefaultPopFetchSize = 30;
+const TInt KDefaultSyncLimit  = 30;
+const TInt KDefaultPopPort = 110;
+const TInt KDefaultImapPort = 993;
+const TInt KDefaultSmtpPort = 465;
+_LIT(KDefaultAddress,"user.name@testemail.com");
+_LIT8(KDefaultUserName,"username");
+_LIT8(KDefaultPassword,"password");
+_LIT(KDefaultServerIn, "imap.server.testemail.com");
+_LIT(KDefaultServerOut, "smtp.server.testemail.com");
+#else
 _LIT(KPopServer, "ban-sindhub01.intra");
 _LIT8(KPopLoginName, "ban-sindhub01");
 _LIT8(KPopPassword, "ban-sindhub01");
@@ -73,6 +80,7 @@ _LIT8(KImapLoginName,"ban-sindhub01");
 
 _LIT(KSmtpServerAddress, "ban-sindhub01.intra");
 _LIT(KEmailAlias, "Messaging example");
+#endif
 
 #define KDocumentsEntryIdValue    0x1008
 
@@ -118,6 +126,7 @@ QMessageId MapiSession::addMessage(const Support::Parameters &params)
     QString parentFolderPath(params["parentFolderPath"]);
     QString to(params["to"]);
     QString cc(params["cc"]);
+    QString bcc(params["bcc"]);
     QString from(params["from"]);
     QString date(params["date"]);
     QString receivedDate(params["receivedDate"]);
@@ -161,6 +170,14 @@ QMessageId MapiSession::addMessage(const Support::Parameters &params)
                 }
                 message.setCc(ccList);
 
+                QList<QMessageAddress> bccList;
+                foreach (const QString &addr, bcc.split(",")) {
+                    if (!addr.isEmpty()) {
+                    bccList.append(QMessageAddress(QMessageAddress::Email, addr.trimmed()));
+                    }
+                }
+                message.setBcc(bccList);
+
                 message.setFrom(QMessageAddress(QMessageAddress::Email, from));
                 message.setSubject(subject);
 
@@ -272,10 +289,17 @@ void clearMessageStoreL()
         CImImap4Settings* settings = new(ELeave) CImImap4Settings();
         CleanupStack::PushL(settings);
         pEmailAccounts->LoadImapSettingsL(imapAccounts[i], *settings);
+#ifdef FREESTYLEMAILUSED
+        if (settings->ServerAddress().Compare(KDefaultServerIn) == 0) {
+            pEmailAccounts->DeleteImapAccountL(imapAccounts[i]);
+            deleteServiceRelatedEntriesFromFolder(imapAccounts[i].iImapService, KMsvDraftEntryId);
+        }
+#else
         if (settings->ServerAddress().Compare(KImapServer) == 0) {
             pEmailAccounts->DeleteImapAccountL(imapAccounts[i]);
             deleteServiceRelatedEntriesFromFolder(imapAccounts[i].iImapService, KDocumentsEntryIdValue);
         }
+#endif
         CleanupStack::PopAndDestroy(settings);
     }
 
@@ -285,10 +309,17 @@ void clearMessageStoreL()
         CImPop3Settings* settings = new(ELeave) CImPop3Settings();
         CleanupStack::PushL(settings);
         pEmailAccounts->LoadPopSettingsL(popAccounts[i], *settings);
+#ifdef FREESTYLEMAILUSED
+        if (settings->ServerAddress().Compare(KDefaultServerIn) == 0) {
+            pEmailAccounts->DeletePopAccountL(popAccounts[i]);
+            deleteServiceRelatedEntriesFromFolder(popAccounts[i].iPopService, KMsvDraftEntryId);
+        }
+#else
         if (settings->ServerAddress().Compare(KPopServer) == 0) {
             pEmailAccounts->DeletePopAccountL(popAccounts[i]);
             deleteServiceRelatedEntriesFromFolder(popAccounts[i].iPopService, KDocumentsEntryIdValue);
         }
+#endif
         CleanupStack::PopAndDestroy(settings);
     }
 
@@ -298,10 +329,17 @@ void clearMessageStoreL()
         CImSmtpSettings* settings = new(ELeave) CImSmtpSettings();
         CleanupStack::PushL(settings);
         pEmailAccounts->LoadSmtpSettingsL(smtpAccounts[i], *settings);
+#ifdef FREESTYLEMAILUSED
+        if (settings->ServerAddress().Compare(KDefaultServerOut) == 0) {
+            pEmailAccounts->DeleteSmtpAccountL(smtpAccounts[i]);
+            deleteServiceRelatedEntriesFromFolder(smtpAccounts[i].iSmtpService, KMsvDraftEntryId);
+        }
+#else
         if (settings->ServerAddress().Compare(KSmtpServerAddress) == 0) {
             pEmailAccounts->DeleteSmtpAccountL(smtpAccounts[i]);
             deleteServiceRelatedEntriesFromFolder(smtpAccounts[i].iSmtpService, KDocumentsEntryIdValue);
         }
+#endif
         CleanupStack::PopAndDestroy(settings);
     }
 
@@ -325,22 +363,54 @@ QMessageAccountId createPopAndSmtpAccountL(const TDesC& accountName, const TDesC
     CImPop3Settings* pImPop3Settings = new(ELeave) CImPop3Settings();
     CleanupStack::PushL(pImPop3Settings);
     pEmailAccounts->PopulateDefaultPopSettingsL(*pImPop3Settings, *pImIAPPreferences);
+#ifdef FREESTYLEMAILUSED
+    pImPop3Settings->SetAutoSendOnConnect(ETrue);
+    pImPop3Settings->SetDisconnectedUserMode(ETrue);
+    pImPop3Settings->SetDeleteEmailsWhenDisconnecting(EFalse);
+    pImPop3Settings->SetAcknowledgeReceipts(EFalse);
+    pImPop3Settings->SetGetMailOptions(EGetPop3EmailMessages);
+    pImPop3Settings->SetInboxSynchronisationLimit(KDefaultSyncLimit);
+    pImPop3Settings->SetPopulationLimitL(KDefaultPopFetchSize);
+    pImPop3Settings->SetSecureSockets(EFalse);
+    pImPop3Settings->SetSSLWrapper(EFalse);
+    pImPop3Settings->SetLoginNameL(KDefaultUserName);
+    pImPop3Settings->SetPasswordL(KDefaultPassword);
+    pImPop3Settings->SetServerAddressL(KDefaultServerIn);
+    pImPop3Settings->SetPort(KDefaultPopPort);
+#else
     pImPop3Settings->SetServerAddressL(KPopServer);
     pImPop3Settings->SetLoginNameL(KPopLoginName);
     pImPop3Settings->SetPasswordL(KPopPassword);
     pImPop3Settings->SetPort(110);
+#endif
     TPopAccount popAccount = pEmailAccounts->CreatePopAccountL(accountName, *pImPop3Settings, *pImIAPPreferences, EFalse);
 
     // Create SMTP Account
     CImSmtpSettings *pImSmtpSettings = new (ELeave) CImSmtpSettings();
     CleanupStack::PushL(pImSmtpSettings);
     pEmailAccounts->PopulateDefaultSmtpSettingsL(*pImSmtpSettings, *pImIAPPreferences);
+#ifdef FREESTYLEMAILUSED
+    pImSmtpSettings->SetBodyEncoding(EMsgOutboxMIME);
+    pImSmtpSettings->SetAddVCardToEmail(EFalse);
+    pImSmtpSettings->SetAddSignatureToEmail(EFalse);
+    pImSmtpSettings->SetRequestReceipts(EFalse);
+    pImSmtpSettings->SetSMTPAuth(ETrue);
+    pImSmtpSettings->SetToCcIncludeLimitL(KSmtpToCcIncludeLimitMax);
+    pImSmtpSettings->SetSecureSockets(EFalse);
+    pImSmtpSettings->SetSSLWrapper(EFalse);
+    pImSmtpSettings->SetEmailAddressL(KDefaultAddress);
+    pImSmtpSettings->SetLoginNameL(KDefaultUserName);
+    pImSmtpSettings->SetPasswordL(KDefaultPassword);
+    pImSmtpSettings->SetPort(KDefaultSmtpPort);
+    pImSmtpSettings->SetServerAddressL(KDefaultServerOut);
+#else
     pImSmtpSettings->SetServerAddressL(KSmtpServerAddress);
     pImSmtpSettings->SetEmailAliasL(KEmailAlias);
+    pImSmtpSettings->SetPort(25);
+#endif
     pImSmtpSettings->SetEmailAddressL(fromAddress);
     pImSmtpSettings->SetReplyToAddressL(fromAddress);
     pImSmtpSettings->SetReceiptAddressL(fromAddress);
-    pImSmtpSettings->SetPort(25);
     pEmailAccounts->CreateSmtpAccountL(popAccount, *pImSmtpSettings, *pImIAPPreferences, EFalse);
 
     CleanupStack::PopAndDestroy(pImSmtpSettings);
@@ -348,7 +418,11 @@ QMessageAccountId createPopAndSmtpAccountL(const TDesC& accountName, const TDesC
     CleanupStack::PopAndDestroy(pImIAPPreferences);
     CleanupStack::PopAndDestroy(pEmailAccounts);
 
+#ifdef FREESTYLEMAILUSED
+    return QMessageAccountId(addIdPrefix(QString::number(popAccount.iPopService), SymbianHelpers::EngineTypeFreestyle));
+#else
     return QMessageAccountId(addIdPrefix(QString::number(popAccount.iPopService), SymbianHelpers::EngineTypeMTM));
+#endif
 }
 
 QMessageAccountId createPopAndSmtpAccount(const TDesC& accountName, const TDesC& fromAddress)
@@ -448,22 +522,57 @@ QMessageAccountId createImapAndSmtpAccountL(const TDesC& accountName, const TDes
     CImImap4Settings* pImap4Settings = new(ELeave)CImImap4Settings;
     CleanupStack::PushL(pImap4Settings);
     pEmailAccounts->PopulateDefaultImapSettingsL(*pImap4Settings, *pImIAPPreferences);
+#ifdef FREESTYLEMAILUSED
+    pImap4Settings->SetAutoSendOnConnect(ETrue);
+    pImap4Settings->SetDisconnectedUserMode(ETrue);
+    pImap4Settings->SetDeleteEmailsWhenDisconnecting(EFalse);
+    pImap4Settings->SetAcknowledgeReceipts(EFalse);
+    pImap4Settings->SetSynchronise(EUseLocal);
+    pImap4Settings->SetInboxSynchronisationLimit(KDefaultSyncLimit);
+    pImap4Settings->SetBodyTextSizeLimitL(KDefaultImapFetchSize);
+    pImap4Settings->SetPathSeparator('/');
+    pImap4Settings->SetUpdatingSeenFlags(ETrue);
+    pImap4Settings->SetLoginNameL(KDefaultUserName);
+    pImap4Settings->SetPasswordL(KDefaultPassword);
+    pImap4Settings->SetServerAddressL(KDefaultServerIn);
+    pImap4Settings->SetPort(KDefaultImapPort);
+    pImap4Settings->SetSecureSockets(EFalse);
+    pImap4Settings->SetSSLWrapper(ETrue);
+#else
     pImap4Settings->SetServerAddressL(KImapServer);
     pImap4Settings->SetLoginNameL(KImapLoginName);
     pImap4Settings->SetPasswordL(KImapPassword);
     pImap4Settings->SetPort(143);
+#endif
     TImapAccount imapAccount = pEmailAccounts->CreateImapAccountL(accountName, *pImap4Settings, *pImIAPPreferences, EFalse);
 
     // Create SMTP Account
     CImSmtpSettings* pImSmtpSettings = new (ELeave) CImSmtpSettings();
     CleanupStack::PushL(pImSmtpSettings);
     pEmailAccounts->PopulateDefaultSmtpSettingsL(*pImSmtpSettings, *pImIAPPreferences);
+
+#ifdef FREESTYLEMAILUSED
+    pImSmtpSettings->SetBodyEncoding(EMsgOutboxMIME);
+    pImSmtpSettings->SetAddVCardToEmail(EFalse);
+    pImSmtpSettings->SetAddSignatureToEmail(EFalse);
+    pImSmtpSettings->SetRequestReceipts(EFalse);
+    pImSmtpSettings->SetSMTPAuth(ETrue);
+    pImSmtpSettings->SetToCcIncludeLimitL(KSmtpToCcIncludeLimitMax);
+    pImSmtpSettings->SetSecureSockets(EFalse);
+    pImSmtpSettings->SetSSLWrapper(EFalse);
+    pImSmtpSettings->SetEmailAddressL(KDefaultAddress);
+    pImSmtpSettings->SetLoginNameL(KDefaultUserName);
+    pImSmtpSettings->SetPasswordL(KDefaultPassword);
+    pImSmtpSettings->SetPort(KDefaultSmtpPort);
+    pImSmtpSettings->SetServerAddressL(KDefaultServerOut);
+#else
     pImSmtpSettings->SetServerAddressL(KSmtpServerAddress);
     pImSmtpSettings->SetEmailAliasL(KEmailAlias);
+    pImSmtpSettings->SetPort(25);
+#endif
     pImSmtpSettings->SetEmailAddressL(fromAddress);
     pImSmtpSettings->SetReplyToAddressL(fromAddress);
     pImSmtpSettings->SetReceiptAddressL(fromAddress);
-    pImSmtpSettings->SetPort(25);
     TSmtpAccount smtpAccount = pEmailAccounts->CreateSmtpAccountL(imapAccount, *pImSmtpSettings, *pImIAPPreferences, EFalse);
     
     TSmtpAccount defaultAccount;
@@ -477,7 +586,11 @@ QMessageAccountId createImapAndSmtpAccountL(const TDesC& accountName, const TDes
     CleanupStack::PopAndDestroy(pImIAPPreferences);
     CleanupStack::PopAndDestroy(pEmailAccounts);
 
+#ifdef FREESTYLEMAILUSED
+    return QMessageAccountId(addIdPrefix(QString::number(imapAccount.iImapService), SymbianHelpers::EngineTypeFreestyle));
+#else
     return QMessageAccountId(addIdPrefix(QString::number(imapAccount.iImapService), SymbianHelpers::EngineTypeMTM));
+#endif
 }
 
 QMessageAccountId createImapAndSmtpAccount(const TDesC& accountName, const TDesC& fromAddress)
@@ -537,6 +650,9 @@ QMessageFolderId addFolderL(const TDesC& symbianAccountName, const TDesC& symbia
 
 QMessageFolderId addFolder(const Parameters &params)
 {
+#ifdef FREESTYLEMAILUSED
+    return QMessageFolderId(); // Local folders can not be created for FreeStyle
+#else
     QString accountName(params["parentAccountName"]);
     TPtrC16 symbianAccountName(KNullDesC);
     symbianAccountName.Set(reinterpret_cast<const TUint16*>(accountName.utf16()));
@@ -549,6 +665,7 @@ QMessageFolderId addFolder(const Parameters &params)
     TRAPD(err, id = addFolderL(symbianAccountName, symbianFolderName));
     Q_UNUSED(err)
     return id;
+#endif
 }
 
 QMessageId addMessage(const Parameters &params)
