@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -746,7 +746,7 @@ void tst_QContactBenchmark::benchmarking()
             }
         }
 
-        quint64 succeededCount, failedCount, averageSuccessTime, averageFailTime;
+        qint64 succeededCount, failedCount, averageSuccessTime, averageFailTime;
         outputMessage += QString("\nwith numberOfContacts = %1").arg(numberOfContacts);
         outputMessage += QLatin1String("\n  Synchronous:");
 
@@ -766,7 +766,7 @@ void tst_QContactBenchmark::benchmarking()
             for (int j = 0; j < whitespaceAdjust; ++j) {
                 tempStr += " ";
             }
-            tempStr += QString("  succeeded: %1  average_time(success): %2  failed: %3  average_time(failed): %4").arg(succeededCount).arg(averageSuccessTime).arg(failedCount).arg(averageFailTime);
+            tempStr += QString("  succeeded: %1  average_time(success): %2\t  failed: %3  average_time(failed): %4").arg(succeededCount).arg(averageSuccessTime).arg(failedCount).arg(averageFailTime);
             if (i == 9) {
                 outputMessage += QString(QLatin1String("\n    (")) + QString::number(i+1) + QString(QLatin1String(") "));
             } else {
@@ -792,7 +792,7 @@ void tst_QContactBenchmark::benchmarking()
             for (int j = 0; j < whitespaceAdjust; ++j) {
                 tempStr += " ";
             }
-            tempStr += QString("  succeeded: %1  average_time(success): %2  failed: %3 average_time(failed): %4").arg(succeededCount).arg(averageSuccessTime).arg(failedCount).arg(averageFailTime);
+            tempStr += QString("  succeeded: %1  average_time(success): %2\t  failed: %3 average_time(failed): %4").arg(succeededCount).arg(averageSuccessTime).arg(failedCount).arg(averageFailTime);
             if (i == 9) {
                 outputMessage += QString(QLatin1String("\n    (")) + QString::number(i+1) + QString(QLatin1String(") "));
             } else {
@@ -801,6 +801,14 @@ void tst_QContactBenchmark::benchmarking()
             outputMessage += tempStr;
         }
         outputMessage += QLatin1String("\n----------------------------------------");
+
+        // clear the variables.
+        memset(ssb, 0, sizeof(ssb));
+        memset(esb, 0, sizeof(esb));
+        memset(sab, 0, sizeof(sab));
+        memset(eab, 0, sizeof(eab));
+        memset(esbc, 0, sizeof(esbc));
+        memset(eabc, 0, sizeof(eabc));
     }
 
     outputMessage += QLatin1String("\n(All times measured in milliseconds).");
