@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Solutions Commercial License Agreement provided
-** with the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,29 +25,23 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
 **
-** Please note Third Party Software included with Qt Solutions may impose
-** additional restrictions and it is the user's responsibility to ensure
-** that they have met the licensing requirements of the GPL, LGPL, or Qt
-** Solutions Commercial license and the relevant license of the Third
-** Party Software they are using.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #include "parsemanager.h"
 #include "cplusplus/CppDocument.h"
-#include "./parser/src/shared/cplusplus/Control.h"
+#include "./parser/src/shared/cplusplus/CppControl.h"
 #include "TranslationUnit.h"
 #include "AST.h"
 #include "Symbols.h"
@@ -376,7 +370,7 @@ void ParseManager::getBaseClasses(const CLASSLISTITEM* pclass
 }
 
 /**************************************************
-This function finds and creates all Elements wich
+This function finds and creates all Elements which
 are significant for MetaDatas.
 Those element will be added in the aparameter 
 lists.
@@ -637,7 +631,7 @@ bool ParseManager::checkAllMetadatas(ParseManager* pInterfaceParserManager, QStr
     }
 
     /******************************
-    Check for properies
+    Check for properties
     ******************************/
     Trace("Compare all interface MetaData properties:");
     QList<PROPERTYITEM*> missingippts = checkMetadataProperties(propertieslookuplist, functionslookuplist, ipropertieslookuplist, ifunctionslookuplist);
@@ -691,7 +685,7 @@ bool ParseManager::checkAllMetadatas(ParseManager* pInterfaceParserManager, QStr
     Trace("\n");
     Trace("### summary ###");
     if(m_errormsgs.size() > 0){
-        Trace("- Folowing interface items are missing:");
+        Trace("- Following interface items are missing:");
         foreach(QString msg, m_errormsgs)
             Trace("  - " + msg);
     }
@@ -787,7 +781,7 @@ QList<FUNCTIONITEM*> ParseManager::checkMetadataFunctions(const QList<QList<FUNC
 
 /*********************************************
 Helper function to check if a function will 
-occure in the MetaData.
+occur in the MetaData.
 *********************************************/
 bool ParseManager::isMetaObjFunction(FUNCTIONITEM* fct)
 {
@@ -986,7 +980,7 @@ void ParseManager::assignPropertyFunctions(PROPERTYITEM* prop, const QList<QList
         notifyfctname = prop->trlUnit->spell(prop->ast->notify_function_token);
         needtofind++;
     }
-    //Now iterate over all function to find all functions wich are defined in the Q_PROPERTY macro
+    //Now iterate over all function to find all functions which are defined in the Q_PROPERTY macro
     if(needtofind > 0){
         prop->foundalldefinedfct = false;
         foreach(QList<FUNCTIONITEM*> fctlist, fctlookuplist){
