@@ -93,13 +93,6 @@
         <translation>Сире аудіо PCM</translation>
     </message>
 </context>
-<context>
-    <name>QGstreamerCameraControl</name>
-    <message>
-        <source>State not supported.</source>
-        <translation>Стан не підтримується.</translation>
-    </message>
-</context>
 <context>
     <name>QGstreamerCaptureSession</name>
     <message>
@@ -111,13 +104,6 @@
         <translation>Збій побудови конвеєру захоплення медіа.</translation>
     </message>
 </context>
-<context>
-    <name>QGstreamerImageEncode</name>
-    <message>
-        <source>JPEG image encoder</source>
-        <translation>Кодувальник зображень JPEG</translation>
-    </message>
-</context>
 <context>
     <name>QGstreamerPlayerSession</name>
     <message>
@@ -338,6 +324,10 @@
         <source>Unable to load media</source>
         <translation>Неможливо завантажити медіа</translation>
     </message>
+    <message>
+        <source>Resources Unavailable</source>
+        <translation>Ресурси недоступні</translation>
+    </message>
 </context>
 <context>
     <name>QXARecordSession</name>
@@ -389,6 +379,9 @@
         <source>Internal error</source>
         <translation>Внутрішня помилка</translation>
     </message>
+    <message>
+        <source>Invalid sample rate</source>
+        <translation>Неправильний розмір семплу</translation>
 </context>
 <context>
     <name>S60CameraImageCaptureControl</name>
@@ -467,17 +460,6 @@
         <translation>LandmarkAbstractModel - абстрактний клас</translation>
     </message>
 </context>
-<context>
-    <name>QDeclarativeContactModel</name>
-    <message>
-        <source>Phone</source>
-        <translation>Телефон</translation>
-    </message>
-    <message>
-        <source>Email</source>
-        <translation>Ел. пошта</translation>
-    </message>
-</context>
 <context>
     <name>S60CameraViewfinderEngine</name>
     <message>
